!function(t){var e={};function i(n){if(e[n])return e[n].exports;var o=e[n]={i:n,l:!1,exports:{}};return t[n].call(o.exports,o,o.exports,i),o.l=!0,o.exports}i.m=t,i.c=e,i.d=function(t,e,n){i.o(t,e)||Object.defineProperty(t,e,{enumerable:!0,get:n})},i.r=function(t){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})},i.t=function(t,e){if(1&e&&(t=i(t)),8&e)return t;if(4&e&&"object"==typeof t&&t&&t.__esModule)return t;var n=Object.create(null);if(i.r(n),Object.defineProperty(n,"default",{enumerable:!0,value:t}),2&e&&"string"!=typeof t)for(var o in t)i.d(n,o,function(e){return t[e]}.bind(null,o));return n},i.n=function(t){var e=t&&t.__esModule?function(){return t.default}:function(){return t};return i.d(e,"a",e),e},i.o=function(t,e){return Object.prototype.hasOwnProperty.call(t,e)},i.p="",i(i.s=161)}({1:function(t,e,i){var n;
/*!
 * jQuery JavaScript Library v3.4.1
 * https://jquery.com/
 *
 * Includes Sizzle.js
 * https://sizzlejs.com/
 *
 * Copyright JS Foundation and other contributors
 * Released under the MIT license
 * https://jquery.org/license
 *
 * Date: 2019-05-01T21:04Z
 */
/*!
 * jQuery JavaScript Library v3.4.1
 * https://jquery.com/
 *
 * Includes Sizzle.js
 * https://sizzlejs.com/
 *
 * Copyright JS Foundation and other contributors
 * Released under the MIT license
 * https://jquery.org/license
 *
 * Date: 2019-05-01T21:04Z
 */
!function(e,i){"use strict";"object"==typeof t.exports?t.exports=e.document?i(e,!0):function(t){if(!t.document)throw new Error("jQuery requires a window with a document");return i(t)}:i(e)}("undefined"!=typeof window?window:this,function(i,o){"use strict";var r=[],s=i.document,a=Object.getPrototypeOf,l=r.slice,c=r.concat,u=r.push,d=r.indexOf,h={},p=h.toString,f=h.hasOwnProperty,m=f.toString,g=m.call(Object),v={},y=function(t){return"function"==typeof t&&"number"!=typeof t.nodeType},b=function(t){return null!=t&&t===t.window},w={type:!0,src:!0,nonce:!0,noModule:!0};function T(t,e,i){var n,o,r=(i=i||s).createElement("script");if(r.text=t,e)for(n in w)(o=e[n]||e.getAttribute&&e.getAttribute(n))&&r.setAttribute(n,o);i.head.appendChild(r).parentNode.removeChild(r)}function x(t){return null==t?t+"":"object"==typeof t||"function"==typeof t?h[p.call(t)]||"object":typeof t}var _=function(t,e){return new _.fn.init(t,e)},C=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g;function E(t){var e=!!t&&"length"in t&&t.length,i=x(t);return!y(t)&&!b(t)&&("array"===i||0===e||"number"==typeof e&&e>0&&e-1 in t)}_.fn=_.prototype={jquery:"3.4.1",constructor:_,length:0,toArray:function(){return l.call(this)},get:function(t){return null==t?l.call(this):t<0?this[t+this.length]:this[t]},pushStack:function(t){var e=_.merge(this.constructor(),t);return e.prevObject=this,e},each:function(t){return _.each(this,t)},map:function(t){return this.pushStack(_.map(this,function(e,i){return t.call(e,i,e)}))},slice:function(){return this.pushStack(l.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(t){var e=this.length,i=+t+(t<0?e:0);return this.pushStack(i>=0&&i<e?[this[i]]:[])},end:function(){return this.prevObject||this.constructor()},push:u,sort:r.sort,splice:r.splice},_.extend=_.fn.extend=function(){var t,e,i,n,o,r,s=arguments[0]||{},a=1,l=arguments.length,c=!1;for("boolean"==typeof s&&(c=s,s=arguments[a]||{},a++),"object"==typeof s||y(s)||(s={}),a===l&&(s=this,a--);a<l;a++)if(null!=(t=arguments[a]))for(e in t)n=t[e],"__proto__"!==e&&s!==n&&(c&&n&&(_.isPlainObject(n)||(o=Array.isArray(n)))?(i=s[e],r=o&&!Array.isArray(i)?[]:o||_.isPlainObject(i)?i:{},o=!1,s[e]=_.extend(c,r,n)):void 0!==n&&(s[e]=n));return s},_.extend({expando:"jQuery"+("3.4.1"+Math.random()).replace(/\D/g,""),isReady:!0,error:function(t){throw new Error(t)},noop:function(){},isPlainObject:function(t){var e,i;return!(!t||"[object Object]"!==p.call(t))&&(!(e=a(t))||"function"==typeof(i=f.call(e,"constructor")&&e.constructor)&&m.call(i)===g)},isEmptyObject:function(t){var e;for(e in t)return!1;return!0},globalEval:function(t,e){T(t,{nonce:e&&e.nonce})},each:function(t,e){var i,n=0;if(E(t))for(i=t.length;n<i&&!1!==e.call(t[n],n,t[n]);n++);else for(n in t)if(!1===e.call(t[n],n,t[n]))break;return t},trim:function(t){return null==t?"":(t+"").replace(C,"")},makeArray:function(t,e){var i=e||[];return null!=t&&(E(Object(t))?_.merge(i,"string"==typeof t?[t]:t):u.call(i,t)),i},inArray:function(t,e,i){return null==e?-1:d.call(e,t,i)},merge:function(t,e){for(var i=+e.length,n=0,o=t.length;n<i;n++)t[o++]=e[n];return t.length=o,t},grep:function(t,e,i){for(var n=[],o=0,r=t.length,s=!i;o<r;o++)!e(t[o],o)!==s&&n.push(t[o]);return n},map:function(t,e,i){var n,o,r=0,s=[];if(E(t))for(n=t.length;r<n;r++)null!=(o=e(t[r],r,i))&&s.push(o);else for(r in t)null!=(o=e(t[r],r,i))&&s.push(o);return c.apply([],s)},guid:1,support:v}),"function"==typeof Symbol&&(_.fn[Symbol.iterator]=r[Symbol.iterator]),_.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(t,e){h["[object "+e+"]"]=e.toLowerCase()});var S=
/*!
 * Sizzle CSS Selector Engine v2.3.4
 * https://sizzlejs.com/
 *
 * Copyright JS Foundation and other contributors
 * Released under the MIT license
 * https://js.foundation/
 *
 * Date: 2019-04-08
 */
function(t){var e,i,n,o,r,s,a,l,c,u,d,h,p,f,m,g,v,y,b,w="sizzle"+1*new Date,T=t.document,x=0,_=0,C=lt(),E=lt(),S=lt(),D=lt(),k=function(t,e){return t===e&&(d=!0),0},A={}.hasOwnProperty,O=[],I=O.pop,N=O.push,L=O.push,M=O.slice,$=function(t,e){for(var i=0,n=t.length;i<n;i++)if(t[i]===e)return i;return-1},P="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",H="[\\x20\\t\\r\\n\\f]",R="(?:\\\\.|[\\w-]|[^\0-\\xa0])+",j="\\["+H+"*("+R+")(?:"+H+"*([*^$|!~]?=)"+H+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+R+"))|)"+H+"*\\]",F=":("+R+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+j+")*)|.*)\\)|)",z=new RegExp(H+"+","g"),W=new RegExp("^"+H+"+|((?:^|[^\\\\])(?:\\\\.)*)"+H+"+$","g"),U=new RegExp("^"+H+"*,"+H+"*"),B=new RegExp("^"+H+"*([>+~]|"+H+")"+H+"*"),q=new RegExp(H+"|>"),V=new RegExp(F),Y=new RegExp("^"+R+"$"),G={ID:new RegExp("^#("+R+")"),CLASS:new RegExp("^\\.("+R+")"),TAG:new RegExp("^("+R+"|[*])"),ATTR:new RegExp("^"+j),PSEUDO:new RegExp("^"+F),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+H+"*(even|odd|(([+-]|)(\\d*)n|)"+H+"*(?:([+-]|)"+H+"*(\\d+)|))"+H+"*\\)|)","i"),bool:new RegExp("^(?:"+P+")$","i"),needsContext:new RegExp("^"+H+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+H+"*((?:-\\d)?\\d*)"+H+"*\\)|)(?=[^-]|$)","i")},X=/HTML$/i,K=/^(?:input|select|textarea|button)$/i,Q=/^h\d$/i,J=/^[^{]+\{\s*\[native \w/,Z=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,tt=/[+~]/,et=new RegExp("\\\\([\\da-f]{1,6}"+H+"?|("+H+")|.)","ig"),it=function(t,e,i){var n="0x"+e-65536;return n!=n||i?e:n<0?String.fromCharCode(n+65536):String.fromCharCode(n>>10|55296,1023&n|56320)},nt=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,ot=function(t,e){return e?"\0"===t?"�":t.slice(0,-1)+"\\"+t.charCodeAt(t.length-1).toString(16)+" ":"\\"+t},rt=function(){h()},st=wt(function(t){return!0===t.disabled&&"fieldset"===t.nodeName.toLowerCase()},{dir:"parentNode",next:"legend"});try{L.apply(O=M.call(T.childNodes),T.childNodes),O[T.childNodes.length].nodeType}catch(t){L={apply:O.length?function(t,e){N.apply(t,M.call(e))}:function(t,e){for(var i=t.length,n=0;t[i++]=e[n++];);t.length=i-1}}}function at(t,e,n,o){var r,a,c,u,d,f,v,y=e&&e.ownerDocument,x=e?e.nodeType:9;if(n=n||[],"string"!=typeof t||!t||1!==x&&9!==x&&11!==x)return n;if(!o&&((e?e.ownerDocument||e:T)!==p&&h(e),e=e||p,m)){if(11!==x&&(d=Z.exec(t)))if(r=d[1]){if(9===x){if(!(c=e.getElementById(r)))return n;if(c.id===r)return n.push(c),n}else if(y&&(c=y.getElementById(r))&&b(e,c)&&c.id===r)return n.push(c),n}else{if(d[2])return L.apply(n,e.getElementsByTagName(t)),n;if((r=d[3])&&i.getElementsByClassName&&e.getElementsByClassName)return L.apply(n,e.getElementsByClassName(r)),n}if(i.qsa&&!D[t+" "]&&(!g||!g.test(t))&&(1!==x||"object"!==e.nodeName.toLowerCase())){if(v=t,y=e,1===x&&q.test(t)){for((u=e.getAttribute("id"))?u=u.replace(nt,ot):e.setAttribute("id",u=w),a=(f=s(t)).length;a--;)f[a]="#"+u+" "+bt(f[a]);v=f.join(","),y=tt.test(t)&&vt(e.parentNode)||e}try{return L.apply(n,y.querySelectorAll(v)),n}catch(e){D(t,!0)}finally{u===w&&e.removeAttribute("id")}}}return l(t.replace(W,"$1"),e,n,o)}function lt(){var t=[];return function e(i,o){return t.push(i+" ")>n.cacheLength&&delete e[t.shift()],e[i+" "]=o}}function ct(t){return t[w]=!0,t}function ut(t){var e=p.createElement("fieldset");try{return!!t(e)}catch(t){return!1}finally{e.parentNode&&e.parentNode.removeChild(e),e=null}}function dt(t,e){for(var i=t.split("|"),o=i.length;o--;)n.attrHandle[i[o]]=e}function ht(t,e){var i=e&&t,n=i&&1===t.nodeType&&1===e.nodeType&&t.sourceIndex-e.sourceIndex;if(n)return n;if(i)for(;i=i.nextSibling;)if(i===e)return-1;return t?1:-1}function pt(t){return function(e){return"input"===e.nodeName.toLowerCase()&&e.type===t}}function ft(t){return function(e){var i=e.nodeName.toLowerCase();return("input"===i||"button"===i)&&e.type===t}}function mt(t){return function(e){return"form"in e?e.parentNode&&!1===e.disabled?"label"in e?"label"in e.parentNode?e.parentNode.disabled===t:e.disabled===t:e.isDisabled===t||e.isDisabled!==!t&&st(e)===t:e.disabled===t:"label"in e&&e.disabled===t}}function gt(t){return ct(function(e){return e=+e,ct(function(i,n){for(var o,r=t([],i.length,e),s=r.length;s--;)i[o=r[s]]&&(i[o]=!(n[o]=i[o]))})})}function vt(t){return t&&void 0!==t.getElementsByTagName&&t}for(e in i=at.support={},r=at.isXML=function(t){var e=t.namespaceURI,i=(t.ownerDocument||t).documentElement;return!X.test(e||i&&i.nodeName||"HTML")},h=at.setDocument=function(t){var e,o,s=t?t.ownerDocument||t:T;return s!==p&&9===s.nodeType&&s.documentElement?(f=(p=s).documentElement,m=!r(p),T!==p&&(o=p.defaultView)&&o.top!==o&&(o.addEventListener?o.addEventListener("unload",rt,!1):o.attachEvent&&o.attachEvent("onunload",rt)),i.attributes=ut(function(t){return t.className="i",!t.getAttribute("className")}),i.getElementsByTagName=ut(function(t){return t.appendChild(p.createComment("")),!t.getElementsByTagName("*").length}),i.getElementsByClassName=J.test(p.getElementsByClassName),i.getById=ut(function(t){return f.appendChild(t).id=w,!p.getElementsByName||!p.getElementsByName(w).length}),i.getById?(n.filter.ID=function(t){var e=t.replace(et,it);return function(t){return t.getAttribute("id")===e}},n.find.ID=function(t,e){if(void 0!==e.getElementById&&m){var i=e.getElementById(t);return i?[i]:[]}}):(n.filter.ID=function(t){var e=t.replace(et,it);return function(t){var i=void 0!==t.getAttributeNode&&t.getAttributeNode("id");return i&&i.value===e}},n.find.ID=function(t,e){if(void 0!==e.getElementById&&m){var i,n,o,r=e.getElementById(t);if(r){if((i=r.getAttributeNode("id"))&&i.value===t)return[r];for(o=e.getElementsByName(t),n=0;r=o[n++];)if((i=r.getAttributeNode("id"))&&i.value===t)return[r]}return[]}}),n.find.TAG=i.getElementsByTagName?function(t,e){return void 0!==e.getElementsByTagName?e.getElementsByTagName(t):i.qsa?e.querySelectorAll(t):void 0}:function(t,e){var i,n=[],o=0,r=e.getElementsByTagName(t);if("*"===t){for(;i=r[o++];)1===i.nodeType&&n.push(i);return n}return r},n.find.CLASS=i.getElementsByClassName&&function(t,e){if(void 0!==e.getElementsByClassName&&m)return e.getElementsByClassName(t)},v=[],g=[],(i.qsa=J.test(p.querySelectorAll))&&(ut(function(t){f.appendChild(t).innerHTML="<a id='"+w+"'></a><select id='"+w+"-\r\\' msallowcapture=''><option selected=''></option></select>",t.querySelectorAll("[msallowcapture^='']").length&&g.push("[*^$]="+H+"*(?:''|\"\")"),t.querySelectorAll("[selected]").length||g.push("\\["+H+"*(?:value|"+P+")"),t.querySelectorAll("[id~="+w+"-]").length||g.push("~="),t.querySelectorAll(":checked").length||g.push(":checked"),t.querySelectorAll("a#"+w+"+*").length||g.push(".#.+[+~]")}),ut(function(t){t.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var e=p.createElement("input");e.setAttribute("type","hidden"),t.appendChild(e).setAttribute("name","D"),t.querySelectorAll("[name=d]").length&&g.push("name"+H+"*[*^$|!~]?="),2!==t.querySelectorAll(":enabled").length&&g.push(":enabled",":disabled"),f.appendChild(t).disabled=!0,2!==t.querySelectorAll(":disabled").length&&g.push(":enabled",":disabled"),t.querySelectorAll("*,:x"),g.push(",.*:")})),(i.matchesSelector=J.test(y=f.matches||f.webkitMatchesSelector||f.mozMatchesSelector||f.oMatchesSelector||f.msMatchesSelector))&&ut(function(t){i.disconnectedMatch=y.call(t,"*"),y.call(t,"[s!='']:x"),v.push("!=",F)}),g=g.length&&new RegExp(g.join("|")),v=v.length&&new RegExp(v.join("|")),e=J.test(f.compareDocumentPosition),b=e||J.test(f.contains)?function(t,e){var i=9===t.nodeType?t.documentElement:t,n=e&&e.parentNode;return t===n||!(!n||1!==n.nodeType||!(i.contains?i.contains(n):t.compareDocumentPosition&&16&t.compareDocumentPosition(n)))}:function(t,e){if(e)for(;e=e.parentNode;)if(e===t)return!0;return!1},k=e?function(t,e){if(t===e)return d=!0,0;var n=!t.compareDocumentPosition-!e.compareDocumentPosition;return n||(1&(n=(t.ownerDocument||t)===(e.ownerDocument||e)?t.compareDocumentPosition(e):1)||!i.sortDetached&&e.compareDocumentPosition(t)===n?t===p||t.ownerDocument===T&&b(T,t)?-1:e===p||e.ownerDocument===T&&b(T,e)?1:u?$(u,t)-$(u,e):0:4&n?-1:1)}:function(t,e){if(t===e)return d=!0,0;var i,n=0,o=t.parentNode,r=e.parentNode,s=[t],a=[e];if(!o||!r)return t===p?-1:e===p?1:o?-1:r?1:u?$(u,t)-$(u,e):0;if(o===r)return ht(t,e);for(i=t;i=i.parentNode;)s.unshift(i);for(i=e;i=i.parentNode;)a.unshift(i);for(;s[n]===a[n];)n++;return n?ht(s[n],a[n]):s[n]===T?-1:a[n]===T?1:0},p):p},at.matches=function(t,e){return at(t,null,null,e)},at.matchesSelector=function(t,e){if((t.ownerDocument||t)!==p&&h(t),i.matchesSelector&&m&&!D[e+" "]&&(!v||!v.test(e))&&(!g||!g.test(e)))try{var n=y.call(t,e);if(n||i.disconnectedMatch||t.document&&11!==t.document.nodeType)return n}catch(t){D(e,!0)}return at(e,p,null,[t]).length>0},at.contains=function(t,e){return(t.ownerDocument||t)!==p&&h(t),b(t,e)},at.attr=function(t,e){(t.ownerDocument||t)!==p&&h(t);var o=n.attrHandle[e.toLowerCase()],r=o&&A.call(n.attrHandle,e.toLowerCase())?o(t,e,!m):void 0;return void 0!==r?r:i.attributes||!m?t.getAttribute(e):(r=t.getAttributeNode(e))&&r.specified?r.value:null},at.escape=function(t){return(t+"").replace(nt,ot)},at.error=function(t){throw new Error("Syntax error, unrecognized expression: "+t)},at.uniqueSort=function(t){var e,n=[],o=0,r=0;if(d=!i.detectDuplicates,u=!i.sortStable&&t.slice(0),t.sort(k),d){for(;e=t[r++];)e===t[r]&&(o=n.push(r));for(;o--;)t.splice(n[o],1)}return u=null,t},o=at.getText=function(t){var e,i="",n=0,r=t.nodeType;if(r){if(1===r||9===r||11===r){if("string"==typeof t.textContent)return t.textContent;for(t=t.firstChild;t;t=t.nextSibling)i+=o(t)}else if(3===r||4===r)return t.nodeValue}else for(;e=t[n++];)i+=o(e);return i},(n=at.selectors={cacheLength:50,createPseudo:ct,match:G,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(t){return t[1]=t[1].replace(et,it),t[3]=(t[3]||t[4]||t[5]||"").replace(et,it),"~="===t[2]&&(t[3]=" "+t[3]+" "),t.slice(0,4)},CHILD:function(t){return t[1]=t[1].toLowerCase(),"nth"===t[1].slice(0,3)?(t[3]||at.error(t[0]),t[4]=+(t[4]?t[5]+(t[6]||1):2*("even"===t[3]||"odd"===t[3])),t[5]=+(t[7]+t[8]||"odd"===t[3])):t[3]&&at.error(t[0]),t},PSEUDO:function(t){var e,i=!t[6]&&t[2];return G.CHILD.test(t[0])?null:(t[3]?t[2]=t[4]||t[5]||"":i&&V.test(i)&&(e=s(i,!0))&&(e=i.indexOf(")",i.length-e)-i.length)&&(t[0]=t[0].slice(0,e),t[2]=i.slice(0,e)),t.slice(0,3))}},filter:{TAG:function(t){var e=t.replace(et,it).toLowerCase();return"*"===t?function(){return!0}:function(t){return t.nodeName&&t.nodeName.toLowerCase()===e}},CLASS:function(t){var e=C[t+" "];return e||(e=new RegExp("(^|"+H+")"+t+"("+H+"|$)"))&&C(t,function(t){return e.test("string"==typeof t.className&&t.className||void 0!==t.getAttribute&&t.getAttribute("class")||"")})},ATTR:function(t,e,i){return function(n){var o=at.attr(n,t);return null==o?"!="===e:!e||(o+="","="===e?o===i:"!="===e?o!==i:"^="===e?i&&0===o.indexOf(i):"*="===e?i&&o.indexOf(i)>-1:"$="===e?i&&o.slice(-i.length)===i:"~="===e?(" "+o.replace(z," ")+" ").indexOf(i)>-1:"|="===e&&(o===i||o.slice(0,i.length+1)===i+"-"))}},CHILD:function(t,e,i,n,o){var r="nth"!==t.slice(0,3),s="last"!==t.slice(-4),a="of-type"===e;return 1===n&&0===o?function(t){return!!t.parentNode}:function(e,i,l){var c,u,d,h,p,f,m=r!==s?"nextSibling":"previousSibling",g=e.parentNode,v=a&&e.nodeName.toLowerCase(),y=!l&&!a,b=!1;if(g){if(r){for(;m;){for(h=e;h=h[m];)if(a?h.nodeName.toLowerCase()===v:1===h.nodeType)return!1;f=m="only"===t&&!f&&"nextSibling"}return!0}if(f=[s?g.firstChild:g.lastChild],s&&y){for(b=(p=(c=(u=(d=(h=g)[w]||(h[w]={}))[h.uniqueID]||(d[h.uniqueID]={}))[t]||[])[0]===x&&c[1])&&c[2],h=p&&g.childNodes[p];h=++p&&h&&h[m]||(b=p=0)||f.pop();)if(1===h.nodeType&&++b&&h===e){u[t]=[x,p,b];break}}else if(y&&(b=p=(c=(u=(d=(h=e)[w]||(h[w]={}))[h.uniqueID]||(d[h.uniqueID]={}))[t]||[])[0]===x&&c[1]),!1===b)for(;(h=++p&&h&&h[m]||(b=p=0)||f.pop())&&((a?h.nodeName.toLowerCase()!==v:1!==h.nodeType)||!++b||(y&&((u=(d=h[w]||(h[w]={}))[h.uniqueID]||(d[h.uniqueID]={}))[t]=[x,b]),h!==e)););return(b-=o)===n||b%n==0&&b/n>=0}}},PSEUDO:function(t,e){var i,o=n.pseudos[t]||n.setFilters[t.toLowerCase()]||at.error("unsupported pseudo: "+t);return o[w]?o(e):o.length>1?(i=[t,t,"",e],n.setFilters.hasOwnProperty(t.toLowerCase())?ct(function(t,i){for(var n,r=o(t,e),s=r.length;s--;)t[n=$(t,r[s])]=!(i[n]=r[s])}):function(t){return o(t,0,i)}):o}},pseudos:{not:ct(function(t){var e=[],i=[],n=a(t.replace(W,"$1"));return n[w]?ct(function(t,e,i,o){for(var r,s=n(t,null,o,[]),a=t.length;a--;)(r=s[a])&&(t[a]=!(e[a]=r))}):function(t,o,r){return e[0]=t,n(e,null,r,i),e[0]=null,!i.pop()}}),has:ct(function(t){return function(e){return at(t,e).length>0}}),contains:ct(function(t){return t=t.replace(et,it),function(e){return(e.textContent||o(e)).indexOf(t)>-1}}),lang:ct(function(t){return Y.test(t||"")||at.error("unsupported lang: "+t),t=t.replace(et,it).toLowerCase(),function(e){var i;do{if(i=m?e.lang:e.getAttribute("xml:lang")||e.getAttribute("lang"))return(i=i.toLowerCase())===t||0===i.indexOf(t+"-")}while((e=e.parentNode)&&1===e.nodeType);return!1}}),target:function(e){var i=t.location&&t.location.hash;return i&&i.slice(1)===e.id},root:function(t){return t===f},focus:function(t){return t===p.activeElement&&(!p.hasFocus||p.hasFocus())&&!!(t.type||t.href||~t.tabIndex)},enabled:mt(!1),disabled:mt(!0),checked:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&!!t.checked||"option"===e&&!!t.selected},selected:function(t){return t.parentNode&&t.parentNode.selectedIndex,!0===t.selected},empty:function(t){for(t=t.firstChild;t;t=t.nextSibling)if(t.nodeType<6)return!1;return!0},parent:function(t){return!n.pseudos.empty(t)},header:function(t){return Q.test(t.nodeName)},input:function(t){return K.test(t.nodeName)},button:function(t){var e=t.nodeName.toLowerCase();return"input"===e&&"button"===t.type||"button"===e},text:function(t){var e;return"input"===t.nodeName.toLowerCase()&&"text"===t.type&&(null==(e=t.getAttribute("type"))||"text"===e.toLowerCase())},first:gt(function(){return[0]}),last:gt(function(t,e){return[e-1]}),eq:gt(function(t,e,i){return[i<0?i+e:i]}),even:gt(function(t,e){for(var i=0;i<e;i+=2)t.push(i);return t}),odd:gt(function(t,e){for(var i=1;i<e;i+=2)t.push(i);return t}),lt:gt(function(t,e,i){for(var n=i<0?i+e:i>e?e:i;--n>=0;)t.push(n);return t}),gt:gt(function(t,e,i){for(var n=i<0?i+e:i;++n<e;)t.push(n);return t})}}).pseudos.nth=n.pseudos.eq,{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})n.pseudos[e]=pt(e);for(e in{submit:!0,reset:!0})n.pseudos[e]=ft(e);function yt(){}function bt(t){for(var e=0,i=t.length,n="";e<i;e++)n+=t[e].value;return n}function wt(t,e,i){var n=e.dir,o=e.next,r=o||n,s=i&&"parentNode"===r,a=_++;return e.first?function(e,i,o){for(;e=e[n];)if(1===e.nodeType||s)return t(e,i,o);return!1}:function(e,i,l){var c,u,d,h=[x,a];if(l){for(;e=e[n];)if((1===e.nodeType||s)&&t(e,i,l))return!0}else for(;e=e[n];)if(1===e.nodeType||s)if(u=(d=e[w]||(e[w]={}))[e.uniqueID]||(d[e.uniqueID]={}),o&&o===e.nodeName.toLowerCase())e=e[n]||e;else{if((c=u[r])&&c[0]===x&&c[1]===a)return h[2]=c[2];if(u[r]=h,h[2]=t(e,i,l))return!0}return!1}}function Tt(t){return t.length>1?function(e,i,n){for(var o=t.length;o--;)if(!t[o](e,i,n))return!1;return!0}:t[0]}function xt(t,e,i,n,o){for(var r,s=[],a=0,l=t.length,c=null!=e;a<l;a++)(r=t[a])&&(i&&!i(r,n,o)||(s.push(r),c&&e.push(a)));return s}function _t(t,e,i,n,o,r){return n&&!n[w]&&(n=_t(n)),o&&!o[w]&&(o=_t(o,r)),ct(function(r,s,a,l){var c,u,d,h=[],p=[],f=s.length,m=r||function(t,e,i){for(var n=0,o=e.length;n<o;n++)at(t,e[n],i);return i}(e||"*",a.nodeType?[a]:a,[]),g=!t||!r&&e?m:xt(m,h,t,a,l),v=i?o||(r?t:f||n)?[]:s:g;if(i&&i(g,v,a,l),n)for(c=xt(v,p),n(c,[],a,l),u=c.length;u--;)(d=c[u])&&(v[p[u]]=!(g[p[u]]=d));if(r){if(o||t){if(o){for(c=[],u=v.length;u--;)(d=v[u])&&c.push(g[u]=d);o(null,v=[],c,l)}for(u=v.length;u--;)(d=v[u])&&(c=o?$(r,d):h[u])>-1&&(r[c]=!(s[c]=d))}}else v=xt(v===s?v.splice(f,v.length):v),o?o(null,s,v,l):L.apply(s,v)})}function Ct(t){for(var e,i,o,r=t.length,s=n.relative[t[0].type],a=s||n.relative[" "],l=s?1:0,u=wt(function(t){return t===e},a,!0),d=wt(function(t){return $(e,t)>-1},a,!0),h=[function(t,i,n){var o=!s&&(n||i!==c)||((e=i).nodeType?u(t,i,n):d(t,i,n));return e=null,o}];l<r;l++)if(i=n.relative[t[l].type])h=[wt(Tt(h),i)];else{if((i=n.filter[t[l].type].apply(null,t[l].matches))[w]){for(o=++l;o<r&&!n.relative[t[o].type];o++);return _t(l>1&&Tt(h),l>1&&bt(t.slice(0,l-1).concat({value:" "===t[l-2].type?"*":""})).replace(W,"$1"),i,l<o&&Ct(t.slice(l,o)),o<r&&Ct(t=t.slice(o)),o<r&&bt(t))}h.push(i)}return Tt(h)}return yt.prototype=n.filters=n.pseudos,n.setFilters=new yt,s=at.tokenize=function(t,e){var i,o,r,s,a,l,c,u=E[t+" "];if(u)return e?0:u.slice(0);for(a=t,l=[],c=n.preFilter;a;){for(s in i&&!(o=U.exec(a))||(o&&(a=a.slice(o[0].length)||a),l.push(r=[])),i=!1,(o=B.exec(a))&&(i=o.shift(),r.push({value:i,type:o[0].replace(W," ")}),a=a.slice(i.length)),n.filter)!(o=G[s].exec(a))||c[s]&&!(o=c[s](o))||(i=o.shift(),r.push({value:i,type:s,matches:o}),a=a.slice(i.length));if(!i)break}return e?a.length:a?at.error(t):E(t,l).slice(0)},a=at.compile=function(t,e){var i,o=[],r=[],a=S[t+" "];if(!a){for(e||(e=s(t)),i=e.length;i--;)(a=Ct(e[i]))[w]?o.push(a):r.push(a);(a=S(t,function(t,e){var i=e.length>0,o=t.length>0,r=function(r,s,a,l,u){var d,f,g,v=0,y="0",b=r&&[],w=[],T=c,_=r||o&&n.find.TAG("*",u),C=x+=null==T?1:Math.random()||.1,E=_.length;for(u&&(c=s===p||s||u);y!==E&&null!=(d=_[y]);y++){if(o&&d){for(f=0,s||d.ownerDocument===p||(h(d),a=!m);g=t[f++];)if(g(d,s||p,a)){l.push(d);break}u&&(x=C)}i&&((d=!g&&d)&&v--,r&&b.push(d))}if(v+=y,i&&y!==v){for(f=0;g=e[f++];)g(b,w,s,a);if(r){if(v>0)for(;y--;)b[y]||w[y]||(w[y]=I.call(l));w=xt(w)}L.apply(l,w),u&&!r&&w.length>0&&v+e.length>1&&at.uniqueSort(l)}return u&&(x=C,c=T),b};return i?ct(r):r}(r,o))).selector=t}return a},l=at.select=function(t,e,i,o){var r,l,c,u,d,h="function"==typeof t&&t,p=!o&&s(t=h.selector||t);if(i=i||[],1===p.length){if((l=p[0]=p[0].slice(0)).length>2&&"ID"===(c=l[0]).type&&9===e.nodeType&&m&&n.relative[l[1].type]){if(!(e=(n.find.ID(c.matches[0].replace(et,it),e)||[])[0]))return i;h&&(e=e.parentNode),t=t.slice(l.shift().value.length)}for(r=G.needsContext.test(t)?0:l.length;r--&&(c=l[r],!n.relative[u=c.type]);)if((d=n.find[u])&&(o=d(c.matches[0].replace(et,it),tt.test(l[0].type)&&vt(e.parentNode)||e))){if(l.splice(r,1),!(t=o.length&&bt(l)))return L.apply(i,o),i;break}}return(h||a(t,p))(o,e,!m,i,!e||tt.test(t)&&vt(e.parentNode)||e),i},i.sortStable=w.split("").sort(k).join("")===w,i.detectDuplicates=!!d,h(),i.sortDetached=ut(function(t){return 1&t.compareDocumentPosition(p.createElement("fieldset"))}),ut(function(t){return t.innerHTML="<a href='#'></a>","#"===t.firstChild.getAttribute("href")})||dt("type|href|height|width",function(t,e,i){if(!i)return t.getAttribute(e,"type"===e.toLowerCase()?1:2)}),i.attributes&&ut(function(t){return t.innerHTML="<input/>",t.firstChild.setAttribute("value",""),""===t.firstChild.getAttribute("value")})||dt("value",function(t,e,i){if(!i&&"input"===t.nodeName.toLowerCase())return t.defaultValue}),ut(function(t){return null==t.getAttribute("disabled")})||dt(P,function(t,e,i){var n;if(!i)return!0===t[e]?e.toLowerCase():(n=t.getAttributeNode(e))&&n.specified?n.value:null}),at}(i);_.find=S,_.expr=S.selectors,_.expr[":"]=_.expr.pseudos,_.uniqueSort=_.unique=S.uniqueSort,_.text=S.getText,_.isXMLDoc=S.isXML,_.contains=S.contains,_.escapeSelector=S.escape;var D=function(t,e,i){for(var n=[],o=void 0!==i;(t=t[e])&&9!==t.nodeType;)if(1===t.nodeType){if(o&&_(t).is(i))break;n.push(t)}return n},k=function(t,e){for(var i=[];t;t=t.nextSibling)1===t.nodeType&&t!==e&&i.push(t);return i},A=_.expr.match.needsContext;function O(t,e){return t.nodeName&&t.nodeName.toLowerCase()===e.toLowerCase()}var I=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i;function N(t,e,i){return y(e)?_.grep(t,function(t,n){return!!e.call(t,n,t)!==i}):e.nodeType?_.grep(t,function(t){return t===e!==i}):"string"!=typeof e?_.grep(t,function(t){return d.call(e,t)>-1!==i}):_.filter(e,t,i)}_.filter=function(t,e,i){var n=e[0];return i&&(t=":not("+t+")"),1===e.length&&1===n.nodeType?_.find.matchesSelector(n,t)?[n]:[]:_.find.matches(t,_.grep(e,function(t){return 1===t.nodeType}))},_.fn.extend({find:function(t){var e,i,n=this.length,o=this;if("string"!=typeof t)return this.pushStack(_(t).filter(function(){for(e=0;e<n;e++)if(_.contains(o[e],this))return!0}));for(i=this.pushStack([]),e=0;e<n;e++)_.find(t,o[e],i);return n>1?_.uniqueSort(i):i},filter:function(t){return this.pushStack(N(this,t||[],!1))},not:function(t){return this.pushStack(N(this,t||[],!0))},is:function(t){return!!N(this,"string"==typeof t&&A.test(t)?_(t):t||[],!1).length}});var L,M=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/;(_.fn.init=function(t,e,i){var n,o;if(!t)return this;if(i=i||L,"string"==typeof t){if(!(n="<"===t[0]&&">"===t[t.length-1]&&t.length>=3?[null,t,null]:M.exec(t))||!n[1]&&e)return!e||e.jquery?(e||i).find(t):this.constructor(e).find(t);if(n[1]){if(e=e instanceof _?e[0]:e,_.merge(this,_.parseHTML(n[1],e&&e.nodeType?e.ownerDocument||e:s,!0)),I.test(n[1])&&_.isPlainObject(e))for(n in e)y(this[n])?this[n](e[n]):this.attr(n,e[n]);return this}return(o=s.getElementById(n[2]))&&(this[0]=o,this.length=1),this}return t.nodeType?(this[0]=t,this.length=1,this):y(t)?void 0!==i.ready?i.ready(t):t(_):_.makeArray(t,this)}).prototype=_.fn,L=_(s);var $=/^(?:parents|prev(?:Until|All))/,P={children:!0,contents:!0,next:!0,prev:!0};function H(t,e){for(;(t=t[e])&&1!==t.nodeType;);return t}_.fn.extend({has:function(t){var e=_(t,this),i=e.length;return this.filter(function(){for(var t=0;t<i;t++)if(_.contains(this,e[t]))return!0})},closest:function(t,e){var i,n=0,o=this.length,r=[],s="string"!=typeof t&&_(t);if(!A.test(t))for(;n<o;n++)for(i=this[n];i&&i!==e;i=i.parentNode)if(i.nodeType<11&&(s?s.index(i)>-1:1===i.nodeType&&_.find.matchesSelector(i,t))){r.push(i);break}return this.pushStack(r.length>1?_.uniqueSort(r):r)},index:function(t){return t?"string"==typeof t?d.call(_(t),this[0]):d.call(this,t.jquery?t[0]:t):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(t,e){return this.pushStack(_.uniqueSort(_.merge(this.get(),_(t,e))))},addBack:function(t){return this.add(null==t?this.prevObject:this.prevObject.filter(t))}}),_.each({parent:function(t){var e=t.parentNode;return e&&11!==e.nodeType?e:null},parents:function(t){return D(t,"parentNode")},parentsUntil:function(t,e,i){return D(t,"parentNode",i)},next:function(t){return H(t,"nextSibling")},prev:function(t){return H(t,"previousSibling")},nextAll:function(t){return D(t,"nextSibling")},prevAll:function(t){return D(t,"previousSibling")},nextUntil:function(t,e,i){return D(t,"nextSibling",i)},prevUntil:function(t,e,i){return D(t,"previousSibling",i)},siblings:function(t){return k((t.parentNode||{}).firstChild,t)},children:function(t){return k(t.firstChild)},contents:function(t){return void 0!==t.contentDocument?t.contentDocument:(O(t,"template")&&(t=t.content||t),_.merge([],t.childNodes))}},function(t,e){_.fn[t]=function(i,n){var o=_.map(this,e,i);return"Until"!==t.slice(-5)&&(n=i),n&&"string"==typeof n&&(o=_.filter(n,o)),this.length>1&&(P[t]||_.uniqueSort(o),$.test(t)&&o.reverse()),this.pushStack(o)}});var R=/[^\x20\t\r\n\f]+/g;function j(t){return t}function F(t){throw t}function z(t,e,i,n){var o;try{t&&y(o=t.promise)?o.call(t).done(e).fail(i):t&&y(o=t.then)?o.call(t,e,i):e.apply(void 0,[t].slice(n))}catch(t){i.apply(void 0,[t])}}_.Callbacks=function(t){t="string"==typeof t?function(t){var e={};return _.each(t.match(R)||[],function(t,i){e[i]=!0}),e}(t):_.extend({},t);var e,i,n,o,r=[],s=[],a=-1,l=function(){for(o=o||t.once,n=e=!0;s.length;a=-1)for(i=s.shift();++a<r.length;)!1===r[a].apply(i[0],i[1])&&t.stopOnFalse&&(a=r.length,i=!1);t.memory||(i=!1),e=!1,o&&(r=i?[]:"")},c={add:function(){return r&&(i&&!e&&(a=r.length-1,s.push(i)),function e(i){_.each(i,function(i,n){y(n)?t.unique&&c.has(n)||r.push(n):n&&n.length&&"string"!==x(n)&&e(n)})}(arguments),i&&!e&&l()),this},remove:function(){return _.each(arguments,function(t,e){for(var i;(i=_.inArray(e,r,i))>-1;)r.splice(i,1),i<=a&&a--}),this},has:function(t){return t?_.inArray(t,r)>-1:r.length>0},empty:function(){return r&&(r=[]),this},disable:function(){return o=s=[],r=i="",this},disabled:function(){return!r},lock:function(){return o=s=[],i||e||(r=i=""),this},locked:function(){return!!o},fireWith:function(t,i){return o||(i=[t,(i=i||[]).slice?i.slice():i],s.push(i),e||l()),this},fire:function(){return c.fireWith(this,arguments),this},fired:function(){return!!n}};return c},_.extend({Deferred:function(t){var e=[["notify","progress",_.Callbacks("memory"),_.Callbacks("memory"),2],["resolve","done",_.Callbacks("once memory"),_.Callbacks("once memory"),0,"resolved"],["reject","fail",_.Callbacks("once memory"),_.Callbacks("once memory"),1,"rejected"]],n="pending",o={state:function(){return n},always:function(){return r.done(arguments).fail(arguments),this},catch:function(t){return o.then(null,t)},pipe:function(){var t=arguments;return _.Deferred(function(i){_.each(e,function(e,n){var o=y(t[n[4]])&&t[n[4]];r[n[1]](function(){var t=o&&o.apply(this,arguments);t&&y(t.promise)?t.promise().progress(i.notify).done(i.resolve).fail(i.reject):i[n[0]+"With"](this,o?[t]:arguments)})}),t=null}).promise()},then:function(t,n,o){var r=0;function s(t,e,n,o){return function(){var a=this,l=arguments,c=function(){var i,c;if(!(t<r)){if((i=n.apply(a,l))===e.promise())throw new TypeError("Thenable self-resolution");c=i&&("object"==typeof i||"function"==typeof i)&&i.then,y(c)?o?c.call(i,s(r,e,j,o),s(r,e,F,o)):(r++,c.call(i,s(r,e,j,o),s(r,e,F,o),s(r,e,j,e.notifyWith))):(n!==j&&(a=void 0,l=[i]),(o||e.resolveWith)(a,l))}},u=o?c:function(){try{c()}catch(i){_.Deferred.exceptionHook&&_.Deferred.exceptionHook(i,u.stackTrace),t+1>=r&&(n!==F&&(a=void 0,l=[i]),e.rejectWith(a,l))}};t?u():(_.Deferred.getStackHook&&(u.stackTrace=_.Deferred.getStackHook()),i.setTimeout(u))}}return _.Deferred(function(i){e[0][3].add(s(0,i,y(o)?o:j,i.notifyWith)),e[1][3].add(s(0,i,y(t)?t:j)),e[2][3].add(s(0,i,y(n)?n:F))}).promise()},promise:function(t){return null!=t?_.extend(t,o):o}},r={};return _.each(e,function(t,i){var s=i[2],a=i[5];o[i[1]]=s.add,a&&s.add(function(){n=a},e[3-t][2].disable,e[3-t][3].disable,e[0][2].lock,e[0][3].lock),s.add(i[3].fire),r[i[0]]=function(){return r[i[0]+"With"](this===r?void 0:this,arguments),this},r[i[0]+"With"]=s.fireWith}),o.promise(r),t&&t.call(r,r),r},when:function(t){var e=arguments.length,i=e,n=Array(i),o=l.call(arguments),r=_.Deferred(),s=function(t){return function(i){n[t]=this,o[t]=arguments.length>1?l.call(arguments):i,--e||r.resolveWith(n,o)}};if(e<=1&&(z(t,r.done(s(i)).resolve,r.reject,!e),"pending"===r.state()||y(o[i]&&o[i].then)))return r.then();for(;i--;)z(o[i],s(i),r.reject);return r.promise()}});var W=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;_.Deferred.exceptionHook=function(t,e){i.console&&i.console.warn&&t&&W.test(t.name)&&i.console.warn("jQuery.Deferred exception: "+t.message,t.stack,e)},_.readyException=function(t){i.setTimeout(function(){throw t})};var U=_.Deferred();function B(){s.removeEventListener("DOMContentLoaded",B),i.removeEventListener("load",B),_.ready()}_.fn.ready=function(t){return U.then(t).catch(function(t){_.readyException(t)}),this},_.extend({isReady:!1,readyWait:1,ready:function(t){(!0===t?--_.readyWait:_.isReady)||(_.isReady=!0,!0!==t&&--_.readyWait>0||U.resolveWith(s,[_]))}}),_.ready.then=U.then,"complete"===s.readyState||"loading"!==s.readyState&&!s.documentElement.doScroll?i.setTimeout(_.ready):(s.addEventListener("DOMContentLoaded",B),i.addEventListener("load",B));var q=function(t,e,i,n,o,r,s){var a=0,l=t.length,c=null==i;if("object"===x(i))for(a in o=!0,i)q(t,e,a,i[a],!0,r,s);else if(void 0!==n&&(o=!0,y(n)||(s=!0),c&&(s?(e.call(t,n),e=null):(c=e,e=function(t,e,i){return c.call(_(t),i)})),e))for(;a<l;a++)e(t[a],i,s?n:n.call(t[a],a,e(t[a],i)));return o?t:c?e.call(t):l?e(t[0],i):r},V=/^-ms-/,Y=/-([a-z])/g;function G(t,e){return e.toUpperCase()}function X(t){return t.replace(V,"ms-").replace(Y,G)}var K=function(t){return 1===t.nodeType||9===t.nodeType||!+t.nodeType};function Q(){this.expando=_.expando+Q.uid++}Q.uid=1,Q.prototype={cache:function(t){var e=t[this.expando];return e||(e={},K(t)&&(t.nodeType?t[this.expando]=e:Object.defineProperty(t,this.expando,{value:e,configurable:!0}))),e},set:function(t,e,i){var n,o=this.cache(t);if("string"==typeof e)o[X(e)]=i;else for(n in e)o[X(n)]=e[n];return o},get:function(t,e){return void 0===e?this.cache(t):t[this.expando]&&t[this.expando][X(e)]},access:function(t,e,i){return void 0===e||e&&"string"==typeof e&&void 0===i?this.get(t,e):(this.set(t,e,i),void 0!==i?i:e)},remove:function(t,e){var i,n=t[this.expando];if(void 0!==n){if(void 0!==e){i=(e=Array.isArray(e)?e.map(X):(e=X(e))in n?[e]:e.match(R)||[]).length;for(;i--;)delete n[e[i]]}(void 0===e||_.isEmptyObject(n))&&(t.nodeType?t[this.expando]=void 0:delete t[this.expando])}},hasData:function(t){var e=t[this.expando];return void 0!==e&&!_.isEmptyObject(e)}};var J=new Q,Z=new Q,tt=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,et=/[A-Z]/g;function it(t,e,i){var n;if(void 0===i&&1===t.nodeType)if(n="data-"+e.replace(et,"-$&").toLowerCase(),"string"==typeof(i=t.getAttribute(n))){try{i=function(t){return"true"===t||"false"!==t&&("null"===t?null:t===+t+""?+t:tt.test(t)?JSON.parse(t):t)}(i)}catch(t){}Z.set(t,e,i)}else i=void 0;return i}_.extend({hasData:function(t){return Z.hasData(t)||J.hasData(t)},data:function(t,e,i){return Z.access(t,e,i)},removeData:function(t,e){Z.remove(t,e)},_data:function(t,e,i){return J.access(t,e,i)},_removeData:function(t,e){J.remove(t,e)}}),_.fn.extend({data:function(t,e){var i,n,o,r=this[0],s=r&&r.attributes;if(void 0===t){if(this.length&&(o=Z.get(r),1===r.nodeType&&!J.get(r,"hasDataAttrs"))){for(i=s.length;i--;)s[i]&&0===(n=s[i].name).indexOf("data-")&&(n=X(n.slice(5)),it(r,n,o[n]));J.set(r,"hasDataAttrs",!0)}return o}return"object"==typeof t?this.each(function(){Z.set(this,t)}):q(this,function(e){var i;if(r&&void 0===e)return void 0!==(i=Z.get(r,t))?i:void 0!==(i=it(r,t))?i:void 0;this.each(function(){Z.set(this,t,e)})},null,e,arguments.length>1,null,!0)},removeData:function(t){return this.each(function(){Z.remove(this,t)})}}),_.extend({queue:function(t,e,i){var n;if(t)return e=(e||"fx")+"queue",n=J.get(t,e),i&&(!n||Array.isArray(i)?n=J.access(t,e,_.makeArray(i)):n.push(i)),n||[]},dequeue:function(t,e){e=e||"fx";var i=_.queue(t,e),n=i.length,o=i.shift(),r=_._queueHooks(t,e);"inprogress"===o&&(o=i.shift(),n--),o&&("fx"===e&&i.unshift("inprogress"),delete r.stop,o.call(t,function(){_.dequeue(t,e)},r)),!n&&r&&r.empty.fire()},_queueHooks:function(t,e){var i=e+"queueHooks";return J.get(t,i)||J.access(t,i,{empty:_.Callbacks("once memory").add(function(){J.remove(t,[e+"queue",i])})})}}),_.fn.extend({queue:function(t,e){var i=2;return"string"!=typeof t&&(e=t,t="fx",i--),arguments.length<i?_.queue(this[0],t):void 0===e?this:this.each(function(){var i=_.queue(this,t,e);_._queueHooks(this,t),"fx"===t&&"inprogress"!==i[0]&&_.dequeue(this,t)})},dequeue:function(t){return this.each(function(){_.dequeue(this,t)})},clearQueue:function(t){return this.queue(t||"fx",[])},promise:function(t,e){var i,n=1,o=_.Deferred(),r=this,s=this.length,a=function(){--n||o.resolveWith(r,[r])};for("string"!=typeof t&&(e=t,t=void 0),t=t||"fx";s--;)(i=J.get(r[s],t+"queueHooks"))&&i.empty&&(n++,i.empty.add(a));return a(),o.promise(e)}});var nt=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,ot=new RegExp("^(?:([+-])=|)("+nt+")([a-z%]*)$","i"),rt=["Top","Right","Bottom","Left"],st=s.documentElement,at=function(t){return _.contains(t.ownerDocument,t)},lt={composed:!0};st.getRootNode&&(at=function(t){return _.contains(t.ownerDocument,t)||t.getRootNode(lt)===t.ownerDocument});var ct=function(t,e){return"none"===(t=e||t).style.display||""===t.style.display&&at(t)&&"none"===_.css(t,"display")},ut=function(t,e,i,n){var o,r,s={};for(r in e)s[r]=t.style[r],t.style[r]=e[r];for(r in o=i.apply(t,n||[]),e)t.style[r]=s[r];return o};function dt(t,e,i,n){var o,r,s=20,a=n?function(){return n.cur()}:function(){return _.css(t,e,"")},l=a(),c=i&&i[3]||(_.cssNumber[e]?"":"px"),u=t.nodeType&&(_.cssNumber[e]||"px"!==c&&+l)&&ot.exec(_.css(t,e));if(u&&u[3]!==c){for(l/=2,c=c||u[3],u=+l||1;s--;)_.style(t,e,u+c),(1-r)*(1-(r=a()/l||.5))<=0&&(s=0),u/=r;u*=2,_.style(t,e,u+c),i=i||[]}return i&&(u=+u||+l||0,o=i[1]?u+(i[1]+1)*i[2]:+i[2],n&&(n.unit=c,n.start=u,n.end=o)),o}var ht={};function pt(t){var e,i=t.ownerDocument,n=t.nodeName,o=ht[n];return o||(e=i.body.appendChild(i.createElement(n)),o=_.css(e,"display"),e.parentNode.removeChild(e),"none"===o&&(o="block"),ht[n]=o,o)}function ft(t,e){for(var i,n,o=[],r=0,s=t.length;r<s;r++)(n=t[r]).style&&(i=n.style.display,e?("none"===i&&(o[r]=J.get(n,"display")||null,o[r]||(n.style.display="")),""===n.style.display&&ct(n)&&(o[r]=pt(n))):"none"!==i&&(o[r]="none",J.set(n,"display",i)));for(r=0;r<s;r++)null!=o[r]&&(t[r].style.display=o[r]);return t}_.fn.extend({show:function(){return ft(this,!0)},hide:function(){return ft(this)},toggle:function(t){return"boolean"==typeof t?t?this.show():this.hide():this.each(function(){ct(this)?_(this).show():_(this).hide()})}});var mt=/^(?:checkbox|radio)$/i,gt=/<([a-z][^\/\0>\x20\t\r\n\f]*)/i,vt=/^$|^module$|\/(?:java|ecma)script/i,yt={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};function bt(t,e){var i;return i=void 0!==t.getElementsByTagName?t.getElementsByTagName(e||"*"):void 0!==t.querySelectorAll?t.querySelectorAll(e||"*"):[],void 0===e||e&&O(t,e)?_.merge([t],i):i}function wt(t,e){for(var i=0,n=t.length;i<n;i++)J.set(t[i],"globalEval",!e||J.get(e[i],"globalEval"))}yt.optgroup=yt.option,yt.tbody=yt.tfoot=yt.colgroup=yt.caption=yt.thead,yt.th=yt.td;var Tt,xt,_t=/<|&#?\w+;/;function Ct(t,e,i,n,o){for(var r,s,a,l,c,u,d=e.createDocumentFragment(),h=[],p=0,f=t.length;p<f;p++)if((r=t[p])||0===r)if("object"===x(r))_.merge(h,r.nodeType?[r]:r);else if(_t.test(r)){for(s=s||d.appendChild(e.createElement("div")),a=(gt.exec(r)||["",""])[1].toLowerCase(),l=yt[a]||yt._default,s.innerHTML=l[1]+_.htmlPrefilter(r)+l[2],u=l[0];u--;)s=s.lastChild;_.merge(h,s.childNodes),(s=d.firstChild).textContent=""}else h.push(e.createTextNode(r));for(d.textContent="",p=0;r=h[p++];)if(n&&_.inArray(r,n)>-1)o&&o.push(r);else if(c=at(r),s=bt(d.appendChild(r),"script"),c&&wt(s),i)for(u=0;r=s[u++];)vt.test(r.type||"")&&i.push(r);return d}Tt=s.createDocumentFragment().appendChild(s.createElement("div")),(xt=s.createElement("input")).setAttribute("type","radio"),xt.setAttribute("checked","checked"),xt.setAttribute("name","t"),Tt.appendChild(xt),v.checkClone=Tt.cloneNode(!0).cloneNode(!0).lastChild.checked,Tt.innerHTML="<textarea>x</textarea>",v.noCloneChecked=!!Tt.cloneNode(!0).lastChild.defaultValue;var Et=/^key/,St=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,Dt=/^([^.]*)(?:\.(.+)|)/;function kt(){return!0}function At(){return!1}function Ot(t,e){return t===function(){try{return s.activeElement}catch(t){}}()==("focus"===e)}function It(t,e,i,n,o,r){var s,a;if("object"==typeof e){for(a in"string"!=typeof i&&(n=n||i,i=void 0),e)It(t,a,i,n,e[a],r);return t}if(null==n&&null==o?(o=i,n=i=void 0):null==o&&("string"==typeof i?(o=n,n=void 0):(o=n,n=i,i=void 0)),!1===o)o=At;else if(!o)return t;return 1===r&&(s=o,(o=function(t){return _().off(t),s.apply(this,arguments)}).guid=s.guid||(s.guid=_.guid++)),t.each(function(){_.event.add(this,e,o,n,i)})}function Nt(t,e,i){i?(J.set(t,e,!1),_.event.add(t,e,{namespace:!1,handler:function(t){var n,o,r=J.get(this,e);if(1&t.isTrigger&&this[e]){if(r.length)(_.event.special[e]||{}).delegateType&&t.stopPropagation();else if(r=l.call(arguments),J.set(this,e,r),n=i(this,e),this[e](),r!==(o=J.get(this,e))||n?J.set(this,e,!1):o={},r!==o)return t.stopImmediatePropagation(),t.preventDefault(),o.value}else r.length&&(J.set(this,e,{value:_.event.trigger(_.extend(r[0],_.Event.prototype),r.slice(1),this)}),t.stopImmediatePropagation())}})):void 0===J.get(t,e)&&_.event.add(t,e,kt)}_.event={global:{},add:function(t,e,i,n,o){var r,s,a,l,c,u,d,h,p,f,m,g=J.get(t);if(g)for(i.handler&&(i=(r=i).handler,o=r.selector),o&&_.find.matchesSelector(st,o),i.guid||(i.guid=_.guid++),(l=g.events)||(l=g.events={}),(s=g.handle)||(s=g.handle=function(e){return void 0!==_&&_.event.triggered!==e.type?_.event.dispatch.apply(t,arguments):void 0}),c=(e=(e||"").match(R)||[""]).length;c--;)p=m=(a=Dt.exec(e[c])||[])[1],f=(a[2]||"").split(".").sort(),p&&(d=_.event.special[p]||{},p=(o?d.delegateType:d.bindType)||p,d=_.event.special[p]||{},u=_.extend({type:p,origType:m,data:n,handler:i,guid:i.guid,selector:o,needsContext:o&&_.expr.match.needsContext.test(o),namespace:f.join(".")},r),(h=l[p])||((h=l[p]=[]).delegateCount=0,d.setup&&!1!==d.setup.call(t,n,f,s)||t.addEventListener&&t.addEventListener(p,s)),d.add&&(d.add.call(t,u),u.handler.guid||(u.handler.guid=i.guid)),o?h.splice(h.delegateCount++,0,u):h.push(u),_.event.global[p]=!0)},remove:function(t,e,i,n,o){var r,s,a,l,c,u,d,h,p,f,m,g=J.hasData(t)&&J.get(t);if(g&&(l=g.events)){for(c=(e=(e||"").match(R)||[""]).length;c--;)if(p=m=(a=Dt.exec(e[c])||[])[1],f=(a[2]||"").split(".").sort(),p){for(d=_.event.special[p]||{},h=l[p=(n?d.delegateType:d.bindType)||p]||[],a=a[2]&&new RegExp("(^|\\.)"+f.join("\\.(?:.*\\.|)")+"(\\.|$)"),s=r=h.length;r--;)u=h[r],!o&&m!==u.origType||i&&i.guid!==u.guid||a&&!a.test(u.namespace)||n&&n!==u.selector&&("**"!==n||!u.selector)||(h.splice(r,1),u.selector&&h.delegateCount--,d.remove&&d.remove.call(t,u));s&&!h.length&&(d.teardown&&!1!==d.teardown.call(t,f,g.handle)||_.removeEvent(t,p,g.handle),delete l[p])}else for(p in l)_.event.remove(t,p+e[c],i,n,!0);_.isEmptyObject(l)&&J.remove(t,"handle events")}},dispatch:function(t){var e,i,n,o,r,s,a=_.event.fix(t),l=new Array(arguments.length),c=(J.get(this,"events")||{})[a.type]||[],u=_.event.special[a.type]||{};for(l[0]=a,e=1;e<arguments.length;e++)l[e]=arguments[e];if(a.delegateTarget=this,!u.preDispatch||!1!==u.preDispatch.call(this,a)){for(s=_.event.handlers.call(this,a,c),e=0;(o=s[e++])&&!a.isPropagationStopped();)for(a.currentTarget=o.elem,i=0;(r=o.handlers[i++])&&!a.isImmediatePropagationStopped();)a.rnamespace&&!1!==r.namespace&&!a.rnamespace.test(r.namespace)||(a.handleObj=r,a.data=r.data,void 0!==(n=((_.event.special[r.origType]||{}).handle||r.handler).apply(o.elem,l))&&!1===(a.result=n)&&(a.preventDefault(),a.stopPropagation()));return u.postDispatch&&u.postDispatch.call(this,a),a.result}},handlers:function(t,e){var i,n,o,r,s,a=[],l=e.delegateCount,c=t.target;if(l&&c.nodeType&&!("click"===t.type&&t.button>=1))for(;c!==this;c=c.parentNode||this)if(1===c.nodeType&&("click"!==t.type||!0!==c.disabled)){for(r=[],s={},i=0;i<l;i++)void 0===s[o=(n=e[i]).selector+" "]&&(s[o]=n.needsContext?_(o,this).index(c)>-1:_.find(o,this,null,[c]).length),s[o]&&r.push(n);r.length&&a.push({elem:c,handlers:r})}return c=this,l<e.length&&a.push({elem:c,handlers:e.slice(l)}),a},addProp:function(t,e){Object.defineProperty(_.Event.prototype,t,{enumerable:!0,configurable:!0,get:y(e)?function(){if(this.originalEvent)return e(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[t]},set:function(e){Object.defineProperty(this,t,{enumerable:!0,configurable:!0,writable:!0,value:e})}})},fix:function(t){return t[_.expando]?t:new _.Event(t)},special:{load:{noBubble:!0},click:{setup:function(t){var e=this||t;return mt.test(e.type)&&e.click&&O(e,"input")&&Nt(e,"click",kt),!1},trigger:function(t){var e=this||t;return mt.test(e.type)&&e.click&&O(e,"input")&&Nt(e,"click"),!0},_default:function(t){var e=t.target;return mt.test(e.type)&&e.click&&O(e,"input")&&J.get(e,"click")||O(e,"a")}},beforeunload:{postDispatch:function(t){void 0!==t.result&&t.originalEvent&&(t.originalEvent.returnValue=t.result)}}}},_.removeEvent=function(t,e,i){t.removeEventListener&&t.removeEventListener(e,i)},_.Event=function(t,e){if(!(this instanceof _.Event))return new _.Event(t,e);t&&t.type?(this.originalEvent=t,this.type=t.type,this.isDefaultPrevented=t.defaultPrevented||void 0===t.defaultPrevented&&!1===t.returnValue?kt:At,this.target=t.target&&3===t.target.nodeType?t.target.parentNode:t.target,this.currentTarget=t.currentTarget,this.relatedTarget=t.relatedTarget):this.type=t,e&&_.extend(this,e),this.timeStamp=t&&t.timeStamp||Date.now(),this[_.expando]=!0},_.Event.prototype={constructor:_.Event,isDefaultPrevented:At,isPropagationStopped:At,isImmediatePropagationStopped:At,isSimulated:!1,preventDefault:function(){var t=this.originalEvent;this.isDefaultPrevented=kt,t&&!this.isSimulated&&t.preventDefault()},stopPropagation:function(){var t=this.originalEvent;this.isPropagationStopped=kt,t&&!this.isSimulated&&t.stopPropagation()},stopImmediatePropagation:function(){var t=this.originalEvent;this.isImmediatePropagationStopped=kt,t&&!this.isSimulated&&t.stopImmediatePropagation(),this.stopPropagation()}},_.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,char:!0,code:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:function(t){var e=t.button;return null==t.which&&Et.test(t.type)?null!=t.charCode?t.charCode:t.keyCode:!t.which&&void 0!==e&&St.test(t.type)?1&e?1:2&e?3:4&e?2:0:t.which}},_.event.addProp),_.each({focus:"focusin",blur:"focusout"},function(t,e){_.event.special[t]={setup:function(){return Nt(this,t,Ot),!1},trigger:function(){return Nt(this,t),!0},delegateType:e}}),_.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(t,e){_.event.special[t]={delegateType:e,bindType:e,handle:function(t){var i,n=this,o=t.relatedTarget,r=t.handleObj;return o&&(o===n||_.contains(n,o))||(t.type=r.origType,i=r.handler.apply(this,arguments),t.type=e),i}}}),_.fn.extend({on:function(t,e,i,n){return It(this,t,e,i,n)},one:function(t,e,i,n){return It(this,t,e,i,n,1)},off:function(t,e,i){var n,o;if(t&&t.preventDefault&&t.handleObj)return n=t.handleObj,_(t.delegateTarget).off(n.namespace?n.origType+"."+n.namespace:n.origType,n.selector,n.handler),this;if("object"==typeof t){for(o in t)this.off(o,e,t[o]);return this}return!1!==e&&"function"!=typeof e||(i=e,e=void 0),!1===i&&(i=At),this.each(function(){_.event.remove(this,t,i,e)})}});var Lt=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([a-z][^\/\0>\x20\t\r\n\f]*)[^>]*)\/>/gi,Mt=/<script|<style|<link/i,$t=/checked\s*(?:[^=]|=\s*.checked.)/i,Pt=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;function Ht(t,e){return O(t,"table")&&O(11!==e.nodeType?e:e.firstChild,"tr")&&_(t).children("tbody")[0]||t}function Rt(t){return t.type=(null!==t.getAttribute("type"))+"/"+t.type,t}function jt(t){return"true/"===(t.type||"").slice(0,5)?t.type=t.type.slice(5):t.removeAttribute("type"),t}function Ft(t,e){var i,n,o,r,s,a,l,c;if(1===e.nodeType){if(J.hasData(t)&&(r=J.access(t),s=J.set(e,r),c=r.events))for(o in delete s.handle,s.events={},c)for(i=0,n=c[o].length;i<n;i++)_.event.add(e,o,c[o][i]);Z.hasData(t)&&(a=Z.access(t),l=_.extend({},a),Z.set(e,l))}}function zt(t,e){var i=e.nodeName.toLowerCase();"input"===i&&mt.test(t.type)?e.checked=t.checked:"input"!==i&&"textarea"!==i||(e.defaultValue=t.defaultValue)}function Wt(t,e,i,n){e=c.apply([],e);var o,r,s,a,l,u,d=0,h=t.length,p=h-1,f=e[0],m=y(f);if(m||h>1&&"string"==typeof f&&!v.checkClone&&$t.test(f))return t.each(function(o){var r=t.eq(o);m&&(e[0]=f.call(this,o,r.html())),Wt(r,e,i,n)});if(h&&(r=(o=Ct(e,t[0].ownerDocument,!1,t,n)).firstChild,1===o.childNodes.length&&(o=r),r||n)){for(a=(s=_.map(bt(o,"script"),Rt)).length;d<h;d++)l=o,d!==p&&(l=_.clone(l,!0,!0),a&&_.merge(s,bt(l,"script"))),i.call(t[d],l,d);if(a)for(u=s[s.length-1].ownerDocument,_.map(s,jt),d=0;d<a;d++)l=s[d],vt.test(l.type||"")&&!J.access(l,"globalEval")&&_.contains(u,l)&&(l.src&&"module"!==(l.type||"").toLowerCase()?_._evalUrl&&!l.noModule&&_._evalUrl(l.src,{nonce:l.nonce||l.getAttribute("nonce")}):T(l.textContent.replace(Pt,""),l,u))}return t}function Ut(t,e,i){for(var n,o=e?_.filter(e,t):t,r=0;null!=(n=o[r]);r++)i||1!==n.nodeType||_.cleanData(bt(n)),n.parentNode&&(i&&at(n)&&wt(bt(n,"script")),n.parentNode.removeChild(n));return t}_.extend({htmlPrefilter:function(t){return t.replace(Lt,"<$1></$2>")},clone:function(t,e,i){var n,o,r,s,a=t.cloneNode(!0),l=at(t);if(!(v.noCloneChecked||1!==t.nodeType&&11!==t.nodeType||_.isXMLDoc(t)))for(s=bt(a),n=0,o=(r=bt(t)).length;n<o;n++)zt(r[n],s[n]);if(e)if(i)for(r=r||bt(t),s=s||bt(a),n=0,o=r.length;n<o;n++)Ft(r[n],s[n]);else Ft(t,a);return(s=bt(a,"script")).length>0&&wt(s,!l&&bt(t,"script")),a},cleanData:function(t){for(var e,i,n,o=_.event.special,r=0;void 0!==(i=t[r]);r++)if(K(i)){if(e=i[J.expando]){if(e.events)for(n in e.events)o[n]?_.event.remove(i,n):_.removeEvent(i,n,e.handle);i[J.expando]=void 0}i[Z.expando]&&(i[Z.expando]=void 0)}}}),_.fn.extend({detach:function(t){return Ut(this,t,!0)},remove:function(t){return Ut(this,t)},text:function(t){return q(this,function(t){return void 0===t?_.text(this):this.empty().each(function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=t)})},null,t,arguments.length)},append:function(){return Wt(this,arguments,function(t){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||Ht(this,t).appendChild(t)})},prepend:function(){return Wt(this,arguments,function(t){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var e=Ht(this,t);e.insertBefore(t,e.firstChild)}})},before:function(){return Wt(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this)})},after:function(){return Wt(this,arguments,function(t){this.parentNode&&this.parentNode.insertBefore(t,this.nextSibling)})},empty:function(){for(var t,e=0;null!=(t=this[e]);e++)1===t.nodeType&&(_.cleanData(bt(t,!1)),t.textContent="");return this},clone:function(t,e){return t=null!=t&&t,e=null==e?t:e,this.map(function(){return _.clone(this,t,e)})},html:function(t){return q(this,function(t){var e=this[0]||{},i=0,n=this.length;if(void 0===t&&1===e.nodeType)return e.innerHTML;if("string"==typeof t&&!Mt.test(t)&&!yt[(gt.exec(t)||["",""])[1].toLowerCase()]){t=_.htmlPrefilter(t);try{for(;i<n;i++)1===(e=this[i]||{}).nodeType&&(_.cleanData(bt(e,!1)),e.innerHTML=t);e=0}catch(t){}}e&&this.empty().append(t)},null,t,arguments.length)},replaceWith:function(){var t=[];return Wt(this,arguments,function(e){var i=this.parentNode;_.inArray(this,t)<0&&(_.cleanData(bt(this)),i&&i.replaceChild(e,this))},t)}}),_.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(t,e){_.fn[t]=function(t){for(var i,n=[],o=_(t),r=o.length-1,s=0;s<=r;s++)i=s===r?this:this.clone(!0),_(o[s])[e](i),u.apply(n,i.get());return this.pushStack(n)}});var Bt=new RegExp("^("+nt+")(?!px)[a-z%]+$","i"),qt=function(t){var e=t.ownerDocument.defaultView;return e&&e.opener||(e=i),e.getComputedStyle(t)},Vt=new RegExp(rt.join("|"),"i");function Yt(t,e,i){var n,o,r,s,a=t.style;return(i=i||qt(t))&&(""!==(s=i.getPropertyValue(e)||i[e])||at(t)||(s=_.style(t,e)),!v.pixelBoxStyles()&&Bt.test(s)&&Vt.test(e)&&(n=a.width,o=a.minWidth,r=a.maxWidth,a.minWidth=a.maxWidth=a.width=s,s=i.width,a.width=n,a.minWidth=o,a.maxWidth=r)),void 0!==s?s+"":s}function Gt(t,e){return{get:function(){if(!t())return(this.get=e).apply(this,arguments);delete this.get}}}!function(){function t(){if(u){c.style.cssText="position:absolute;left:-11111px;width:60px;margin-top:1px;padding:0;border:0",u.style.cssText="position:relative;display:block;box-sizing:border-box;overflow:scroll;margin:auto;border:1px;padding:1px;width:60%;top:1%",st.appendChild(c).appendChild(u);var t=i.getComputedStyle(u);n="1%"!==t.top,l=12===e(t.marginLeft),u.style.right="60%",a=36===e(t.right),o=36===e(t.width),u.style.position="absolute",r=12===e(u.offsetWidth/3),st.removeChild(c),u=null}}function e(t){return Math.round(parseFloat(t))}var n,o,r,a,l,c=s.createElement("div"),u=s.createElement("div");u.style&&(u.style.backgroundClip="content-box",u.cloneNode(!0).style.backgroundClip="",v.clearCloneStyle="content-box"===u.style.backgroundClip,_.extend(v,{boxSizingReliable:function(){return t(),o},pixelBoxStyles:function(){return t(),a},pixelPosition:function(){return t(),n},reliableMarginLeft:function(){return t(),l},scrollboxSize:function(){return t(),r}}))}();var Xt=["Webkit","Moz","ms"],Kt=s.createElement("div").style,Qt={};function Jt(t){var e=_.cssProps[t]||Qt[t];return e||(t in Kt?t:Qt[t]=function(t){for(var e=t[0].toUpperCase()+t.slice(1),i=Xt.length;i--;)if((t=Xt[i]+e)in Kt)return t}(t)||t)}var Zt=/^(none|table(?!-c[ea]).+)/,te=/^--/,ee={position:"absolute",visibility:"hidden",display:"block"},ie={letterSpacing:"0",fontWeight:"400"};function ne(t,e,i){var n=ot.exec(e);return n?Math.max(0,n[2]-(i||0))+(n[3]||"px"):e}function oe(t,e,i,n,o,r){var s="width"===e?1:0,a=0,l=0;if(i===(n?"border":"content"))return 0;for(;s<4;s+=2)"margin"===i&&(l+=_.css(t,i+rt[s],!0,o)),n?("content"===i&&(l-=_.css(t,"padding"+rt[s],!0,o)),"margin"!==i&&(l-=_.css(t,"border"+rt[s]+"Width",!0,o))):(l+=_.css(t,"padding"+rt[s],!0,o),"padding"!==i?l+=_.css(t,"border"+rt[s]+"Width",!0,o):a+=_.css(t,"border"+rt[s]+"Width",!0,o));return!n&&r>=0&&(l+=Math.max(0,Math.ceil(t["offset"+e[0].toUpperCase()+e.slice(1)]-r-l-a-.5))||0),l}function re(t,e,i){var n=qt(t),o=(!v.boxSizingReliable()||i)&&"border-box"===_.css(t,"boxSizing",!1,n),r=o,s=Yt(t,e,n),a="offset"+e[0].toUpperCase()+e.slice(1);if(Bt.test(s)){if(!i)return s;s="auto"}return(!v.boxSizingReliable()&&o||"auto"===s||!parseFloat(s)&&"inline"===_.css(t,"display",!1,n))&&t.getClientRects().length&&(o="border-box"===_.css(t,"boxSizing",!1,n),(r=a in t)&&(s=t[a])),(s=parseFloat(s)||0)+oe(t,e,i||(o?"border":"content"),r,n,s)+"px"}function se(t,e,i,n,o){return new se.prototype.init(t,e,i,n,o)}_.extend({cssHooks:{opacity:{get:function(t,e){if(e){var i=Yt(t,"opacity");return""===i?"1":i}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,gridArea:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnStart:!0,gridRow:!0,gridRowEnd:!0,gridRowStart:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{},style:function(t,e,i,n){if(t&&3!==t.nodeType&&8!==t.nodeType&&t.style){var o,r,s,a=X(e),l=te.test(e),c=t.style;if(l||(e=Jt(a)),s=_.cssHooks[e]||_.cssHooks[a],void 0===i)return s&&"get"in s&&void 0!==(o=s.get(t,!1,n))?o:c[e];"string"===(r=typeof i)&&(o=ot.exec(i))&&o[1]&&(i=dt(t,e,o),r="number"),null!=i&&i==i&&("number"!==r||l||(i+=o&&o[3]||(_.cssNumber[a]?"":"px")),v.clearCloneStyle||""!==i||0!==e.indexOf("background")||(c[e]="inherit"),s&&"set"in s&&void 0===(i=s.set(t,i,n))||(l?c.setProperty(e,i):c[e]=i))}},css:function(t,e,i,n){var o,r,s,a=X(e);return te.test(e)||(e=Jt(a)),(s=_.cssHooks[e]||_.cssHooks[a])&&"get"in s&&(o=s.get(t,!0,i)),void 0===o&&(o=Yt(t,e,n)),"normal"===o&&e in ie&&(o=ie[e]),""===i||i?(r=parseFloat(o),!0===i||isFinite(r)?r||0:o):o}}),_.each(["height","width"],function(t,e){_.cssHooks[e]={get:function(t,i,n){if(i)return!Zt.test(_.css(t,"display"))||t.getClientRects().length&&t.getBoundingClientRect().width?re(t,e,n):ut(t,ee,function(){return re(t,e,n)})},set:function(t,i,n){var o,r=qt(t),s=!v.scrollboxSize()&&"absolute"===r.position,a=(s||n)&&"border-box"===_.css(t,"boxSizing",!1,r),l=n?oe(t,e,n,a,r):0;return a&&s&&(l-=Math.ceil(t["offset"+e[0].toUpperCase()+e.slice(1)]-parseFloat(r[e])-oe(t,e,"border",!1,r)-.5)),l&&(o=ot.exec(i))&&"px"!==(o[3]||"px")&&(t.style[e]=i,i=_.css(t,e)),ne(0,i,l)}}}),_.cssHooks.marginLeft=Gt(v.reliableMarginLeft,function(t,e){if(e)return(parseFloat(Yt(t,"marginLeft"))||t.getBoundingClientRect().left-ut(t,{marginLeft:0},function(){return t.getBoundingClientRect().left}))+"px"}),_.each({margin:"",padding:"",border:"Width"},function(t,e){_.cssHooks[t+e]={expand:function(i){for(var n=0,o={},r="string"==typeof i?i.split(" "):[i];n<4;n++)o[t+rt[n]+e]=r[n]||r[n-2]||r[0];return o}},"margin"!==t&&(_.cssHooks[t+e].set=ne)}),_.fn.extend({css:function(t,e){return q(this,function(t,e,i){var n,o,r={},s=0;if(Array.isArray(e)){for(n=qt(t),o=e.length;s<o;s++)r[e[s]]=_.css(t,e[s],!1,n);return r}return void 0!==i?_.style(t,e,i):_.css(t,e)},t,e,arguments.length>1)}}),_.Tween=se,se.prototype={constructor:se,init:function(t,e,i,n,o,r){this.elem=t,this.prop=i,this.easing=o||_.easing._default,this.options=e,this.start=this.now=this.cur(),this.end=n,this.unit=r||(_.cssNumber[i]?"":"px")},cur:function(){var t=se.propHooks[this.prop];return t&&t.get?t.get(this):se.propHooks._default.get(this)},run:function(t){var e,i=se.propHooks[this.prop];return this.options.duration?this.pos=e=_.easing[this.easing](t,this.options.duration*t,0,1,this.options.duration):this.pos=e=t,this.now=(this.end-this.start)*e+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),i&&i.set?i.set(this):se.propHooks._default.set(this),this}},se.prototype.init.prototype=se.prototype,se.propHooks={_default:{get:function(t){var e;return 1!==t.elem.nodeType||null!=t.elem[t.prop]&&null==t.elem.style[t.prop]?t.elem[t.prop]:(e=_.css(t.elem,t.prop,""))&&"auto"!==e?e:0},set:function(t){_.fx.step[t.prop]?_.fx.step[t.prop](t):1!==t.elem.nodeType||!_.cssHooks[t.prop]&&null==t.elem.style[Jt(t.prop)]?t.elem[t.prop]=t.now:_.style(t.elem,t.prop,t.now+t.unit)}}},se.propHooks.scrollTop=se.propHooks.scrollLeft={set:function(t){t.elem.nodeType&&t.elem.parentNode&&(t.elem[t.prop]=t.now)}},_.easing={linear:function(t){return t},swing:function(t){return.5-Math.cos(t*Math.PI)/2},_default:"swing"},_.fx=se.prototype.init,_.fx.step={};var ae,le,ce=/^(?:toggle|show|hide)$/,ue=/queueHooks$/;function de(){le&&(!1===s.hidden&&i.requestAnimationFrame?i.requestAnimationFrame(de):i.setTimeout(de,_.fx.interval),_.fx.tick())}function he(){return i.setTimeout(function(){ae=void 0}),ae=Date.now()}function pe(t,e){var i,n=0,o={height:t};for(e=e?1:0;n<4;n+=2-e)o["margin"+(i=rt[n])]=o["padding"+i]=t;return e&&(o.opacity=o.width=t),o}function fe(t,e,i){for(var n,o=(me.tweeners[e]||[]).concat(me.tweeners["*"]),r=0,s=o.length;r<s;r++)if(n=o[r].call(i,e,t))return n}function me(t,e,i){var n,o,r=0,s=me.prefilters.length,a=_.Deferred().always(function(){delete l.elem}),l=function(){if(o)return!1;for(var e=ae||he(),i=Math.max(0,c.startTime+c.duration-e),n=1-(i/c.duration||0),r=0,s=c.tweens.length;r<s;r++)c.tweens[r].run(n);return a.notifyWith(t,[c,n,i]),n<1&&s?i:(s||a.notifyWith(t,[c,1,0]),a.resolveWith(t,[c]),!1)},c=a.promise({elem:t,props:_.extend({},e),opts:_.extend(!0,{specialEasing:{},easing:_.easing._default},i),originalProperties:e,originalOptions:i,startTime:ae||he(),duration:i.duration,tweens:[],createTween:function(e,i){var n=_.Tween(t,c.opts,e,i,c.opts.specialEasing[e]||c.opts.easing);return c.tweens.push(n),n},stop:function(e){var i=0,n=e?c.tweens.length:0;if(o)return this;for(o=!0;i<n;i++)c.tweens[i].run(1);return e?(a.notifyWith(t,[c,1,0]),a.resolveWith(t,[c,e])):a.rejectWith(t,[c,e]),this}}),u=c.props;for(!function(t,e){var i,n,o,r,s;for(i in t)if(o=e[n=X(i)],r=t[i],Array.isArray(r)&&(o=r[1],r=t[i]=r[0]),i!==n&&(t[n]=r,delete t[i]),(s=_.cssHooks[n])&&"expand"in s)for(i in r=s.expand(r),delete t[n],r)i in t||(t[i]=r[i],e[i]=o);else e[n]=o}(u,c.opts.specialEasing);r<s;r++)if(n=me.prefilters[r].call(c,t,u,c.opts))return y(n.stop)&&(_._queueHooks(c.elem,c.opts.queue).stop=n.stop.bind(n)),n;return _.map(u,fe,c),y(c.opts.start)&&c.opts.start.call(t,c),c.progress(c.opts.progress).done(c.opts.done,c.opts.complete).fail(c.opts.fail).always(c.opts.always),_.fx.timer(_.extend(l,{elem:t,anim:c,queue:c.opts.queue})),c}_.Animation=_.extend(me,{tweeners:{"*":[function(t,e){var i=this.createTween(t,e);return dt(i.elem,t,ot.exec(e),i),i}]},tweener:function(t,e){y(t)?(e=t,t=["*"]):t=t.match(R);for(var i,n=0,o=t.length;n<o;n++)i=t[n],me.tweeners[i]=me.tweeners[i]||[],me.tweeners[i].unshift(e)},prefilters:[function(t,e,i){var n,o,r,s,a,l,c,u,d="width"in e||"height"in e,h=this,p={},f=t.style,m=t.nodeType&&ct(t),g=J.get(t,"fxshow");for(n in i.queue||(null==(s=_._queueHooks(t,"fx")).unqueued&&(s.unqueued=0,a=s.empty.fire,s.empty.fire=function(){s.unqueued||a()}),s.unqueued++,h.always(function(){h.always(function(){s.unqueued--,_.queue(t,"fx").length||s.empty.fire()})})),e)if(o=e[n],ce.test(o)){if(delete e[n],r=r||"toggle"===o,o===(m?"hide":"show")){if("show"!==o||!g||void 0===g[n])continue;m=!0}p[n]=g&&g[n]||_.style(t,n)}if((l=!_.isEmptyObject(e))||!_.isEmptyObject(p))for(n in d&&1===t.nodeType&&(i.overflow=[f.overflow,f.overflowX,f.overflowY],null==(c=g&&g.display)&&(c=J.get(t,"display")),"none"===(u=_.css(t,"display"))&&(c?u=c:(ft([t],!0),c=t.style.display||c,u=_.css(t,"display"),ft([t]))),("inline"===u||"inline-block"===u&&null!=c)&&"none"===_.css(t,"float")&&(l||(h.done(function(){f.display=c}),null==c&&(u=f.display,c="none"===u?"":u)),f.display="inline-block")),i.overflow&&(f.overflow="hidden",h.always(function(){f.overflow=i.overflow[0],f.overflowX=i.overflow[1],f.overflowY=i.overflow[2]})),l=!1,p)l||(g?"hidden"in g&&(m=g.hidden):g=J.access(t,"fxshow",{display:c}),r&&(g.hidden=!m),m&&ft([t],!0),h.done(function(){for(n in m||ft([t]),J.remove(t,"fxshow"),p)_.style(t,n,p[n])})),l=fe(m?g[n]:0,n,h),n in g||(g[n]=l.start,m&&(l.end=l.start,l.start=0))}],prefilter:function(t,e){e?me.prefilters.unshift(t):me.prefilters.push(t)}}),_.speed=function(t,e,i){var n=t&&"object"==typeof t?_.extend({},t):{complete:i||!i&&e||y(t)&&t,duration:t,easing:i&&e||e&&!y(e)&&e};return _.fx.off?n.duration=0:"number"!=typeof n.duration&&(n.duration in _.fx.speeds?n.duration=_.fx.speeds[n.duration]:n.duration=_.fx.speeds._default),null!=n.queue&&!0!==n.queue||(n.queue="fx"),n.old=n.complete,n.complete=function(){y(n.old)&&n.old.call(this),n.queue&&_.dequeue(this,n.queue)},n},_.fn.extend({fadeTo:function(t,e,i,n){return this.filter(ct).css("opacity",0).show().end().animate({opacity:e},t,i,n)},animate:function(t,e,i,n){var o=_.isEmptyObject(t),r=_.speed(e,i,n),s=function(){var e=me(this,_.extend({},t),r);(o||J.get(this,"finish"))&&e.stop(!0)};return s.finish=s,o||!1===r.queue?this.each(s):this.queue(r.queue,s)},stop:function(t,e,i){var n=function(t){var e=t.stop;delete t.stop,e(i)};return"string"!=typeof t&&(i=e,e=t,t=void 0),e&&!1!==t&&this.queue(t||"fx",[]),this.each(function(){var e=!0,o=null!=t&&t+"queueHooks",r=_.timers,s=J.get(this);if(o)s[o]&&s[o].stop&&n(s[o]);else for(o in s)s[o]&&s[o].stop&&ue.test(o)&&n(s[o]);for(o=r.length;o--;)r[o].elem!==this||null!=t&&r[o].queue!==t||(r[o].anim.stop(i),e=!1,r.splice(o,1));!e&&i||_.dequeue(this,t)})},finish:function(t){return!1!==t&&(t=t||"fx"),this.each(function(){var e,i=J.get(this),n=i[t+"queue"],o=i[t+"queueHooks"],r=_.timers,s=n?n.length:0;for(i.finish=!0,_.queue(this,t,[]),o&&o.stop&&o.stop.call(this,!0),e=r.length;e--;)r[e].elem===this&&r[e].queue===t&&(r[e].anim.stop(!0),r.splice(e,1));for(e=0;e<s;e++)n[e]&&n[e].finish&&n[e].finish.call(this);delete i.finish})}}),_.each(["toggle","show","hide"],function(t,e){var i=_.fn[e];_.fn[e]=function(t,n,o){return null==t||"boolean"==typeof t?i.apply(this,arguments):this.animate(pe(e,!0),t,n,o)}}),_.each({slideDown:pe("show"),slideUp:pe("hide"),slideToggle:pe("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(t,e){_.fn[t]=function(t,i,n){return this.animate(e,t,i,n)}}),_.timers=[],_.fx.tick=function(){var t,e=0,i=_.timers;for(ae=Date.now();e<i.length;e++)(t=i[e])()||i[e]!==t||i.splice(e--,1);i.length||_.fx.stop(),ae=void 0},_.fx.timer=function(t){_.timers.push(t),_.fx.start()},_.fx.interval=13,_.fx.start=function(){le||(le=!0,de())},_.fx.stop=function(){le=null},_.fx.speeds={slow:600,fast:200,_default:400},_.fn.delay=function(t,e){return t=_.fx&&_.fx.speeds[t]||t,e=e||"fx",this.queue(e,function(e,n){var o=i.setTimeout(e,t);n.stop=function(){i.clearTimeout(o)}})},function(){var t=s.createElement("input"),e=s.createElement("select").appendChild(s.createElement("option"));t.type="checkbox",v.checkOn=""!==t.value,v.optSelected=e.selected,(t=s.createElement("input")).value="t",t.type="radio",v.radioValue="t"===t.value}();var ge,ve=_.expr.attrHandle;_.fn.extend({attr:function(t,e){return q(this,_.attr,t,e,arguments.length>1)},removeAttr:function(t){return this.each(function(){_.removeAttr(this,t)})}}),_.extend({attr:function(t,e,i){var n,o,r=t.nodeType;if(3!==r&&8!==r&&2!==r)return void 0===t.getAttribute?_.prop(t,e,i):(1===r&&_.isXMLDoc(t)||(o=_.attrHooks[e.toLowerCase()]||(_.expr.match.bool.test(e)?ge:void 0)),void 0!==i?null===i?void _.removeAttr(t,e):o&&"set"in o&&void 0!==(n=o.set(t,i,e))?n:(t.setAttribute(e,i+""),i):o&&"get"in o&&null!==(n=o.get(t,e))?n:null==(n=_.find.attr(t,e))?void 0:n)},attrHooks:{type:{set:function(t,e){if(!v.radioValue&&"radio"===e&&O(t,"input")){var i=t.value;return t.setAttribute("type",e),i&&(t.value=i),e}}}},removeAttr:function(t,e){var i,n=0,o=e&&e.match(R);if(o&&1===t.nodeType)for(;i=o[n++];)t.removeAttribute(i)}}),ge={set:function(t,e,i){return!1===e?_.removeAttr(t,i):t.setAttribute(i,i),i}},_.each(_.expr.match.bool.source.match(/\w+/g),function(t,e){var i=ve[e]||_.find.attr;ve[e]=function(t,e,n){var o,r,s=e.toLowerCase();return n||(r=ve[s],ve[s]=o,o=null!=i(t,e,n)?s:null,ve[s]=r),o}});var ye=/^(?:input|select|textarea|button)$/i,be=/^(?:a|area)$/i;function we(t){return(t.match(R)||[]).join(" ")}function Te(t){return t.getAttribute&&t.getAttribute("class")||""}function xe(t){return Array.isArray(t)?t:"string"==typeof t&&t.match(R)||[]}_.fn.extend({prop:function(t,e){return q(this,_.prop,t,e,arguments.length>1)},removeProp:function(t){return this.each(function(){delete this[_.propFix[t]||t]})}}),_.extend({prop:function(t,e,i){var n,o,r=t.nodeType;if(3!==r&&8!==r&&2!==r)return 1===r&&_.isXMLDoc(t)||(e=_.propFix[e]||e,o=_.propHooks[e]),void 0!==i?o&&"set"in o&&void 0!==(n=o.set(t,i,e))?n:t[e]=i:o&&"get"in o&&null!==(n=o.get(t,e))?n:t[e]},propHooks:{tabIndex:{get:function(t){var e=_.find.attr(t,"tabindex");return e?parseInt(e,10):ye.test(t.nodeName)||be.test(t.nodeName)&&t.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),v.optSelected||(_.propHooks.selected={get:function(t){var e=t.parentNode;return e&&e.parentNode&&e.parentNode.selectedIndex,null},set:function(t){var e=t.parentNode;e&&(e.selectedIndex,e.parentNode&&e.parentNode.selectedIndex)}}),_.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){_.propFix[this.toLowerCase()]=this}),_.fn.extend({addClass:function(t){var e,i,n,o,r,s,a,l=0;if(y(t))return this.each(function(e){_(this).addClass(t.call(this,e,Te(this)))});if((e=xe(t)).length)for(;i=this[l++];)if(o=Te(i),n=1===i.nodeType&&" "+we(o)+" "){for(s=0;r=e[s++];)n.indexOf(" "+r+" ")<0&&(n+=r+" ");o!==(a=we(n))&&i.setAttribute("class",a)}return this},removeClass:function(t){var e,i,n,o,r,s,a,l=0;if(y(t))return this.each(function(e){_(this).removeClass(t.call(this,e,Te(this)))});if(!arguments.length)return this.attr("class","");if((e=xe(t)).length)for(;i=this[l++];)if(o=Te(i),n=1===i.nodeType&&" "+we(o)+" "){for(s=0;r=e[s++];)for(;n.indexOf(" "+r+" ")>-1;)n=n.replace(" "+r+" "," ");o!==(a=we(n))&&i.setAttribute("class",a)}return this},toggleClass:function(t,e){var i=typeof t,n="string"===i||Array.isArray(t);return"boolean"==typeof e&&n?e?this.addClass(t):this.removeClass(t):y(t)?this.each(function(i){_(this).toggleClass(t.call(this,i,Te(this),e),e)}):this.each(function(){var e,o,r,s;if(n)for(o=0,r=_(this),s=xe(t);e=s[o++];)r.hasClass(e)?r.removeClass(e):r.addClass(e);else void 0!==t&&"boolean"!==i||((e=Te(this))&&J.set(this,"__className__",e),this.setAttribute&&this.setAttribute("class",e||!1===t?"":J.get(this,"__className__")||""))})},hasClass:function(t){var e,i,n=0;for(e=" "+t+" ";i=this[n++];)if(1===i.nodeType&&(" "+we(Te(i))+" ").indexOf(e)>-1)return!0;return!1}});var _e=/\r/g;_.fn.extend({val:function(t){var e,i,n,o=this[0];return arguments.length?(n=y(t),this.each(function(i){var o;1===this.nodeType&&(null==(o=n?t.call(this,i,_(this).val()):t)?o="":"number"==typeof o?o+="":Array.isArray(o)&&(o=_.map(o,function(t){return null==t?"":t+""})),(e=_.valHooks[this.type]||_.valHooks[this.nodeName.toLowerCase()])&&"set"in e&&void 0!==e.set(this,o,"value")||(this.value=o))})):o?(e=_.valHooks[o.type]||_.valHooks[o.nodeName.toLowerCase()])&&"get"in e&&void 0!==(i=e.get(o,"value"))?i:"string"==typeof(i=o.value)?i.replace(_e,""):null==i?"":i:void 0}}),_.extend({valHooks:{option:{get:function(t){var e=_.find.attr(t,"value");return null!=e?e:we(_.text(t))}},select:{get:function(t){var e,i,n,o=t.options,r=t.selectedIndex,s="select-one"===t.type,a=s?null:[],l=s?r+1:o.length;for(n=r<0?l:s?r:0;n<l;n++)if(((i=o[n]).selected||n===r)&&!i.disabled&&(!i.parentNode.disabled||!O(i.parentNode,"optgroup"))){if(e=_(i).val(),s)return e;a.push(e)}return a},set:function(t,e){for(var i,n,o=t.options,r=_.makeArray(e),s=o.length;s--;)((n=o[s]).selected=_.inArray(_.valHooks.option.get(n),r)>-1)&&(i=!0);return i||(t.selectedIndex=-1),r}}}}),_.each(["radio","checkbox"],function(){_.valHooks[this]={set:function(t,e){if(Array.isArray(e))return t.checked=_.inArray(_(t).val(),e)>-1}},v.checkOn||(_.valHooks[this].get=function(t){return null===t.getAttribute("value")?"on":t.value})}),v.focusin="onfocusin"in i;var Ce=/^(?:focusinfocus|focusoutblur)$/,Ee=function(t){t.stopPropagation()};_.extend(_.event,{trigger:function(t,e,n,o){var r,a,l,c,u,d,h,p,m=[n||s],g=f.call(t,"type")?t.type:t,v=f.call(t,"namespace")?t.namespace.split("."):[];if(a=p=l=n=n||s,3!==n.nodeType&&8!==n.nodeType&&!Ce.test(g+_.event.triggered)&&(g.indexOf(".")>-1&&(v=g.split("."),g=v.shift(),v.sort()),u=g.indexOf(":")<0&&"on"+g,(t=t[_.expando]?t:new _.Event(g,"object"==typeof t&&t)).isTrigger=o?2:3,t.namespace=v.join("."),t.rnamespace=t.namespace?new RegExp("(^|\\.)"+v.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,t.result=void 0,t.target||(t.target=n),e=null==e?[t]:_.makeArray(e,[t]),h=_.event.special[g]||{},o||!h.trigger||!1!==h.trigger.apply(n,e))){if(!o&&!h.noBubble&&!b(n)){for(c=h.delegateType||g,Ce.test(c+g)||(a=a.parentNode);a;a=a.parentNode)m.push(a),l=a;l===(n.ownerDocument||s)&&m.push(l.defaultView||l.parentWindow||i)}for(r=0;(a=m[r++])&&!t.isPropagationStopped();)p=a,t.type=r>1?c:h.bindType||g,(d=(J.get(a,"events")||{})[t.type]&&J.get(a,"handle"))&&d.apply(a,e),(d=u&&a[u])&&d.apply&&K(a)&&(t.result=d.apply(a,e),!1===t.result&&t.preventDefault());return t.type=g,o||t.isDefaultPrevented()||h._default&&!1!==h._default.apply(m.pop(),e)||!K(n)||u&&y(n[g])&&!b(n)&&((l=n[u])&&(n[u]=null),_.event.triggered=g,t.isPropagationStopped()&&p.addEventListener(g,Ee),n[g](),t.isPropagationStopped()&&p.removeEventListener(g,Ee),_.event.triggered=void 0,l&&(n[u]=l)),t.result}},simulate:function(t,e,i){var n=_.extend(new _.Event,i,{type:t,isSimulated:!0});_.event.trigger(n,null,e)}}),_.fn.extend({trigger:function(t,e){return this.each(function(){_.event.trigger(t,e,this)})},triggerHandler:function(t,e){var i=this[0];if(i)return _.event.trigger(t,e,i,!0)}}),v.focusin||_.each({focus:"focusin",blur:"focusout"},function(t,e){var i=function(t){_.event.simulate(e,t.target,_.event.fix(t))};_.event.special[e]={setup:function(){var n=this.ownerDocument||this,o=J.access(n,e);o||n.addEventListener(t,i,!0),J.access(n,e,(o||0)+1)},teardown:function(){var n=this.ownerDocument||this,o=J.access(n,e)-1;o?J.access(n,e,o):(n.removeEventListener(t,i,!0),J.remove(n,e))}}});var Se=i.location,De=Date.now(),ke=/\?/;_.parseXML=function(t){var e;if(!t||"string"!=typeof t)return null;try{e=(new i.DOMParser).parseFromString(t,"text/xml")}catch(t){e=void 0}return e&&!e.getElementsByTagName("parsererror").length||_.error("Invalid XML: "+t),e};var Ae=/\[\]$/,Oe=/\r?\n/g,Ie=/^(?:submit|button|image|reset|file)$/i,Ne=/^(?:input|select|textarea|keygen)/i;function Le(t,e,i,n){var o;if(Array.isArray(e))_.each(e,function(e,o){i||Ae.test(t)?n(t,o):Le(t+"["+("object"==typeof o&&null!=o?e:"")+"]",o,i,n)});else if(i||"object"!==x(e))n(t,e);else for(o in e)Le(t+"["+o+"]",e[o],i,n)}_.param=function(t,e){var i,n=[],o=function(t,e){var i=y(e)?e():e;n[n.length]=encodeURIComponent(t)+"="+encodeURIComponent(null==i?"":i)};if(null==t)return"";if(Array.isArray(t)||t.jquery&&!_.isPlainObject(t))_.each(t,function(){o(this.name,this.value)});else for(i in t)Le(i,t[i],e,o);return n.join("&")},_.fn.extend({serialize:function(){return _.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var t=_.prop(this,"elements");return t?_.makeArray(t):this}).filter(function(){var t=this.type;return this.name&&!_(this).is(":disabled")&&Ne.test(this.nodeName)&&!Ie.test(t)&&(this.checked||!mt.test(t))}).map(function(t,e){var i=_(this).val();return null==i?null:Array.isArray(i)?_.map(i,function(t){return{name:e.name,value:t.replace(Oe,"\r\n")}}):{name:e.name,value:i.replace(Oe,"\r\n")}}).get()}});var Me=/%20/g,$e=/#.*$/,Pe=/([?&])_=[^&]*/,He=/^(.*?):[ \t]*([^\r\n]*)$/gm,Re=/^(?:GET|HEAD)$/,je=/^\/\//,Fe={},ze={},We="*/".concat("*"),Ue=s.createElement("a");function Be(t){return function(e,i){"string"!=typeof e&&(i=e,e="*");var n,o=0,r=e.toLowerCase().match(R)||[];if(y(i))for(;n=r[o++];)"+"===n[0]?(n=n.slice(1)||"*",(t[n]=t[n]||[]).unshift(i)):(t[n]=t[n]||[]).push(i)}}function qe(t,e,i,n){var o={},r=t===ze;function s(a){var l;return o[a]=!0,_.each(t[a]||[],function(t,a){var c=a(e,i,n);return"string"!=typeof c||r||o[c]?r?!(l=c):void 0:(e.dataTypes.unshift(c),s(c),!1)}),l}return s(e.dataTypes[0])||!o["*"]&&s("*")}function Ve(t,e){var i,n,o=_.ajaxSettings.flatOptions||{};for(i in e)void 0!==e[i]&&((o[i]?t:n||(n={}))[i]=e[i]);return n&&_.extend(!0,t,n),t}Ue.href=Se.href,_.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:Se.href,type:"GET",isLocal:/^(?:about|app|app-storage|.+-extension|file|res|widget):$/.test(Se.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":We,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":_.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(t,e){return e?Ve(Ve(t,_.ajaxSettings),e):Ve(_.ajaxSettings,t)},ajaxPrefilter:Be(Fe),ajaxTransport:Be(ze),ajax:function(t,e){"object"==typeof t&&(e=t,t=void 0),e=e||{};var n,o,r,a,l,c,u,d,h,p,f=_.ajaxSetup({},e),m=f.context||f,g=f.context&&(m.nodeType||m.jquery)?_(m):_.event,v=_.Deferred(),y=_.Callbacks("once memory"),b=f.statusCode||{},w={},T={},x="canceled",C={readyState:0,getResponseHeader:function(t){var e;if(u){if(!a)for(a={};e=He.exec(r);)a[e[1].toLowerCase()+" "]=(a[e[1].toLowerCase()+" "]||[]).concat(e[2]);e=a[t.toLowerCase()+" "]}return null==e?null:e.join(", ")},getAllResponseHeaders:function(){return u?r:null},setRequestHeader:function(t,e){return null==u&&(t=T[t.toLowerCase()]=T[t.toLowerCase()]||t,w[t]=e),this},overrideMimeType:function(t){return null==u&&(f.mimeType=t),this},statusCode:function(t){var e;if(t)if(u)C.always(t[C.status]);else for(e in t)b[e]=[b[e],t[e]];return this},abort:function(t){var e=t||x;return n&&n.abort(e),E(0,e),this}};if(v.promise(C),f.url=((t||f.url||Se.href)+"").replace(je,Se.protocol+"//"),f.type=e.method||e.type||f.method||f.type,f.dataTypes=(f.dataType||"*").toLowerCase().match(R)||[""],null==f.crossDomain){c=s.createElement("a");try{c.href=f.url,c.href=c.href,f.crossDomain=Ue.protocol+"//"+Ue.host!=c.protocol+"//"+c.host}catch(t){f.crossDomain=!0}}if(f.data&&f.processData&&"string"!=typeof f.data&&(f.data=_.param(f.data,f.traditional)),qe(Fe,f,e,C),u)return C;for(h in(d=_.event&&f.global)&&0==_.active++&&_.event.trigger("ajaxStart"),f.type=f.type.toUpperCase(),f.hasContent=!Re.test(f.type),o=f.url.replace($e,""),f.hasContent?f.data&&f.processData&&0===(f.contentType||"").indexOf("application/x-www-form-urlencoded")&&(f.data=f.data.replace(Me,"+")):(p=f.url.slice(o.length),f.data&&(f.processData||"string"==typeof f.data)&&(o+=(ke.test(o)?"&":"?")+f.data,delete f.data),!1===f.cache&&(o=o.replace(Pe,"$1"),p=(ke.test(o)?"&":"?")+"_="+De+++p),f.url=o+p),f.ifModified&&(_.lastModified[o]&&C.setRequestHeader("If-Modified-Since",_.lastModified[o]),_.etag[o]&&C.setRequestHeader("If-None-Match",_.etag[o])),(f.data&&f.hasContent&&!1!==f.contentType||e.contentType)&&C.setRequestHeader("Content-Type",f.contentType),C.setRequestHeader("Accept",f.dataTypes[0]&&f.accepts[f.dataTypes[0]]?f.accepts[f.dataTypes[0]]+("*"!==f.dataTypes[0]?", "+We+"; q=0.01":""):f.accepts["*"]),f.headers)C.setRequestHeader(h,f.headers[h]);if(f.beforeSend&&(!1===f.beforeSend.call(m,C,f)||u))return C.abort();if(x="abort",y.add(f.complete),C.done(f.success),C.fail(f.error),n=qe(ze,f,e,C)){if(C.readyState=1,d&&g.trigger("ajaxSend",[C,f]),u)return C;f.async&&f.timeout>0&&(l=i.setTimeout(function(){C.abort("timeout")},f.timeout));try{u=!1,n.send(w,E)}catch(t){if(u)throw t;E(-1,t)}}else E(-1,"No Transport");function E(t,e,s,a){var c,h,p,w,T,x=e;u||(u=!0,l&&i.clearTimeout(l),n=void 0,r=a||"",C.readyState=t>0?4:0,c=t>=200&&t<300||304===t,s&&(w=function(t,e,i){for(var n,o,r,s,a=t.contents,l=t.dataTypes;"*"===l[0];)l.shift(),void 0===n&&(n=t.mimeType||e.getResponseHeader("Content-Type"));if(n)for(o in a)if(a[o]&&a[o].test(n)){l.unshift(o);break}if(l[0]in i)r=l[0];else{for(o in i){if(!l[0]||t.converters[o+" "+l[0]]){r=o;break}s||(s=o)}r=r||s}if(r)return r!==l[0]&&l.unshift(r),i[r]}(f,C,s)),w=function(t,e,i,n){var o,r,s,a,l,c={},u=t.dataTypes.slice();if(u[1])for(s in t.converters)c[s.toLowerCase()]=t.converters[s];for(r=u.shift();r;)if(t.responseFields[r]&&(i[t.responseFields[r]]=e),!l&&n&&t.dataFilter&&(e=t.dataFilter(e,t.dataType)),l=r,r=u.shift())if("*"===r)r=l;else if("*"!==l&&l!==r){if(!(s=c[l+" "+r]||c["* "+r]))for(o in c)if((a=o.split(" "))[1]===r&&(s=c[l+" "+a[0]]||c["* "+a[0]])){!0===s?s=c[o]:!0!==c[o]&&(r=a[0],u.unshift(a[1]));break}if(!0!==s)if(s&&t.throws)e=s(e);else try{e=s(e)}catch(t){return{state:"parsererror",error:s?t:"No conversion from "+l+" to "+r}}}return{state:"success",data:e}}(f,w,C,c),c?(f.ifModified&&((T=C.getResponseHeader("Last-Modified"))&&(_.lastModified[o]=T),(T=C.getResponseHeader("etag"))&&(_.etag[o]=T)),204===t||"HEAD"===f.type?x="nocontent":304===t?x="notmodified":(x=w.state,h=w.data,c=!(p=w.error))):(p=x,!t&&x||(x="error",t<0&&(t=0))),C.status=t,C.statusText=(e||x)+"",c?v.resolveWith(m,[h,x,C]):v.rejectWith(m,[C,x,p]),C.statusCode(b),b=void 0,d&&g.trigger(c?"ajaxSuccess":"ajaxError",[C,f,c?h:p]),y.fireWith(m,[C,x]),d&&(g.trigger("ajaxComplete",[C,f]),--_.active||_.event.trigger("ajaxStop")))}return C},getJSON:function(t,e,i){return _.get(t,e,i,"json")},getScript:function(t,e){return _.get(t,void 0,e,"script")}}),_.each(["get","post"],function(t,e){_[e]=function(t,i,n,o){return y(i)&&(o=o||n,n=i,i=void 0),_.ajax(_.extend({url:t,type:e,dataType:o,data:i,success:n},_.isPlainObject(t)&&t))}}),_._evalUrl=function(t,e){return _.ajax({url:t,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,converters:{"text script":function(){}},dataFilter:function(t){_.globalEval(t,e)}})},_.fn.extend({wrapAll:function(t){var e;return this[0]&&(y(t)&&(t=t.call(this[0])),e=_(t,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&e.insertBefore(this[0]),e.map(function(){for(var t=this;t.firstElementChild;)t=t.firstElementChild;return t}).append(this)),this},wrapInner:function(t){return y(t)?this.each(function(e){_(this).wrapInner(t.call(this,e))}):this.each(function(){var e=_(this),i=e.contents();i.length?i.wrapAll(t):e.append(t)})},wrap:function(t){var e=y(t);return this.each(function(i){_(this).wrapAll(e?t.call(this,i):t)})},unwrap:function(t){return this.parent(t).not("body").each(function(){_(this).replaceWith(this.childNodes)}),this}}),_.expr.pseudos.hidden=function(t){return!_.expr.pseudos.visible(t)},_.expr.pseudos.visible=function(t){return!!(t.offsetWidth||t.offsetHeight||t.getClientRects().length)},_.ajaxSettings.xhr=function(){try{return new i.XMLHttpRequest}catch(t){}};var Ye={0:200,1223:204},Ge=_.ajaxSettings.xhr();v.cors=!!Ge&&"withCredentials"in Ge,v.ajax=Ge=!!Ge,_.ajaxTransport(function(t){var e,n;if(v.cors||Ge&&!t.crossDomain)return{send:function(o,r){var s,a=t.xhr();if(a.open(t.type,t.url,t.async,t.username,t.password),t.xhrFields)for(s in t.xhrFields)a[s]=t.xhrFields[s];for(s in t.mimeType&&a.overrideMimeType&&a.overrideMimeType(t.mimeType),t.crossDomain||o["X-Requested-With"]||(o["X-Requested-With"]="XMLHttpRequest"),o)a.setRequestHeader(s,o[s]);e=function(t){return function(){e&&(e=n=a.onload=a.onerror=a.onabort=a.ontimeout=a.onreadystatechange=null,"abort"===t?a.abort():"error"===t?"number"!=typeof a.status?r(0,"error"):r(a.status,a.statusText):r(Ye[a.status]||a.status,a.statusText,"text"!==(a.responseType||"text")||"string"!=typeof a.responseText?{binary:a.response}:{text:a.responseText},a.getAllResponseHeaders()))}},a.onload=e(),n=a.onerror=a.ontimeout=e("error"),void 0!==a.onabort?a.onabort=n:a.onreadystatechange=function(){4===a.readyState&&i.setTimeout(function(){e&&n()})},e=e("abort");try{a.send(t.hasContent&&t.data||null)}catch(t){if(e)throw t}},abort:function(){e&&e()}}}),_.ajaxPrefilter(function(t){t.crossDomain&&(t.contents.script=!1)}),_.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(t){return _.globalEval(t),t}}}),_.ajaxPrefilter("script",function(t){void 0===t.cache&&(t.cache=!1),t.crossDomain&&(t.type="GET")}),_.ajaxTransport("script",function(t){var e,i;if(t.crossDomain||t.scriptAttrs)return{send:function(n,o){e=_("<script>").attr(t.scriptAttrs||{}).prop({charset:t.scriptCharset,src:t.url}).on("load error",i=function(t){e.remove(),i=null,t&&o("error"===t.type?404:200,t.type)}),s.head.appendChild(e[0])},abort:function(){i&&i()}}});var Xe,Ke=[],Qe=/(=)\?(?=&|$)|\?\?/;_.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var t=Ke.pop()||_.expando+"_"+De++;return this[t]=!0,t}}),_.ajaxPrefilter("json jsonp",function(t,e,n){var o,r,s,a=!1!==t.jsonp&&(Qe.test(t.url)?"url":"string"==typeof t.data&&0===(t.contentType||"").indexOf("application/x-www-form-urlencoded")&&Qe.test(t.data)&&"data");if(a||"jsonp"===t.dataTypes[0])return o=t.jsonpCallback=y(t.jsonpCallback)?t.jsonpCallback():t.jsonpCallback,a?t[a]=t[a].replace(Qe,"$1"+o):!1!==t.jsonp&&(t.url+=(ke.test(t.url)?"&":"?")+t.jsonp+"="+o),t.converters["script json"]=function(){return s||_.error(o+" was not called"),s[0]},t.dataTypes[0]="json",r=i[o],i[o]=function(){s=arguments},n.always(function(){void 0===r?_(i).removeProp(o):i[o]=r,t[o]&&(t.jsonpCallback=e.jsonpCallback,Ke.push(o)),s&&y(r)&&r(s[0]),s=r=void 0}),"script"}),v.createHTMLDocument=((Xe=s.implementation.createHTMLDocument("").body).innerHTML="<form></form><form></form>",2===Xe.childNodes.length),_.parseHTML=function(t,e,i){return"string"!=typeof t?[]:("boolean"==typeof e&&(i=e,e=!1),e||(v.createHTMLDocument?((n=(e=s.implementation.createHTMLDocument("")).createElement("base")).href=s.location.href,e.head.appendChild(n)):e=s),r=!i&&[],(o=I.exec(t))?[e.createElement(o[1])]:(o=Ct([t],e,r),r&&r.length&&_(r).remove(),_.merge([],o.childNodes)));var n,o,r},_.fn.load=function(t,e,i){var n,o,r,s=this,a=t.indexOf(" ");return a>-1&&(n=we(t.slice(a)),t=t.slice(0,a)),y(e)?(i=e,e=void 0):e&&"object"==typeof e&&(o="POST"),s.length>0&&_.ajax({url:t,type:o||"GET",dataType:"html",data:e}).done(function(t){r=arguments,s.html(n?_("<div>").append(_.parseHTML(t)).find(n):t)}).always(i&&function(t,e){s.each(function(){i.apply(this,r||[t.responseText,e,t])})}),this},_.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(t,e){_.fn[e]=function(t){return this.on(e,t)}}),_.expr.pseudos.animated=function(t){return _.grep(_.timers,function(e){return t===e.elem}).length},_.offset={setOffset:function(t,e,i){var n,o,r,s,a,l,c=_.css(t,"position"),u=_(t),d={};"static"===c&&(t.style.position="relative"),a=u.offset(),r=_.css(t,"top"),l=_.css(t,"left"),("absolute"===c||"fixed"===c)&&(r+l).indexOf("auto")>-1?(s=(n=u.position()).top,o=n.left):(s=parseFloat(r)||0,o=parseFloat(l)||0),y(e)&&(e=e.call(t,i,_.extend({},a))),null!=e.top&&(d.top=e.top-a.top+s),null!=e.left&&(d.left=e.left-a.left+o),"using"in e?e.using.call(t,d):u.css(d)}},_.fn.extend({offset:function(t){if(arguments.length)return void 0===t?this:this.each(function(e){_.offset.setOffset(this,t,e)});var e,i,n=this[0];return n?n.getClientRects().length?(e=n.getBoundingClientRect(),i=n.ownerDocument.defaultView,{top:e.top+i.pageYOffset,left:e.left+i.pageXOffset}):{top:0,left:0}:void 0},position:function(){if(this[0]){var t,e,i,n=this[0],o={top:0,left:0};if("fixed"===_.css(n,"position"))e=n.getBoundingClientRect();else{for(e=this.offset(),i=n.ownerDocument,t=n.offsetParent||i.documentElement;t&&(t===i.body||t===i.documentElement)&&"static"===_.css(t,"position");)t=t.parentNode;t&&t!==n&&1===t.nodeType&&((o=_(t).offset()).top+=_.css(t,"borderTopWidth",!0),o.left+=_.css(t,"borderLeftWidth",!0))}return{top:e.top-o.top-_.css(n,"marginTop",!0),left:e.left-o.left-_.css(n,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){for(var t=this.offsetParent;t&&"static"===_.css(t,"position");)t=t.offsetParent;return t||st})}}),_.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(t,e){var i="pageYOffset"===e;_.fn[t]=function(n){return q(this,function(t,n,o){var r;if(b(t)?r=t:9===t.nodeType&&(r=t.defaultView),void 0===o)return r?r[e]:t[n];r?r.scrollTo(i?r.pageXOffset:o,i?o:r.pageYOffset):t[n]=o},t,n,arguments.length)}}),_.each(["top","left"],function(t,e){_.cssHooks[e]=Gt(v.pixelPosition,function(t,i){if(i)return i=Yt(t,e),Bt.test(i)?_(t).position()[e]+"px":i})}),_.each({Height:"height",Width:"width"},function(t,e){_.each({padding:"inner"+t,content:e,"":"outer"+t},function(i,n){_.fn[n]=function(o,r){var s=arguments.length&&(i||"boolean"!=typeof o),a=i||(!0===o||!0===r?"margin":"border");return q(this,function(e,i,o){var r;return b(e)?0===n.indexOf("outer")?e["inner"+t]:e.document.documentElement["client"+t]:9===e.nodeType?(r=e.documentElement,Math.max(e.body["scroll"+t],r["scroll"+t],e.body["offset"+t],r["offset"+t],r["client"+t])):void 0===o?_.css(e,i,a):_.style(e,i,o,a)},e,s?o:void 0,s)}})}),_.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),function(t,e){_.fn[e]=function(t,i){return arguments.length>0?this.on(e,null,t,i):this.trigger(e)}}),_.fn.extend({hover:function(t,e){return this.mouseenter(t).mouseleave(e||t)}}),_.fn.extend({bind:function(t,e,i){return this.on(t,null,e,i)},unbind:function(t,e){return this.off(t,null,e)},delegate:function(t,e,i,n){return this.on(e,t,i,n)},undelegate:function(t,e,i){return 1===arguments.length?this.off(t,"**"):this.off(e,t||"**",i)}}),_.proxy=function(t,e){var i,n,o;if("string"==typeof e&&(i=t[e],e=t,t=i),y(t))return n=l.call(arguments,2),(o=function(){return t.apply(e||this,n.concat(l.call(arguments)))}).guid=t.guid=t.guid||_.guid++,o},_.holdReady=function(t){t?_.readyWait++:_.ready(!0)},_.isArray=Array.isArray,_.parseJSON=JSON.parse,_.nodeName=O,_.isFunction=y,_.isWindow=b,_.camelCase=X,_.type=x,_.now=Date.now,_.isNumeric=function(t){var e=_.type(t);return("number"===e||"string"===e)&&!isNaN(t-parseFloat(t))},void 0===(n=function(){return _}.apply(e,[]))||(t.exports=n);var Je=i.jQuery,Ze=i.$;return _.noConflict=function(t){return i.$===_&&(i.$=Ze),t&&i.jQuery===_&&(i.jQuery=Je),_},o||(i.jQuery=i.$=_),_})},10:function(t,e,i){var n,o,r;o=[i(1)],void 0===(r="function"==typeof(n=function(t){"use strict";var e=!1,i=!1,n=0,o=2e3,r=0,s=t,a=document,l=window,c=s(l),u=[],d=l.requestAnimationFrame||l.webkitRequestAnimationFrame||l.mozRequestAnimationFrame||!1,h=l.cancelAnimationFrame||l.webkitCancelAnimationFrame||l.mozCancelAnimationFrame||!1;if(d)l.cancelAnimationFrame||(h=function(t){});else{var p=0;d=function(t,e){var i=(new Date).getTime(),n=Math.max(0,16-(i-p)),o=l.setTimeout(function(){t(i+n)},n);return p=i+n,o},h=function(t){l.clearTimeout(t)}}var f=l.MutationObserver||l.WebKitMutationObserver||!1,m=Date.now||function(){return(new Date).getTime()},g={zindex:"auto",cursoropacitymin:0,cursoropacitymax:1,cursorcolor:"#424242",cursorwidth:"6px",cursorborder:"1px solid #fff",cursorborderradius:"5px",scrollspeed:40,mousescrollstep:27,touchbehavior:!1,emulatetouch:!1,hwacceleration:!0,usetransition:!0,boxzoom:!1,dblclickzoom:!0,gesturezoom:!0,grabcursorenabled:!0,autohidemode:!0,background:"",iframeautoresize:!0,cursorminheight:32,preservenativescrolling:!0,railoffset:!1,railhoffset:!1,bouncescroll:!0,spacebarenabled:!0,railpadding:{top:0,right:0,left:0,bottom:0},disableoutline:!0,horizrailenabled:!0,railalign:"right",railvalign:"bottom",enabletranslate3d:!0,enablemousewheel:!0,enablekeyboard:!0,smoothscroll:!0,sensitiverail:!0,enablemouselockapi:!0,cursorfixedheight:!1,directionlockdeadzone:6,hidecursordelay:400,nativeparentscrolling:!0,enablescrollonselection:!0,overflowx:!0,overflowy:!0,cursordragspeed:.3,rtlmode:"auto",cursordragontouch:!1,oneaxismousemode:"auto",scriptpath:function(){var t=a.currentScript||function(){var t=a.getElementsByTagName("script");return!!t.length&&t[t.length-1]}(),e=t?t.src.split("?")[0]:"";return e.split("/").length>0?e.split("/").slice(0,-1).join("/")+"/":""}(),preventmultitouchscrolling:!0,disablemutationobserver:!1,enableobserver:!0,scrollbarid:!1},v=!1,y=function(){if(v)return v;var t=a.createElement("DIV"),e=t.style,i=navigator.userAgent,n=navigator.platform,o={};return o.haspointerlock="pointerLockElement"in a||"webkitPointerLockElement"in a||"mozPointerLockElement"in a,o.isopera="opera"in l,o.isopera12=o.isopera&&"getUserMedia"in navigator,o.isoperamini="[object OperaMini]"===Object.prototype.toString.call(l.operamini),o.isie="all"in a&&"attachEvent"in t&&!o.isopera,o.isieold=o.isie&&!("msInterpolationMode"in e),o.isie7=o.isie&&!o.isieold&&(!("documentMode"in a)||7===a.documentMode),o.isie8=o.isie&&"documentMode"in a&&8===a.documentMode,o.isie9=o.isie&&"performance"in l&&9===a.documentMode,o.isie10=o.isie&&"performance"in l&&10===a.documentMode,o.isie11="msRequestFullscreen"in t&&a.documentMode>=11,o.ismsedge="msCredentials"in l,o.ismozilla="MozAppearance"in e,o.iswebkit=!o.ismsedge&&"WebkitAppearance"in e,o.ischrome=o.iswebkit&&"chrome"in l,o.ischrome38=o.ischrome&&"touchAction"in e,o.ischrome22=!o.ischrome38&&o.ischrome&&o.haspointerlock,o.ischrome26=!o.ischrome38&&o.ischrome&&"transition"in e,o.cantouch="ontouchstart"in a.documentElement||"ontouchstart"in l,o.hasw3ctouch=!!l.PointerEvent&&(navigator.maxTouchPoints>0||navigator.msMaxTouchPoints>0),o.hasmstouch=!o.hasw3ctouch&&(l.MSPointerEvent||!1),o.ismac=/^mac$/i.test(n),o.isios=o.cantouch&&/iphone|ipad|ipod/i.test(n),o.isios4=o.isios&&!("seal"in Object),o.isios7=o.isios&&"webkitHidden"in a,o.isios8=o.isios&&"hidden"in a,o.isios10=o.isios&&l.Proxy,o.isandroid=/android/i.test(i),o.haseventlistener="addEventListener"in t,o.trstyle=!1,o.hastransform=!1,o.hastranslate3d=!1,o.transitionstyle=!1,o.hastransition=!1,o.transitionend=!1,o.trstyle="transform",o.hastransform="transform"in e||function(){for(var t=["msTransform","webkitTransform","MozTransform","OTransform"],i=0,n=t.length;i<n;i++)if(void 0!==e[t[i]]){o.trstyle=t[i];break}o.hastransform=!!o.trstyle}(),o.hastransform&&(e[o.trstyle]="translate3d(1px,2px,3px)",o.hastranslate3d=/translate3d/.test(e[o.trstyle])),o.transitionstyle="transition",o.prefixstyle="",o.transitionend="transitionend",o.hastransition="transition"in e||function(){o.transitionend=!1;for(var t=["webkitTransition","msTransition","MozTransition","OTransition","OTransition","KhtmlTransition"],i=["-webkit-","-ms-","-moz-","-o-","-o","-khtml-"],n=["webkitTransitionEnd","msTransitionEnd","transitionend","otransitionend","oTransitionEnd","KhtmlTransitionEnd"],r=0,s=t.length;r<s;r++)if(t[r]in e){o.transitionstyle=t[r],o.prefixstyle=i[r],o.transitionend=n[r];break}o.ischrome26&&(o.prefixstyle=i[1]),o.hastransition=o.transitionstyle}(),o.cursorgrabvalue=function(){var t=["grab","-webkit-grab","-moz-grab"];(o.ischrome&&!o.ischrome38||o.isie)&&(t=[]);for(var i=0,n=t.length;i<n;i++){var r=t[i];if(e.cursor=r,e.cursor==r)return r}return"url(https://cdnjs.cloudflare.com/ajax/libs/slider-pro/1.3.0/css/images/openhand.cur),n-resize"}(),o.hasmousecapture="setCapture"in t,o.hasMutationObserver=!1!==f,t=null,v=o,o},b=function(t,p){function v(){var t=C.doc.css(O.trstyle);return!(!t||"matrix"!=t.substr(0,6))&&t.replace(/^.*\((.*)\)$/g,"$1").replace(/px/g,"").split(/, +/)}function b(t,e,i){var n=t.css(e),o=parseFloat(n);if(isNaN(o)){var r=3==(o=L[n]||0)?i?C.win.outerHeight()-C.win.innerHeight():C.win.outerWidth()-C.win.innerWidth():1;return C.isie8&&o&&(o+=1),r?o:0}return o}function T(t,e,i,n){C._bind(t,e,function(n){var o={original:n=n||l.event,target:n.target||n.srcElement,type:"wheel",deltaMode:"MozMousePixelScroll"==n.type?0:1,deltaX:0,deltaZ:0,preventDefault:function(){return n.preventDefault?n.preventDefault():n.returnValue=!1,!1},stopImmediatePropagation:function(){n.stopImmediatePropagation?n.stopImmediatePropagation():n.cancelBubble=!0}};return"mousewheel"==e?(n.wheelDeltaX&&(o.deltaX=-.025*n.wheelDeltaX),n.wheelDeltaY&&(o.deltaY=-.025*n.wheelDeltaY),!o.deltaY&&!o.deltaX&&(o.deltaY=-.025*n.wheelDelta)):o.deltaY=n.detail,i.call(t,o)},n)}function x(t,e,i,n){C.scrollrunning||(C.newscrolly=C.getScrollTop(),C.newscrollx=C.getScrollLeft(),j=m());var o=m()-j;if(j=m(),o>350?F=1:F+=(2-F)/10,e=e*F|0,t=t*F|0){if(n)if(t<0){if(C.getScrollLeft()>=C.page.maxw)return!0}else if(C.getScrollLeft()<=0)return!0;var r=t>0?1:-1;R!==r&&(C.scrollmom&&C.scrollmom.stop(),C.newscrollx=C.getScrollLeft(),R=r),C.lastdeltax-=t}if(e){if(function(){var t=C.getScrollTop();if(e<0){if(t>=C.page.maxh)return!0}else if(t<=0)return!0}()){if(S.nativeparentscrolling&&i&&!C.ispage&&!C.zoomactive)return!0;var s=C.view.h>>1;C.newscrolly<-s?(C.newscrolly=-s,e=-1):C.newscrolly>C.page.maxh+s?(C.newscrolly=C.page.maxh+s,e=1):e=0}var a=e>0?1:-1;H!==a&&(C.scrollmom&&C.scrollmom.stop(),C.newscrolly=C.getScrollTop(),H=a),C.lastdeltay-=e}(e||t)&&C.synched("relativexy",function(){var t=C.lastdeltay+C.newscrolly;C.lastdeltay=0;var e=C.lastdeltax+C.newscrollx;C.lastdeltax=0,C.rail.drag||C.doScrollPos(e,t)})}function _(t,e,i){var n,o;return!(i||!z)||(0===t.deltaMode?(n=-t.deltaX*(S.mousescrollstep/54)|0,o=-t.deltaY*(S.mousescrollstep/54)|0):1===t.deltaMode&&(n=-t.deltaX*S.mousescrollstep*50/80|0,o=-t.deltaY*S.mousescrollstep*50/80|0),e&&S.oneaxismousemode&&0===n&&o&&(n=o,o=0,i&&(n<0?C.getScrollLeft()>=C.page.maxw:C.getScrollLeft()<=0)&&(o=n,n=0)),C.isrtlmode&&(n=-n),x(n,o,i,!0)?void(i&&(z=!0)):(z=!1,t.stopImmediatePropagation(),t.preventDefault()))}var C=this;this.version="3.7.6",this.name="nicescroll",this.me=p;var E=s("body"),S=this.opt={doc:E,win:!1};if(s.extend(S,g),S.snapbackspeed=80,t)for(var D in S)void 0!==t[D]&&(S[D]=t[D]);if(S.disablemutationobserver&&(f=!1),this.doc=S.doc,this.iddoc=this.doc&&this.doc[0]&&this.doc[0].id||"",this.ispage=/^BODY|HTML/.test(S.win?S.win[0].nodeName:this.doc[0].nodeName),this.haswrapper=!1!==S.win,this.win=S.win||(this.ispage?c:this.doc),this.docscroll=this.ispage&&!this.haswrapper?c:this.win,this.body=E,this.viewport=!1,this.isfixed=!1,this.iframe=!1,this.isiframe="IFRAME"==this.doc[0].nodeName&&"IFRAME"==this.win[0].nodeName,this.istextarea="TEXTAREA"==this.win[0].nodeName,this.forcescreen=!1,this.canshowonmouseevent="scroll"!=S.autohidemode,this.onmousedown=!1,this.onmouseup=!1,this.onmousemove=!1,this.onmousewheel=!1,this.onkeypress=!1,this.ongesturezoom=!1,this.onclick=!1,this.onscrollstart=!1,this.onscrollend=!1,this.onscrollcancel=!1,this.onzoomin=!1,this.onzoomout=!1,this.view=!1,this.page=!1,this.scroll={x:0,y:0},this.scrollratio={x:0,y:0},this.cursorheight=20,this.scrollvaluemax=0,"auto"==S.rtlmode){var k=this.win[0]==l?this.body:this.win,A=k.css("writing-mode")||k.css("-webkit-writing-mode")||k.css("-ms-writing-mode")||k.css("-moz-writing-mode");"horizontal-tb"==A||"lr-tb"==A||""===A?(this.isrtlmode="rtl"==k.css("direction"),this.isvertical=!1):(this.isrtlmode="vertical-rl"==A||"tb"==A||"tb-rl"==A||"rl-tb"==A,this.isvertical="vertical-rl"==A||"tb"==A||"tb-rl"==A)}else this.isrtlmode=!0===S.rtlmode,this.isvertical=!1;if(this.scrollrunning=!1,this.scrollmom=!1,this.observer=!1,this.observerremover=!1,this.observerbody=!1,!1!==S.scrollbarid)this.id=S.scrollbarid;else do{this.id="ascrail"+o++}while(a.getElementById(this.id));this.rail=!1,this.cursor=!1,this.cursorfreezed=!1,this.selectiondrag=!1,this.zoom=!1,this.zoomactive=!1,this.hasfocus=!1,this.hasmousefocus=!1,this.railslocked=!1,this.locked=!1,this.hidden=!1,this.cursoractive=!0,this.wheelprevented=!1,this.overflowx=S.overflowx,this.overflowy=S.overflowy,this.nativescrollingarea=!1,this.checkarea=0,this.events=[],this.saved={},this.delaylist={},this.synclist={},this.lastdeltax=0,this.lastdeltay=0,this.detected=y();var O=s.extend({},this.detected);this.canhwscroll=O.hastransform&&S.hwacceleration,this.ishwscroll=this.canhwscroll&&C.haswrapper,this.isrtlmode?this.isvertical?this.hasreversehr=!(O.iswebkit||O.isie||O.isie11):this.hasreversehr=!(O.iswebkit||O.isie&&!O.isie10&&!O.isie11):this.hasreversehr=!1,this.istouchcapable=!1,(O.cantouch||!O.hasw3ctouch&&!O.hasmstouch)&&(!O.cantouch||O.isios||O.isandroid||!O.iswebkit&&!O.ismozilla)||(this.istouchcapable=!0),S.enablemouselockapi||(O.hasmousecapture=!1,O.haspointerlock=!1),this.debounced=function(t,e,i){C&&(C.delaylist[t]||(C.delaylist[t]={h:d(function(){C.delaylist[t].fn.call(C),C.delaylist[t]=!1},i)},e.call(C)),C.delaylist[t].fn=e)},this.synched=function(t,e){C.synclist[t]?C.synclist[t]=e:(C.synclist[t]=e,d(function(){C&&(C.synclist[t]&&C.synclist[t].call(C),C.synclist[t]=null)}))},this.unsynched=function(t){C.synclist[t]&&(C.synclist[t]=!1)},this.css=function(t,e){for(var i in e)C.saved.css.push([t,i,t.css(i)]),t.css(i,e[i])},this.scrollTop=function(t){return void 0===t?C.getScrollTop():C.setScrollTop(t)},this.scrollLeft=function(t){return void 0===t?C.getScrollLeft():C.setScrollLeft(t)};var I=function(t,e,i,n,o,r,s){this.st=t,this.ed=e,this.spd=i,this.p1=n||0,this.p2=o||1,this.p3=r||0,this.p4=s||1,this.ts=m(),this.df=e-t};if(I.prototype={B2:function(t){return 3*(1-t)*(1-t)*t},B3:function(t){return 3*(1-t)*t*t},B4:function(t){return t*t*t},getPos:function(){return(m()-this.ts)/this.spd},getNow:function(){var t=(m()-this.ts)/this.spd,e=this.B2(t)+this.B3(t)+this.B4(t);return t>=1?this.ed:this.st+this.df*e|0},update:function(t,e){return this.st=this.getNow(),this.ed=t,this.spd=e,this.ts=m(),this.df=this.ed-this.st,this}},this.ishwscroll){this.doc.translate={x:0,y:0,tx:"0px",ty:"0px"},O.hastranslate3d&&O.isios&&this.doc.css("-webkit-backface-visibility","hidden"),this.getScrollTop=function(t){if(!t){var e=v();if(e)return 16==e.length?-e[13]:-e[5];if(C.timerscroll&&C.timerscroll.bz)return C.timerscroll.bz.getNow()}return C.doc.translate.y},this.getScrollLeft=function(t){if(!t){var e=v();if(e)return 16==e.length?-e[12]:-e[4];if(C.timerscroll&&C.timerscroll.bh)return C.timerscroll.bh.getNow()}return C.doc.translate.x},this.notifyScrollEvent=function(t){var e=a.createEvent("UIEvents");e.initUIEvent("scroll",!1,!1,l,1),e.niceevent=!0,t.dispatchEvent(e)};var N=this.isrtlmode?1:-1;O.hastranslate3d&&S.enabletranslate3d?(this.setScrollTop=function(t,e){C.doc.translate.y=t,C.doc.translate.ty=-1*t+"px",C.doc.css(O.trstyle,"translate3d("+C.doc.translate.tx+","+C.doc.translate.ty+",0)"),e||C.notifyScrollEvent(C.win[0])},this.setScrollLeft=function(t,e){C.doc.translate.x=t,C.doc.translate.tx=t*N+"px",C.doc.css(O.trstyle,"translate3d("+C.doc.translate.tx+","+C.doc.translate.ty+",0)"),e||C.notifyScrollEvent(C.win[0])}):(this.setScrollTop=function(t,e){C.doc.translate.y=t,C.doc.translate.ty=-1*t+"px",C.doc.css(O.trstyle,"translate("+C.doc.translate.tx+","+C.doc.translate.ty+")"),e||C.notifyScrollEvent(C.win[0])},this.setScrollLeft=function(t,e){C.doc.translate.x=t,C.doc.translate.tx=t*N+"px",C.doc.css(O.trstyle,"translate("+C.doc.translate.tx+","+C.doc.translate.ty+")"),e||C.notifyScrollEvent(C.win[0])})}else this.getScrollTop=function(){return C.docscroll.scrollTop()},this.setScrollTop=function(t){C.docscroll.scrollTop(t)},this.getScrollLeft=function(){return C.hasreversehr?C.detected.ismozilla?C.page.maxw-Math.abs(C.docscroll.scrollLeft()):C.page.maxw-C.docscroll.scrollLeft():C.docscroll.scrollLeft()},this.setScrollLeft=function(t){return setTimeout(function(){if(C)return C.hasreversehr&&(t=C.detected.ismozilla?-(C.page.maxw-t):C.page.maxw-t),C.docscroll.scrollLeft(t)},1)};this.getTarget=function(t){return!!t&&(t.target?t.target:!!t.srcElement&&t.srcElement)},this.hasParent=function(t,e){if(!t)return!1;for(var i=t.target||t.srcElement||t||!1;i&&i.id!=e;)i=i.parentNode||!1;return!1!==i};var L={thin:1,medium:3,thick:5};this.getDocumentScrollOffset=function(){return{top:l.pageYOffset||a.documentElement.scrollTop,left:l.pageXOffset||a.documentElement.scrollLeft}},this.getOffset=function(){if(C.isfixed){var t=C.win.offset(),e=C.getDocumentScrollOffset();return t.top-=e.top,t.left-=e.left,t}var i=C.win.offset();if(!C.viewport)return i;var n=C.viewport.offset();return{top:i.top-n.top,left:i.left-n.left}},this.updateScrollBar=function(t){var e,i;if(C.ishwscroll)C.rail.css({height:C.win.innerHeight()-(S.railpadding.top+S.railpadding.bottom)}),C.railh&&C.railh.css({width:C.win.innerWidth()-(S.railpadding.left+S.railpadding.right)});else{var n=C.getOffset();if((e={top:n.top,left:n.left-(S.railpadding.left+S.railpadding.right)}).top+=b(C.win,"border-top-width",!0),e.left+=C.rail.align?C.win.outerWidth()-b(C.win,"border-right-width")-C.rail.width:b(C.win,"border-left-width"),(i=S.railoffset)&&(i.top&&(e.top+=i.top),i.left&&(e.left+=i.left)),C.railslocked||C.rail.css({top:e.top,left:e.left,height:(t?t.h:C.win.innerHeight())-(S.railpadding.top+S.railpadding.bottom)}),C.zoom&&C.zoom.css({top:e.top+1,left:1==C.rail.align?e.left-20:e.left+C.rail.width+4}),C.railh&&!C.railslocked){e={top:n.top,left:n.left},(i=S.railhoffset)&&(i.top&&(e.top+=i.top),i.left&&(e.left+=i.left));var o=C.railh.align?e.top+b(C.win,"border-top-width",!0)+C.win.innerHeight()-C.railh.height:e.top+b(C.win,"border-top-width",!0),r=e.left+b(C.win,"border-left-width");C.railh.css({top:o-(S.railpadding.top+S.railpadding.bottom),left:r,width:C.railh.width})}}},this.doRailClick=function(t,e,i){var n,o,r,s;C.railslocked||(C.cancelEvent(t),"pageY"in t||(t.pageX=t.clientX+a.documentElement.scrollLeft,t.pageY=t.clientY+a.documentElement.scrollTop),e?(n=i?C.doScrollLeft:C.doScrollTop,r=i?(t.pageX-C.railh.offset().left-C.cursorwidth/2)*C.scrollratio.x:(t.pageY-C.rail.offset().top-C.cursorheight/2)*C.scrollratio.y,C.unsynched("relativexy"),n(0|r)):(n=i?C.doScrollLeftBy:C.doScrollBy,r=i?C.scroll.x:C.scroll.y,s=i?t.pageX-C.railh.offset().left:t.pageY-C.rail.offset().top,o=i?C.view.w:C.view.h,n(r>=s?o:-o)))},C.newscrolly=C.newscrollx=0,C.hasanimationframe="requestAnimationFrame"in l,C.hascancelanimationframe="cancelAnimationFrame"in l,C.hasborderbox=!1,this.init=function(){if(C.saved.css=[],O.isoperamini)return!0;if(O.isandroid&&!("hidden"in a))return!0;S.emulatetouch=S.emulatetouch||S.touchbehavior,C.hasborderbox=l.getComputedStyle&&"border-box"===l.getComputedStyle(a.body)["box-sizing"];var t={"overflow-y":"hidden"};if((O.isie11||O.isie10)&&(t["-ms-overflow-style"]="none"),C.ishwscroll&&(this.doc.css(O.transitionstyle,O.prefixstyle+"transform 0ms ease-out"),O.transitionend&&C.bind(C.doc,O.transitionend,C.onScrollTransitionEnd,!1)),C.zindex="auto",C.ispage||"auto"!=S.zindex?C.zindex=S.zindex:C.zindex=function(){var t=C.win;if("zIndex"in t)return t.zIndex();for(;t.length>0;){if(9==t[0].nodeType)return!1;var e=t.css("zIndex");if(!isNaN(e)&&0!==e)return parseInt(e);t=t.parent()}return!1}()||"auto",!C.ispage&&"auto"!=C.zindex&&C.zindex>r&&(r=C.zindex),C.isie&&0===C.zindex&&"auto"==S.zindex&&(C.zindex="auto"),!C.ispage||!O.isieold){var o=C.docscroll;C.ispage&&(o=C.haswrapper?C.win:C.doc),C.css(o,t),C.ispage&&(O.isie11||O.isie)&&C.css(s("html"),t),!O.isios||C.ispage||C.haswrapper||C.css(E,{"-webkit-overflow-scrolling":"touch"});var u=s(a.createElement("div"));u.css({position:"relative",top:0,float:"right",width:S.cursorwidth,height:0,"background-color":S.cursorcolor,border:S.cursorborder,"background-clip":"padding-box","-webkit-border-radius":S.cursorborderradius,"-moz-border-radius":S.cursorborderradius,"border-radius":S.cursorborderradius}),u.addClass("nicescroll-cursors"),C.cursor=u;var d=s(a.createElement("div"));d.attr("id",C.id),d.addClass("nicescroll-rails nicescroll-rails-vr");var h,p,m=["left","right","top","bottom"];for(var g in m)p=m[g],(h=S.railpadding[p]||0)&&d.css("padding-"+p,h+"px");d.append(u),d.width=Math.max(parseFloat(S.cursorwidth),u.outerWidth()),d.css({width:d.width+"px",zIndex:C.zindex,background:S.background,cursor:"default"}),d.visibility=!0,d.scrollable=!0,d.align="left"==S.railalign?0:1,C.rail=d,C.rail.drag=!1;var v,y=!1;if(!S.boxzoom||C.ispage||O.isieold||(y=a.createElement("div"),C.bind(y,"click",C.doZoom),C.bind(y,"mouseenter",function(){C.zoom.css("opacity",S.cursoropacitymax)}),C.bind(y,"mouseleave",function(){C.zoom.css("opacity",S.cursoropacitymin)}),C.zoom=s(y),C.zoom.css({cursor:"pointer",zIndex:C.zindex,backgroundImage:"url("+S.scriptpath+"zoomico.png)",height:18,width:18,backgroundPosition:"0 0"}),S.dblclickzoom&&C.bind(C.win,"dblclick",C.doZoom),O.cantouch&&S.gesturezoom&&(C.ongesturezoom=function(t){return t.scale>1.5&&C.doZoomIn(t),t.scale<.8&&C.doZoomOut(t),C.cancelEvent(t)},C.bind(C.win,"gestureend",C.ongesturezoom))),C.railh=!1,S.horizrailenabled&&(C.css(o,{overflowX:"hidden"}),(u=s(a.createElement("div"))).css({position:"absolute",top:0,height:S.cursorwidth,width:0,backgroundColor:S.cursorcolor,border:S.cursorborder,backgroundClip:"padding-box","-webkit-border-radius":S.cursorborderradius,"-moz-border-radius":S.cursorborderradius,"border-radius":S.cursorborderradius}),O.isieold&&u.css("overflow","hidden"),u.addClass("nicescroll-cursors"),C.cursorh=u,(v=s(a.createElement("div"))).attr("id",C.id+"-hr"),v.addClass("nicescroll-rails nicescroll-rails-hr"),v.height=Math.max(parseFloat(S.cursorwidth),u.outerHeight()),v.css({height:v.height+"px",zIndex:C.zindex,background:S.background}),v.append(u),v.visibility=!0,v.scrollable=!0,v.align="top"==S.railvalign?0:1,C.railh=v,C.railh.drag=!1),C.ispage)d.css({position:"fixed",top:0,height:"100%"}),d.css(d.align?{right:0}:{left:0}),C.body.append(d),C.railh&&(v.css({position:"fixed",left:0,width:"100%"}),v.css(v.align?{bottom:0}:{top:0}),C.body.append(v));else{if(C.ishwscroll){"static"==C.win.css("position")&&C.css(C.win,{position:"relative"});var b="HTML"==C.win[0].nodeName?C.body:C.win;s(b).scrollTop(0).scrollLeft(0),C.zoom&&(C.zoom.css({position:"absolute",top:1,right:0,"margin-right":d.width+4}),b.append(C.zoom)),d.css({position:"absolute",top:0}),d.css(d.align?{right:0}:{left:0}),b.append(d),v&&(v.css({position:"absolute",left:0,bottom:0}),v.css(v.align?{bottom:0}:{top:0}),b.append(v))}else{C.isfixed="fixed"==C.win.css("position");var T=C.isfixed?"fixed":"absolute";C.isfixed||(C.viewport=C.getViewport(C.win[0])),C.viewport&&(C.body=C.viewport,/fixed|absolute/.test(C.viewport.css("position"))||C.css(C.viewport,{position:"relative"})),d.css({position:T}),C.zoom&&C.zoom.css({position:T}),C.updateScrollBar(),C.body.append(d),C.zoom&&C.body.append(C.zoom),C.railh&&(v.css({position:T}),C.body.append(v))}O.isios&&C.css(C.win,{"-webkit-tap-highlight-color":"rgba(0,0,0,0)","-webkit-touch-callout":"none"}),S.disableoutline&&(O.isie&&C.win.attr("hideFocus","true"),O.iswebkit&&C.win.css("outline","none"))}if(!1===S.autohidemode?(C.autohidedom=!1,C.rail.css({opacity:S.cursoropacitymax}),C.railh&&C.railh.css({opacity:S.cursoropacitymax})):!0===S.autohidemode||"leave"===S.autohidemode?(C.autohidedom=s().add(C.rail),O.isie8&&(C.autohidedom=C.autohidedom.add(C.cursor)),C.railh&&(C.autohidedom=C.autohidedom.add(C.railh)),C.railh&&O.isie8&&(C.autohidedom=C.autohidedom.add(C.cursorh))):"scroll"==S.autohidemode?(C.autohidedom=s().add(C.rail),C.railh&&(C.autohidedom=C.autohidedom.add(C.railh))):"cursor"==S.autohidemode?(C.autohidedom=s().add(C.cursor),C.railh&&(C.autohidedom=C.autohidedom.add(C.cursorh))):"hidden"==S.autohidemode&&(C.autohidedom=!1,C.hide(),C.railslocked=!1),O.cantouch||C.istouchcapable||S.emulatetouch||O.hasmstouch){C.scrollmom=new w(C),C.ontouchstart=function(t){if(C.locked)return!1;if(t.pointerType&&("mouse"===t.pointerType||t.pointerType===t.MSPOINTER_TYPE_MOUSE))return!1;if(C.hasmoving=!1,C.scrollmom.timer&&(C.triggerScrollEnd(),C.scrollmom.stop()),!C.railslocked){var e=C.getTarget(t);if(e&&/INPUT/i.test(e.nodeName)&&/range/i.test(e.type))return C.stopPropagation(t);var i="mousedown"===t.type;if(!("clientX"in t)&&"changedTouches"in t&&(t.clientX=t.changedTouches[0].clientX,t.clientY=t.changedTouches[0].clientY),C.forcescreen){var n=t;(t={original:t.original?t.original:t}).clientX=n.screenX,t.clientY=n.screenY}if(C.rail.drag={x:t.clientX,y:t.clientY,sx:C.scroll.x,sy:C.scroll.y,st:C.getScrollTop(),sl:C.getScrollLeft(),pt:2,dl:!1,tg:e},C.ispage||!S.directionlockdeadzone)C.rail.drag.dl="f";else{var o={w:c.width(),h:c.height()},r=C.getContentSize(),a=r.h-o.h,l=r.w-o.w;C.rail.scrollable&&!C.railh.scrollable?C.rail.drag.ck=a>0&&"v":!C.rail.scrollable&&C.railh.scrollable?C.rail.drag.ck=l>0&&"h":C.rail.drag.ck=!1}if(S.emulatetouch&&C.isiframe&&O.isie){var u=C.win.position();C.rail.drag.x+=u.left,C.rail.drag.y+=u.top}if(C.hasmoving=!1,C.lastmouseup=!1,C.scrollmom.reset(t.clientX,t.clientY),e&&i){if(!/INPUT|SELECT|BUTTON|TEXTAREA/i.test(e.nodeName))return O.hasmousecapture&&e.setCapture(),S.emulatetouch?(e.onclick&&!e._onclick&&(e._onclick=e.onclick,e.onclick=function(t){if(C.hasmoving)return!1;e._onclick.call(this,t)}),C.cancelEvent(t)):C.stopPropagation(t);/SUBMIT|CANCEL|BUTTON/i.test(s(e).attr("type"))&&(C.preventclick={tg:e,click:!1})}}},C.ontouchend=function(t){if(!C.rail.drag)return!0;if(2==C.rail.drag.pt){if(t.pointerType&&("mouse"===t.pointerType||t.pointerType===t.MSPOINTER_TYPE_MOUSE))return!1;C.rail.drag=!1;var e="mouseup"===t.type;if(C.hasmoving&&(C.scrollmom.doMomentum(),C.lastmouseup=!0,C.hideCursor(),O.hasmousecapture&&a.releaseCapture(),e))return C.cancelEvent(t)}else if(1==C.rail.drag.pt)return C.onmouseup(t)};var x=S.emulatetouch&&C.isiframe&&!O.hasmousecapture,_=.3*S.directionlockdeadzone|0;C.ontouchmove=function(t,e){if(!C.rail.drag)return!0;if(t.targetTouches&&S.preventmultitouchscrolling&&t.targetTouches.length>1)return!0;if(t.pointerType&&("mouse"===t.pointerType||t.pointerType===t.MSPOINTER_TYPE_MOUSE))return!0;if(2==C.rail.drag.pt){var i,n;if("changedTouches"in t&&(t.clientX=t.changedTouches[0].clientX,t.clientY=t.changedTouches[0].clientY),n=i=0,x&&!e){var o=C.win.position();n=-o.left,i=-o.top}var r=t.clientY+i,s=r-C.rail.drag.y,l=t.clientX+n,c=l-C.rail.drag.x,u=C.rail.drag.st-s;if(C.ishwscroll&&S.bouncescroll)u<0?u=Math.round(u/2):u>C.page.maxh&&(u=C.page.maxh+Math.round((u-C.page.maxh)/2));else if(u<0?(u=0,r=0):u>C.page.maxh&&(u=C.page.maxh,r=0),0===r&&!C.hasmoving)return C.ispage||(C.rail.drag=!1),!0;var d=C.getScrollLeft();if(C.railh&&C.railh.scrollable&&(d=C.isrtlmode?c-C.rail.drag.sl:C.rail.drag.sl-c,C.ishwscroll&&S.bouncescroll?d<0?d=Math.round(d/2):d>C.page.maxw&&(d=C.page.maxw+Math.round((d-C.page.maxw)/2)):(d<0&&(d=0,l=0),d>C.page.maxw&&(d=C.page.maxw,l=0))),!C.hasmoving){if(C.rail.drag.y===t.clientY&&C.rail.drag.x===t.clientX)return C.cancelEvent(t);var h=Math.abs(s),p=Math.abs(c),f=S.directionlockdeadzone;if(C.rail.drag.ck?"v"==C.rail.drag.ck?p>f&&h<=_?C.rail.drag=!1:h>f&&(C.rail.drag.dl="v"):"h"==C.rail.drag.ck&&(h>f&&p<=_?C.rail.drag=!1:p>f&&(C.rail.drag.dl="h")):h>f&&p>f?C.rail.drag.dl="f":h>f?C.rail.drag.dl=p>_?"f":"v":p>f&&(C.rail.drag.dl=h>_?"f":"h"),!C.rail.drag.dl)return C.cancelEvent(t);C.triggerScrollStart(t.clientX,t.clientY,0,0,0),C.hasmoving=!0}return C.preventclick&&!C.preventclick.click&&(C.preventclick.click=C.preventclick.tg.onclick||!1,C.preventclick.tg.onclick=C.onpreventclick),C.rail.drag.dl&&("v"==C.rail.drag.dl?d=C.rail.drag.sl:"h"==C.rail.drag.dl&&(u=C.rail.drag.st)),C.synched("touchmove",function(){C.rail.drag&&2==C.rail.drag.pt&&(C.prepareTransition&&C.resetTransition(),C.rail.scrollable&&C.setScrollTop(u),C.scrollmom.update(l,r),C.railh&&C.railh.scrollable?(C.setScrollLeft(d),C.showCursor(u,d)):C.showCursor(u),O.isie10&&a.selection.clear())}),C.cancelEvent(t)}return 1==C.rail.drag.pt?C.onmousemove(t):void 0},C.ontouchstartCursor=function(t,e){if(!C.rail.drag||3==C.rail.drag.pt){if(C.locked)return C.cancelEvent(t);C.cancelScroll(),C.rail.drag={x:t.touches[0].clientX,y:t.touches[0].clientY,sx:C.scroll.x,sy:C.scroll.y,pt:3,hr:!!e};var i=C.getTarget(t);return!C.ispage&&O.hasmousecapture&&i.setCapture(),C.isiframe&&!O.hasmousecapture&&(C.saved.csspointerevents=C.doc.css("pointer-events"),C.css(C.doc,{"pointer-events":"none"})),C.cancelEvent(t)}},C.ontouchendCursor=function(t){if(C.rail.drag){if(O.hasmousecapture&&a.releaseCapture(),C.isiframe&&!O.hasmousecapture&&C.doc.css("pointer-events",C.saved.csspointerevents),3!=C.rail.drag.pt)return;return C.rail.drag=!1,C.cancelEvent(t)}},C.ontouchmoveCursor=function(t){if(C.rail.drag){if(3!=C.rail.drag.pt)return;if(C.cursorfreezed=!0,C.rail.drag.hr){C.scroll.x=C.rail.drag.sx+(t.touches[0].clientX-C.rail.drag.x),C.scroll.x<0&&(C.scroll.x=0);var e=C.scrollvaluemaxw;C.scroll.x>e&&(C.scroll.x=e)}else{C.scroll.y=C.rail.drag.sy+(t.touches[0].clientY-C.rail.drag.y),C.scroll.y<0&&(C.scroll.y=0);var i=C.scrollvaluemax;C.scroll.y>i&&(C.scroll.y=i)}return C.synched("touchmove",function(){C.rail.drag&&3==C.rail.drag.pt&&(C.showCursor(),C.rail.drag.hr?C.doScrollLeft(Math.round(C.scroll.x*C.scrollratio.x),S.cursordragspeed):C.doScrollTop(Math.round(C.scroll.y*C.scrollratio.y),S.cursordragspeed))}),C.cancelEvent(t)}}}if(C.onmousedown=function(t,e){if(!C.rail.drag||1==C.rail.drag.pt){if(C.railslocked)return C.cancelEvent(t);C.cancelScroll(),C.rail.drag={x:t.clientX,y:t.clientY,sx:C.scroll.x,sy:C.scroll.y,pt:1,hr:e||!1};var i=C.getTarget(t);return O.hasmousecapture&&i.setCapture(),C.isiframe&&!O.hasmousecapture&&(C.saved.csspointerevents=C.doc.css("pointer-events"),C.css(C.doc,{"pointer-events":"none"})),C.hasmoving=!1,C.cancelEvent(t)}},C.onmouseup=function(t){if(C.rail.drag)return 1!=C.rail.drag.pt||(O.hasmousecapture&&a.releaseCapture(),C.isiframe&&!O.hasmousecapture&&C.doc.css("pointer-events",C.saved.csspointerevents),C.rail.drag=!1,C.cursorfreezed=!1,C.hasmoving&&C.triggerScrollEnd(),C.cancelEvent(t))},C.onmousemove=function(t){if(C.rail.drag){if(1!==C.rail.drag.pt)return;if(O.ischrome&&0===t.which)return C.onmouseup(t);if(C.cursorfreezed=!0,C.hasmoving||C.triggerScrollStart(t.clientX,t.clientY,0,0,0),C.hasmoving=!0,C.rail.drag.hr){C.scroll.x=C.rail.drag.sx+(t.clientX-C.rail.drag.x),C.scroll.x<0&&(C.scroll.x=0);var e=C.scrollvaluemaxw;C.scroll.x>e&&(C.scroll.x=e)}else{C.scroll.y=C.rail.drag.sy+(t.clientY-C.rail.drag.y),C.scroll.y<0&&(C.scroll.y=0);var i=C.scrollvaluemax;C.scroll.y>i&&(C.scroll.y=i)}return C.synched("mousemove",function(){C.cursorfreezed&&(C.showCursor(),C.rail.drag.hr?C.scrollLeft(Math.round(C.scroll.x*C.scrollratio.x)):C.scrollTop(Math.round(C.scroll.y*C.scrollratio.y)))}),C.cancelEvent(t)}C.checkarea=0},O.cantouch||S.emulatetouch)C.onpreventclick=function(t){if(C.preventclick)return C.preventclick.tg.onclick=C.preventclick.click,C.preventclick=!1,C.cancelEvent(t)},C.onclick=!O.isios&&function(t){return!C.lastmouseup||(C.lastmouseup=!1,C.cancelEvent(t))},S.grabcursorenabled&&O.cursorgrabvalue&&(C.css(C.ispage?C.doc:C.win,{cursor:O.cursorgrabvalue}),C.css(C.rail,{cursor:O.cursorgrabvalue}));else{var D=function(t){if(C.selectiondrag){if(t){var e=C.win.outerHeight(),i=t.pageY-C.selectiondrag.top;i>0&&i<e&&(i=0),i>=e&&(i-=e),C.selectiondrag.df=i}if(0!==C.selectiondrag.df){var n=-2*C.selectiondrag.df/6|0;C.doScrollBy(n),C.debounced("doselectionscroll",function(){D()},50)}}};C.hasTextSelected="getSelection"in a?function(){return a.getSelection().rangeCount>0}:"selection"in a?function(){return"None"!=a.selection.type}:function(){return!1},C.onselectionstart=function(t){C.ispage||(C.selectiondrag=C.win.offset())},C.onselectionend=function(t){C.selectiondrag=!1},C.onselectiondrag=function(t){C.selectiondrag&&C.hasTextSelected()&&C.debounced("selectionscroll",function(){D(t)},250)}}if(O.hasw3ctouch?(C.css(C.ispage?s("html"):C.win,{"touch-action":"none"}),C.css(C.rail,{"touch-action":"none"}),C.css(C.cursor,{"touch-action":"none"}),C.bind(C.win,"pointerdown",C.ontouchstart),C.bind(a,"pointerup",C.ontouchend),C.delegate(a,"pointermove",C.ontouchmove)):O.hasmstouch?(C.css(C.ispage?s("html"):C.win,{"-ms-touch-action":"none"}),C.css(C.rail,{"-ms-touch-action":"none"}),C.css(C.cursor,{"-ms-touch-action":"none"}),C.bind(C.win,"MSPointerDown",C.ontouchstart),C.bind(a,"MSPointerUp",C.ontouchend),C.delegate(a,"MSPointerMove",C.ontouchmove),C.bind(C.cursor,"MSGestureHold",function(t){t.preventDefault()}),C.bind(C.cursor,"contextmenu",function(t){t.preventDefault()})):O.cantouch&&(C.bind(C.win,"touchstart",C.ontouchstart,!1,!0),C.bind(a,"touchend",C.ontouchend,!1,!0),C.bind(a,"touchcancel",C.ontouchend,!1,!0),C.delegate(a,"touchmove",C.ontouchmove,!1,!0)),S.emulatetouch&&(C.bind(C.win,"mousedown",C.ontouchstart,!1,!0),C.bind(a,"mouseup",C.ontouchend,!1,!0),C.bind(a,"mousemove",C.ontouchmove,!1,!0)),(S.cursordragontouch||!O.cantouch&&!S.emulatetouch)&&(C.rail.css({cursor:"default"}),C.railh&&C.railh.css({cursor:"default"}),C.jqbind(C.rail,"mouseenter",function(){if(!C.ispage&&!C.win.is(":visible"))return!1;C.canshowonmouseevent&&C.showCursor(),C.rail.active=!0}),C.jqbind(C.rail,"mouseleave",function(){C.rail.active=!1,C.rail.drag||C.hideCursor()}),S.sensitiverail&&(C.bind(C.rail,"click",function(t){C.doRailClick(t,!1,!1)}),C.bind(C.rail,"dblclick",function(t){C.doRailClick(t,!0,!1)}),C.bind(C.cursor,"click",function(t){C.cancelEvent(t)}),C.bind(C.cursor,"dblclick",function(t){C.cancelEvent(t)})),C.railh&&(C.jqbind(C.railh,"mouseenter",function(){if(!C.ispage&&!C.win.is(":visible"))return!1;C.canshowonmouseevent&&C.showCursor(),C.rail.active=!0}),C.jqbind(C.railh,"mouseleave",function(){C.rail.active=!1,C.rail.drag||C.hideCursor()}),S.sensitiverail&&(C.bind(C.railh,"click",function(t){C.doRailClick(t,!1,!0)}),C.bind(C.railh,"dblclick",function(t){C.doRailClick(t,!0,!0)}),C.bind(C.cursorh,"click",function(t){C.cancelEvent(t)}),C.bind(C.cursorh,"dblclick",function(t){C.cancelEvent(t)})))),S.cursordragontouch&&(this.istouchcapable||O.cantouch)&&(C.bind(C.cursor,"touchstart",C.ontouchstartCursor),C.bind(C.cursor,"touchmove",C.ontouchmoveCursor),C.bind(C.cursor,"touchend",C.ontouchendCursor),C.cursorh&&C.bind(C.cursorh,"touchstart",function(t){C.ontouchstartCursor(t,!0)}),C.cursorh&&C.bind(C.cursorh,"touchmove",C.ontouchmoveCursor),C.cursorh&&C.bind(C.cursorh,"touchend",C.ontouchendCursor)),S.emulatetouch||O.isandroid||O.isios?(C.bind(O.hasmousecapture?C.win:a,"mouseup",C.ontouchend),C.onclick&&C.bind(a,"click",C.onclick),S.cursordragontouch?(C.bind(C.cursor,"mousedown",C.onmousedown),C.bind(C.cursor,"mouseup",C.onmouseup),C.cursorh&&C.bind(C.cursorh,"mousedown",function(t){C.onmousedown(t,!0)}),C.cursorh&&C.bind(C.cursorh,"mouseup",C.onmouseup)):(C.bind(C.rail,"mousedown",function(t){t.preventDefault()}),C.railh&&C.bind(C.railh,"mousedown",function(t){t.preventDefault()}))):(C.bind(O.hasmousecapture?C.win:a,"mouseup",C.onmouseup),C.bind(a,"mousemove",C.onmousemove),C.onclick&&C.bind(a,"click",C.onclick),C.bind(C.cursor,"mousedown",C.onmousedown),C.bind(C.cursor,"mouseup",C.onmouseup),C.railh&&(C.bind(C.cursorh,"mousedown",function(t){C.onmousedown(t,!0)}),C.bind(C.cursorh,"mouseup",C.onmouseup)),!C.ispage&&S.enablescrollonselection&&(C.bind(C.win[0],"mousedown",C.onselectionstart),C.bind(a,"mouseup",C.onselectionend),C.bind(C.cursor,"mouseup",C.onselectionend),C.cursorh&&C.bind(C.cursorh,"mouseup",C.onselectionend),C.bind(a,"mousemove",C.onselectiondrag)),C.zoom&&(C.jqbind(C.zoom,"mouseenter",function(){C.canshowonmouseevent&&C.showCursor(),C.rail.active=!0}),C.jqbind(C.zoom,"mouseleave",function(){C.rail.active=!1,C.rail.drag||C.hideCursor()}))),S.enablemousewheel&&(C.isiframe||C.mousewheel(O.isie&&C.ispage?a:C.win,C.onmousewheel),C.mousewheel(C.rail,C.onmousewheel),C.railh&&C.mousewheel(C.railh,C.onmousewheelhr)),C.ispage||O.cantouch||/HTML|^BODY/.test(C.win[0].nodeName)||(C.win.attr("tabindex")||C.win.attr({tabindex:++n}),C.bind(C.win,"focus",function(t){e=C.getTarget(t).id||C.getTarget(t)||!1,C.hasfocus=!0,C.canshowonmouseevent&&C.noticeCursor()}),C.bind(C.win,"blur",function(t){e=!1,C.hasfocus=!1}),C.bind(C.win,"mouseenter",function(t){i=C.getTarget(t).id||C.getTarget(t)||!1,C.hasmousefocus=!0,C.canshowonmouseevent&&C.noticeCursor()}),C.bind(C.win,"mouseleave",function(t){i=!1,C.hasmousefocus=!1,C.rail.drag||C.hideCursor()})),C.onkeypress=function(t){if(C.railslocked&&0===C.page.maxh)return!0;t=t||l.event;var n=C.getTarget(t);if(n&&/INPUT|TEXTAREA|SELECT|OPTION/.test(n.nodeName)&&(!n.getAttribute("type")&&!n.type||!/submit|button|cancel/i.tp))return!0;if(s(n).attr("contenteditable"))return!0;if(C.hasfocus||C.hasmousefocus&&!e||C.ispage&&!e&&!i){var o=t.keyCode;if(C.railslocked&&27!=o)return C.cancelEvent(t);var r=t.ctrlKey||!1,a=t.shiftKey||!1,c=!1;switch(o){case 38:case 63233:C.doScrollBy(72),c=!0;break;case 40:case 63235:C.doScrollBy(-72),c=!0;break;case 37:case 63232:C.railh&&(r?C.doScrollLeft(0):C.doScrollLeftBy(72),c=!0);break;case 39:case 63234:C.railh&&(r?C.doScrollLeft(C.page.maxw):C.doScrollLeftBy(-72),c=!0);break;case 33:case 63276:C.doScrollBy(C.view.h),c=!0;break;case 34:case 63277:C.doScrollBy(-C.view.h),c=!0;break;case 36:case 63273:C.railh&&r?C.doScrollPos(0,0):C.doScrollTo(0),c=!0;break;case 35:case 63275:C.railh&&r?C.doScrollPos(C.page.maxw,C.page.maxh):C.doScrollTo(C.page.maxh),c=!0;break;case 32:S.spacebarenabled&&(a?C.doScrollBy(C.view.h):C.doScrollBy(-C.view.h),c=!0);break;case 27:C.zoomactive&&(C.doZoom(),c=!0)}if(c)return C.cancelEvent(t)}},S.enablekeyboard&&C.bind(a,O.isopera&&!O.isopera12?"keypress":"keydown",C.onkeypress),C.bind(a,"keydown",function(t){t.ctrlKey&&(C.wheelprevented=!0)}),C.bind(a,"keyup",function(t){t.ctrlKey||(C.wheelprevented=!1)}),C.bind(l,"blur",function(t){C.wheelprevented=!1}),C.bind(l,"resize",C.onscreenresize),C.bind(l,"orientationchange",C.onscreenresize),C.bind(l,"load",C.lazyResize),O.ischrome&&!C.ispage&&!C.haswrapper){var k=C.win.attr("style"),A=parseFloat(C.win.css("width"))+1;C.win.css("width",A),C.synched("chromefix",function(){C.win.attr("style",k)})}if(C.onAttributeChange=function(t){C.lazyResize(C.isieold?250:30)},S.enableobserver&&(C.isie11||!1===f||(C.observerbody=new f(function(t){if(t.forEach(function(t){if("attributes"==t.type)return E.hasClass("modal-open")&&E.hasClass("modal-dialog")&&!s.contains(s(".modal-dialog")[0],C.doc[0])?C.hide():C.show()}),C.me.clientWidth!=C.page.width||C.me.clientHeight!=C.page.height)return C.lazyResize(30)}),C.observerbody.observe(a.body,{childList:!0,subtree:!0,characterData:!1,attributes:!0,attributeFilter:["class"]})),!C.ispage&&!C.haswrapper)){var I=C.win[0];!1!==f?(C.observer=new f(function(t){t.forEach(C.onAttributeChange)}),C.observer.observe(I,{childList:!0,characterData:!1,attributes:!0,subtree:!1}),C.observerremover=new f(function(t){t.forEach(function(t){if(t.removedNodes.length>0)for(var e in t.removedNodes)if(C&&t.removedNodes[e]===I)return C.remove()})}),C.observerremover.observe(I.parentNode,{childList:!0,characterData:!1,attributes:!1,subtree:!1})):(C.bind(I,O.isie&&!O.isie9?"propertychange":"DOMAttrModified",C.onAttributeChange),O.isie9&&I.attachEvent("onpropertychange",C.onAttributeChange),C.bind(I,"DOMNodeRemoved",function(t){t.target===I&&C.remove()}))}!C.ispage&&S.boxzoom&&C.bind(l,"resize",C.resizeZoom),C.istextarea&&(C.bind(C.win,"keydown",C.lazyResize),C.bind(C.win,"mouseup",C.lazyResize)),C.lazyResize(30)}if("IFRAME"==this.doc[0].nodeName){var N=function(){var e;C.iframexd=!1;try{(e="contentDocument"in this?this.contentDocument:this.contentWindow._doc).domain}catch(t){C.iframexd=!0,e=!1}if(C.iframexd)return"console"in l&&console.log("NiceScroll error: policy restriced iframe"),!0;if(C.forcescreen=!0,C.isiframe&&(C.iframe={doc:s(e),html:C.doc.contents().find("html")[0],body:C.doc.contents().find("body")[0]},C.getContentSize=function(){return{w:Math.max(C.iframe.html.scrollWidth,C.iframe.body.scrollWidth),h:Math.max(C.iframe.html.scrollHeight,C.iframe.body.scrollHeight)}},C.docscroll=s(C.iframe.body)),!O.isios&&S.iframeautoresize&&!C.isiframe){C.win.scrollTop(0),C.doc.height("");var i=Math.max(e.getElementsByTagName("html")[0].scrollHeight,e.body.scrollHeight);C.doc.height(i)}C.lazyResize(30),C.css(s(C.iframe.body),t),O.isios&&C.haswrapper&&C.css(s(e.body),{"-webkit-transform":"translate3d(0,0,0)"}),"contentWindow"in this?C.bind(this.contentWindow,"scroll",C.onscroll):C.bind(e,"scroll",C.onscroll),S.enablemousewheel&&C.mousewheel(e,C.onmousewheel),S.enablekeyboard&&C.bind(e,O.isopera?"keypress":"keydown",C.onkeypress),O.cantouch?(C.bind(e,"touchstart",C.ontouchstart),C.bind(e,"touchmove",C.ontouchmove)):S.emulatetouch&&(C.bind(e,"mousedown",C.ontouchstart),C.bind(e,"mousemove",function(t){return C.ontouchmove(t,!0)}),S.grabcursorenabled&&O.cursorgrabvalue&&C.css(s(e.body),{cursor:O.cursorgrabvalue})),C.bind(e,"mouseup",C.ontouchend),C.zoom&&(S.dblclickzoom&&C.bind(e,"dblclick",C.doZoom),C.ongesturezoom&&C.bind(e,"gestureend",C.ongesturezoom))};this.doc[0].readyState&&"complete"===this.doc[0].readyState&&setTimeout(function(){N.call(C.doc[0],!1)},500),C.bind(this.doc,"load",N)}},this.showCursor=function(t,e){if(C.cursortimeout&&(clearTimeout(C.cursortimeout),C.cursortimeout=0),C.rail){if(C.autohidedom&&(C.autohidedom.stop().css({opacity:S.cursoropacitymax}),C.cursoractive=!0),C.rail.drag&&1==C.rail.drag.pt||(void 0!==t&&!1!==t&&(C.scroll.y=t/C.scrollratio.y|0),void 0!==e&&(C.scroll.x=e/C.scrollratio.x|0)),C.cursor.css({height:C.cursorheight,top:C.scroll.y}),C.cursorh){var i=C.hasreversehr?C.scrollvaluemaxw-C.scroll.x:C.scroll.x;C.cursorh.css({width:C.cursorwidth,left:!C.rail.align&&C.rail.visibility?i+C.rail.width:i}),C.cursoractive=!0}C.zoom&&C.zoom.stop().css({opacity:S.cursoropacitymax})}},this.hideCursor=function(t){C.cursortimeout||C.rail&&C.autohidedom&&(C.hasmousefocus&&"leave"===S.autohidemode||(C.cursortimeout=setTimeout(function(){C.rail.active&&C.showonmouseevent||(C.autohidedom.stop().animate({opacity:S.cursoropacitymin}),C.zoom&&C.zoom.stop().animate({opacity:S.cursoropacitymin}),C.cursoractive=!1),C.cursortimeout=0},t||S.hidecursordelay)))},this.noticeCursor=function(t,e,i){C.showCursor(e,i),C.rail.active||C.hideCursor(t)},this.getContentSize=C.ispage?function(){return{w:Math.max(a.body.scrollWidth,a.documentElement.scrollWidth),h:Math.max(a.body.scrollHeight,a.documentElement.scrollHeight)}}:C.haswrapper?function(){return{w:C.doc[0].offsetWidth,h:C.doc[0].offsetHeight}}:function(){return{w:C.docscroll[0].scrollWidth,h:C.docscroll[0].scrollHeight}},this.onResize=function(t,e){if(!C||!C.win)return!1;var i=C.page.maxh,n=C.page.maxw,o=C.view.h,r=C.view.w;if(C.view={w:C.ispage?C.win.width():C.win[0].clientWidth,h:C.ispage?C.win.height():C.win[0].clientHeight},C.page=e||C.getContentSize(),C.page.maxh=Math.max(0,C.page.h-C.view.h),C.page.maxw=Math.max(0,C.page.w-C.view.w),C.page.maxh==i&&C.page.maxw==n&&C.view.w==r&&C.view.h==o){if(C.ispage)return C;var s=C.win.offset();if(C.lastposition){var a=C.lastposition;if(a.top==s.top&&a.left==s.left)return C}C.lastposition=s}return 0===C.page.maxh?(C.hideRail(),C.scrollvaluemax=0,C.scroll.y=0,C.scrollratio.y=0,C.cursorheight=0,C.setScrollTop(0),C.rail&&(C.rail.scrollable=!1)):(C.page.maxh-=S.railpadding.top+S.railpadding.bottom,C.rail.scrollable=!0),0===C.page.maxw?(C.hideRailHr(),C.scrollvaluemaxw=0,C.scroll.x=0,C.scrollratio.x=0,C.cursorwidth=0,C.setScrollLeft(0),C.railh&&(C.railh.scrollable=!1)):(C.page.maxw-=S.railpadding.left+S.railpadding.right,C.railh&&(C.railh.scrollable=S.horizrailenabled)),C.railslocked=C.locked||0===C.page.maxh&&0===C.page.maxw,C.railslocked?(C.ispage||C.updateScrollBar(C.view),!1):(C.hidden||(C.rail.visibility||C.showRail(),C.railh&&!C.railh.visibility&&C.showRailHr()),C.istextarea&&C.win.css("resize")&&"none"!=C.win.css("resize")&&(C.view.h-=20),C.cursorheight=Math.min(C.view.h,Math.round(C.view.h*(C.view.h/C.page.h))),C.cursorheight=S.cursorfixedheight?S.cursorfixedheight:Math.max(S.cursorminheight,C.cursorheight),C.cursorwidth=Math.min(C.view.w,Math.round(C.view.w*(C.view.w/C.page.w))),C.cursorwidth=S.cursorfixedheight?S.cursorfixedheight:Math.max(S.cursorminheight,C.cursorwidth),C.scrollvaluemax=C.view.h-C.cursorheight-(S.railpadding.top+S.railpadding.bottom),C.hasborderbox||(C.scrollvaluemax-=C.cursor[0].offsetHeight-C.cursor[0].clientHeight),C.railh&&(C.railh.width=C.page.maxh>0?C.view.w-C.rail.width:C.view.w,C.scrollvaluemaxw=C.railh.width-C.cursorwidth-(S.railpadding.left+S.railpadding.right)),C.ispage||C.updateScrollBar(C.view),C.scrollratio={x:C.page.maxw/C.scrollvaluemaxw,y:C.page.maxh/C.scrollvaluemax},C.getScrollTop()>C.page.maxh?C.doScrollTop(C.page.maxh):(C.scroll.y=C.getScrollTop()/C.scrollratio.y|0,C.scroll.x=C.getScrollLeft()/C.scrollratio.x|0,C.cursoractive&&C.noticeCursor()),C.scroll.y&&0===C.getScrollTop()&&C.doScrollTo(C.scroll.y*C.scrollratio.y|0),C)},this.resize=C.onResize;var M=0;this.onscreenresize=function(t){clearTimeout(M);var e=!C.ispage&&!C.haswrapper;e&&C.hideRails(),M=setTimeout(function(){C&&(e&&C.showRails(),C.resize()),M=0},120)},this.lazyResize=function(t){return clearTimeout(M),t=isNaN(t)?240:t,M=setTimeout(function(){C&&C.resize(),M=0},t),C},this.jqbind=function(t,e,i){C.events.push({e:t,n:e,f:i,q:!0}),s(t).on(e,i)},this.mousewheel=function(t,e,i){var n="jquery"in t?t[0]:t;if("onwheel"in a.createElement("div"))C._bind(n,"wheel",e,i||!1);else{var o=void 0!==a.onmousewheel?"mousewheel":"DOMMouseScroll";T(n,o,e,i||!1),"DOMMouseScroll"==o&&T(n,"MozMousePixelScroll",e,i||!1)}};var $=!1;if(O.haseventlistener){try{var P=Object.defineProperty({},"passive",{get:function(){$=!0}});l.addEventListener("test",null,P)}catch(t){}this.stopPropagation=function(t){return!!t&&((t=t.original?t.original:t).stopPropagation(),!1)},this.cancelEvent=function(t){return t.cancelable&&t.preventDefault(),t.stopImmediatePropagation(),t.preventManipulation&&t.preventManipulation(),!1}}else Event.prototype.preventDefault=function(){this.returnValue=!1},Event.prototype.stopPropagation=function(){this.cancelBubble=!0},l.constructor.prototype.addEventListener=a.constructor.prototype.addEventListener=Element.prototype.addEventListener=function(t,e,i){this.attachEvent("on"+t,e)},l.constructor.prototype.removeEventListener=a.constructor.prototype.removeEventListener=Element.prototype.removeEventListener=function(t,e,i){this.detachEvent("on"+t,e)},this.cancelEvent=function(t){return(t=t||l.event)&&(t.cancelBubble=!0,t.cancel=!0,t.returnValue=!1),!1},this.stopPropagation=function(t){return(t=t||l.event)&&(t.cancelBubble=!0),!1};this.delegate=function(t,e,i,n,o){var r=u[e]||!1;r||(r={a:[],l:[],f:function(t){for(var e=r.l,i=!1,n=e.length-1;n>=0;n--)if(!1===(i=e[n].call(t.target,t)))return!1;return i}},C.bind(t,e,r.f,n,o),u[e]=r),C.ispage?(r.a=[C.id].concat(r.a),r.l=[i].concat(r.l)):(r.a.push(C.id),r.l.push(i))},this.undelegate=function(t,e,i,n,o){var r=u[e]||!1;if(r&&r.l)for(var s=0,a=r.l.length;s<a;s++)r.a[s]===C.id&&(r.a.splice(s),r.l.splice(s),0===r.a.length&&(C._unbind(t,e,r.l.f),u[e]=null))},this.bind=function(t,e,i,n,o){var r="jquery"in t?t[0]:t;C._bind(r,e,i,n||!1,o||!1)},this._bind=function(t,e,i,n,o){C.events.push({e:t,n:e,f:i,b:n,q:!1}),$&&o?t.addEventListener(e,i,{passive:!1,capture:n}):t.addEventListener(e,i,n||!1)},this._unbind=function(t,e,i,n){u[e]?C.undelegate(t,e,i,n):t.removeEventListener(e,i,n)},this.unbindAll=function(){for(var t=0;t<C.events.length;t++){var e=C.events[t];e.q?e.e.unbind(e.n,e.f):C._unbind(e.e,e.n,e.f,e.b)}},this.showRails=function(){return C.showRail().showRailHr()},this.showRail=function(){return 0===C.page.maxh||!C.ispage&&"none"==C.win.css("display")||(C.rail.visibility=!0,C.rail.css("display","block")),C},this.showRailHr=function(){return C.railh&&(0===C.page.maxw||!C.ispage&&"none"==C.win.css("display")||(C.railh.visibility=!0,C.railh.css("display","block"))),C},this.hideRails=function(){return C.hideRail().hideRailHr()},this.hideRail=function(){return C.rail.visibility=!1,C.rail.css("display","none"),C},this.hideRailHr=function(){return C.railh&&(C.railh.visibility=!1,C.railh.css("display","none")),C},this.show=function(){return C.hidden=!1,C.railslocked=!1,C.showRails()},this.hide=function(){return C.hidden=!0,C.railslocked=!0,C.hideRails()},this.toggle=function(){return C.hidden?C.show():C.hide()},this.remove=function(){for(var t in C.stop(),C.cursortimeout&&clearTimeout(C.cursortimeout),C.delaylist)C.delaylist[t]&&h(C.delaylist[t].h);C.doZoomOut(),C.unbindAll(),O.isie9&&C.win[0].detachEvent("onpropertychange",C.onAttributeChange),!1!==C.observer&&C.observer.disconnect(),!1!==C.observerremover&&C.observerremover.disconnect(),!1!==C.observerbody&&C.observerbody.disconnect(),C.events=null,C.cursor&&C.cursor.remove(),C.cursorh&&C.cursorh.remove(),C.rail&&C.rail.remove(),C.railh&&C.railh.remove(),C.zoom&&C.zoom.remove();for(var e=0;e<C.saved.css.length;e++){var i=C.saved.css[e];i[0].css(i[1],void 0===i[2]?"":i[2])}C.saved=!1,C.me.data("__nicescroll","");var n=s.nicescroll;for(var o in n.each(function(t){if(this&&this.id===C.id){delete n[t];for(var e=++t;e<n.length;e++,t++)n[t]=n[e];--n.length&&delete n[n.length]}}),C)C[o]=null,delete C[o];C=null},this.scrollstart=function(t){return this.onscrollstart=t,C},this.scrollend=function(t){return this.onscrollend=t,C},this.scrollcancel=function(t){return this.onscrollcancel=t,C},this.zoomin=function(t){return this.onzoomin=t,C},this.zoomout=function(t){return this.onzoomout=t,C},this.isScrollable=function(t){var e=t.target?t.target:t;if("OPTION"==e.nodeName)return!0;for(;e&&1==e.nodeType&&e!==this.me[0]&&!/^BODY|HTML/.test(e.nodeName);){var i=s(e),n=i.css("overflowY")||i.css("overflowX")||i.css("overflow")||"";if(/scroll|auto/.test(n))return e.clientHeight!=e.scrollHeight;e=!!e.parentNode&&e.parentNode}return!1},this.getViewport=function(t){for(var e=!(!t||!t.parentNode)&&t.parentNode;e&&1==e.nodeType&&!/^BODY|HTML/.test(e.nodeName);){var i=s(e);if(/fixed|absolute/.test(i.css("position")))return i;var n=i.css("overflowY")||i.css("overflowX")||i.css("overflow")||"";if(/scroll|auto/.test(n)&&e.clientHeight!=e.scrollHeight)return i;if(i.getNiceScroll().length>0)return i;e=!!e.parentNode&&e.parentNode}return!1},this.triggerScrollStart=function(t,e,i,n,o){if(C.onscrollstart){var r={type:"scrollstart",current:{x:t,y:e},request:{x:i,y:n},end:{x:C.newscrollx,y:C.newscrolly},speed:o};C.onscrollstart.call(C,r)}},this.triggerScrollEnd=function(){if(C.onscrollend){var t=C.getScrollLeft(),e=C.getScrollTop(),i={type:"scrollend",current:{x:t,y:e},end:{x:t,y:e}};C.onscrollend.call(C,i)}};var H=0,R=0,j=0,F=1,z=!1;if(this.onmousewheel=function(t){if(C.wheelprevented||C.locked)return!1;if(C.railslocked)return C.debounced("checkunlock",C.resize,250),!1;if(C.rail.drag)return C.cancelEvent(t);if("auto"===S.oneaxismousemode&&0!==t.deltaX&&(S.oneaxismousemode=!1),S.oneaxismousemode&&0===t.deltaX&&!C.rail.scrollable)return!C.railh||!C.railh.scrollable||C.onmousewheelhr(t);var e=m(),i=!1;if(S.preservenativescrolling&&C.checkarea+600<e&&(C.nativescrollingarea=C.isScrollable(t),i=!0),C.checkarea=e,C.nativescrollingarea)return!0;var n=_(t,!1,i);return n&&(C.checkarea=0),n},this.onmousewheelhr=function(t){if(!C.wheelprevented){if(C.railslocked||!C.railh.scrollable)return!0;if(C.rail.drag)return C.cancelEvent(t);var e=m(),i=!1;return S.preservenativescrolling&&C.checkarea+600<e&&(C.nativescrollingarea=C.isScrollable(t),i=!0),C.checkarea=e,!!C.nativescrollingarea||(C.railslocked?C.cancelEvent(t):_(t,!0,i))}},this.stop=function(){return C.cancelScroll(),C.scrollmon&&C.scrollmon.stop(),C.cursorfreezed=!1,C.scroll.y=Math.round(C.getScrollTop()*(1/C.scrollratio.y)),C.noticeCursor(),C},this.getTransitionSpeed=function(t){return 80+t/72*S.scrollspeed|0},S.smoothscroll)if(C.ishwscroll&&O.hastransition&&S.usetransition&&S.smoothscroll){var W="";this.resetTransition=function(){W="",C.doc.css(O.prefixstyle+"transition-duration","0ms")},this.prepareTransition=function(t,e){var i=e?t:C.getTransitionSpeed(t),n=i+"ms";return W!==n&&(W=n,C.doc.css(O.prefixstyle+"transition-duration",n)),i},this.doScrollLeft=function(t,e){var i=C.scrollrunning?C.newscrolly:C.getScrollTop();C.doScrollPos(t,i,e)},this.doScrollTop=function(t,e){var i=C.scrollrunning?C.newscrollx:C.getScrollLeft();C.doScrollPos(i,t,e)},this.cursorupdate={running:!1,start:function(){var t=this;if(!t.running){t.running=!0;var e=function(){t.running&&d(e),C.showCursor(C.getScrollTop(),C.getScrollLeft()),C.notifyScrollEvent(C.win[0])};d(e)}},stop:function(){this.running=!1}},this.doScrollPos=function(t,e,i){var n=C.getScrollTop(),o=C.getScrollLeft();if(((C.newscrolly-n)*(e-n)<0||(C.newscrollx-o)*(t-o)<0)&&C.cancelScroll(),S.bouncescroll?(e<0?e=e/2|0:e>C.page.maxh&&(e=C.page.maxh+(e-C.page.maxh)/2|0),t<0?t=t/2|0:t>C.page.maxw&&(t=C.page.maxw+(t-C.page.maxw)/2|0)):(e<0?e=0:e>C.page.maxh&&(e=C.page.maxh),t<0?t=0:t>C.page.maxw&&(t=C.page.maxw)),C.scrollrunning&&t==C.newscrollx&&e==C.newscrolly)return!1;C.newscrolly=e,C.newscrollx=t;var r=C.getScrollTop(),s=C.getScrollLeft(),a={};a.x=t-s,a.y=e-r;var l=0|Math.sqrt(a.x*a.x+a.y*a.y),c=C.prepareTransition(l);C.scrollrunning||(C.scrollrunning=!0,C.triggerScrollStart(s,r,t,e,c),C.cursorupdate.start()),C.scrollendtrapped=!0,O.transitionend||(C.scrollendtrapped&&clearTimeout(C.scrollendtrapped),C.scrollendtrapped=setTimeout(C.onScrollTransitionEnd,c)),C.setScrollTop(C.newscrolly),C.setScrollLeft(C.newscrollx)},this.cancelScroll=function(){if(!C.scrollendtrapped)return!0;var t=C.getScrollTop(),e=C.getScrollLeft();return C.scrollrunning=!1,O.transitionend||clearTimeout(O.transitionend),C.scrollendtrapped=!1,C.resetTransition(),C.setScrollTop(t),C.railh&&C.setScrollLeft(e),C.timerscroll&&C.timerscroll.tm&&clearInterval(C.timerscroll.tm),C.timerscroll=!1,C.cursorfreezed=!1,C.cursorupdate.stop(),C.showCursor(t,e),C},this.onScrollTransitionEnd=function(){if(C.scrollendtrapped){var t=C.getScrollTop(),e=C.getScrollLeft();if(t<0?t=0:t>C.page.maxh&&(t=C.page.maxh),e<0?e=0:e>C.page.maxw&&(e=C.page.maxw),t!=C.newscrolly||e!=C.newscrollx)return C.doScrollPos(e,t,S.snapbackspeed);C.scrollrunning&&C.triggerScrollEnd(),C.scrollrunning=!1,C.scrollendtrapped=!1,C.resetTransition(),C.timerscroll=!1,C.setScrollTop(t),C.railh&&C.setScrollLeft(e),C.cursorupdate.stop(),C.noticeCursor(!1,t,e),C.cursorfreezed=!1}}}else this.doScrollLeft=function(t,e){var i=C.scrollrunning?C.newscrolly:C.getScrollTop();C.doScrollPos(t,i,e)},this.doScrollTop=function(t,e){var i=C.scrollrunning?C.newscrollx:C.getScrollLeft();C.doScrollPos(i,t,e)},this.doScrollPos=function(t,e,i){var n=C.getScrollTop(),o=C.getScrollLeft();((C.newscrolly-n)*(e-n)<0||(C.newscrollx-o)*(t-o)<0)&&C.cancelScroll();var r=!1;if(C.bouncescroll&&C.rail.visibility||(e<0?(e=0,r=!0):e>C.page.maxh&&(e=C.page.maxh,r=!0)),C.bouncescroll&&C.railh.visibility||(t<0?(t=0,r=!0):t>C.page.maxw&&(t=C.page.maxw,r=!0)),C.scrollrunning&&C.newscrolly===e&&C.newscrollx===t)return!0;C.newscrolly=e,C.newscrollx=t,C.dst={},C.dst.x=t-o,C.dst.y=e-n,C.dst.px=o,C.dst.py=n;var s=0|Math.sqrt(C.dst.x*C.dst.x+C.dst.y*C.dst.y),a=C.getTransitionSpeed(s);C.bzscroll={};var l=r?1:.58;C.bzscroll.x=new I(o,C.newscrollx,a,0,0,l,1),C.bzscroll.y=new I(n,C.newscrolly,a,0,0,l,1),m();var c=function(){if(C.scrollrunning){var t=C.bzscroll.y.getPos();C.setScrollLeft(C.bzscroll.x.getNow()),C.setScrollTop(C.bzscroll.y.getNow()),t<=1?C.timer=d(c):(C.scrollrunning=!1,C.timer=0,C.triggerScrollEnd())}};C.scrollrunning||(C.triggerScrollStart(o,n,t,e,a),C.scrollrunning=!0,C.timer=d(c))},this.cancelScroll=function(){return C.timer&&h(C.timer),C.timer=0,C.bzscroll=!1,C.scrollrunning=!1,C};else this.doScrollLeft=function(t,e){var i=C.getScrollTop();C.doScrollPos(t,i,e)},this.doScrollTop=function(t,e){var i=C.getScrollLeft();C.doScrollPos(i,t,e)},this.doScrollPos=function(t,e,i){var n=t>C.page.maxw?C.page.maxw:t;n<0&&(n=0);var o=e>C.page.maxh?C.page.maxh:e;o<0&&(o=0),C.synched("scroll",function(){C.setScrollTop(o),C.setScrollLeft(n)})},this.cancelScroll=function(){};this.doScrollBy=function(t,e){x(0,t)},this.doScrollLeftBy=function(t,e){x(t,0)},this.doScrollTo=function(t,e){var i=e?Math.round(t*C.scrollratio.y):t;i<0?i=0:i>C.page.maxh&&(i=C.page.maxh),C.cursorfreezed=!1,C.doScrollTop(t)},this.checkContentSize=function(){var t=C.getContentSize();t.h==C.page.h&&t.w==C.page.w||C.resize(!1,t)},C.onscroll=function(t){C.rail.drag||C.cursorfreezed||C.synched("scroll",function(){C.scroll.y=Math.round(C.getScrollTop()/C.scrollratio.y),C.railh&&(C.scroll.x=Math.round(C.getScrollLeft()/C.scrollratio.x)),C.noticeCursor()})},C.bind(C.docscroll,"scroll",C.onscroll),this.doZoomIn=function(t){if(!C.zoomactive){C.zoomactive=!0,C.zoomrestore={style:{}};var e=["position","top","left","zIndex","backgroundColor","marginTop","marginBottom","marginLeft","marginRight"],i=C.win[0].style;for(var n in e){var o=e[n];C.zoomrestore.style[o]=void 0!==i[o]?i[o]:""}C.zoomrestore.style.width=C.win.css("width"),C.zoomrestore.style.height=C.win.css("height"),C.zoomrestore.padding={w:C.win.outerWidth()-C.win.width(),h:C.win.outerHeight()-C.win.height()},O.isios4&&(C.zoomrestore.scrollTop=c.scrollTop(),c.scrollTop(0)),C.win.css({position:O.isios4?"absolute":"fixed",top:0,left:0,zIndex:r+100,margin:0});var s=C.win.css("backgroundColor");return(""===s||/transparent|rgba\(0, 0, 0, 0\)|rgba\(0,0,0,0\)/.test(s))&&C.win.css("backgroundColor","#fff"),C.rail.css({zIndex:r+101}),C.zoom.css({zIndex:r+102}),C.zoom.css("backgroundPosition","0 -18px"),C.resizeZoom(),C.onzoomin&&C.onzoomin.call(C),C.cancelEvent(t)}},this.doZoomOut=function(t){if(C.zoomactive)return C.zoomactive=!1,C.win.css("margin",""),C.win.css(C.zoomrestore.style),O.isios4&&c.scrollTop(C.zoomrestore.scrollTop),C.rail.css({"z-index":C.zindex}),C.zoom.css({"z-index":C.zindex}),C.zoomrestore=!1,C.zoom.css("backgroundPosition","0 0"),C.onResize(),C.onzoomout&&C.onzoomout.call(C),C.cancelEvent(t)},this.doZoom=function(t){return C.zoomactive?C.doZoomOut(t):C.doZoomIn(t)},this.resizeZoom=function(){if(C.zoomactive){var t=C.getScrollTop();C.win.css({width:c.width()-C.zoomrestore.padding.w+"px",height:c.height()-C.zoomrestore.padding.h+"px"}),C.onResize(),C.setScrollTop(Math.min(C.page.maxh,t))}},this.init(),s.nicescroll.push(this)},w=function(t){var e=this;this.nc=t,this.lastx=0,this.lasty=0,this.speedx=0,this.speedy=0,this.lasttime=0,this.steptime=0,this.snapx=!1,this.snapy=!1,this.demulx=0,this.demuly=0,this.lastscrollx=-1,this.lastscrolly=-1,this.chkx=0,this.chky=0,this.timer=0,this.reset=function(t,i){e.stop(),e.steptime=0,e.lasttime=m(),e.speedx=0,e.speedy=0,e.lastx=t,e.lasty=i,e.lastscrollx=-1,e.lastscrolly=-1},this.update=function(t,i){var n=m();e.steptime=n-e.lasttime,e.lasttime=n;var o=i-e.lasty,r=t-e.lastx,s=e.nc.getScrollTop()+o,a=e.nc.getScrollLeft()+r;e.snapx=a<0||a>e.nc.page.maxw,e.snapy=s<0||s>e.nc.page.maxh,e.speedx=r,e.speedy=o,e.lastx=t,e.lasty=i},this.stop=function(){e.nc.unsynched("domomentum2d"),e.timer&&clearTimeout(e.timer),e.timer=0,e.lastscrollx=-1,e.lastscrolly=-1},this.doSnapy=function(t,i){var n=!1;i<0?(i=0,n=!0):i>e.nc.page.maxh&&(i=e.nc.page.maxh,n=!0),t<0?(t=0,n=!0):t>e.nc.page.maxw&&(t=e.nc.page.maxw,n=!0),n?e.nc.doScrollPos(t,i,e.nc.opt.snapbackspeed):e.nc.triggerScrollEnd()},this.doMomentum=function(t){var i=m(),n=t?i+t:e.lasttime,o=e.nc.getScrollLeft(),r=e.nc.getScrollTop(),s=e.nc.page.maxh,a=e.nc.page.maxw;e.speedx=a>0?Math.min(60,e.speedx):0,e.speedy=s>0?Math.min(60,e.speedy):0;var l=n&&i-n<=60;(r<0||r>s||o<0||o>a)&&(l=!1);var c=!(!e.speedy||!l)&&e.speedy,u=!(!e.speedx||!l)&&e.speedx;if(c||u){var d=Math.max(16,e.steptime);if(d>50){var h=d/50;e.speedx*=h,e.speedy*=h,d=50}e.demulxy=0,e.lastscrollx=e.nc.getScrollLeft(),e.chkx=e.lastscrollx,e.lastscrolly=e.nc.getScrollTop(),e.chky=e.lastscrolly;var p=e.lastscrollx,f=e.lastscrolly,g=function(){var t=m()-i>600?.04:.02;e.speedx&&(p=Math.floor(e.lastscrollx-e.speedx*(1-e.demulxy)),e.lastscrollx=p,(p<0||p>a)&&(t=.1)),e.speedy&&(f=Math.floor(e.lastscrolly-e.speedy*(1-e.demulxy)),e.lastscrolly=f,(f<0||f>s)&&(t=.1)),e.demulxy=Math.min(1,e.demulxy+t),e.nc.synched("domomentum2d",function(){e.speedx&&(e.nc.getScrollLeft(),e.chkx=p,e.nc.setScrollLeft(p)),e.speedy&&(e.nc.getScrollTop(),e.chky=f,e.nc.setScrollTop(f)),e.timer||(e.nc.hideCursor(),e.doSnapy(p,f))}),e.demulxy<1?e.timer=setTimeout(g,d):(e.stop(),e.nc.hideCursor(),e.doSnapy(p,f))};g()}else e.doSnapy(e.nc.getScrollLeft(),e.nc.getScrollTop())}},T=t.fn.scrollTop;t.cssHooks.pageYOffset={get:function(t,e,i){var n=s.data(t,"__nicescroll")||!1;return n&&n.ishwscroll?n.getScrollTop():T.call(t)},set:function(t,e){var i=s.data(t,"__nicescroll")||!1;return i&&i.ishwscroll?i.setScrollTop(parseInt(e)):T.call(t,e),this}},t.fn.scrollTop=function(t){if(void 0===t){var e=!!this[0]&&(s.data(this[0],"__nicescroll")||!1);return e&&e.ishwscroll?e.getScrollTop():T.call(this)}return this.each(function(){var e=s.data(this,"__nicescroll")||!1;e&&e.ishwscroll?e.setScrollTop(parseInt(t)):T.call(s(this),t)})};var x=t.fn.scrollLeft;s.cssHooks.pageXOffset={get:function(t,e,i){var n=s.data(t,"__nicescroll")||!1;return n&&n.ishwscroll?n.getScrollLeft():x.call(t)},set:function(t,e){var i=s.data(t,"__nicescroll")||!1;return i&&i.ishwscroll?i.setScrollLeft(parseInt(e)):x.call(t,e),this}},t.fn.scrollLeft=function(t){if(void 0===t){var e=!!this[0]&&(s.data(this[0],"__nicescroll")||!1);return e&&e.ishwscroll?e.getScrollLeft():x.call(this)}return this.each(function(){var e=s.data(this,"__nicescroll")||!1;e&&e.ishwscroll?e.setScrollLeft(parseInt(t)):x.call(s(this),t)})};var _=function(t){var e=this;if(this.length=0,this.name="nicescrollarray",this.each=function(t){return s.each(e,t),e},this.push=function(t){e[e.length]=t,e.length++},this.eq=function(t){return e[t]},t)for(var i=0;i<t.length;i++){var n=s.data(t[i],"__nicescroll")||!1;n&&(this[this.length]=n,this.length++)}return this};!function(t,e,i){for(var n=0,o=e.length;n<o;n++)i(t,e[n])}(_.prototype,["show","hide","toggle","onResize","resize","remove","stop","doScrollPos"],function(t,e){t[e]=function(){var t=arguments;return this.each(function(){this[e].apply(this,t)})}}),t.fn.getNiceScroll=function(t){return void 0===t?new _(this):this[t]&&s.data(this[t],"__nicescroll")||!1},(t.expr.pseudos||t.expr[":"]).nicescroll=function(t){return void 0!==s.data(t,"__nicescroll")},s.fn.niceScroll=function(t,e){void 0!==e||"object"!=typeof t||"jquery"in t||(e=t,t=!1);var i=new _;return this.each(function(){var n=s(this),o=s.extend({},e);if(t){var r=s(t);o.doc=r.length>1?s(t,n):r,o.win=n}!("doc"in o)||"win"in o||(o.win=n);var a=n.data("__nicescroll")||!1;a||(o.doc=o.doc||n,a=new b(o,n),n.data("__nicescroll",a)),i.push(a)}),1===i.length?i[0]:i},l.NiceScroll={getjQuery:function(){return t}},s.nicescroll||(s.nicescroll=new _,s.nicescroll.options=g)})?n.apply(e,o):n)||(t.exports=r)},11:function(t,e,i){"use strict";i.r(e),function(t){var e,n,o=i(1),r=i.n(o);function s(t){return(s="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}window.$=r.a,n=0,(e=t).fn.fireModal=function(t){t=e.extend({size:"modal-md",center:!1,animation:!0,title:"Modal Title",closeButton:!0,header:!0,bodyClass:"",footerClass:"",body:"",buttons:[],autoFocus:!0,created:function(){},appended:function(){},onFormSubmit:function(){},modal:{}},t),this.each(function(){var i="fire-modal-"+ ++n,o="trigger--"+i;e("."+o),e(this).addClass(o);var r=t.body;if("object"==s(r))if(r.length){var a=r;r=r.removeAttr("id").clone().removeClass("modal-part"),a.remove()}else r='<div class="text-danger">Modal part element not found!</div>';var l,c='   <div class="modal'+(1==t.animation?" fade":"")+'" tabindex="-1" role="dialog" id="'+i+'">       <div class="modal-dialog '+t.size+(t.center?" modal-dialog-centered":"")+'" role="document">         <div class="modal-content">  '+(1==t.header?'         <div class="modal-header">             <h5 class="modal-title">'+t.title+"</h5>  "+(1==t.closeButton?'           <button type="button" class="close" data-dismiss="modal" aria-label="Close">               <span aria-hidden="true">&times;</span>             </button>  ':"")+"         </div>  ":"")+'         <div class="modal-body">           </div>  '+(t.buttons.length>0?'         <div class="modal-footer">           </div>  ':"")+"       </div>       </div>    </div>  ";c=e(c),t.buttons.forEach(function(t){var i="id"in t?t.id:"";l='<button type="'+("submit"in t&&1==t.submit?"submit":"button")+'" class="'+t.class+'" id="'+i+'">'+t.text+"</button>",l=e(l).off("click").on("click",function(){t.handler.call(this,c)}),e(c).find(".modal-footer").append(l)}),e(c).find(".modal-body").append(r),t.bodyClass&&e(c).find(".modal-body").addClass(t.bodyClass),t.footerClass&&e(c).find(".modal-footer").addClass(t.footerClass),t.created.call(this,c,t);var u=e(c).find(".modal-body form"),d=c.find("button[type=submit]");if(e("body").append(c),t.appended.call(this,e("#"+i),u,t),u.length){t.autoFocus&&e(c).on("shown.bs.modal",function(){"boolean"==typeof t.autoFocus?u.find("input:eq(0)").focus():"string"==typeof t.autoFocus&&u.find(t.autoFocus).length&&u.find(t.autoFocus).focus()});var h={startProgress:function(){c.addClass("modal-progress")},stopProgress:function(){c.removeClass("modal-progress")}};u.find("button").length||e(u).append('<button class="d-none" id="'+i+'-submit"></button>'),d.click(function(){u.submit()}),u.submit(function(e){h.startProgress(),t.onFormSubmit.call(this,c,e,h)})}e(document).on("click","."+o,function(){return e("#"+i).modal(t.modal),!1})})},e.destroyModal=function(t){t.modal("hide"),t.on("hidden.bs.modal",function(){})},e.cardProgress=function(t,i){i=e.extend({dismiss:!1,dismissText:"Cancel",spinner:!0,onDismiss:function(){}},i);var n=e(t);if(n.addClass("card-progress"),0==i.spinner&&n.addClass("remove-spinner"),1==i.dismiss){var o='<a class="btn btn-danger card-progress-dismiss">'+i.dismissText+"</a>";o=e(o).off("click").on("click",function(){n.removeClass("card-progress"),n.find(".card-progress-dismiss").remove(),i.onDismiss.call(this,n)}),n.append(o)}return{dismiss:function(t){e.cardProgressDismiss(n,t)}}},e.cardProgressDismiss=function(t,i){var n=e(t);n.removeClass("card-progress"),n.find(".card-progress-dismiss").remove(),i&&i.call(this,n)},e.chatCtrl=function(t,i){i=e.extend({position:"chat-right",text:"",time:moment((new Date).toISOString()).format("hh:mm"),picture:"",type:"text",timeout:0,onShow:function(){}},i);var n=e(t),o=(t='<div class="chat-item '+i.position+'" style="display:none"><img src="'+i.picture+'"><div class="chat-details"><div class="chat-text">'+i.text+'</div><div class="chat-time">'+i.time+"</div></div></div>",'<div class="chat-item chat-left chat-typing" style="display:none"><img src="'+i.picture+'"><div class="chat-details"><div class="chat-text"></div></div></div>'),r=t;"typing"==i.type&&(r=o),i.timeout>0?setTimeout(function(){n.find(".chat-content").append(e(r).fadeIn())},i.timeout):n.find(".chat-content").append(e(r).fadeIn());var s=0;n.find(".chat-content .chat-item").each(function(){s+=e(this).outerHeight()}),setTimeout(function(){n.find(".chat-content").scrollTop(s,-1)},100),i.onShow.call(this,r)}}.call(this,i(1))},12:function(module,exports,__webpack_require__){"use strict";(function($,jQuery){window.Chart&&(Chart.defaults.global.defaultFontFamily="'Nunito', 'Segoe UI', 'Arial'",Chart.defaults.global.defaultFontSize=11,Chart.defaults.global.defaultFontStyle=500,Chart.defaults.global.defaultFontColor="#999",Chart.defaults.global.tooltips.backgroundColor="#000",Chart.defaults.global.tooltips.titleFontFamily="'Nunito', 'Segoe UI', 'Arial'",Chart.defaults.global.tooltips.titleFontColor="#fff",Chart.defaults.global.tooltips.titleFontSize=20,Chart.defaults.global.tooltips.xPadding=10,Chart.defaults.global.tooltips.yPadding=10,Chart.defaults.global.tooltips.cornerRadius=3),window.Dropzone&&(Dropzone.autoDiscover=!1),$("[data-confirm]").each(function(){var me=$(this),me_data=me.data("confirm");me_data=me_data.split("|"),me.fireModal({title:me_data[0],body:me_data[1],buttons:[{text:me.data("confirm-text-yes")||"Yes",class:"btn btn-danger btn-shadow",handler:function handler(){eval(me.data("confirm-yes"))}},{text:me.data("confirm-text-cancel")||"Cancel",class:"btn btn-secondary",handler:function handler(modal){$.destroyModal(modal),eval(me.data("confirm-no"))}}]})}),$(function(){var sidebar_nicescroll_opts={cursoropacitymin:0,cursoropacitymax:.8,zindex:892},now_layout_class=null,sidebar_sticky=function(){$("body").hasClass("layout-2")&&($("body.layout-2 #sidebar-wrapper").stick_in_parent({parent:$("body")}),$("body.layout-2 #sidebar-wrapper").stick_in_parent({recalc_every:1}))},sidebar_nicescroll;sidebar_sticky();var update_sidebar_nicescroll=function(){var t=setInterval(function(){null!=sidebar_nicescroll&&sidebar_nicescroll.resize()},10);setTimeout(function(){clearInterval(t)},600)},sidebar_dropdown=function(){$(".main-sidebar").length&&($(".main-sidebar").niceScroll(sidebar_nicescroll_opts),sidebar_nicescroll=$(".main-sidebar").getNiceScroll(),$(".main-sidebar .sidebar-menu li a.has-dropdown").off("click").on("click",function(){return $(this).parent().find("> .dropdown-menu").slideToggle(500,function(){return update_sidebar_nicescroll(),!1}),!1}))};sidebar_dropdown(),$("#top-5-scroll").length&&$("#top-5-scroll").css({height:315}).niceScroll(),$(".main-content").css({minHeight:$(window).outerHeight()-95}),$(".nav-collapse-toggle").click(function(){return $(this).parent().find(".navbar-nav").toggleClass("show"),!1}),$(document).on("click",function(t){$(".nav-collapse .navbar-nav").removeClass("show")});var toggle_sidebar_mini=function(t){var e=$("body");t?(e.addClass("sidebar-mini"),e.removeClass("sidebar-show"),sidebar_nicescroll.remove(),sidebar_nicescroll=null,$(".main-sidebar .sidebar-menu > li").each(function(){var t=$(this);t.find("> .dropdown-menu").length?(t.find("> .dropdown-menu").hide(),t.find("> .dropdown-menu").prepend('<li class="dropdown-title pt-3">'+t.find("> a").text()+"</li>")):(t.find("> a").attr("data-toggle","tooltip"),t.find("> a").attr("data-original-title",t.find("> a").text()),$("[data-toggle='tooltip']").tooltip({placement:"right"}))})):(e.removeClass("sidebar-mini"),$(".main-sidebar").css({overflow:"hidden"}),setTimeout(function(){$(".main-sidebar").niceScroll(sidebar_nicescroll_opts),sidebar_nicescroll=$(".main-sidebar").getNiceScroll()},500),$(".main-sidebar .sidebar-menu > li > ul .dropdown-title").remove(),$(".main-sidebar .sidebar-menu > li > a").removeAttr("data-toggle"),$(".main-sidebar .sidebar-menu > li > a").removeAttr("data-original-title"),$(".main-sidebar .sidebar-menu > li > a").removeAttr("title"))};$("[data-toggle='sidebar']").click(function(){var t=$("body");return $(window).outerWidth()<=1024?(t.removeClass("search-show search-gone"),t.hasClass("sidebar-gone")?(t.removeClass("sidebar-gone"),t.addClass("sidebar-show")):(t.addClass("sidebar-gone"),t.removeClass("sidebar-show")),update_sidebar_nicescroll()):(t.removeClass("search-show search-gone"),t.hasClass("sidebar-mini")?toggle_sidebar_mini(!1):toggle_sidebar_mini(!0)),!1});var toggleLayout=function(){var t=$(window),e=$("body").attr("class")||"",i=e.trim().length>0?e.split(" "):"";if(i.length>0&&i.forEach(function(t){-1!=t.indexOf("layout-")&&(now_layout_class=t)}),t.outerWidth()<=1024){if($("body").hasClass("sidebar-mini")&&(toggle_sidebar_mini(!1),$(".main-sidebar").niceScroll(sidebar_nicescroll_opts),sidebar_nicescroll=$(".main-sidebar").getNiceScroll()),$("body").addClass("sidebar-gone"),$("body").removeClass("layout-2 layout-3 sidebar-mini sidebar-show"),$("body").off("click").on("click",function(t){($(t.target).hasClass("sidebar-show")||$(t.target).hasClass("search-show"))&&($("body").removeClass("sidebar-show"),$("body").addClass("sidebar-gone"),$("body").removeClass("search-show"),update_sidebar_nicescroll())}),update_sidebar_nicescroll(),"layout-3"==now_layout_class){var n=$(".navbar-secondary").attr("class"),o=$(".navbar-secondary");o.attr("data-nav-classes",n),o.removeAttr("class"),o.addClass("main-sidebar");var r=$(".main-sidebar");r.find(".container").addClass("sidebar-wrapper").removeClass("container"),r.find(".navbar-nav").addClass("sidebar-menu").removeClass("navbar-nav"),r.find(".sidebar-menu .nav-item.dropdown.show a").click(),r.find(".sidebar-brand").remove(),r.find(".sidebar-menu").before($("<div>",{class:"sidebar-brand"}).append($("<a>",{href:$(".navbar-brand").attr("href")}).html($(".navbar-brand").html()))),setTimeout(function(){sidebar_nicescroll=r.niceScroll(sidebar_nicescroll_opts),sidebar_nicescroll=r.getNiceScroll()},700),sidebar_dropdown(),$(".main-wrapper").removeClass("container")}}else{$("body").removeClass("sidebar-gone sidebar-show"),now_layout_class&&$("body").addClass(now_layout_class);var s=$(".main-sidebar").attr("data-nav-classes"),a=$(".main-sidebar");if("layout-3"==now_layout_class&&a.hasClass("main-sidebar")){a.find(".sidebar-menu li a.has-dropdown").off("click"),a.find(".sidebar-brand").remove(),a.removeAttr("class"),a.addClass(s);var l=$(".navbar-secondary");l.find(".sidebar-wrapper").addClass("container").removeClass("sidebar-wrapper"),l.find(".sidebar-menu").addClass("navbar-nav").removeClass("sidebar-menu"),l.find(".dropdown-menu").hide(),l.removeAttr("style"),l.removeAttr("tabindex"),l.removeAttr("data-nav-classes"),$(".main-wrapper").addClass("container")}else"layout-2"==now_layout_class?$("body").addClass("layout-2"):update_sidebar_nicescroll()}};toggleLayout(),$(window).resize(toggleLayout),$("[data-toggle='search']").click(function(){var t=$("body");t.hasClass("search-gone")?(t.addClass("search-gone"),t.removeClass("search-show")):(t.removeClass("search-gone"),t.addClass("search-show"))}),$("[data-toggle='tooltip']").tooltip(),$('[data-toggle="popover"]').popover({container:"body"}),jQuery().select2&&$(".select2").select2(),jQuery().selectric&&$(".selectric").selectric({disableOnMobile:!1,nativeOnMobile:!1}),$(".notification-toggle").dropdown(),$(".notification-toggle").parent().on("shown.bs.dropdown",function(){$(".dropdown-list-icons").niceScroll({cursoropacitymin:.3,cursoropacitymax:.8,cursorwidth:7})}),$(".message-toggle").dropdown(),$(".message-toggle").parent().on("shown.bs.dropdown",function(){$(".dropdown-list-message").niceScroll({cursoropacitymin:.3,cursoropacitymax:.8,cursorwidth:7})}),$(".chat-content").length&&($(".chat-content").niceScroll({cursoropacitymin:.3,cursoropacitymax:.8}),$(".chat-content").getNiceScroll(0).doScrollTop($(".chat-content").height())),jQuery().summernote&&($(".summernote").summernote({dialogsInBody:!0,minHeight:250}),$(".summernote-simple").summernote({dialogsInBody:!0,minHeight:150,toolbar:[["style",["bold","italic","underline","clear"]],["font",["strikethrough"]],["para",["paragraph"]]]})),window.CodeMirror&&$(".codeeditor").each(function(){CodeMirror.fromTextArea(this,{lineNumbers:!0,theme:"duotone-dark",mode:"javascript",height:200}).setSize("100%",200)}),$(".follow-btn, .following-btn").each(function(){var me=$(this),follow_text="Follow",unfollow_text="Following";me.click(function(){return me.hasClass("following-btn")?(me.removeClass("btn-danger"),me.removeClass("following-btn"),me.addClass("btn-primary"),me.html(follow_text),eval(me.data("unfollow-action"))):(me.removeClass("btn-primary"),me.addClass("btn-danger"),me.addClass("following-btn"),me.html(unfollow_text),eval(me.data("follow-action"))),!1})}),$("[data-dismiss]").each(function(){var t=$(this),e=t.data("dismiss");t.click(function(){return $(e).fadeOut(function(){$(e).remove()}),!1})}),$("[data-collapse]").each(function(){var t=$(this),e=t.data("collapse");t.click(function(){return $(e).collapse("toggle"),$(e).on("shown.bs.collapse",function(){t.html('<i class="fas fa-minus"></i>')}),$(e).on("hidden.bs.collapse",function(){t.html('<i class="fas fa-plus"></i>')}),!1})}),$(".gallery .gallery-item").each(function(){var t=$(this);t.attr("href",t.data("image")),t.attr("title",t.data("title")),t.parent().hasClass("gallery-fw")&&(t.css({height:t.parent().data("item-height")}),t.find("div").css({lineHeight:t.parent().data("item-height")+"px"})),t.css({backgroundImage:'url("'+t.data("image")+'")'})}),jQuery().Chocolat&&$(".gallery").Chocolat({className:"gallery",imageSelector:".gallery-item"}),$("[data-background]").each(function(){var t=$(this);t.css({backgroundImage:"url("+t.data("background")+")"})}),$("[data-tab]").each(function(){var t=$(this);t.click(function(){if(!t.hasClass("active")){$('[data-tab-group="'+t.data("tab")+'"]');var e=$('[data-tab-group="'+t.data("tab")+'"].active'),i=$(t.attr("href"));$('[data-tab="'+t.data("tab")+'"]').removeClass("active"),t.addClass("active"),i.addClass("active"),e.removeClass("active")}return!1})}),$(".needs-validation").submit(function(){var t=$(this);!1===t[0].checkValidity()&&(event.preventDefault(),event.stopPropagation()),t.addClass("was-validated")}),$(".alert-dismissible").each(function(){var t=$(this);t.find(".close").click(function(){t.alert("close")})}),$(".main-navbar").length,$("[data-crop-image]").each(function(t){$(this).css({overflow:"hidden",position:"relative",height:$(this).data("crop-image")})}),$("[data-toggle-slide]").click(function(){var t=$(this).data("toggle-slide");return $(t).slideToggle(),!1}),$("[data-dismiss=modal]").click(function(){return $(this).closest(".modal").modal("hide"),!1}),$("[data-width]").each(function(){$(this).css({width:$(this).data("width")})}),$("[data-height]").each(function(){$(this).css({height:$(this).data("height")})}),$(".chocolat-parent").length&&jQuery().Chocolat&&$(".chocolat-parent").Chocolat(),$(".sortable-card").length&&jQuery().sortable&&$(".sortable-card").sortable({handle:".card-header",opacity:.8,tolerance:"pointer"}),jQuery().daterangepicker&&($(".datepicker").length&&$(".datepicker").daterangepicker({locale:{format:"YYYY-MM-DD"},singleDatePicker:!0}),$(".datetimepicker").length&&$(".datetimepicker").daterangepicker({locale:{format:"YYYY-MM-DD hh:mm"},singleDatePicker:!0,timePicker:!0,timePicker24Hour:!0}),$(".daterange").length&&$(".daterange").daterangepicker({locale:{format:"YYYY-MM-DD"},drops:"down",opens:"right"})),jQuery().timepicker&&$(".timepicker").length&&$(".timepicker").timepicker({icons:{up:"fas fa-chevron-up",down:"fas fa-chevron-down"}})})}).call(this,__webpack_require__(1),__webpack_require__(1))},161:function(t,e,i){"use strict";i.r(e);i(162),i(11),i(12),i(8)},162:function(t,e,i){
/*!
  * Bootstrap v4.3.1 (https://getbootstrap.com/)
  * Copyright 2011-2019 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
  * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
  */
!function(t,e,i){"use strict";function n(t,e){for(var i=0;i<e.length;i++){var n=e[i];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(t,n.key,n)}}function o(t,e,i){return e&&n(t.prototype,e),i&&n(t,i),t}function r(t,e,i){return e in t?Object.defineProperty(t,e,{value:i,enumerable:!0,configurable:!0,writable:!0}):t[e]=i,t}function s(t){for(var e=1;e<arguments.length;e++){var i=null!=arguments[e]?arguments[e]:{},n=Object.keys(i);"function"==typeof Object.getOwnPropertySymbols&&(n=n.concat(Object.getOwnPropertySymbols(i).filter(function(t){return Object.getOwnPropertyDescriptor(i,t).enumerable}))),n.forEach(function(e){r(t,e,i[e])})}return t}e=e&&e.hasOwnProperty("default")?e.default:e,i=i&&i.hasOwnProperty("default")?i.default:i;var a="transitionend";function l(t){var i=this,n=!1;return e(this).one(c.TRANSITION_END,function(){n=!0}),setTimeout(function(){n||c.triggerTransitionEnd(i)},t),this}var c={TRANSITION_END:"bsTransitionEnd",getUID:function(t){do{t+=~~(1e6*Math.random())}while(document.getElementById(t));return t},getSelectorFromElement:function(t){var e=t.getAttribute("data-target");if(!e||"#"===e){var i=t.getAttribute("href");e=i&&"#"!==i?i.trim():""}try{return document.querySelector(e)?e:null}catch(t){return null}},getTransitionDurationFromElement:function(t){if(!t)return 0;var i=e(t).css("transition-duration"),n=e(t).css("transition-delay"),o=parseFloat(i),r=parseFloat(n);return o||r?(i=i.split(",")[0],n=n.split(",")[0],1e3*(parseFloat(i)+parseFloat(n))):0},reflow:function(t){return t.offsetHeight},triggerTransitionEnd:function(t){e(t).trigger(a)},supportsTransitionEnd:function(){return Boolean(a)},isElement:function(t){return(t[0]||t).nodeType},typeCheckConfig:function(t,e,i){for(var n in i)if(Object.prototype.hasOwnProperty.call(i,n)){var o=i[n],r=e[n],s=r&&c.isElement(r)?"element":(a=r,{}.toString.call(a).match(/\s([a-z]+)/i)[1].toLowerCase());if(!new RegExp(o).test(s))throw new Error(t.toUpperCase()+': Option "'+n+'" provided type "'+s+'" but expected type "'+o+'".')}var a},findShadowRoot:function(t){if(!document.documentElement.attachShadow)return null;if("function"==typeof t.getRootNode){var e=t.getRootNode();return e instanceof ShadowRoot?e:null}return t instanceof ShadowRoot?t:t.parentNode?c.findShadowRoot(t.parentNode):null}};e.fn.emulateTransitionEnd=l,e.event.special[c.TRANSITION_END]={bindType:a,delegateType:a,handle:function(t){if(e(t.target).is(this))return t.handleObj.handler.apply(this,arguments)}};var u=e.fn.alert,d={CLOSE:"close.bs.alert",CLOSED:"closed.bs.alert",CLICK_DATA_API:"click.bs.alert.data-api"},h={ALERT:"alert",FADE:"fade",SHOW:"show"},p=function(){function t(t){this._element=t}var i=t.prototype;return i.close=function(t){var e=this._element;t&&(e=this._getRootElement(t));var i=this._triggerCloseEvent(e);i.isDefaultPrevented()||this._removeElement(e)},i.dispose=function(){e.removeData(this._element,"bs.alert"),this._element=null},i._getRootElement=function(t){var i=c.getSelectorFromElement(t),n=!1;return i&&(n=document.querySelector(i)),n||(n=e(t).closest("."+h.ALERT)[0]),n},i._triggerCloseEvent=function(t){var i=e.Event(d.CLOSE);return e(t).trigger(i),i},i._removeElement=function(t){var i=this;if(e(t).removeClass(h.SHOW),e(t).hasClass(h.FADE)){var n=c.getTransitionDurationFromElement(t);e(t).one(c.TRANSITION_END,function(e){return i._destroyElement(t,e)}).emulateTransitionEnd(n)}else this._destroyElement(t)},i._destroyElement=function(t){e(t).detach().trigger(d.CLOSED).remove()},t._jQueryInterface=function(i){return this.each(function(){var n=e(this),o=n.data("bs.alert");o||(o=new t(this),n.data("bs.alert",o)),"close"===i&&o[i](this)})},t._handleDismiss=function(t){return function(e){e&&e.preventDefault(),t.close(this)}},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}}]),t}();e(document).on(d.CLICK_DATA_API,'[data-dismiss="alert"]',p._handleDismiss(new p)),e.fn.alert=p._jQueryInterface,e.fn.alert.Constructor=p,e.fn.alert.noConflict=function(){return e.fn.alert=u,p._jQueryInterface};var f=e.fn.button,m={ACTIVE:"active",BUTTON:"btn",FOCUS:"focus"},g={DATA_TOGGLE_CARROT:'[data-toggle^="button"]',DATA_TOGGLE:'[data-toggle="buttons"]',INPUT:'input:not([type="hidden"])',ACTIVE:".active",BUTTON:".btn"},v={CLICK_DATA_API:"click.bs.button.data-api",FOCUS_BLUR_DATA_API:"focus.bs.button.data-api blur.bs.button.data-api"},y=function(){function t(t){this._element=t}var i=t.prototype;return i.toggle=function(){var t=!0,i=!0,n=e(this._element).closest(g.DATA_TOGGLE)[0];if(n){var o=this._element.querySelector(g.INPUT);if(o){if("radio"===o.type)if(o.checked&&this._element.classList.contains(m.ACTIVE))t=!1;else{var r=n.querySelector(g.ACTIVE);r&&e(r).removeClass(m.ACTIVE)}if(t){if(o.hasAttribute("disabled")||n.hasAttribute("disabled")||o.classList.contains("disabled")||n.classList.contains("disabled"))return;o.checked=!this._element.classList.contains(m.ACTIVE),e(o).trigger("change")}o.focus(),i=!1}}i&&this._element.setAttribute("aria-pressed",!this._element.classList.contains(m.ACTIVE)),t&&e(this._element).toggleClass(m.ACTIVE)},i.dispose=function(){e.removeData(this._element,"bs.button"),this._element=null},t._jQueryInterface=function(i){return this.each(function(){var n=e(this).data("bs.button");n||(n=new t(this),e(this).data("bs.button",n)),"toggle"===i&&n[i]()})},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}}]),t}();e(document).on(v.CLICK_DATA_API,g.DATA_TOGGLE_CARROT,function(t){t.preventDefault();var i=t.target;e(i).hasClass(m.BUTTON)||(i=e(i).closest(g.BUTTON)),y._jQueryInterface.call(e(i),"toggle")}).on(v.FOCUS_BLUR_DATA_API,g.DATA_TOGGLE_CARROT,function(t){var i=e(t.target).closest(g.BUTTON)[0];e(i).toggleClass(m.FOCUS,/^focus(in)?$/.test(t.type))}),e.fn.button=y._jQueryInterface,e.fn.button.Constructor=y,e.fn.button.noConflict=function(){return e.fn.button=f,y._jQueryInterface};var b="carousel",w=".bs.carousel",T=e.fn[b],x={interval:5e3,keyboard:!0,slide:!1,pause:"hover",wrap:!0,touch:!0},_={interval:"(number|boolean)",keyboard:"boolean",slide:"(boolean|string)",pause:"(string|boolean)",wrap:"boolean",touch:"boolean"},C={NEXT:"next",PREV:"prev",LEFT:"left",RIGHT:"right"},E={SLIDE:"slide.bs.carousel",SLID:"slid.bs.carousel",KEYDOWN:"keydown.bs.carousel",MOUSEENTER:"mouseenter.bs.carousel",MOUSELEAVE:"mouseleave.bs.carousel",TOUCHSTART:"touchstart.bs.carousel",TOUCHMOVE:"touchmove.bs.carousel",TOUCHEND:"touchend.bs.carousel",POINTERDOWN:"pointerdown.bs.carousel",POINTERUP:"pointerup.bs.carousel",DRAG_START:"dragstart.bs.carousel",LOAD_DATA_API:"load.bs.carousel.data-api",CLICK_DATA_API:"click.bs.carousel.data-api"},S={CAROUSEL:"carousel",ACTIVE:"active",SLIDE:"slide",RIGHT:"carousel-item-right",LEFT:"carousel-item-left",NEXT:"carousel-item-next",PREV:"carousel-item-prev",ITEM:"carousel-item",POINTER_EVENT:"pointer-event"},D={ACTIVE:".active",ACTIVE_ITEM:".active.carousel-item",ITEM:".carousel-item",ITEM_IMG:".carousel-item img",NEXT_PREV:".carousel-item-next, .carousel-item-prev",INDICATORS:".carousel-indicators",DATA_SLIDE:"[data-slide], [data-slide-to]",DATA_RIDE:'[data-ride="carousel"]'},k={TOUCH:"touch",PEN:"pen"},A=function(){function t(t,e){this._items=null,this._interval=null,this._activeElement=null,this._isPaused=!1,this._isSliding=!1,this.touchTimeout=null,this.touchStartX=0,this.touchDeltaX=0,this._config=this._getConfig(e),this._element=t,this._indicatorsElement=this._element.querySelector(D.INDICATORS),this._touchSupported="ontouchstart"in document.documentElement||navigator.maxTouchPoints>0,this._pointerEvent=Boolean(window.PointerEvent||window.MSPointerEvent),this._addEventListeners()}var i=t.prototype;return i.next=function(){this._isSliding||this._slide(C.NEXT)},i.nextWhenVisible=function(){!document.hidden&&e(this._element).is(":visible")&&"hidden"!==e(this._element).css("visibility")&&this.next()},i.prev=function(){this._isSliding||this._slide(C.PREV)},i.pause=function(t){t||(this._isPaused=!0),this._element.querySelector(D.NEXT_PREV)&&(c.triggerTransitionEnd(this._element),this.cycle(!0)),clearInterval(this._interval),this._interval=null},i.cycle=function(t){t||(this._isPaused=!1),this._interval&&(clearInterval(this._interval),this._interval=null),this._config.interval&&!this._isPaused&&(this._interval=setInterval((document.visibilityState?this.nextWhenVisible:this.next).bind(this),this._config.interval))},i.to=function(t){var i=this;this._activeElement=this._element.querySelector(D.ACTIVE_ITEM);var n=this._getItemIndex(this._activeElement);if(!(t>this._items.length-1||t<0))if(this._isSliding)e(this._element).one(E.SLID,function(){return i.to(t)});else{if(n===t)return this.pause(),void this.cycle();var o=t>n?C.NEXT:C.PREV;this._slide(o,this._items[t])}},i.dispose=function(){e(this._element).off(w),e.removeData(this._element,"bs.carousel"),this._items=null,this._config=null,this._element=null,this._interval=null,this._isPaused=null,this._isSliding=null,this._activeElement=null,this._indicatorsElement=null},i._getConfig=function(t){return t=s({},x,t),c.typeCheckConfig(b,t,_),t},i._handleSwipe=function(){var t=Math.abs(this.touchDeltaX);if(!(t<=40)){var e=t/this.touchDeltaX;e>0&&this.prev(),e<0&&this.next()}},i._addEventListeners=function(){var t=this;this._config.keyboard&&e(this._element).on(E.KEYDOWN,function(e){return t._keydown(e)}),"hover"===this._config.pause&&e(this._element).on(E.MOUSEENTER,function(e){return t.pause(e)}).on(E.MOUSELEAVE,function(e){return t.cycle(e)}),this._config.touch&&this._addTouchEventListeners()},i._addTouchEventListeners=function(){var t=this;if(this._touchSupported){var i=function(e){t._pointerEvent&&k[e.originalEvent.pointerType.toUpperCase()]?t.touchStartX=e.originalEvent.clientX:t._pointerEvent||(t.touchStartX=e.originalEvent.touches[0].clientX)},n=function(e){t._pointerEvent&&k[e.originalEvent.pointerType.toUpperCase()]&&(t.touchDeltaX=e.originalEvent.clientX-t.touchStartX),t._handleSwipe(),"hover"===t._config.pause&&(t.pause(),t.touchTimeout&&clearTimeout(t.touchTimeout),t.touchTimeout=setTimeout(function(e){return t.cycle(e)},500+t._config.interval))};e(this._element.querySelectorAll(D.ITEM_IMG)).on(E.DRAG_START,function(t){return t.preventDefault()}),this._pointerEvent?(e(this._element).on(E.POINTERDOWN,function(t){return i(t)}),e(this._element).on(E.POINTERUP,function(t){return n(t)}),this._element.classList.add(S.POINTER_EVENT)):(e(this._element).on(E.TOUCHSTART,function(t){return i(t)}),e(this._element).on(E.TOUCHMOVE,function(e){return function(e){e.originalEvent.touches&&e.originalEvent.touches.length>1?t.touchDeltaX=0:t.touchDeltaX=e.originalEvent.touches[0].clientX-t.touchStartX}(e)}),e(this._element).on(E.TOUCHEND,function(t){return n(t)}))}},i._keydown=function(t){if(!/input|textarea/i.test(t.target.tagName))switch(t.which){case 37:t.preventDefault(),this.prev();break;case 39:t.preventDefault(),this.next()}},i._getItemIndex=function(t){return this._items=t&&t.parentNode?[].slice.call(t.parentNode.querySelectorAll(D.ITEM)):[],this._items.indexOf(t)},i._getItemByDirection=function(t,e){var i=t===C.NEXT,n=t===C.PREV,o=this._getItemIndex(e),r=this._items.length-1,s=n&&0===o||i&&o===r;if(s&&!this._config.wrap)return e;var a=t===C.PREV?-1:1,l=(o+a)%this._items.length;return-1===l?this._items[this._items.length-1]:this._items[l]},i._triggerSlideEvent=function(t,i){var n=this._getItemIndex(t),o=this._getItemIndex(this._element.querySelector(D.ACTIVE_ITEM)),r=e.Event(E.SLIDE,{relatedTarget:t,direction:i,from:o,to:n});return e(this._element).trigger(r),r},i._setActiveIndicatorElement=function(t){if(this._indicatorsElement){var i=[].slice.call(this._indicatorsElement.querySelectorAll(D.ACTIVE));e(i).removeClass(S.ACTIVE);var n=this._indicatorsElement.children[this._getItemIndex(t)];n&&e(n).addClass(S.ACTIVE)}},i._slide=function(t,i){var n,o,r,s=this,a=this._element.querySelector(D.ACTIVE_ITEM),l=this._getItemIndex(a),u=i||a&&this._getItemByDirection(t,a),d=this._getItemIndex(u),h=Boolean(this._interval);if(t===C.NEXT?(n=S.LEFT,o=S.NEXT,r=C.LEFT):(n=S.RIGHT,o=S.PREV,r=C.RIGHT),u&&e(u).hasClass(S.ACTIVE))this._isSliding=!1;else{var p=this._triggerSlideEvent(u,r);if(!p.isDefaultPrevented()&&a&&u){this._isSliding=!0,h&&this.pause(),this._setActiveIndicatorElement(u);var f=e.Event(E.SLID,{relatedTarget:u,direction:r,from:l,to:d});if(e(this._element).hasClass(S.SLIDE)){e(u).addClass(o),c.reflow(u),e(a).addClass(n),e(u).addClass(n);var m=parseInt(u.getAttribute("data-interval"),10);m?(this._config.defaultInterval=this._config.defaultInterval||this._config.interval,this._config.interval=m):this._config.interval=this._config.defaultInterval||this._config.interval;var g=c.getTransitionDurationFromElement(a);e(a).one(c.TRANSITION_END,function(){e(u).removeClass(n+" "+o).addClass(S.ACTIVE),e(a).removeClass(S.ACTIVE+" "+o+" "+n),s._isSliding=!1,setTimeout(function(){return e(s._element).trigger(f)},0)}).emulateTransitionEnd(g)}else e(a).removeClass(S.ACTIVE),e(u).addClass(S.ACTIVE),this._isSliding=!1,e(this._element).trigger(f);h&&this.cycle()}}},t._jQueryInterface=function(i){return this.each(function(){var n=e(this).data("bs.carousel"),o=s({},x,e(this).data());"object"==typeof i&&(o=s({},o,i));var r="string"==typeof i?i:o.slide;if(n||(n=new t(this,o),e(this).data("bs.carousel",n)),"number"==typeof i)n.to(i);else if("string"==typeof r){if(void 0===n[r])throw new TypeError('No method named "'+r+'"');n[r]()}else o.interval&&o.ride&&(n.pause(),n.cycle())})},t._dataApiClickHandler=function(i){var n=c.getSelectorFromElement(this);if(n){var o=e(n)[0];if(o&&e(o).hasClass(S.CAROUSEL)){var r=s({},e(o).data(),e(this).data()),a=this.getAttribute("data-slide-to");a&&(r.interval=!1),t._jQueryInterface.call(e(o),r),a&&e(o).data("bs.carousel").to(a),i.preventDefault()}}},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}},{key:"Default",get:function(){return x}}]),t}();e(document).on(E.CLICK_DATA_API,D.DATA_SLIDE,A._dataApiClickHandler),e(window).on(E.LOAD_DATA_API,function(){for(var t=[].slice.call(document.querySelectorAll(D.DATA_RIDE)),i=0,n=t.length;i<n;i++){var o=e(t[i]);A._jQueryInterface.call(o,o.data())}}),e.fn[b]=A._jQueryInterface,e.fn[b].Constructor=A,e.fn[b].noConflict=function(){return e.fn[b]=T,A._jQueryInterface};var O="collapse",I=e.fn[O],N={toggle:!0,parent:""},L={toggle:"boolean",parent:"(string|element)"},M={SHOW:"show.bs.collapse",SHOWN:"shown.bs.collapse",HIDE:"hide.bs.collapse",HIDDEN:"hidden.bs.collapse",CLICK_DATA_API:"click.bs.collapse.data-api"},$={SHOW:"show",COLLAPSE:"collapse",COLLAPSING:"collapsing",COLLAPSED:"collapsed"},P={WIDTH:"width",HEIGHT:"height"},H={ACTIVES:".show, .collapsing",DATA_TOGGLE:'[data-toggle="collapse"]'},R=function(){function t(t,e){this._isTransitioning=!1,this._element=t,this._config=this._getConfig(e),this._triggerArray=[].slice.call(document.querySelectorAll('[data-toggle="collapse"][href="#'+t.id+'"],[data-toggle="collapse"][data-target="#'+t.id+'"]'));for(var i=[].slice.call(document.querySelectorAll(H.DATA_TOGGLE)),n=0,o=i.length;n<o;n++){var r=i[n],s=c.getSelectorFromElement(r),a=[].slice.call(document.querySelectorAll(s)).filter(function(e){return e===t});null!==s&&a.length>0&&(this._selector=s,this._triggerArray.push(r))}this._parent=this._config.parent?this._getParent():null,this._config.parent||this._addAriaAndCollapsedClass(this._element,this._triggerArray),this._config.toggle&&this.toggle()}var i=t.prototype;return i.toggle=function(){e(this._element).hasClass($.SHOW)?this.hide():this.show()},i.show=function(){var i,n,o=this;if(!(this._isTransitioning||e(this._element).hasClass($.SHOW)||(this._parent&&0===(i=[].slice.call(this._parent.querySelectorAll(H.ACTIVES)).filter(function(t){return"string"==typeof o._config.parent?t.getAttribute("data-parent")===o._config.parent:t.classList.contains($.COLLAPSE)})).length&&(i=null),i&&(n=e(i).not(this._selector).data("bs.collapse"))&&n._isTransitioning))){var r=e.Event(M.SHOW);if(e(this._element).trigger(r),!r.isDefaultPrevented()){i&&(t._jQueryInterface.call(e(i).not(this._selector),"hide"),n||e(i).data("bs.collapse",null));var s=this._getDimension();e(this._element).removeClass($.COLLAPSE).addClass($.COLLAPSING),this._element.style[s]=0,this._triggerArray.length&&e(this._triggerArray).removeClass($.COLLAPSED).attr("aria-expanded",!0),this.setTransitioning(!0);var a=s[0].toUpperCase()+s.slice(1),l="scroll"+a,u=c.getTransitionDurationFromElement(this._element);e(this._element).one(c.TRANSITION_END,function(){e(o._element).removeClass($.COLLAPSING).addClass($.COLLAPSE).addClass($.SHOW),o._element.style[s]="",o.setTransitioning(!1),e(o._element).trigger(M.SHOWN)}).emulateTransitionEnd(u),this._element.style[s]=this._element[l]+"px"}}},i.hide=function(){var t=this;if(!this._isTransitioning&&e(this._element).hasClass($.SHOW)){var i=e.Event(M.HIDE);if(e(this._element).trigger(i),!i.isDefaultPrevented()){var n=this._getDimension();this._element.style[n]=this._element.getBoundingClientRect()[n]+"px",c.reflow(this._element),e(this._element).addClass($.COLLAPSING).removeClass($.COLLAPSE).removeClass($.SHOW);var o=this._triggerArray.length;if(o>0)for(var r=0;r<o;r++){var s=this._triggerArray[r],a=c.getSelectorFromElement(s);if(null!==a){var l=e([].slice.call(document.querySelectorAll(a)));l.hasClass($.SHOW)||e(s).addClass($.COLLAPSED).attr("aria-expanded",!1)}}this.setTransitioning(!0),this._element.style[n]="";var u=c.getTransitionDurationFromElement(this._element);e(this._element).one(c.TRANSITION_END,function(){t.setTransitioning(!1),e(t._element).removeClass($.COLLAPSING).addClass($.COLLAPSE).trigger(M.HIDDEN)}).emulateTransitionEnd(u)}}},i.setTransitioning=function(t){this._isTransitioning=t},i.dispose=function(){e.removeData(this._element,"bs.collapse"),this._config=null,this._parent=null,this._element=null,this._triggerArray=null,this._isTransitioning=null},i._getConfig=function(t){return(t=s({},N,t)).toggle=Boolean(t.toggle),c.typeCheckConfig(O,t,L),t},i._getDimension=function(){var t=e(this._element).hasClass(P.WIDTH);return t?P.WIDTH:P.HEIGHT},i._getParent=function(){var i,n=this;c.isElement(this._config.parent)?(i=this._config.parent,void 0!==this._config.parent.jquery&&(i=this._config.parent[0])):i=document.querySelector(this._config.parent);var o='[data-toggle="collapse"][data-parent="'+this._config.parent+'"]',r=[].slice.call(i.querySelectorAll(o));return e(r).each(function(e,i){n._addAriaAndCollapsedClass(t._getTargetFromElement(i),[i])}),i},i._addAriaAndCollapsedClass=function(t,i){var n=e(t).hasClass($.SHOW);i.length&&e(i).toggleClass($.COLLAPSED,!n).attr("aria-expanded",n)},t._getTargetFromElement=function(t){var e=c.getSelectorFromElement(t);return e?document.querySelector(e):null},t._jQueryInterface=function(i){return this.each(function(){var n=e(this),o=n.data("bs.collapse"),r=s({},N,n.data(),"object"==typeof i&&i?i:{});if(!o&&r.toggle&&/show|hide/.test(i)&&(r.toggle=!1),o||(o=new t(this,r),n.data("bs.collapse",o)),"string"==typeof i){if(void 0===o[i])throw new TypeError('No method named "'+i+'"');o[i]()}})},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}},{key:"Default",get:function(){return N}}]),t}();e(document).on(M.CLICK_DATA_API,H.DATA_TOGGLE,function(t){"A"===t.currentTarget.tagName&&t.preventDefault();var i=e(this),n=c.getSelectorFromElement(this),o=[].slice.call(document.querySelectorAll(n));e(o).each(function(){var t=e(this),n=t.data("bs.collapse"),o=n?"toggle":i.data();R._jQueryInterface.call(t,o)})}),e.fn[O]=R._jQueryInterface,e.fn[O].Constructor=R,e.fn[O].noConflict=function(){return e.fn[O]=I,R._jQueryInterface};var j="dropdown",F=e.fn[j],z=new RegExp("38|40|27"),W={HIDE:"hide.bs.dropdown",HIDDEN:"hidden.bs.dropdown",SHOW:"show.bs.dropdown",SHOWN:"shown.bs.dropdown",CLICK:"click.bs.dropdown",CLICK_DATA_API:"click.bs.dropdown.data-api",KEYDOWN_DATA_API:"keydown.bs.dropdown.data-api",KEYUP_DATA_API:"keyup.bs.dropdown.data-api"},U={DISABLED:"disabled",SHOW:"show",DROPUP:"dropup",DROPRIGHT:"dropright",DROPLEFT:"dropleft",MENURIGHT:"dropdown-menu-right",MENULEFT:"dropdown-menu-left",POSITION_STATIC:"position-static"},B={DATA_TOGGLE:'[data-toggle="dropdown"]',FORM_CHILD:".dropdown form",MENU:".dropdown-menu",NAVBAR_NAV:".navbar-nav",VISIBLE_ITEMS:".dropdown-menu .dropdown-item:not(.disabled):not(:disabled)"},q={TOP:"top-start",TOPEND:"top-end",BOTTOM:"bottom-start",BOTTOMEND:"bottom-end",RIGHT:"right-start",RIGHTEND:"right-end",LEFT:"left-start",LEFTEND:"left-end"},V={offset:0,flip:!0,boundary:"scrollParent",reference:"toggle",display:"dynamic"},Y={offset:"(number|string|function)",flip:"boolean",boundary:"(string|element)",reference:"(string|element)",display:"string"},G=function(){function t(t,e){this._element=t,this._popper=null,this._config=this._getConfig(e),this._menu=this._getMenuElement(),this._inNavbar=this._detectNavbar(),this._addEventListeners()}var n=t.prototype;return n.toggle=function(){if(!this._element.disabled&&!e(this._element).hasClass(U.DISABLED)){var n=t._getParentFromElement(this._element),o=e(this._menu).hasClass(U.SHOW);if(t._clearMenus(),!o){var r={relatedTarget:this._element},s=e.Event(W.SHOW,r);if(e(n).trigger(s),!s.isDefaultPrevented()){if(!this._inNavbar){if(void 0===i)throw new TypeError("Bootstrap's dropdowns require Popper.js (https://popper.js.org/)");var a=this._element;"parent"===this._config.reference?a=n:c.isElement(this._config.reference)&&(a=this._config.reference,void 0!==this._config.reference.jquery&&(a=this._config.reference[0])),"scrollParent"!==this._config.boundary&&e(n).addClass(U.POSITION_STATIC),this._popper=new i(a,this._menu,this._getPopperConfig())}"ontouchstart"in document.documentElement&&0===e(n).closest(B.NAVBAR_NAV).length&&e(document.body).children().on("mouseover",null,e.noop),this._element.focus(),this._element.setAttribute("aria-expanded",!0),e(this._menu).toggleClass(U.SHOW),e(n).toggleClass(U.SHOW).trigger(e.Event(W.SHOWN,r))}}}},n.show=function(){if(!(this._element.disabled||e(this._element).hasClass(U.DISABLED)||e(this._menu).hasClass(U.SHOW))){var i={relatedTarget:this._element},n=e.Event(W.SHOW,i),o=t._getParentFromElement(this._element);e(o).trigger(n),n.isDefaultPrevented()||(e(this._menu).toggleClass(U.SHOW),e(o).toggleClass(U.SHOW).trigger(e.Event(W.SHOWN,i)))}},n.hide=function(){if(!this._element.disabled&&!e(this._element).hasClass(U.DISABLED)&&e(this._menu).hasClass(U.SHOW)){var i={relatedTarget:this._element},n=e.Event(W.HIDE,i),o=t._getParentFromElement(this._element);e(o).trigger(n),n.isDefaultPrevented()||(e(this._menu).toggleClass(U.SHOW),e(o).toggleClass(U.SHOW).trigger(e.Event(W.HIDDEN,i)))}},n.dispose=function(){e.removeData(this._element,"bs.dropdown"),e(this._element).off(".bs.dropdown"),this._element=null,this._menu=null,null!==this._popper&&(this._popper.destroy(),this._popper=null)},n.update=function(){this._inNavbar=this._detectNavbar(),null!==this._popper&&this._popper.scheduleUpdate()},n._addEventListeners=function(){var t=this;e(this._element).on(W.CLICK,function(e){e.preventDefault(),e.stopPropagation(),t.toggle()})},n._getConfig=function(t){return t=s({},this.constructor.Default,e(this._element).data(),t),c.typeCheckConfig(j,t,this.constructor.DefaultType),t},n._getMenuElement=function(){if(!this._menu){var e=t._getParentFromElement(this._element);e&&(this._menu=e.querySelector(B.MENU))}return this._menu},n._getPlacement=function(){var t=e(this._element.parentNode),i=q.BOTTOM;return t.hasClass(U.DROPUP)?(i=q.TOP,e(this._menu).hasClass(U.MENURIGHT)&&(i=q.TOPEND)):t.hasClass(U.DROPRIGHT)?i=q.RIGHT:t.hasClass(U.DROPLEFT)?i=q.LEFT:e(this._menu).hasClass(U.MENURIGHT)&&(i=q.BOTTOMEND),i},n._detectNavbar=function(){return e(this._element).closest(".navbar").length>0},n._getOffset=function(){var t=this,e={};return"function"==typeof this._config.offset?e.fn=function(e){return e.offsets=s({},e.offsets,t._config.offset(e.offsets,t._element)||{}),e}:e.offset=this._config.offset,e},n._getPopperConfig=function(){var t={placement:this._getPlacement(),modifiers:{offset:this._getOffset(),flip:{enabled:this._config.flip},preventOverflow:{boundariesElement:this._config.boundary}}};return"static"===this._config.display&&(t.modifiers.applyStyle={enabled:!1}),t},t._jQueryInterface=function(i){return this.each(function(){var n=e(this).data("bs.dropdown"),o="object"==typeof i?i:null;if(n||(n=new t(this,o),e(this).data("bs.dropdown",n)),"string"==typeof i){if(void 0===n[i])throw new TypeError('No method named "'+i+'"');n[i]()}})},t._clearMenus=function(i){if(!i||3!==i.which&&("keyup"!==i.type||9===i.which))for(var n=[].slice.call(document.querySelectorAll(B.DATA_TOGGLE)),o=0,r=n.length;o<r;o++){var s=t._getParentFromElement(n[o]),a=e(n[o]).data("bs.dropdown"),l={relatedTarget:n[o]};if(i&&"click"===i.type&&(l.clickEvent=i),a){var c=a._menu;if(e(s).hasClass(U.SHOW)&&!(i&&("click"===i.type&&/input|textarea/i.test(i.target.tagName)||"keyup"===i.type&&9===i.which)&&e.contains(s,i.target))){var u=e.Event(W.HIDE,l);e(s).trigger(u),u.isDefaultPrevented()||("ontouchstart"in document.documentElement&&e(document.body).children().off("mouseover",null,e.noop),n[o].setAttribute("aria-expanded","false"),e(c).removeClass(U.SHOW),e(s).removeClass(U.SHOW).trigger(e.Event(W.HIDDEN,l)))}}}},t._getParentFromElement=function(t){var e,i=c.getSelectorFromElement(t);return i&&(e=document.querySelector(i)),e||t.parentNode},t._dataApiKeydownHandler=function(i){if((/input|textarea/i.test(i.target.tagName)?!(32===i.which||27!==i.which&&(40!==i.which&&38!==i.which||e(i.target).closest(B.MENU).length)):z.test(i.which))&&(i.preventDefault(),i.stopPropagation(),!this.disabled&&!e(this).hasClass(U.DISABLED))){var n=t._getParentFromElement(this),o=e(n).hasClass(U.SHOW);if(o&&(!o||27!==i.which&&32!==i.which)){var r=[].slice.call(n.querySelectorAll(B.VISIBLE_ITEMS));if(0!==r.length){var s=r.indexOf(i.target);38===i.which&&s>0&&s--,40===i.which&&s<r.length-1&&s++,s<0&&(s=0),r[s].focus()}}else{if(27===i.which){var a=n.querySelector(B.DATA_TOGGLE);e(a).trigger("focus")}e(this).trigger("click")}}},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}},{key:"Default",get:function(){return V}},{key:"DefaultType",get:function(){return Y}}]),t}();e(document).on(W.KEYDOWN_DATA_API,B.DATA_TOGGLE,G._dataApiKeydownHandler).on(W.KEYDOWN_DATA_API,B.MENU,G._dataApiKeydownHandler).on(W.CLICK_DATA_API+" "+W.KEYUP_DATA_API,G._clearMenus).on(W.CLICK_DATA_API,B.DATA_TOGGLE,function(t){t.preventDefault(),t.stopPropagation(),G._jQueryInterface.call(e(this),"toggle")}).on(W.CLICK_DATA_API,B.FORM_CHILD,function(t){t.stopPropagation()}),e.fn[j]=G._jQueryInterface,e.fn[j].Constructor=G,e.fn[j].noConflict=function(){return e.fn[j]=F,G._jQueryInterface};var X=e.fn.modal,K={backdrop:!0,keyboard:!0,focus:!0,show:!0},Q={backdrop:"(boolean|string)",keyboard:"boolean",focus:"boolean",show:"boolean"},J={HIDE:"hide.bs.modal",HIDDEN:"hidden.bs.modal",SHOW:"show.bs.modal",SHOWN:"shown.bs.modal",FOCUSIN:"focusin.bs.modal",RESIZE:"resize.bs.modal",CLICK_DISMISS:"click.dismiss.bs.modal",KEYDOWN_DISMISS:"keydown.dismiss.bs.modal",MOUSEUP_DISMISS:"mouseup.dismiss.bs.modal",MOUSEDOWN_DISMISS:"mousedown.dismiss.bs.modal",CLICK_DATA_API:"click.bs.modal.data-api"},Z={SCROLLABLE:"modal-dialog-scrollable",SCROLLBAR_MEASURER:"modal-scrollbar-measure",BACKDROP:"modal-backdrop",OPEN:"modal-open",FADE:"fade",SHOW:"show"},tt={DIALOG:".modal-dialog",MODAL_BODY:".modal-body",DATA_TOGGLE:'[data-toggle="modal"]',DATA_DISMISS:'[data-dismiss="modal"]',FIXED_CONTENT:".fixed-top, .fixed-bottom, .is-fixed, .sticky-top",STICKY_CONTENT:".sticky-top"},et=function(){function t(t,e){this._config=this._getConfig(e),this._element=t,this._dialog=t.querySelector(tt.DIALOG),this._backdrop=null,this._isShown=!1,this._isBodyOverflowing=!1,this._ignoreBackdropClick=!1,this._isTransitioning=!1,this._scrollbarWidth=0}var i=t.prototype;return i.toggle=function(t){return this._isShown?this.hide():this.show(t)},i.show=function(t){var i=this;if(!this._isShown&&!this._isTransitioning){e(this._element).hasClass(Z.FADE)&&(this._isTransitioning=!0);var n=e.Event(J.SHOW,{relatedTarget:t});e(this._element).trigger(n),this._isShown||n.isDefaultPrevented()||(this._isShown=!0,this._checkScrollbar(),this._setScrollbar(),this._adjustDialog(),this._setEscapeEvent(),this._setResizeEvent(),e(this._element).on(J.CLICK_DISMISS,tt.DATA_DISMISS,function(t){return i.hide(t)}),e(this._dialog).on(J.MOUSEDOWN_DISMISS,function(){e(i._element).one(J.MOUSEUP_DISMISS,function(t){e(t.target).is(i._element)&&(i._ignoreBackdropClick=!0)})}),this._showBackdrop(function(){return i._showElement(t)}))}},i.hide=function(t){var i=this;if(t&&t.preventDefault(),this._isShown&&!this._isTransitioning){var n=e.Event(J.HIDE);if(e(this._element).trigger(n),this._isShown&&!n.isDefaultPrevented()){this._isShown=!1;var o=e(this._element).hasClass(Z.FADE);if(o&&(this._isTransitioning=!0),this._setEscapeEvent(),this._setResizeEvent(),e(document).off(J.FOCUSIN),e(this._element).removeClass(Z.SHOW),e(this._element).off(J.CLICK_DISMISS),e(this._dialog).off(J.MOUSEDOWN_DISMISS),o){var r=c.getTransitionDurationFromElement(this._element);e(this._element).one(c.TRANSITION_END,function(t){return i._hideModal(t)}).emulateTransitionEnd(r)}else this._hideModal()}}},i.dispose=function(){[window,this._element,this._dialog].forEach(function(t){return e(t).off(".bs.modal")}),e(document).off(J.FOCUSIN),e.removeData(this._element,"bs.modal"),this._config=null,this._element=null,this._dialog=null,this._backdrop=null,this._isShown=null,this._isBodyOverflowing=null,this._ignoreBackdropClick=null,this._isTransitioning=null,this._scrollbarWidth=null},i.handleUpdate=function(){this._adjustDialog()},i._getConfig=function(t){return t=s({},K,t),c.typeCheckConfig("modal",t,Q),t},i._showElement=function(t){var i=this,n=e(this._element).hasClass(Z.FADE);this._element.parentNode&&this._element.parentNode.nodeType===Node.ELEMENT_NODE||document.body.appendChild(this._element),this._element.style.display="block",this._element.removeAttribute("aria-hidden"),this._element.setAttribute("aria-modal",!0),e(this._dialog).hasClass(Z.SCROLLABLE)?this._dialog.querySelector(tt.MODAL_BODY).scrollTop=0:this._element.scrollTop=0,n&&c.reflow(this._element),e(this._element).addClass(Z.SHOW),this._config.focus&&this._enforceFocus();var o=e.Event(J.SHOWN,{relatedTarget:t}),r=function(){i._config.focus&&i._element.focus(),i._isTransitioning=!1,e(i._element).trigger(o)};if(n){var s=c.getTransitionDurationFromElement(this._dialog);e(this._dialog).one(c.TRANSITION_END,r).emulateTransitionEnd(s)}else r()},i._enforceFocus=function(){var t=this;e(document).off(J.FOCUSIN).on(J.FOCUSIN,function(i){document!==i.target&&t._element!==i.target&&0===e(t._element).has(i.target).length&&t._element.focus()})},i._setEscapeEvent=function(){var t=this;this._isShown&&this._config.keyboard?e(this._element).on(J.KEYDOWN_DISMISS,function(e){27===e.which&&(e.preventDefault(),t.hide())}):this._isShown||e(this._element).off(J.KEYDOWN_DISMISS)},i._setResizeEvent=function(){var t=this;this._isShown?e(window).on(J.RESIZE,function(e){return t.handleUpdate(e)}):e(window).off(J.RESIZE)},i._hideModal=function(){var t=this;this._element.style.display="none",this._element.setAttribute("aria-hidden",!0),this._element.removeAttribute("aria-modal"),this._isTransitioning=!1,this._showBackdrop(function(){e(document.body).removeClass(Z.OPEN),t._resetAdjustments(),t._resetScrollbar(),e(t._element).trigger(J.HIDDEN)})},i._removeBackdrop=function(){this._backdrop&&(e(this._backdrop).remove(),this._backdrop=null)},i._showBackdrop=function(t){var i=this,n=e(this._element).hasClass(Z.FADE)?Z.FADE:"";if(this._isShown&&this._config.backdrop){if(this._backdrop=document.createElement("div"),this._backdrop.className=Z.BACKDROP,n&&this._backdrop.classList.add(n),e(this._backdrop).appendTo(document.body),e(this._element).on(J.CLICK_DISMISS,function(t){i._ignoreBackdropClick?i._ignoreBackdropClick=!1:t.target===t.currentTarget&&("static"===i._config.backdrop?i._element.focus():i.hide())}),n&&c.reflow(this._backdrop),e(this._backdrop).addClass(Z.SHOW),!t)return;if(!n)return void t();var o=c.getTransitionDurationFromElement(this._backdrop);e(this._backdrop).one(c.TRANSITION_END,t).emulateTransitionEnd(o)}else if(!this._isShown&&this._backdrop){e(this._backdrop).removeClass(Z.SHOW);var r=function(){i._removeBackdrop(),t&&t()};if(e(this._element).hasClass(Z.FADE)){var s=c.getTransitionDurationFromElement(this._backdrop);e(this._backdrop).one(c.TRANSITION_END,r).emulateTransitionEnd(s)}else r()}else t&&t()},i._adjustDialog=function(){var t=this._element.scrollHeight>document.documentElement.clientHeight;!this._isBodyOverflowing&&t&&(this._element.style.paddingLeft=this._scrollbarWidth+"px"),this._isBodyOverflowing&&!t&&(this._element.style.paddingRight=this._scrollbarWidth+"px")},i._resetAdjustments=function(){this._element.style.paddingLeft="",this._element.style.paddingRight=""},i._checkScrollbar=function(){var t=document.body.getBoundingClientRect();this._isBodyOverflowing=t.left+t.right<window.innerWidth,this._scrollbarWidth=this._getScrollbarWidth()},i._setScrollbar=function(){var t=this;if(this._isBodyOverflowing){var i=[].slice.call(document.querySelectorAll(tt.FIXED_CONTENT)),n=[].slice.call(document.querySelectorAll(tt.STICKY_CONTENT));e(i).each(function(i,n){var o=n.style.paddingRight,r=e(n).css("padding-right");e(n).data("padding-right",o).css("padding-right",parseFloat(r)+t._scrollbarWidth+"px")}),e(n).each(function(i,n){var o=n.style.marginRight,r=e(n).css("margin-right");e(n).data("margin-right",o).css("margin-right",parseFloat(r)-t._scrollbarWidth+"px")});var o=document.body.style.paddingRight,r=e(document.body).css("padding-right");e(document.body).data("padding-right",o).css("padding-right",parseFloat(r)+this._scrollbarWidth+"px")}e(document.body).addClass(Z.OPEN)},i._resetScrollbar=function(){var t=[].slice.call(document.querySelectorAll(tt.FIXED_CONTENT));e(t).each(function(t,i){var n=e(i).data("padding-right");e(i).removeData("padding-right"),i.style.paddingRight=n||""});var i=[].slice.call(document.querySelectorAll(""+tt.STICKY_CONTENT));e(i).each(function(t,i){var n=e(i).data("margin-right");void 0!==n&&e(i).css("margin-right",n).removeData("margin-right")});var n=e(document.body).data("padding-right");e(document.body).removeData("padding-right"),document.body.style.paddingRight=n||""},i._getScrollbarWidth=function(){var t=document.createElement("div");t.className=Z.SCROLLBAR_MEASURER,document.body.appendChild(t);var e=t.getBoundingClientRect().width-t.clientWidth;return document.body.removeChild(t),e},t._jQueryInterface=function(i,n){return this.each(function(){var o=e(this).data("bs.modal"),r=s({},K,e(this).data(),"object"==typeof i&&i?i:{});if(o||(o=new t(this,r),e(this).data("bs.modal",o)),"string"==typeof i){if(void 0===o[i])throw new TypeError('No method named "'+i+'"');o[i](n)}else r.show&&o.show(n)})},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}},{key:"Default",get:function(){return K}}]),t}();e(document).on(J.CLICK_DATA_API,tt.DATA_TOGGLE,function(t){var i,n=this,o=c.getSelectorFromElement(this);o&&(i=document.querySelector(o));var r=e(i).data("bs.modal")?"toggle":s({},e(i).data(),e(this).data());"A"!==this.tagName&&"AREA"!==this.tagName||t.preventDefault();var a=e(i).one(J.SHOW,function(t){t.isDefaultPrevented()||a.one(J.HIDDEN,function(){e(n).is(":visible")&&n.focus()})});et._jQueryInterface.call(e(i),r,this)}),e.fn.modal=et._jQueryInterface,e.fn.modal.Constructor=et,e.fn.modal.noConflict=function(){return e.fn.modal=X,et._jQueryInterface};var it=["background","cite","href","itemtype","longdesc","poster","src","xlink:href"],nt={"*":["class","dir","id","lang","role",/^aria-[\w-]*$/i],a:["target","href","title","rel"],area:[],b:[],br:[],col:[],code:[],div:[],em:[],hr:[],h1:[],h2:[],h3:[],h4:[],h5:[],h6:[],i:[],img:["src","alt","title","width","height"],li:[],ol:[],p:[],pre:[],s:[],small:[],span:[],sub:[],sup:[],strong:[],u:[],ul:[]},ot=/^(?:(?:https?|mailto|ftp|tel|file):|[^&:\/?#]*(?:[\/?#]|$))/gi,rt=/^data:(?:image\/(?:bmp|gif|jpeg|jpg|png|tiff|webp)|video\/(?:mpeg|mp4|ogg|webm)|audio\/(?:mp3|oga|ogg|opus));base64,[a-z0-9+\/]+=*$/i;function st(t,e,i){if(0===t.length)return t;if(i&&"function"==typeof i)return i(t);for(var n=new window.DOMParser,o=n.parseFromString(t,"text/html"),r=Object.keys(e),s=[].slice.call(o.body.querySelectorAll("*")),a=function(t,i){var n=s[t],o=n.nodeName.toLowerCase();if(-1===r.indexOf(n.nodeName.toLowerCase()))return n.parentNode.removeChild(n),"continue";var a=[].slice.call(n.attributes),l=[].concat(e["*"]||[],e[o]||[]);a.forEach(function(t){(function(t,e){var i=t.nodeName.toLowerCase();if(-1!==e.indexOf(i))return-1===it.indexOf(i)||Boolean(t.nodeValue.match(ot)||t.nodeValue.match(rt));for(var n=e.filter(function(t){return t instanceof RegExp}),o=0,r=n.length;o<r;o++)if(i.match(n[o]))return!0;return!1})(t,l)||n.removeAttribute(t.nodeName)})},l=0,c=s.length;l<c;l++)a(l);return o.body.innerHTML}var at="tooltip",lt=e.fn.tooltip,ct=new RegExp("(^|\\s)bs-tooltip\\S+","g"),ut=["sanitize","whiteList","sanitizeFn"],dt={animation:"boolean",template:"string",title:"(string|element|function)",trigger:"string",delay:"(number|object)",html:"boolean",selector:"(string|boolean)",placement:"(string|function)",offset:"(number|string|function)",container:"(string|element|boolean)",fallbackPlacement:"(string|array)",boundary:"(string|element)",sanitize:"boolean",sanitizeFn:"(null|function)",whiteList:"object"},ht={AUTO:"auto",TOP:"top",RIGHT:"right",BOTTOM:"bottom",LEFT:"left"},pt={animation:!0,template:'<div class="tooltip" role="tooltip"><div class="arrow"></div><div class="tooltip-inner"></div></div>',trigger:"hover focus",title:"",delay:0,html:!1,selector:!1,placement:"top",offset:0,container:!1,fallbackPlacement:"flip",boundary:"scrollParent",sanitize:!0,sanitizeFn:null,whiteList:nt},ft={SHOW:"show",OUT:"out"},mt={HIDE:"hide.bs.tooltip",HIDDEN:"hidden.bs.tooltip",SHOW:"show.bs.tooltip",SHOWN:"shown.bs.tooltip",INSERTED:"inserted.bs.tooltip",CLICK:"click.bs.tooltip",FOCUSIN:"focusin.bs.tooltip",FOCUSOUT:"focusout.bs.tooltip",MOUSEENTER:"mouseenter.bs.tooltip",MOUSELEAVE:"mouseleave.bs.tooltip"},gt={FADE:"fade",SHOW:"show"},vt={TOOLTIP:".tooltip",TOOLTIP_INNER:".tooltip-inner",ARROW:".arrow"},yt={HOVER:"hover",FOCUS:"focus",CLICK:"click",MANUAL:"manual"},bt=function(){function t(t,e){if(void 0===i)throw new TypeError("Bootstrap's tooltips require Popper.js (https://popper.js.org/)");this._isEnabled=!0,this._timeout=0,this._hoverState="",this._activeTrigger={},this._popper=null,this.element=t,this.config=this._getConfig(e),this.tip=null,this._setListeners()}var n=t.prototype;return n.enable=function(){this._isEnabled=!0},n.disable=function(){this._isEnabled=!1},n.toggleEnabled=function(){this._isEnabled=!this._isEnabled},n.toggle=function(t){if(this._isEnabled)if(t){var i=this.constructor.DATA_KEY,n=e(t.currentTarget).data(i);n||(n=new this.constructor(t.currentTarget,this._getDelegateConfig()),e(t.currentTarget).data(i,n)),n._activeTrigger.click=!n._activeTrigger.click,n._isWithActiveTrigger()?n._enter(null,n):n._leave(null,n)}else{if(e(this.getTipElement()).hasClass(gt.SHOW))return void this._leave(null,this);this._enter(null,this)}},n.dispose=function(){clearTimeout(this._timeout),e.removeData(this.element,this.constructor.DATA_KEY),e(this.element).off(this.constructor.EVENT_KEY),e(this.element).closest(".modal").off("hide.bs.modal"),this.tip&&e(this.tip).remove(),this._isEnabled=null,this._timeout=null,this._hoverState=null,this._activeTrigger=null,null!==this._popper&&this._popper.destroy(),this._popper=null,this.element=null,this.config=null,this.tip=null},n.show=function(){var t=this;if("none"===e(this.element).css("display"))throw new Error("Please use show on visible elements");var n=e.Event(this.constructor.Event.SHOW);if(this.isWithContent()&&this._isEnabled){e(this.element).trigger(n);var o=c.findShadowRoot(this.element),r=e.contains(null!==o?o:this.element.ownerDocument.documentElement,this.element);if(n.isDefaultPrevented()||!r)return;var s=this.getTipElement(),a=c.getUID(this.constructor.NAME);s.setAttribute("id",a),this.element.setAttribute("aria-describedby",a),this.setContent(),this.config.animation&&e(s).addClass(gt.FADE);var l="function"==typeof this.config.placement?this.config.placement.call(this,s,this.element):this.config.placement,u=this._getAttachment(l);this.addAttachmentClass(u);var d=this._getContainer();e(s).data(this.constructor.DATA_KEY,this),e.contains(this.element.ownerDocument.documentElement,this.tip)||e(s).appendTo(d),e(this.element).trigger(this.constructor.Event.INSERTED),this._popper=new i(this.element,s,{placement:u,modifiers:{offset:this._getOffset(),flip:{behavior:this.config.fallbackPlacement},arrow:{element:vt.ARROW},preventOverflow:{boundariesElement:this.config.boundary}},onCreate:function(e){e.originalPlacement!==e.placement&&t._handlePopperPlacementChange(e)},onUpdate:function(e){return t._handlePopperPlacementChange(e)}}),e(s).addClass(gt.SHOW),"ontouchstart"in document.documentElement&&e(document.body).children().on("mouseover",null,e.noop);var h=function(){t.config.animation&&t._fixTransition();var i=t._hoverState;t._hoverState=null,e(t.element).trigger(t.constructor.Event.SHOWN),i===ft.OUT&&t._leave(null,t)};if(e(this.tip).hasClass(gt.FADE)){var p=c.getTransitionDurationFromElement(this.tip);e(this.tip).one(c.TRANSITION_END,h).emulateTransitionEnd(p)}else h()}},n.hide=function(t){var i=this,n=this.getTipElement(),o=e.Event(this.constructor.Event.HIDE),r=function(){i._hoverState!==ft.SHOW&&n.parentNode&&n.parentNode.removeChild(n),i._cleanTipClass(),i.element.removeAttribute("aria-describedby"),e(i.element).trigger(i.constructor.Event.HIDDEN),null!==i._popper&&i._popper.destroy(),t&&t()};if(e(this.element).trigger(o),!o.isDefaultPrevented()){if(e(n).removeClass(gt.SHOW),"ontouchstart"in document.documentElement&&e(document.body).children().off("mouseover",null,e.noop),this._activeTrigger[yt.CLICK]=!1,this._activeTrigger[yt.FOCUS]=!1,this._activeTrigger[yt.HOVER]=!1,e(this.tip).hasClass(gt.FADE)){var s=c.getTransitionDurationFromElement(n);e(n).one(c.TRANSITION_END,r).emulateTransitionEnd(s)}else r();this._hoverState=""}},n.update=function(){null!==this._popper&&this._popper.scheduleUpdate()},n.isWithContent=function(){return Boolean(this.getTitle())},n.addAttachmentClass=function(t){e(this.getTipElement()).addClass("bs-tooltip-"+t)},n.getTipElement=function(){return this.tip=this.tip||e(this.config.template)[0],this.tip},n.setContent=function(){var t=this.getTipElement();this.setElementContent(e(t.querySelectorAll(vt.TOOLTIP_INNER)),this.getTitle()),e(t).removeClass(gt.FADE+" "+gt.SHOW)},n.setElementContent=function(t,i){"object"!=typeof i||!i.nodeType&&!i.jquery?this.config.html?(this.config.sanitize&&(i=st(i,this.config.whiteList,this.config.sanitizeFn)),t.html(i)):t.text(i):this.config.html?e(i).parent().is(t)||t.empty().append(i):t.text(e(i).text())},n.getTitle=function(){var t=this.element.getAttribute("data-original-title");return t||(t="function"==typeof this.config.title?this.config.title.call(this.element):this.config.title),t},n._getOffset=function(){var t=this,e={};return"function"==typeof this.config.offset?e.fn=function(e){return e.offsets=s({},e.offsets,t.config.offset(e.offsets,t.element)||{}),e}:e.offset=this.config.offset,e},n._getContainer=function(){return!1===this.config.container?document.body:c.isElement(this.config.container)?e(this.config.container):e(document).find(this.config.container)},n._getAttachment=function(t){return ht[t.toUpperCase()]},n._setListeners=function(){var t=this,i=this.config.trigger.split(" ");i.forEach(function(i){if("click"===i)e(t.element).on(t.constructor.Event.CLICK,t.config.selector,function(e){return t.toggle(e)});else if(i!==yt.MANUAL){var n=i===yt.HOVER?t.constructor.Event.MOUSEENTER:t.constructor.Event.FOCUSIN,o=i===yt.HOVER?t.constructor.Event.MOUSELEAVE:t.constructor.Event.FOCUSOUT;e(t.element).on(n,t.config.selector,function(e){return t._enter(e)}).on(o,t.config.selector,function(e){return t._leave(e)})}}),e(this.element).closest(".modal").on("hide.bs.modal",function(){t.element&&t.hide()}),this.config.selector?this.config=s({},this.config,{trigger:"manual",selector:""}):this._fixTitle()},n._fixTitle=function(){var t=typeof this.element.getAttribute("data-original-title");(this.element.getAttribute("title")||"string"!==t)&&(this.element.setAttribute("data-original-title",this.element.getAttribute("title")||""),this.element.setAttribute("title",""))},n._enter=function(t,i){var n=this.constructor.DATA_KEY;(i=i||e(t.currentTarget).data(n))||(i=new this.constructor(t.currentTarget,this._getDelegateConfig()),e(t.currentTarget).data(n,i)),t&&(i._activeTrigger["focusin"===t.type?yt.FOCUS:yt.HOVER]=!0),e(i.getTipElement()).hasClass(gt.SHOW)||i._hoverState===ft.SHOW?i._hoverState=ft.SHOW:(clearTimeout(i._timeout),i._hoverState=ft.SHOW,i.config.delay&&i.config.delay.show?i._timeout=setTimeout(function(){i._hoverState===ft.SHOW&&i.show()},i.config.delay.show):i.show())},n._leave=function(t,i){var n=this.constructor.DATA_KEY;(i=i||e(t.currentTarget).data(n))||(i=new this.constructor(t.currentTarget,this._getDelegateConfig()),e(t.currentTarget).data(n,i)),t&&(i._activeTrigger["focusout"===t.type?yt.FOCUS:yt.HOVER]=!1),i._isWithActiveTrigger()||(clearTimeout(i._timeout),i._hoverState=ft.OUT,i.config.delay&&i.config.delay.hide?i._timeout=setTimeout(function(){i._hoverState===ft.OUT&&i.hide()},i.config.delay.hide):i.hide())},n._isWithActiveTrigger=function(){for(var t in this._activeTrigger)if(this._activeTrigger[t])return!0;return!1},n._getConfig=function(t){var i=e(this.element).data();return Object.keys(i).forEach(function(t){-1!==ut.indexOf(t)&&delete i[t]}),"number"==typeof(t=s({},this.constructor.Default,i,"object"==typeof t&&t?t:{})).delay&&(t.delay={show:t.delay,hide:t.delay}),"number"==typeof t.title&&(t.title=t.title.toString()),"number"==typeof t.content&&(t.content=t.content.toString()),c.typeCheckConfig(at,t,this.constructor.DefaultType),t.sanitize&&(t.template=st(t.template,t.whiteList,t.sanitizeFn)),t},n._getDelegateConfig=function(){var t={};if(this.config)for(var e in this.config)this.constructor.Default[e]!==this.config[e]&&(t[e]=this.config[e]);return t},n._cleanTipClass=function(){var t=e(this.getTipElement()),i=t.attr("class").match(ct);null!==i&&i.length&&t.removeClass(i.join(""))},n._handlePopperPlacementChange=function(t){var e=t.instance;this.tip=e.popper,this._cleanTipClass(),this.addAttachmentClass(this._getAttachment(t.placement))},n._fixTransition=function(){var t=this.getTipElement(),i=this.config.animation;null===t.getAttribute("x-placement")&&(e(t).removeClass(gt.FADE),this.config.animation=!1,this.hide(),this.show(),this.config.animation=i)},t._jQueryInterface=function(i){return this.each(function(){var n=e(this).data("bs.tooltip"),o="object"==typeof i&&i;if((n||!/dispose|hide/.test(i))&&(n||(n=new t(this,o),e(this).data("bs.tooltip",n)),"string"==typeof i)){if(void 0===n[i])throw new TypeError('No method named "'+i+'"');n[i]()}})},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}},{key:"Default",get:function(){return pt}},{key:"NAME",get:function(){return at}},{key:"DATA_KEY",get:function(){return"bs.tooltip"}},{key:"Event",get:function(){return mt}},{key:"EVENT_KEY",get:function(){return".bs.tooltip"}},{key:"DefaultType",get:function(){return dt}}]),t}();e.fn.tooltip=bt._jQueryInterface,e.fn.tooltip.Constructor=bt,e.fn.tooltip.noConflict=function(){return e.fn.tooltip=lt,bt._jQueryInterface};var wt="popover",Tt=e.fn.popover,xt=new RegExp("(^|\\s)bs-popover\\S+","g"),_t=s({},bt.Default,{placement:"right",trigger:"click",content:"",template:'<div class="popover" role="tooltip"><div class="arrow"></div><h3 class="popover-header"></h3><div class="popover-body"></div></div>'}),Ct=s({},bt.DefaultType,{content:"(string|element|function)"}),Et={FADE:"fade",SHOW:"show"},St={TITLE:".popover-header",CONTENT:".popover-body"},Dt={HIDE:"hide.bs.popover",HIDDEN:"hidden.bs.popover",SHOW:"show.bs.popover",SHOWN:"shown.bs.popover",INSERTED:"inserted.bs.popover",CLICK:"click.bs.popover",FOCUSIN:"focusin.bs.popover",FOCUSOUT:"focusout.bs.popover",MOUSEENTER:"mouseenter.bs.popover",MOUSELEAVE:"mouseleave.bs.popover"},kt=function(t){var i,n;function r(){return t.apply(this,arguments)||this}n=t,(i=r).prototype=Object.create(n.prototype),i.prototype.constructor=i,i.__proto__=n;var s=r.prototype;return s.isWithContent=function(){return this.getTitle()||this._getContent()},s.addAttachmentClass=function(t){e(this.getTipElement()).addClass("bs-popover-"+t)},s.getTipElement=function(){return this.tip=this.tip||e(this.config.template)[0],this.tip},s.setContent=function(){var t=e(this.getTipElement());this.setElementContent(t.find(St.TITLE),this.getTitle());var i=this._getContent();"function"==typeof i&&(i=i.call(this.element)),this.setElementContent(t.find(St.CONTENT),i),t.removeClass(Et.FADE+" "+Et.SHOW)},s._getContent=function(){return this.element.getAttribute("data-content")||this.config.content},s._cleanTipClass=function(){var t=e(this.getTipElement()),i=t.attr("class").match(xt);null!==i&&i.length>0&&t.removeClass(i.join(""))},r._jQueryInterface=function(t){return this.each(function(){var i=e(this).data("bs.popover"),n="object"==typeof t?t:null;if((i||!/dispose|hide/.test(t))&&(i||(i=new r(this,n),e(this).data("bs.popover",i)),"string"==typeof t)){if(void 0===i[t])throw new TypeError('No method named "'+t+'"');i[t]()}})},o(r,null,[{key:"VERSION",get:function(){return"4.3.1"}},{key:"Default",get:function(){return _t}},{key:"NAME",get:function(){return wt}},{key:"DATA_KEY",get:function(){return"bs.popover"}},{key:"Event",get:function(){return Dt}},{key:"EVENT_KEY",get:function(){return".bs.popover"}},{key:"DefaultType",get:function(){return Ct}}]),r}(bt);e.fn.popover=kt._jQueryInterface,e.fn.popover.Constructor=kt,e.fn.popover.noConflict=function(){return e.fn.popover=Tt,kt._jQueryInterface};var At="scrollspy",Ot=e.fn[At],It={offset:10,method:"auto",target:""},Nt={offset:"number",method:"string",target:"(string|element)"},Lt={ACTIVATE:"activate.bs.scrollspy",SCROLL:"scroll.bs.scrollspy",LOAD_DATA_API:"load.bs.scrollspy.data-api"},Mt={DROPDOWN_ITEM:"dropdown-item",DROPDOWN_MENU:"dropdown-menu",ACTIVE:"active"},$t={DATA_SPY:'[data-spy="scroll"]',ACTIVE:".active",NAV_LIST_GROUP:".nav, .list-group",NAV_LINKS:".nav-link",NAV_ITEMS:".nav-item",LIST_ITEMS:".list-group-item",DROPDOWN:".dropdown",DROPDOWN_ITEMS:".dropdown-item",DROPDOWN_TOGGLE:".dropdown-toggle"},Pt={OFFSET:"offset",POSITION:"position"},Ht=function(){function t(t,i){var n=this;this._element=t,this._scrollElement="BODY"===t.tagName?window:t,this._config=this._getConfig(i),this._selector=this._config.target+" "+$t.NAV_LINKS+","+this._config.target+" "+$t.LIST_ITEMS+","+this._config.target+" "+$t.DROPDOWN_ITEMS,this._offsets=[],this._targets=[],this._activeTarget=null,this._scrollHeight=0,e(this._scrollElement).on(Lt.SCROLL,function(t){return n._process(t)}),this.refresh(),this._process()}var i=t.prototype;return i.refresh=function(){var t=this,i=this._scrollElement===this._scrollElement.window?Pt.OFFSET:Pt.POSITION,n="auto"===this._config.method?i:this._config.method,o=n===Pt.POSITION?this._getScrollTop():0;this._offsets=[],this._targets=[],this._scrollHeight=this._getScrollHeight();var r=[].slice.call(document.querySelectorAll(this._selector));r.map(function(t){var i,r=c.getSelectorFromElement(t);if(r&&(i=document.querySelector(r)),i){var s=i.getBoundingClientRect();if(s.width||s.height)return[e(i)[n]().top+o,r]}return null}).filter(function(t){return t}).sort(function(t,e){return t[0]-e[0]}).forEach(function(e){t._offsets.push(e[0]),t._targets.push(e[1])})},i.dispose=function(){e.removeData(this._element,"bs.scrollspy"),e(this._scrollElement).off(".bs.scrollspy"),this._element=null,this._scrollElement=null,this._config=null,this._selector=null,this._offsets=null,this._targets=null,this._activeTarget=null,this._scrollHeight=null},i._getConfig=function(t){if("string"!=typeof(t=s({},It,"object"==typeof t&&t?t:{})).target){var i=e(t.target).attr("id");i||(i=c.getUID(At),e(t.target).attr("id",i)),t.target="#"+i}return c.typeCheckConfig(At,t,Nt),t},i._getScrollTop=function(){return this._scrollElement===window?this._scrollElement.pageYOffset:this._scrollElement.scrollTop},i._getScrollHeight=function(){return this._scrollElement.scrollHeight||Math.max(document.body.scrollHeight,document.documentElement.scrollHeight)},i._getOffsetHeight=function(){return this._scrollElement===window?window.innerHeight:this._scrollElement.getBoundingClientRect().height},i._process=function(){var t=this._getScrollTop()+this._config.offset,e=this._getScrollHeight(),i=this._config.offset+e-this._getOffsetHeight();if(this._scrollHeight!==e&&this.refresh(),t>=i){var n=this._targets[this._targets.length-1];this._activeTarget!==n&&this._activate(n)}else{if(this._activeTarget&&t<this._offsets[0]&&this._offsets[0]>0)return this._activeTarget=null,void this._clear();for(var o=this._offsets.length,r=o;r--;){var s=this._activeTarget!==this._targets[r]&&t>=this._offsets[r]&&(void 0===this._offsets[r+1]||t<this._offsets[r+1]);s&&this._activate(this._targets[r])}}},i._activate=function(t){this._activeTarget=t,this._clear();var i=this._selector.split(",").map(function(e){return e+'[data-target="'+t+'"],'+e+'[href="'+t+'"]'}),n=e([].slice.call(document.querySelectorAll(i.join(","))));n.hasClass(Mt.DROPDOWN_ITEM)?(n.closest($t.DROPDOWN).find($t.DROPDOWN_TOGGLE).addClass(Mt.ACTIVE),n.addClass(Mt.ACTIVE)):(n.addClass(Mt.ACTIVE),n.parents($t.NAV_LIST_GROUP).prev($t.NAV_LINKS+", "+$t.LIST_ITEMS).addClass(Mt.ACTIVE),n.parents($t.NAV_LIST_GROUP).prev($t.NAV_ITEMS).children($t.NAV_LINKS).addClass(Mt.ACTIVE)),e(this._scrollElement).trigger(Lt.ACTIVATE,{relatedTarget:t})},i._clear=function(){[].slice.call(document.querySelectorAll(this._selector)).filter(function(t){return t.classList.contains(Mt.ACTIVE)}).forEach(function(t){return t.classList.remove(Mt.ACTIVE)})},t._jQueryInterface=function(i){return this.each(function(){var n=e(this).data("bs.scrollspy"),o="object"==typeof i&&i;if(n||(n=new t(this,o),e(this).data("bs.scrollspy",n)),"string"==typeof i){if(void 0===n[i])throw new TypeError('No method named "'+i+'"');n[i]()}})},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}},{key:"Default",get:function(){return It}}]),t}();e(window).on(Lt.LOAD_DATA_API,function(){for(var t=[].slice.call(document.querySelectorAll($t.DATA_SPY)),i=t.length,n=i;n--;){var o=e(t[n]);Ht._jQueryInterface.call(o,o.data())}}),e.fn[At]=Ht._jQueryInterface,e.fn[At].Constructor=Ht,e.fn[At].noConflict=function(){return e.fn[At]=Ot,Ht._jQueryInterface};var Rt=e.fn.tab,jt={HIDE:"hide.bs.tab",HIDDEN:"hidden.bs.tab",SHOW:"show.bs.tab",SHOWN:"shown.bs.tab",CLICK_DATA_API:"click.bs.tab.data-api"},Ft={DROPDOWN_MENU:"dropdown-menu",ACTIVE:"active",DISABLED:"disabled",FADE:"fade",SHOW:"show"},zt={DROPDOWN:".dropdown",NAV_LIST_GROUP:".nav, .list-group",ACTIVE:".active",ACTIVE_UL:"> li > .active",DATA_TOGGLE:'[data-toggle="tab"], [data-toggle="pill"], [data-toggle="list"]',DROPDOWN_TOGGLE:".dropdown-toggle",DROPDOWN_ACTIVE_CHILD:"> .dropdown-menu .active"},Wt=function(){function t(t){this._element=t}var i=t.prototype;return i.show=function(){var t=this;if(!(this._element.parentNode&&this._element.parentNode.nodeType===Node.ELEMENT_NODE&&e(this._element).hasClass(Ft.ACTIVE)||e(this._element).hasClass(Ft.DISABLED))){var i,n,o=e(this._element).closest(zt.NAV_LIST_GROUP)[0],r=c.getSelectorFromElement(this._element);if(o){var s="UL"===o.nodeName||"OL"===o.nodeName?zt.ACTIVE_UL:zt.ACTIVE;n=(n=e.makeArray(e(o).find(s)))[n.length-1]}var a=e.Event(jt.HIDE,{relatedTarget:this._element}),l=e.Event(jt.SHOW,{relatedTarget:n});if(n&&e(n).trigger(a),e(this._element).trigger(l),!l.isDefaultPrevented()&&!a.isDefaultPrevented()){r&&(i=document.querySelector(r)),this._activate(this._element,o);var u=function(){var i=e.Event(jt.HIDDEN,{relatedTarget:t._element}),o=e.Event(jt.SHOWN,{relatedTarget:n});e(n).trigger(i),e(t._element).trigger(o)};i?this._activate(i,i.parentNode,u):u()}}},i.dispose=function(){e.removeData(this._element,"bs.tab"),this._element=null},i._activate=function(t,i,n){var o=this,r=!i||"UL"!==i.nodeName&&"OL"!==i.nodeName?e(i).children(zt.ACTIVE):e(i).find(zt.ACTIVE_UL),s=r[0],a=n&&s&&e(s).hasClass(Ft.FADE),l=function(){return o._transitionComplete(t,s,n)};if(s&&a){var u=c.getTransitionDurationFromElement(s);e(s).removeClass(Ft.SHOW).one(c.TRANSITION_END,l).emulateTransitionEnd(u)}else l()},i._transitionComplete=function(t,i,n){if(i){e(i).removeClass(Ft.ACTIVE);var o=e(i.parentNode).find(zt.DROPDOWN_ACTIVE_CHILD)[0];o&&e(o).removeClass(Ft.ACTIVE),"tab"===i.getAttribute("role")&&i.setAttribute("aria-selected",!1)}if(e(t).addClass(Ft.ACTIVE),"tab"===t.getAttribute("role")&&t.setAttribute("aria-selected",!0),c.reflow(t),t.classList.contains(Ft.FADE)&&t.classList.add(Ft.SHOW),t.parentNode&&e(t.parentNode).hasClass(Ft.DROPDOWN_MENU)){var r=e(t).closest(zt.DROPDOWN)[0];if(r){var s=[].slice.call(r.querySelectorAll(zt.DROPDOWN_TOGGLE));e(s).addClass(Ft.ACTIVE)}t.setAttribute("aria-expanded",!0)}n&&n()},t._jQueryInterface=function(i){return this.each(function(){var n=e(this),o=n.data("bs.tab");if(o||(o=new t(this),n.data("bs.tab",o)),"string"==typeof i){if(void 0===o[i])throw new TypeError('No method named "'+i+'"');o[i]()}})},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}}]),t}();e(document).on(jt.CLICK_DATA_API,zt.DATA_TOGGLE,function(t){t.preventDefault(),Wt._jQueryInterface.call(e(this),"show")}),e.fn.tab=Wt._jQueryInterface,e.fn.tab.Constructor=Wt,e.fn.tab.noConflict=function(){return e.fn.tab=Rt,Wt._jQueryInterface};var Ut=e.fn.toast,Bt={CLICK_DISMISS:"click.dismiss.bs.toast",HIDE:"hide.bs.toast",HIDDEN:"hidden.bs.toast",SHOW:"show.bs.toast",SHOWN:"shown.bs.toast"},qt={FADE:"fade",HIDE:"hide",SHOW:"show",SHOWING:"showing"},Vt={animation:"boolean",autohide:"boolean",delay:"number"},Yt={animation:!0,autohide:!0,delay:500},Gt={DATA_DISMISS:'[data-dismiss="toast"]'},Xt=function(){function t(t,e){this._element=t,this._config=this._getConfig(e),this._timeout=null,this._setListeners()}var i=t.prototype;return i.show=function(){var t=this;e(this._element).trigger(Bt.SHOW),this._config.animation&&this._element.classList.add(qt.FADE);var i=function(){t._element.classList.remove(qt.SHOWING),t._element.classList.add(qt.SHOW),e(t._element).trigger(Bt.SHOWN),t._config.autohide&&t.hide()};if(this._element.classList.remove(qt.HIDE),this._element.classList.add(qt.SHOWING),this._config.animation){var n=c.getTransitionDurationFromElement(this._element);e(this._element).one(c.TRANSITION_END,i).emulateTransitionEnd(n)}else i()},i.hide=function(t){var i=this;this._element.classList.contains(qt.SHOW)&&(e(this._element).trigger(Bt.HIDE),t?this._close():this._timeout=setTimeout(function(){i._close()},this._config.delay))},i.dispose=function(){clearTimeout(this._timeout),this._timeout=null,this._element.classList.contains(qt.SHOW)&&this._element.classList.remove(qt.SHOW),e(this._element).off(Bt.CLICK_DISMISS),e.removeData(this._element,"bs.toast"),this._element=null,this._config=null},i._getConfig=function(t){return t=s({},Yt,e(this._element).data(),"object"==typeof t&&t?t:{}),c.typeCheckConfig("toast",t,this.constructor.DefaultType),t},i._setListeners=function(){var t=this;e(this._element).on(Bt.CLICK_DISMISS,Gt.DATA_DISMISS,function(){return t.hide(!0)})},i._close=function(){var t=this,i=function(){t._element.classList.add(qt.HIDE),e(t._element).trigger(Bt.HIDDEN)};if(this._element.classList.remove(qt.SHOW),this._config.animation){var n=c.getTransitionDurationFromElement(this._element);e(this._element).one(c.TRANSITION_END,i).emulateTransitionEnd(n)}else i()},t._jQueryInterface=function(i){return this.each(function(){var n=e(this),o=n.data("bs.toast"),r="object"==typeof i&&i;if(o||(o=new t(this,r),n.data("bs.toast",o)),"string"==typeof i){if(void 0===o[i])throw new TypeError('No method named "'+i+'"');o[i](this)}})},o(t,null,[{key:"VERSION",get:function(){return"4.3.1"}},{key:"DefaultType",get:function(){return Vt}},{key:"Default",get:function(){return Yt}}]),t}();e.fn.toast=Xt._jQueryInterface,e.fn.toast.Constructor=Xt,e.fn.toast.noConflict=function(){return e.fn.toast=Ut,Xt._jQueryInterface},function(){if(void 0===e)throw new TypeError("Bootstrap's JavaScript requires jQuery. jQuery must be included before Bootstrap's JavaScript.");var t=e.fn.jquery.split(" ")[0].split(".");if(t[0]<2&&t[1]<9||1===t[0]&&9===t[1]&&t[2]<1||t[0]>=4)throw new Error("Bootstrap's JavaScript requires at least jQuery v1.9.1 but less than v4.0.0")}(),t.Util=c,t.Alert=p,t.Button=y,t.Carousel=A,t.Collapse=R,t.Dropdown=G,t.Modal=et,t.Popover=kt,t.Scrollspy=Ht,t.Tab=Wt,t.Toast=Xt,t.Tooltip=bt,Object.defineProperty(t,"__esModule",{value:!0})}(e,i(1),i(163))},163:function(t,e,i){"use strict";i.r(e),function(t){for(
/**!
 * @fileOverview Kickass library to create and place poppers near their reference elements.
 * @version 1.15.0
 * @license
 * Copyright (c) 2016 Federico Zivolo and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var i="undefined"!=typeof window&&"undefined"!=typeof document,n=["Edge","Trident","Firefox"],o=0,r=0;r<n.length;r+=1)if(i&&navigator.userAgent.indexOf(n[r])>=0){o=1;break}var s=i&&window.Promise?function(t){var e=!1;return function(){e||(e=!0,window.Promise.resolve().then(function(){e=!1,t()}))}}:function(t){var e=!1;return function(){e||(e=!0,setTimeout(function(){e=!1,t()},o))}};function a(t){return t&&"[object Function]"==={}.toString.call(t)}function l(t,e){if(1!==t.nodeType)return[];var i=t.ownerDocument.defaultView.getComputedStyle(t,null);return e?i[e]:i}function c(t){return"HTML"===t.nodeName?t:t.parentNode||t.host}function u(t){if(!t)return document.body;switch(t.nodeName){case"HTML":case"BODY":return t.ownerDocument.body;case"#document":return t.body}var e=l(t),i=e.overflow,n=e.overflowX,o=e.overflowY;return/(auto|scroll|overlay)/.test(i+o+n)?t:u(c(t))}var d=i&&!(!window.MSInputMethodContext||!document.documentMode),h=i&&/MSIE 10/.test(navigator.userAgent);function p(t){return 11===t?d:10===t?h:d||h}function f(t){if(!t)return document.documentElement;for(var e=p(10)?document.body:null,i=t.offsetParent||null;i===e&&t.nextElementSibling;)i=(t=t.nextElementSibling).offsetParent;var n=i&&i.nodeName;return n&&"BODY"!==n&&"HTML"!==n?-1!==["TH","TD","TABLE"].indexOf(i.nodeName)&&"static"===l(i,"position")?f(i):i:t?t.ownerDocument.documentElement:document.documentElement}function m(t){return null!==t.parentNode?m(t.parentNode):t}function g(t,e){if(!(t&&t.nodeType&&e&&e.nodeType))return document.documentElement;var i=t.compareDocumentPosition(e)&Node.DOCUMENT_POSITION_FOLLOWING,n=i?t:e,o=i?e:t,r=document.createRange();r.setStart(n,0),r.setEnd(o,0);var s,a,l=r.commonAncestorContainer;if(t!==l&&e!==l||n.contains(o))return"BODY"===(a=(s=l).nodeName)||"HTML"!==a&&f(s.firstElementChild)!==s?f(l):l;var c=m(t);return c.host?g(c.host,e):g(t,m(e).host)}function v(t){var e="top"===(arguments.length>1&&void 0!==arguments[1]?arguments[1]:"top")?"scrollTop":"scrollLeft",i=t.nodeName;if("BODY"===i||"HTML"===i){var n=t.ownerDocument.documentElement;return(t.ownerDocument.scrollingElement||n)[e]}return t[e]}function y(t,e){var i="x"===e?"Left":"Top",n="Left"===i?"Right":"Bottom";return parseFloat(t["border"+i+"Width"],10)+parseFloat(t["border"+n+"Width"],10)}function b(t,e,i,n){return Math.max(e["offset"+t],e["scroll"+t],i["client"+t],i["offset"+t],i["scroll"+t],p(10)?parseInt(i["offset"+t])+parseInt(n["margin"+("Height"===t?"Top":"Left")])+parseInt(n["margin"+("Height"===t?"Bottom":"Right")]):0)}function w(t){var e=t.body,i=t.documentElement,n=p(10)&&getComputedStyle(i);return{height:b("Height",e,i,n),width:b("Width",e,i,n)}}var T=function(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")},x=function(){function t(t,e){for(var i=0;i<e.length;i++){var n=e[i];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(t,n.key,n)}}return function(e,i,n){return i&&t(e.prototype,i),n&&t(e,n),e}}(),_=function(t,e,i){return e in t?Object.defineProperty(t,e,{value:i,enumerable:!0,configurable:!0,writable:!0}):t[e]=i,t},C=Object.assign||function(t){for(var e=1;e<arguments.length;e++){var i=arguments[e];for(var n in i)Object.prototype.hasOwnProperty.call(i,n)&&(t[n]=i[n])}return t};function E(t){return C({},t,{right:t.left+t.width,bottom:t.top+t.height})}function S(t){var e={};try{if(p(10)){e=t.getBoundingClientRect();var i=v(t,"top"),n=v(t,"left");e.top+=i,e.left+=n,e.bottom+=i,e.right+=n}else e=t.getBoundingClientRect()}catch(t){}var o={left:e.left,top:e.top,width:e.right-e.left,height:e.bottom-e.top},r="HTML"===t.nodeName?w(t.ownerDocument):{},s=r.width||t.clientWidth||o.right-o.left,a=r.height||t.clientHeight||o.bottom-o.top,c=t.offsetWidth-s,u=t.offsetHeight-a;if(c||u){var d=l(t);c-=y(d,"x"),u-=y(d,"y"),o.width-=c,o.height-=u}return E(o)}function D(t,e){var i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=p(10),o="HTML"===e.nodeName,r=S(t),s=S(e),a=u(t),c=l(e),d=parseFloat(c.borderTopWidth,10),h=parseFloat(c.borderLeftWidth,10);i&&o&&(s.top=Math.max(s.top,0),s.left=Math.max(s.left,0));var f=E({top:r.top-s.top-d,left:r.left-s.left-h,width:r.width,height:r.height});if(f.marginTop=0,f.marginLeft=0,!n&&o){var m=parseFloat(c.marginTop,10),g=parseFloat(c.marginLeft,10);f.top-=d-m,f.bottom-=d-m,f.left-=h-g,f.right-=h-g,f.marginTop=m,f.marginLeft=g}return(n&&!i?e.contains(a):e===a&&"BODY"!==a.nodeName)&&(f=function(t,e){var i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=v(e,"top"),o=v(e,"left"),r=i?-1:1;return t.top+=n*r,t.bottom+=n*r,t.left+=o*r,t.right+=o*r,t}(f,e)),f}function k(t){if(!t||!t.parentElement||p())return document.documentElement;for(var e=t.parentElement;e&&"none"===l(e,"transform");)e=e.parentElement;return e||document.documentElement}function A(t,e,i,n){var o=arguments.length>4&&void 0!==arguments[4]&&arguments[4],r={top:0,left:0},s=o?k(t):g(t,e);if("viewport"===n)r=function(t){var e=arguments.length>1&&void 0!==arguments[1]&&arguments[1],i=t.ownerDocument.documentElement,n=D(t,i),o=Math.max(i.clientWidth,window.innerWidth||0),r=Math.max(i.clientHeight,window.innerHeight||0),s=e?0:v(i),a=e?0:v(i,"left");return E({top:s-n.top+n.marginTop,left:a-n.left+n.marginLeft,width:o,height:r})}(s,o);else{var a=void 0;"scrollParent"===n?"BODY"===(a=u(c(e))).nodeName&&(a=t.ownerDocument.documentElement):a="window"===n?t.ownerDocument.documentElement:n;var d=D(a,s,o);if("HTML"!==a.nodeName||function t(e){var i=e.nodeName;if("BODY"===i||"HTML"===i)return!1;if("fixed"===l(e,"position"))return!0;var n=c(e);return!!n&&t(n)}(s))r=d;else{var h=w(t.ownerDocument),p=h.height,f=h.width;r.top+=d.top-d.marginTop,r.bottom=p+d.top,r.left+=d.left-d.marginLeft,r.right=f+d.left}}var m="number"==typeof(i=i||0);return r.left+=m?i:i.left||0,r.top+=m?i:i.top||0,r.right-=m?i:i.right||0,r.bottom-=m?i:i.bottom||0,r}function O(t,e,i,n,o){var r=arguments.length>5&&void 0!==arguments[5]?arguments[5]:0;if(-1===t.indexOf("auto"))return t;var s=A(i,n,r,o),a={top:{width:s.width,height:e.top-s.top},right:{width:s.right-e.right,height:s.height},bottom:{width:s.width,height:s.bottom-e.bottom},left:{width:e.left-s.left,height:s.height}},l=Object.keys(a).map(function(t){return C({key:t},a[t],{area:(e=a[t],e.width*e.height)});var e}).sort(function(t,e){return e.area-t.area}),c=l.filter(function(t){var e=t.width,n=t.height;return e>=i.clientWidth&&n>=i.clientHeight}),u=c.length>0?c[0].key:l[0].key,d=t.split("-")[1];return u+(d?"-"+d:"")}function I(t,e,i){var n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:null;return D(i,n?k(e):g(e,i),n)}function N(t){var e=t.ownerDocument.defaultView.getComputedStyle(t),i=parseFloat(e.marginTop||0)+parseFloat(e.marginBottom||0),n=parseFloat(e.marginLeft||0)+parseFloat(e.marginRight||0);return{width:t.offsetWidth+n,height:t.offsetHeight+i}}function L(t){var e={left:"right",right:"left",bottom:"top",top:"bottom"};return t.replace(/left|right|bottom|top/g,function(t){return e[t]})}function M(t,e,i){i=i.split("-")[0];var n=N(t),o={width:n.width,height:n.height},r=-1!==["right","left"].indexOf(i),s=r?"top":"left",a=r?"left":"top",l=r?"height":"width",c=r?"width":"height";return o[s]=e[s]+e[l]/2-n[l]/2,o[a]=i===a?e[a]-n[c]:e[L(a)],o}function $(t,e){return Array.prototype.find?t.find(e):t.filter(e)[0]}function P(t,e,i){return(void 0===i?t:t.slice(0,function(t,e,i){if(Array.prototype.findIndex)return t.findIndex(function(t){return t[e]===i});var n=$(t,function(t){return t[e]===i});return t.indexOf(n)}(t,"name",i))).forEach(function(t){t.function&&console.warn("`modifier.function` is deprecated, use `modifier.fn`!");var i=t.function||t.fn;t.enabled&&a(i)&&(e.offsets.popper=E(e.offsets.popper),e.offsets.reference=E(e.offsets.reference),e=i(e,t))}),e}function H(t,e){return t.some(function(t){var i=t.name;return t.enabled&&i===e})}function R(t){for(var e=[!1,"ms","Webkit","Moz","O"],i=t.charAt(0).toUpperCase()+t.slice(1),n=0;n<e.length;n++){var o=e[n],r=o?""+o+i:t;if(void 0!==document.body.style[r])return r}return null}function j(t){var e=t.ownerDocument;return e?e.defaultView:window}function F(t,e,i,n){i.updateBound=n,j(t).addEventListener("resize",i.updateBound,{passive:!0});var o=u(t);return function t(e,i,n,o){var r="BODY"===e.nodeName,s=r?e.ownerDocument.defaultView:e;s.addEventListener(i,n,{passive:!0}),r||t(u(s.parentNode),i,n,o),o.push(s)}(o,"scroll",i.updateBound,i.scrollParents),i.scrollElement=o,i.eventsEnabled=!0,i}function z(){var t,e;this.state.eventsEnabled&&(cancelAnimationFrame(this.scheduleUpdate),this.state=(t=this.reference,e=this.state,j(t).removeEventListener("resize",e.updateBound),e.scrollParents.forEach(function(t){t.removeEventListener("scroll",e.updateBound)}),e.updateBound=null,e.scrollParents=[],e.scrollElement=null,e.eventsEnabled=!1,e))}function W(t){return""!==t&&!isNaN(parseFloat(t))&&isFinite(t)}function U(t,e){Object.keys(e).forEach(function(i){var n="";-1!==["width","height","top","right","bottom","left"].indexOf(i)&&W(e[i])&&(n="px"),t.style[i]=e[i]+n})}var B=i&&/Firefox/i.test(navigator.userAgent);function q(t,e,i){var n=$(t,function(t){return t.name===e}),o=!!n&&t.some(function(t){return t.name===i&&t.enabled&&t.order<n.order});if(!o){var r="`"+e+"`",s="`"+i+"`";console.warn(s+" modifier is required by "+r+" modifier in order to work, be sure to include it before "+r+"!")}return o}var V=["auto-start","auto","auto-end","top-start","top","top-end","right-start","right","right-end","bottom-end","bottom","bottom-start","left-end","left","left-start"],Y=V.slice(3);function G(t){var e=arguments.length>1&&void 0!==arguments[1]&&arguments[1],i=Y.indexOf(t),n=Y.slice(i+1).concat(Y.slice(0,i));return e?n.reverse():n}var X={FLIP:"flip",CLOCKWISE:"clockwise",COUNTERCLOCKWISE:"counterclockwise"};function K(t,e,i,n){var o=[0,0],r=-1!==["right","left"].indexOf(n),s=t.split(/(\+|\-)/).map(function(t){return t.trim()}),a=s.indexOf($(s,function(t){return-1!==t.search(/,|\s/)}));s[a]&&-1===s[a].indexOf(",")&&console.warn("Offsets separated by white space(s) are deprecated, use a comma (,) instead.");var l=/\s*,\s*|\s+/,c=-1!==a?[s.slice(0,a).concat([s[a].split(l)[0]]),[s[a].split(l)[1]].concat(s.slice(a+1))]:[s];return(c=c.map(function(t,n){var o=(1===n?!r:r)?"height":"width",s=!1;return t.reduce(function(t,e){return""===t[t.length-1]&&-1!==["+","-"].indexOf(e)?(t[t.length-1]=e,s=!0,t):s?(t[t.length-1]+=e,s=!1,t):t.concat(e)},[]).map(function(t){return function(t,e,i,n){var o=t.match(/((?:\-|\+)?\d*\.?\d*)(.*)/),r=+o[1],s=o[2];if(!r)return t;if(0===s.indexOf("%")){var a=void 0;switch(s){case"%p":a=i;break;case"%":case"%r":default:a=n}return E(a)[e]/100*r}if("vh"===s||"vw"===s)return("vh"===s?Math.max(document.documentElement.clientHeight,window.innerHeight||0):Math.max(document.documentElement.clientWidth,window.innerWidth||0))/100*r;return r}(t,o,e,i)})})).forEach(function(t,e){t.forEach(function(i,n){W(i)&&(o[e]+=i*("-"===t[n-1]?-1:1))})}),o}var Q={placement:"bottom",positionFixed:!1,eventsEnabled:!0,removeOnDestroy:!1,onCreate:function(){},onUpdate:function(){},modifiers:{shift:{order:100,enabled:!0,fn:function(t){var e=t.placement,i=e.split("-")[0],n=e.split("-")[1];if(n){var o=t.offsets,r=o.reference,s=o.popper,a=-1!==["bottom","top"].indexOf(i),l=a?"left":"top",c=a?"width":"height",u={start:_({},l,r[l]),end:_({},l,r[l]+r[c]-s[c])};t.offsets.popper=C({},s,u[n])}return t}},offset:{order:200,enabled:!0,fn:function(t,e){var i=e.offset,n=t.placement,o=t.offsets,r=o.popper,s=o.reference,a=n.split("-")[0],l=void 0;return l=W(+i)?[+i,0]:K(i,r,s,a),"left"===a?(r.top+=l[0],r.left-=l[1]):"right"===a?(r.top+=l[0],r.left+=l[1]):"top"===a?(r.left+=l[0],r.top-=l[1]):"bottom"===a&&(r.left+=l[0],r.top+=l[1]),t.popper=r,t},offset:0},preventOverflow:{order:300,enabled:!0,fn:function(t,e){var i=e.boundariesElement||f(t.instance.popper);t.instance.reference===i&&(i=f(i));var n=R("transform"),o=t.instance.popper.style,r=o.top,s=o.left,a=o[n];o.top="",o.left="",o[n]="";var l=A(t.instance.popper,t.instance.reference,e.padding,i,t.positionFixed);o.top=r,o.left=s,o[n]=a,e.boundaries=l;var c=e.priority,u=t.offsets.popper,d={primary:function(t){var i=u[t];return u[t]<l[t]&&!e.escapeWithReference&&(i=Math.max(u[t],l[t])),_({},t,i)},secondary:function(t){var i="right"===t?"left":"top",n=u[i];return u[t]>l[t]&&!e.escapeWithReference&&(n=Math.min(u[i],l[t]-("right"===t?u.width:u.height))),_({},i,n)}};return c.forEach(function(t){var e=-1!==["left","top"].indexOf(t)?"primary":"secondary";u=C({},u,d[e](t))}),t.offsets.popper=u,t},priority:["left","right","top","bottom"],padding:5,boundariesElement:"scrollParent"},keepTogether:{order:400,enabled:!0,fn:function(t){var e=t.offsets,i=e.popper,n=e.reference,o=t.placement.split("-")[0],r=Math.floor,s=-1!==["top","bottom"].indexOf(o),a=s?"right":"bottom",l=s?"left":"top",c=s?"width":"height";return i[a]<r(n[l])&&(t.offsets.popper[l]=r(n[l])-i[c]),i[l]>r(n[a])&&(t.offsets.popper[l]=r(n[a])),t}},arrow:{order:500,enabled:!0,fn:function(t,e){var i;if(!q(t.instance.modifiers,"arrow","keepTogether"))return t;var n=e.element;if("string"==typeof n){if(!(n=t.instance.popper.querySelector(n)))return t}else if(!t.instance.popper.contains(n))return console.warn("WARNING: `arrow.element` must be child of its popper element!"),t;var o=t.placement.split("-")[0],r=t.offsets,s=r.popper,a=r.reference,c=-1!==["left","right"].indexOf(o),u=c?"height":"width",d=c?"Top":"Left",h=d.toLowerCase(),p=c?"left":"top",f=c?"bottom":"right",m=N(n)[u];a[f]-m<s[h]&&(t.offsets.popper[h]-=s[h]-(a[f]-m)),a[h]+m>s[f]&&(t.offsets.popper[h]+=a[h]+m-s[f]),t.offsets.popper=E(t.offsets.popper);var g=a[h]+a[u]/2-m/2,v=l(t.instance.popper),y=parseFloat(v["margin"+d],10),b=parseFloat(v["border"+d+"Width"],10),w=g-t.offsets.popper[h]-y-b;return w=Math.max(Math.min(s[u]-m,w),0),t.arrowElement=n,t.offsets.arrow=(_(i={},h,Math.round(w)),_(i,p,""),i),t},element:"[x-arrow]"},flip:{order:600,enabled:!0,fn:function(t,e){if(H(t.instance.modifiers,"inner"))return t;if(t.flipped&&t.placement===t.originalPlacement)return t;var i=A(t.instance.popper,t.instance.reference,e.padding,e.boundariesElement,t.positionFixed),n=t.placement.split("-")[0],o=L(n),r=t.placement.split("-")[1]||"",s=[];switch(e.behavior){case X.FLIP:s=[n,o];break;case X.CLOCKWISE:s=G(n);break;case X.COUNTERCLOCKWISE:s=G(n,!0);break;default:s=e.behavior}return s.forEach(function(a,l){if(n!==a||s.length===l+1)return t;n=t.placement.split("-")[0],o=L(n);var c=t.offsets.popper,u=t.offsets.reference,d=Math.floor,h="left"===n&&d(c.right)>d(u.left)||"right"===n&&d(c.left)<d(u.right)||"top"===n&&d(c.bottom)>d(u.top)||"bottom"===n&&d(c.top)<d(u.bottom),p=d(c.left)<d(i.left),f=d(c.right)>d(i.right),m=d(c.top)<d(i.top),g=d(c.bottom)>d(i.bottom),v="left"===n&&p||"right"===n&&f||"top"===n&&m||"bottom"===n&&g,y=-1!==["top","bottom"].indexOf(n),b=!!e.flipVariations&&(y&&"start"===r&&p||y&&"end"===r&&f||!y&&"start"===r&&m||!y&&"end"===r&&g),w=!!e.flipVariationsByContent&&(y&&"start"===r&&f||y&&"end"===r&&p||!y&&"start"===r&&g||!y&&"end"===r&&m),T=b||w;(h||v||T)&&(t.flipped=!0,(h||v)&&(n=s[l+1]),T&&(r=function(t){return"end"===t?"start":"start"===t?"end":t}(r)),t.placement=n+(r?"-"+r:""),t.offsets.popper=C({},t.offsets.popper,M(t.instance.popper,t.offsets.reference,t.placement)),t=P(t.instance.modifiers,t,"flip"))}),t},behavior:"flip",padding:5,boundariesElement:"viewport",flipVariations:!1,flipVariationsByContent:!1},inner:{order:700,enabled:!1,fn:function(t){var e=t.placement,i=e.split("-")[0],n=t.offsets,o=n.popper,r=n.reference,s=-1!==["left","right"].indexOf(i),a=-1===["top","left"].indexOf(i);return o[s?"left":"top"]=r[i]-(a?o[s?"width":"height"]:0),t.placement=L(e),t.offsets.popper=E(o),t}},hide:{order:800,enabled:!0,fn:function(t){if(!q(t.instance.modifiers,"hide","preventOverflow"))return t;var e=t.offsets.reference,i=$(t.instance.modifiers,function(t){return"preventOverflow"===t.name}).boundaries;if(e.bottom<i.top||e.left>i.right||e.top>i.bottom||e.right<i.left){if(!0===t.hide)return t;t.hide=!0,t.attributes["x-out-of-boundaries"]=""}else{if(!1===t.hide)return t;t.hide=!1,t.attributes["x-out-of-boundaries"]=!1}return t}},computeStyle:{order:850,enabled:!0,fn:function(t,e){var i=e.x,n=e.y,o=t.offsets.popper,r=$(t.instance.modifiers,function(t){return"applyStyle"===t.name}).gpuAcceleration;void 0!==r&&console.warn("WARNING: `gpuAcceleration` option moved to `computeStyle` modifier and will not be supported in future versions of Popper.js!");var s=void 0!==r?r:e.gpuAcceleration,a=f(t.instance.popper),l=S(a),c={position:o.position},u=function(t,e){var i=t.offsets,n=i.popper,o=i.reference,r=Math.round,s=Math.floor,a=function(t){return t},l=r(o.width),c=r(n.width),u=-1!==["left","right"].indexOf(t.placement),d=-1!==t.placement.indexOf("-"),h=e?u||d||l%2==c%2?r:s:a,p=e?r:a;return{left:h(l%2==1&&c%2==1&&!d&&e?n.left-1:n.left),top:p(n.top),bottom:p(n.bottom),right:h(n.right)}}(t,window.devicePixelRatio<2||!B),d="bottom"===i?"top":"bottom",h="right"===n?"left":"right",p=R("transform"),m=void 0,g=void 0;if(g="bottom"===d?"HTML"===a.nodeName?-a.clientHeight+u.bottom:-l.height+u.bottom:u.top,m="right"===h?"HTML"===a.nodeName?-a.clientWidth+u.right:-l.width+u.right:u.left,s&&p)c[p]="translate3d("+m+"px, "+g+"px, 0)",c[d]=0,c[h]=0,c.willChange="transform";else{var v="bottom"===d?-1:1,y="right"===h?-1:1;c[d]=g*v,c[h]=m*y,c.willChange=d+", "+h}var b={"x-placement":t.placement};return t.attributes=C({},b,t.attributes),t.styles=C({},c,t.styles),t.arrowStyles=C({},t.offsets.arrow,t.arrowStyles),t},gpuAcceleration:!0,x:"bottom",y:"right"},applyStyle:{order:900,enabled:!0,fn:function(t){var e,i;return U(t.instance.popper,t.styles),e=t.instance.popper,i=t.attributes,Object.keys(i).forEach(function(t){!1!==i[t]?e.setAttribute(t,i[t]):e.removeAttribute(t)}),t.arrowElement&&Object.keys(t.arrowStyles).length&&U(t.arrowElement,t.arrowStyles),t},onLoad:function(t,e,i,n,o){var r=I(o,e,t,i.positionFixed),s=O(i.placement,r,e,t,i.modifiers.flip.boundariesElement,i.modifiers.flip.padding);return e.setAttribute("x-placement",s),U(e,{position:i.positionFixed?"fixed":"absolute"}),i},gpuAcceleration:void 0}}},J=function(){function t(e,i){var n=this,o=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};T(this,t),this.scheduleUpdate=function(){return requestAnimationFrame(n.update)},this.update=s(this.update.bind(this)),this.options=C({},t.Defaults,o),this.state={isDestroyed:!1,isCreated:!1,scrollParents:[]},this.reference=e&&e.jquery?e[0]:e,this.popper=i&&i.jquery?i[0]:i,this.options.modifiers={},Object.keys(C({},t.Defaults.modifiers,o.modifiers)).forEach(function(e){n.options.modifiers[e]=C({},t.Defaults.modifiers[e]||{},o.modifiers?o.modifiers[e]:{})}),this.modifiers=Object.keys(this.options.modifiers).map(function(t){return C({name:t},n.options.modifiers[t])}).sort(function(t,e){return t.order-e.order}),this.modifiers.forEach(function(t){t.enabled&&a(t.onLoad)&&t.onLoad(n.reference,n.popper,n.options,t,n.state)}),this.update();var r=this.options.eventsEnabled;r&&this.enableEventListeners(),this.state.eventsEnabled=r}return x(t,[{key:"update",value:function(){return function(){if(!this.state.isDestroyed){var t={instance:this,styles:{},arrowStyles:{},attributes:{},flipped:!1,offsets:{}};t.offsets.reference=I(this.state,this.popper,this.reference,this.options.positionFixed),t.placement=O(this.options.placement,t.offsets.reference,this.popper,this.reference,this.options.modifiers.flip.boundariesElement,this.options.modifiers.flip.padding),t.originalPlacement=t.placement,t.positionFixed=this.options.positionFixed,t.offsets.popper=M(this.popper,t.offsets.reference,t.placement),t.offsets.popper.position=this.options.positionFixed?"fixed":"absolute",t=P(this.modifiers,t),this.state.isCreated?this.options.onUpdate(t):(this.state.isCreated=!0,this.options.onCreate(t))}}.call(this)}},{key:"destroy",value:function(){return function(){return this.state.isDestroyed=!0,H(this.modifiers,"applyStyle")&&(this.popper.removeAttribute("x-placement"),this.popper.style.position="",this.popper.style.top="",this.popper.style.left="",this.popper.style.right="",this.popper.style.bottom="",this.popper.style.willChange="",this.popper.style[R("transform")]=""),this.disableEventListeners(),this.options.removeOnDestroy&&this.popper.parentNode.removeChild(this.popper),this}.call(this)}},{key:"enableEventListeners",value:function(){return function(){this.state.eventsEnabled||(this.state=F(this.reference,this.options,this.state,this.scheduleUpdate))}.call(this)}},{key:"disableEventListeners",value:function(){return z.call(this)}}]),t}();J.Utils=("undefined"!=typeof window?window:t).PopperUtils,J.placements=V,J.Defaults=Q,e.default=J}.call(this,i(4))},2:function(t,e,i){(function(i){var n,o,r;void 0!==i||window||this.window||this.global,o=[],n=function(t){"use strict";var e={},i="iziToast",n=(document.querySelector("body"),!!/Mobi/.test(navigator.userAgent)),o=/Chrome/.test(navigator.userAgent)&&/Google Inc/.test(navigator.vendor),r="undefined"!=typeof InstallTrigger,s="ontouchstart"in document.documentElement,a=["bottomRight","bottomLeft","bottomCenter","topRight","topLeft","topCenter","center"],l=568,c={};e.children={};var u={id:null,class:"",title:"",titleColor:"",titleSize:"",titleLineHeight:"",message:"",messageColor:"",messageSize:"",messageLineHeight:"",backgroundColor:"",theme:"light",color:"",icon:"",iconText:"",iconColor:"",iconUrl:null,image:"",imageWidth:50,maxWidth:null,zindex:null,layout:1,balloon:!1,close:!0,closeOnEscape:!1,closeOnClick:!1,displayMode:0,position:"bottomRight",target:"",targetFirst:!0,timeout:5e3,rtl:!1,animateInside:!0,drag:!0,pauseOnHover:!0,resetOnHover:!1,progressBar:!0,progressBarColor:"",progressBarEasing:"linear",overlay:!1,overlayClose:!1,overlayColor:"rgba(0, 0, 0, 0.6)",transitionIn:"fadeInUp",transitionOut:"fadeOut",transitionInMobile:"fadeInUp",transitionOutMobile:"fadeOutDown",buttons:{},inputs:{},onOpening:function(){},onOpened:function(){},onClosing:function(){},onClosed:function(){}};if("remove"in Element.prototype||(Element.prototype.remove=function(){this.parentNode&&this.parentNode.removeChild(this)}),"function"!=typeof window.CustomEvent){var d=function(t,e){e=e||{bubbles:!1,cancelable:!1,detail:void 0};var i=document.createEvent("CustomEvent");return i.initCustomEvent(t,e.bubbles,e.cancelable,e.detail),i};d.prototype=window.Event.prototype,window.CustomEvent=d}var h=function(t,e,i){if("[object Object]"===Object.prototype.toString.call(t))for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&e.call(i,t[n],n,t);else if(t)for(var o=0,r=t.length;r>o;o++)e.call(i,t[o],o,t)},p=function(t,e){var i={};return h(t,function(e,n){i[n]=t[n]}),h(e,function(t,n){i[n]=e[n]}),i},f=function(t){var e=document.createDocumentFragment(),i=document.createElement("div");for(i.innerHTML=t;i.firstChild;)e.appendChild(i.firstChild);return e},m={move:function(t,e,n,s){var a,l=180;0!==s&&(t.classList.add(i+"-dragged"),t.style.transform="translateX("+s+"px)",s>0?.3>(a=(l-s)/l)&&e.hide(p(n,{transitionOut:"fadeOutRight",transitionOutMobile:"fadeOutRight"}),t,"drag"):.3>(a=(l+s)/l)&&e.hide(p(n,{transitionOut:"fadeOutLeft",transitionOutMobile:"fadeOutLeft"}),t,"drag"),t.style.opacity=a,.3>a&&((o||r)&&(t.style.left=s+"px"),t.parentNode.style.opacity=.3,this.stopMoving(t,null)))},startMoving:function(t,e,i,n){n=n||window.event;var o=s?n.touches[0].clientX:n.clientX,r=t.style.transform.replace("px)","");r=r.replace("translateX(","");var a=o-r;i.transitionIn&&t.classList.remove(i.transitionIn),i.transitionInMobile&&t.classList.remove(i.transitionInMobile),t.style.transition="",s?document.ontouchmove=function(n){n.preventDefault();var o=(n=n||window.event).touches[0].clientX,r=o-a;m.move(t,e,i,r)}:document.onmousemove=function(n){n.preventDefault();var o=(n=n||window.event).clientX,r=o-a;m.move(t,e,i,r)}},stopMoving:function(t,e){s?document.ontouchmove=function(){}:document.onmousemove=function(){},t.style.opacity="",t.style.transform="",t.classList.contains(i+"-dragged")&&(t.classList.remove(i+"-dragged"),t.style.transition="transform 0.4s ease, opacity 0.4s ease",setTimeout(function(){t.style.transition=""},400))}};return e.setSetting=function(t,i,n){e.children[t][i]=n},e.getSetting=function(t,i){return e.children[t][i]},e.destroy=function(){h(document.querySelectorAll("."+i+"-overlay"),function(t,e){t.remove()}),h(document.querySelectorAll("."+i+"-wrapper"),function(t,e){t.remove()}),h(document.querySelectorAll("."+i),function(t,e){t.remove()}),this.children={},document.removeEventListener(i+"-opened",{},!1),document.removeEventListener(i+"-opening",{},!1),document.removeEventListener(i+"-closing",{},!1),document.removeEventListener(i+"-closed",{},!1),document.removeEventListener("keyup",{},!1),c={}},e.settings=function(t){e.destroy(),c=t,u=p(u,t||{})},h({info:{color:"blue",icon:"ico-info"},success:{color:"green",icon:"ico-success"},warning:{color:"orange",icon:"ico-warning"},error:{color:"red",icon:"ico-error"},question:{color:"yellow",icon:"ico-question"}},function(t,i){e[i]=function(e){var i=p(c,e||{});i=p(t,i||{}),this.show(i)}}),e.progress=function(t,e,n){var o=this,r=e.getAttribute("data-iziToast-ref"),s=p(this.children[r],t||{}),a=e.querySelector("."+i+"-progressbar div");return{start:function(){void 0===s.time.REMAINING&&(e.classList.remove(i+"-reseted"),null!==a&&(a.style.transition="width "+s.timeout+"ms "+s.progressBarEasing,a.style.width="0%"),s.time.START=(new Date).getTime(),s.time.END=s.time.START+s.timeout,s.time.TIMER=setTimeout(function(){clearTimeout(s.time.TIMER),e.classList.contains(i+"-closing")||(o.hide(s,e,"timeout"),"function"==typeof n&&n.apply(o))},s.timeout),o.setSetting(r,"time",s.time))},pause:function(){if(void 0!==s.time.START&&!e.classList.contains(i+"-paused")&&!e.classList.contains(i+"-reseted")){if(e.classList.add(i+"-paused"),s.time.REMAINING=s.time.END-(new Date).getTime(),clearTimeout(s.time.TIMER),o.setSetting(r,"time",s.time),null!==a){var t=window.getComputedStyle(a),l=t.getPropertyValue("width");a.style.transition="none",a.style.width=l}"function"==typeof n&&setTimeout(function(){n.apply(o)},10)}},resume:function(){void 0!==s.time.REMAINING?(e.classList.remove(i+"-paused"),null!==a&&(a.style.transition="width "+s.time.REMAINING+"ms "+s.progressBarEasing,a.style.width="0%"),s.time.END=(new Date).getTime()+s.time.REMAINING,s.time.TIMER=setTimeout(function(){clearTimeout(s.time.TIMER),e.classList.contains(i+"-closing")||(o.hide(s,e,"timeout"),"function"==typeof n&&n.apply(o))},s.time.REMAINING),o.setSetting(r,"time",s.time)):this.start()},reset:function(){clearTimeout(s.time.TIMER),delete s.time.REMAINING,o.setSetting(r,"time",s.time),e.classList.add(i+"-reseted"),e.classList.remove(i+"-paused"),null!==a&&(a.style.transition="none",a.style.width="100%"),"function"==typeof n&&setTimeout(function(){n.apply(o)},10)}}},e.hide=function(t,e,o){"object"!=typeof e&&(e=document.querySelector(e));var r=this,s=p(this.children[e.getAttribute("data-iziToast-ref")],t||{});s.closedBy=o||null,delete s.time.REMAINING,e.classList.add(i+"-closing"),function(){var t=document.querySelector("."+i+"-overlay");if(null!==t){var e=t.getAttribute("data-iziToast-ref"),n=(e=e.split(",")).indexOf(String(s.ref));-1!==n&&e.splice(n,1),t.setAttribute("data-iziToast-ref",e.join()),0===e.length&&(t.classList.remove("fadeIn"),t.classList.add("fadeOut"),setTimeout(function(){t.remove()},700))}}(),s.transitionIn&&e.classList.remove(s.transitionIn),s.transitionInMobile&&e.classList.remove(s.transitionInMobile),n||window.innerWidth<=l?s.transitionOutMobile&&e.classList.add(s.transitionOutMobile):s.transitionOut&&e.classList.add(s.transitionOut);var a=e.parentNode.offsetHeight;e.parentNode.style.height=a+"px",e.style.pointerEvents="none",(!n||window.innerWidth>l)&&(e.parentNode.style.transitionDelay="0.2s");try{var c=new CustomEvent(i+"-closing",{detail:s,bubbles:!0,cancelable:!0});document.dispatchEvent(c)}catch(t){console.warn(t)}setTimeout(function(){e.parentNode.style.height="0px",e.parentNode.style.overflow="",setTimeout(function(){delete r.children[s.ref],e.parentNode.remove();try{var t=new CustomEvent(i+"-closed",{detail:s,bubbles:!0,cancelable:!0});document.dispatchEvent(t)}catch(t){console.warn(t)}void 0!==s.onClosed&&s.onClosed.apply(null,[s,e,o])},1e3)},200),void 0!==s.onClosing&&s.onClosing.apply(null,[s,e,o])},e.show=function(t){var o=this,r=p(c,t||{});if((r=p(u,r)).time={},null===r.id&&(r.id=function(t){return btoa(encodeURIComponent(t)).replace(/=/g,"")}(r.title+r.message+r.color)),1===r.displayMode||"once"==r.displayMode)try{if(document.querySelectorAll("."+i+"#"+r.id).length>0)return!1}catch(t){console.warn("["+i+"] Could not find an element with this selector: #"+r.id+". Try to set an valid id.")}if(2===r.displayMode||"replace"==r.displayMode)try{h(document.querySelectorAll("."+i+"#"+r.id),function(t,e){o.hide(r,t,"replaced")})}catch(t){console.warn("["+i+"] Could not find an element with this selector: #"+r.id+". Try to set an valid id.")}r.ref=(new Date).getTime()+Math.floor(1e7*Math.random()+1),e.children[r.ref]=r;var d,g={body:document.querySelector("body"),overlay:document.createElement("div"),toast:document.createElement("div"),toastBody:document.createElement("div"),toastTexts:document.createElement("div"),toastCapsule:document.createElement("div"),cover:document.createElement("div"),buttons:document.createElement("div"),inputs:document.createElement("div"),icon:r.iconUrl?document.createElement("img"):document.createElement("i"),wrapper:null};g.toast.setAttribute("data-iziToast-ref",r.ref),g.toast.appendChild(g.toastBody),g.toastCapsule.appendChild(g.toast),function(){if(g.toast.classList.add(i),g.toast.classList.add(i+"-opening"),g.toastCapsule.classList.add(i+"-capsule"),g.toastBody.classList.add(i+"-body"),g.toastTexts.classList.add(i+"-texts"),n||window.innerWidth<=l?r.transitionInMobile&&g.toast.classList.add(r.transitionInMobile):r.transitionIn&&g.toast.classList.add(r.transitionIn),r.class){var t=r.class.split(" ");h(t,function(t,e){g.toast.classList.add(t)})}r.id&&(g.toast.id=r.id),r.rtl&&(g.toast.classList.add(i+"-rtl"),g.toast.setAttribute("dir","rtl")),r.layout>1&&g.toast.classList.add(i+"-layout"+r.layout),r.balloon&&g.toast.classList.add(i+"-balloon"),r.maxWidth&&(isNaN(r.maxWidth)?g.toast.style.maxWidth=r.maxWidth:g.toast.style.maxWidth=r.maxWidth+"px"),""===r.theme&&"light"===r.theme||g.toast.classList.add(i+"-theme-"+r.theme),r.color&&(function(t){return"#"==t.substring(0,1)||"rgb"==t.substring(0,3)||"hsl"==t.substring(0,3)}(r.color)?g.toast.style.background=r.color:g.toast.classList.add(i+"-color-"+r.color)),r.backgroundColor&&(g.toast.style.background=r.backgroundColor,r.balloon&&(g.toast.style.borderColor=r.backgroundColor))}(),r.image&&(g.cover.classList.add(i+"-cover"),g.cover.style.width=r.imageWidth+"px",function(t){try{return btoa(atob(t))==t}catch(t){return!1}}(r.image.replace(/ /g,""))?g.cover.style.backgroundImage="url(data:image/png;base64,"+r.image.replace(/ /g,"")+")":g.cover.style.backgroundImage="url("+r.image+")",r.rtl?g.toastBody.style.marginRight=r.imageWidth+10+"px":g.toastBody.style.marginLeft=r.imageWidth+10+"px",g.toast.appendChild(g.cover)),r.close?(g.buttonClose=document.createElement("button"),g.buttonClose.type="button",g.buttonClose.classList.add(i+"-close"),g.buttonClose.addEventListener("click",function(t){t.target,o.hide(r,g.toast,"button")}),g.toast.appendChild(g.buttonClose)):r.rtl?g.toast.style.paddingLeft="18px":g.toast.style.paddingRight="18px",r.progressBar&&(g.progressBar=document.createElement("div"),g.progressBarDiv=document.createElement("div"),g.progressBar.classList.add(i+"-progressbar"),g.progressBarDiv.style.background=r.progressBarColor,g.progressBar.appendChild(g.progressBarDiv),g.toast.appendChild(g.progressBar)),r.timeout&&(r.pauseOnHover&&!r.resetOnHover&&(g.toast.addEventListener("mouseenter",function(t){o.progress(r,g.toast).pause()}),g.toast.addEventListener("mouseleave",function(t){o.progress(r,g.toast).resume()})),r.resetOnHover&&(g.toast.addEventListener("mouseenter",function(t){o.progress(r,g.toast).reset()}),g.toast.addEventListener("mouseleave",function(t){o.progress(r,g.toast).start()}))),r.iconUrl?(g.icon.setAttribute("class",i+"-icon"),g.icon.setAttribute("src",r.iconUrl)):r.icon&&(g.icon.setAttribute("class",i+"-icon "+r.icon),r.iconText&&g.icon.appendChild(document.createTextNode(r.iconText)),r.iconColor&&(g.icon.style.color=r.iconColor)),(r.icon||r.iconUrl)&&(r.rtl?g.toastBody.style.paddingRight="33px":g.toastBody.style.paddingLeft="33px",g.toastBody.appendChild(g.icon)),r.title.length>0&&(g.strong=document.createElement("strong"),g.strong.classList.add(i+"-title"),g.strong.appendChild(f(r.title)),g.toastTexts.appendChild(g.strong),r.titleColor&&(g.strong.style.color=r.titleColor),r.titleSize&&(isNaN(r.titleSize)?g.strong.style.fontSize=r.titleSize:g.strong.style.fontSize=r.titleSize+"px"),r.titleLineHeight&&(isNaN(r.titleSize)?g.strong.style.lineHeight=r.titleLineHeight:g.strong.style.lineHeight=r.titleLineHeight+"px")),r.message.length>0&&(g.p=document.createElement("p"),g.p.classList.add(i+"-message"),g.p.appendChild(f(r.message)),g.toastTexts.appendChild(g.p),r.messageColor&&(g.p.style.color=r.messageColor),r.messageSize&&(isNaN(r.titleSize)?g.p.style.fontSize=r.messageSize:g.p.style.fontSize=r.messageSize+"px"),r.messageLineHeight&&(isNaN(r.titleSize)?g.p.style.lineHeight=r.messageLineHeight:g.p.style.lineHeight=r.messageLineHeight+"px")),r.title.length>0&&r.message.length>0&&(r.rtl?g.strong.style.marginLeft="10px":2===r.layout||r.rtl||(g.strong.style.marginRight="10px")),g.toastBody.appendChild(g.toastTexts),r.inputs.length>0&&(g.inputs.classList.add(i+"-inputs"),h(r.inputs,function(t,e){g.inputs.appendChild(f(t[0])),(d=g.inputs.childNodes)[e].classList.add(i+"-inputs-child"),t[3]&&setTimeout(function(){d[e].focus()},300),d[e].addEventListener(t[1],function(e){var i=t[2];return i(o,g.toast,this,e)})}),g.toastBody.appendChild(g.inputs)),r.buttons.length>0&&(g.buttons.classList.add(i+"-buttons"),h(r.buttons,function(t,e){g.buttons.appendChild(f(t[0]));var n=g.buttons.childNodes;n[e].classList.add(i+"-buttons-child"),t[2]&&setTimeout(function(){n[e].focus()},300),n[e].addEventListener("click",function(e){e.preventDefault();var i=t[1];return i(o,g.toast,this,e,d)})})),g.toastBody.appendChild(g.buttons),r.message.length>0&&(r.inputs.length>0||r.buttons.length>0)&&(g.p.style.marginBottom="0"),(r.inputs.length>0||r.buttons.length>0)&&(r.rtl?g.toastTexts.style.marginLeft="10px":g.toastTexts.style.marginRight="10px",r.inputs.length>0&&r.buttons.length>0&&(r.rtl?g.inputs.style.marginLeft="8px":g.inputs.style.marginRight="8px")),g.toastCapsule.style.visibility="hidden",setTimeout(function(){var t=g.toast.offsetHeight,e=g.toast.currentStyle||window.getComputedStyle(g.toast),i=e.marginTop;i=i.split("px"),i=parseInt(i[0]);var n=e.marginBottom;n=n.split("px"),n=parseInt(n[0]),g.toastCapsule.style.visibility="",g.toastCapsule.style.height=t+n+i+"px",setTimeout(function(){g.toastCapsule.style.height="auto",r.target&&(g.toastCapsule.style.overflow="visible")},500),r.timeout&&o.progress(r,g.toast).start()},100),function(){var t=r.position;if(r.target)g.wrapper=document.querySelector(r.target),g.wrapper.classList.add(i+"-target"),r.targetFirst?g.wrapper.insertBefore(g.toastCapsule,g.wrapper.firstChild):g.wrapper.appendChild(g.toastCapsule);else{if(-1==a.indexOf(r.position))return void console.warn("["+i+"] Incorrect position.\nIt can be › "+a);t=n||window.innerWidth<=l?"bottomLeft"==r.position||"bottomRight"==r.position||"bottomCenter"==r.position?i+"-wrapper-bottomCenter":"topLeft"==r.position||"topRight"==r.position||"topCenter"==r.position?i+"-wrapper-topCenter":i+"-wrapper-center":i+"-wrapper-"+t,g.wrapper=document.querySelector("."+i+"-wrapper."+t),g.wrapper||(g.wrapper=document.createElement("div"),g.wrapper.classList.add(i+"-wrapper"),g.wrapper.classList.add(t),document.body.appendChild(g.wrapper)),"topLeft"==r.position||"topCenter"==r.position||"topRight"==r.position?g.wrapper.insertBefore(g.toastCapsule,g.wrapper.firstChild):g.wrapper.appendChild(g.toastCapsule)}isNaN(r.zindex)?console.warn("["+i+"] Invalid zIndex."):g.wrapper.style.zIndex=r.zindex}(),r.overlay&&(null!==document.querySelector("."+i+"-overlay.fadeIn")?(g.overlay=document.querySelector("."+i+"-overlay"),g.overlay.setAttribute("data-iziToast-ref",g.overlay.getAttribute("data-iziToast-ref")+","+r.ref),isNaN(r.zindex)||null===r.zindex||(g.overlay.style.zIndex=r.zindex-1)):(g.overlay.classList.add(i+"-overlay"),g.overlay.classList.add("fadeIn"),g.overlay.style.background=r.overlayColor,g.overlay.setAttribute("data-iziToast-ref",r.ref),isNaN(r.zindex)||null===r.zindex||(g.overlay.style.zIndex=r.zindex-1),document.querySelector("body").appendChild(g.overlay)),r.overlayClose?(g.overlay.removeEventListener("click",{}),g.overlay.addEventListener("click",function(t){o.hide(r,g.toast,"overlay")})):g.overlay.removeEventListener("click",{})),function(){if(r.animateInside){g.toast.classList.add(i+"-animateInside");var t=[200,100,300];"bounceInLeft"!=r.transitionIn&&"bounceInRight"!=r.transitionIn||(t=[400,200,400]),r.title.length>0&&setTimeout(function(){g.strong.classList.add("slideIn")},t[0]),r.message.length>0&&setTimeout(function(){g.p.classList.add("slideIn")},t[1]),(r.icon||r.iconUrl)&&setTimeout(function(){g.icon.classList.add("revealIn")},t[2]);var e=150;r.buttons.length>0&&g.buttons&&setTimeout(function(){h(g.buttons.childNodes,function(t,i){setTimeout(function(){t.classList.add("revealIn")},e),e+=150})},r.inputs.length>0?150:0),r.inputs.length>0&&g.inputs&&(e=150,h(g.inputs.childNodes,function(t,i){setTimeout(function(){t.classList.add("revealIn")},e),e+=150}))}}(),r.onOpening.apply(null,[r,g.toast]);try{var v=new CustomEvent(i+"-opening",{detail:r,bubbles:!0,cancelable:!0});document.dispatchEvent(v)}catch(t){console.warn(t)}setTimeout(function(){g.toast.classList.remove(i+"-opening"),g.toast.classList.add(i+"-opened");try{var t=new CustomEvent(i+"-opened",{detail:r,bubbles:!0,cancelable:!0});document.dispatchEvent(t)}catch(t){console.warn(t)}r.onOpened.apply(null,[r,g.toast])},1e3),r.drag&&(s?(g.toast.addEventListener("touchstart",function(t){m.startMoving(this,o,r,t)},!1),g.toast.addEventListener("touchend",function(t){m.stopMoving(this,t)},!1)):(g.toast.addEventListener("mousedown",function(t){t.preventDefault(),m.startMoving(this,o,r,t)},!1),g.toast.addEventListener("mouseup",function(t){t.preventDefault(),m.stopMoving(this,t)},!1))),r.closeOnEscape&&document.addEventListener("keyup",function(t){27==(t=t||window.event).keyCode&&o.hide(r,g.toast,"esc")}),r.closeOnClick&&g.toast.addEventListener("click",function(t){o.hide(r,g.toast,"toast")}),o.toast=g.toast},e}(),void 0===(r="function"==typeof n?n.apply(e,o):n)||(t.exports=r)}).call(this,i(4))},3:function(t,e,i){"use strict";Object.defineProperty(e,"__esModule",{value:!0});var n={get:function(t){var e=document.cookie.match("(^|;) ?"+t+"=([^;]*)(;|$)"),i=e?unescape(e[2]):e;try{i=JSON.parse(i)}catch(t){}return i},set:function(t,e){var i=arguments.length<=2||void 0===arguments[2]?{}:arguments[2],n=t+"="+escape(JSON.stringify(e))+"; path="+(i.path?escape(i.path):"/");return i.domain&&(n+="; domain="+escape(i.domain)),i.secure&&(n+="; secure"),i.expires&&(n+="; expires="+i.expires),i.live&&(n+="; expires="+o(i.live)),document.cookie=n,e},remove:function(t){var e=this.get(t);return this.set(t,e,{live:-1}),e}};function o(t){var e=new Date;return e.setDate(e.getDate()+parseInt(t)),e.setMinutes(e.getMinutes()-e.getTimezoneOffset()),e.toUTCString()}e.default=n,t.exports=e.default},4:function(t,e){var i;i=function(){return this}();try{i=i||new Function("return this")()}catch(t){"object"==typeof window&&(i=window)}t.exports=i},8:function(t,e,i){"use strict";i.r(e),function(t){i(9),i(10);var e=i(3),n=i.n(e),o=i(2),r=i.n(o);t.fn.editable.defaults.mode="inline",t(function(){var t=n.a.get("toast");t&&(r.a.success({title:t,position:"topRight",timeout:3e3}),n.a.remove("toast"))}),window.delete_key=function(e){t.ajax({method:"delete",url:e,success:function(t){0==t.code?(n.a.set("toast","Delete Success!"),window.location.assign(t.data)):r.a.error({title:"Error!",message:t.error,position:"topRight"})}}),t("#fire-modal-1").modal("hide")}}.call(this,i(1))},9:function(t,e,i){(function(t,e){var i,n;
/*! X-editable - v1.5.3 
* In-place editing with Twitter Bootstrap, jQuery UI or pure jQuery
* http://github.com/vitalets/x-editable
* Copyright (c) 2018 Vitaliy Potapov; Licensed MIT */
!function(t){"use strict";var e=function(e,i){this.options=t.extend({},t.fn.editableform.defaults,i),this.$div=t(e),this.options.scope||(this.options.scope=this)};e.prototype={constructor:e,initInput:function(){this.input=this.options.input,this.value=this.input.str2value(this.options.value),this.input.prerender()},initTemplate:function(){this.$form=t(t.fn.editableform.template)},initButtons:function(){var e=this.$form.find(".editable-buttons");e.append(t.fn.editableform.buttons),"bottom"===this.options.showbuttons&&e.addClass("editable-buttons-bottom")},render:function(){this.$loading=t(t.fn.editableform.loading),this.$div.empty().append(this.$loading),this.initTemplate(),this.options.showbuttons?this.initButtons():this.$form.find(".editable-buttons").remove(),this.showLoading(),this.isSaving=!1,this.$div.triggerHandler("rendering"),this.initInput(),this.$form.find("div.editable-input").append(this.input.$tpl),this.$div.append(this.$form),t.when(this.input.render()).then(t.proxy(function(){if(this.options.showbuttons||this.input.autosubmit(),this.$form.find(".editable-cancel").click(t.proxy(this.cancel,this)),this.input.error)this.error(this.input.error),this.$form.find(".editable-submit").attr("disabled",!0),this.input.$input.attr("disabled",!0),this.$form.submit(function(t){t.preventDefault()});else{this.error(!1),this.input.$input.removeAttr("disabled"),this.$form.find(".editable-submit").removeAttr("disabled");var e=null===this.value||void 0===this.value||""===this.value?this.options.defaultValue:this.value;this.input.value2input(e),this.$form.submit(t.proxy(this.submit,this))}this.$div.triggerHandler("rendered"),this.showForm(),this.input.postrender&&this.input.postrender()},this))},cancel:function(){this.$div.triggerHandler("cancel")},showLoading:function(){var t,e;this.$form?(t=this.$form.outerWidth(),e=this.$form.outerHeight(),t&&this.$loading.width(t),e&&this.$loading.height(e),this.$form.hide()):(t=this.$loading.parent().width())&&this.$loading.width(t),this.$loading.show()},showForm:function(t){this.$loading.hide(),this.$form.show(),!1!==t&&this.input.activate(),this.$div.triggerHandler("show")},error:function(e){var i,n=this.$form.find(".control-group"),o=this.$form.find(".editable-error-block");if(!1===e)n.removeClass(t.fn.editableform.errorGroupClass),o.removeClass(t.fn.editableform.errorBlockClass).empty().hide();else{if(e){i=(""+e).split("\n");for(var r=0;r<i.length;r++)i[r]=t("<div>").text(i[r]).html();e=i.join("<br>")}n.addClass(t.fn.editableform.errorGroupClass),o.addClass(t.fn.editableform.errorBlockClass).html(e).show()}},submit:function(e){e.stopPropagation(),e.preventDefault();var i=this.input.input2value(),n=this.validate(i);if("object"===t.type(n)&&void 0!==n.newValue){if(i=n.newValue,this.input.value2input(i),"string"==typeof n.msg)return this.error(n.msg),void this.showForm()}else if(n)return this.error(n),void this.showForm();if(this.options.savenochange||this.input.value2str(i)!==this.input.value2str(this.value)){var o=this.input.value2submit(i);this.isSaving=!0,t.when(this.save(o)).done(t.proxy(function(t){this.isSaving=!1;var e="function"==typeof this.options.success?this.options.success.call(this.options.scope,t,i):null;return!1===e?(this.error(!1),void this.showForm(!1)):"string"==typeof e?(this.error(e),void this.showForm()):(e&&"object"==typeof e&&e.hasOwnProperty("newValue")&&(i=e.newValue),this.error(!1),this.value=i,void this.$div.triggerHandler("save",{newValue:i,submitValue:o,response:t}))},this)).fail(t.proxy(function(t){var e;this.isSaving=!1,e="function"==typeof this.options.error?this.options.error.call(this.options.scope,t,i):"string"==typeof t?t:t.responseText||t.statusText||"Unknown error!",this.error(e),this.showForm()},this))}else this.$div.triggerHandler("nochange")},save:function(e){this.options.pk=t.fn.editableutils.tryParseJson(this.options.pk,!0);var i,n="function"==typeof this.options.pk?this.options.pk.call(this.options.scope):this.options.pk;if(!!("function"==typeof this.options.url||this.options.url&&("always"===this.options.send||"auto"===this.options.send&&null!=n)))return this.showLoading(),i={name:this.options.name||"",value:e,pk:n},"function"==typeof this.options.params?i=this.options.params.call(this.options.scope,i):(this.options.params=t.fn.editableutils.tryParseJson(this.options.params,!0),t.extend(i,this.options.params)),"function"==typeof this.options.url?this.options.url.call(this.options.scope,i):t.ajax(t.extend({url:this.options.url,data:i,type:"POST"},this.options.ajaxOptions))},validate:function(t){if(void 0===t&&(t=this.value),"function"==typeof this.options.validate)return this.options.validate.call(this.options.scope,t)},option:function(t,e){t in this.options&&(this.options[t]=e),"value"===t&&this.setValue(e)},setValue:function(t,e){this.value=e?this.input.str2value(t):t,this.$form&&this.$form.is(":visible")&&this.input.value2input(this.value)}},t.fn.editableform=function(i){var n=arguments;return this.each(function(){var o=t(this),r=o.data("editableform"),s="object"==typeof i&&i;r||o.data("editableform",r=new e(this,s)),"string"==typeof i&&r[i].apply(r,Array.prototype.slice.call(n,1))})},t.fn.editableform.Constructor=e,t.fn.editableform.defaults={type:"text",url:null,params:null,name:null,pk:null,value:null,defaultValue:null,send:"auto",validate:null,success:null,error:null,ajaxOptions:null,showbuttons:!0,scope:null,savenochange:!1},t.fn.editableform.template='<form class="form-inline editableform"><div class="control-group"><div><div class="editable-input"></div><div class="editable-buttons"></div></div><div class="editable-error-block"></div></div></form>',t.fn.editableform.loading='<div class="editableform-loading"></div>',t.fn.editableform.buttons='<button type="submit" class="editable-submit">ok</button><button type="button" class="editable-cancel">cancel</button>',t.fn.editableform.errorGroupClass=null,t.fn.editableform.errorBlockClass="editable-error",t.fn.editableform.engine="jquery"}(t),function(t){"use strict";t.fn.editableutils={inherit:function(t,e){var i=function(){};i.prototype=e.prototype,t.prototype=new i,t.prototype.constructor=t,t.superclass=e.prototype},setCursorPosition:function(t,e){if(t.setSelectionRange)try{t.setSelectionRange(e,e)}catch(t){}else if(t.createTextRange){var i=t.createTextRange();i.collapse(!0),i.moveEnd("character",e),i.moveStart("character",e),i.select()}},tryParseJson:function(t,e){if("string"==typeof t&&t.length&&t.match(/^[\{\[].*[\}\]]$/))if(e)try{t=new Function("return "+t)()}catch(t){}finally{return t}else t=new Function("return "+t)();return t},sliceObj:function(e,i,n){var o,r,s={};if(!t.isArray(i)||!i.length)return s;for(var a=0;a<i.length;a++)o=i[a],e.hasOwnProperty(o)&&(s[o]=e[o]),!0!==n&&(r=o.toLowerCase(),e.hasOwnProperty(r)&&(s[o]=e[r]));return s},getConfigData:function(e){var i={};return t.each(e[0].dataset,function(t,e){("object"!=typeof e||e&&"object"==typeof e&&(e.constructor===Object||e.constructor===Array))&&(i[t]=e)}),i},objectKeys:function(t){if(Object.keys)return Object.keys(t);if(t!==Object(t))throw new TypeError("Object.keys called on a non-object");var e,i=[];for(e in t)Object.prototype.hasOwnProperty.call(t,e)&&i.push(e);return i},escape:function(e){return t("<div>").text(e).html()},itemsByValue:function(e,i,n){if(!i||null===e)return[];if("function"!=typeof n){var o=n||"value";n=function(t){return t[o]}}var r=t.isArray(e),s=[],a=this;return t.each(i,function(i,o){if(o.children)s=s.concat(a.itemsByValue(e,o.children,n));else if(r)t.grep(e,function(t){return t==(o&&"object"==typeof o?n(o):o)}).length&&s.push(o);else{var l=o&&"object"==typeof o?n(o):o;e==l&&s.push(o)}}),s},createInput:function(e){var i,n=e.type;return"date"===n&&("inline"===e.mode?t.fn.editabletypes.datefield?n="datefield":t.fn.editabletypes.dateuifield&&(n="dateuifield"):t.fn.editabletypes.date?n="date":t.fn.editabletypes.dateui&&(n="dateui"),"date"!==n||t.fn.editabletypes.date||(n="combodate")),"datetime"===n&&"inline"===e.mode&&(n="datetimefield"),"wysihtml5"!==n||t.fn.editabletypes[n]||(n="textarea"),"function"==typeof t.fn.editabletypes[n]?new(i=t.fn.editabletypes[n])(this.sliceObj(e,this.objectKeys(i.defaults))):(t.error("Unknown type: "+n),!1)},supportsTransitions:function(){var t=(document.body||document.documentElement).style,e="transition",i=["Moz","Webkit","Khtml","O","ms"];if("string"==typeof t[e])return!0;e=e.charAt(0).toUpperCase()+e.substr(1);for(var n=0;n<i.length;n++)if("string"==typeof t[i[n]+e])return!0;return!1}}}(t),function(t){"use strict";var i=function(t,e){this.init(t,e)},n=function(t,e){this.init(t,e)};i.prototype={containerName:null,containerDataName:null,innerCss:null,containerClass:"editable-container editable-popup",defaults:{},init:function(e,n){this.$element=t(e),this.options=t.extend({},t.fn.editableContainer.defaults,n),this.splitOptions(),this.formOptions.scope=this.$element[0],this.initContainer(),this.delayedHide=!1,this.$element.on("destroyed",t.proxy(function(){this.destroy()},this)),t(document).data("editable-handlers-attached")||(t(document).on("keyup.editable",function(e){27===e.which&&t(".editable-open").editableContainer("hide","cancel")}),t(document).on("click.editable",function(e){var n,o=t(e.target),r=[".editable-container",".ui-datepicker-header",".datepicker",".modal-backdrop",".bootstrap-wysihtml5-insert-image-modal",".bootstrap-wysihtml5-insert-link-modal"];if(!t(".select2-drop-mask").is(":visible")&&t.contains(document.documentElement,e.target)&&!o.is(document)){for(n=0;n<r.length;n++)if(o.is(r[n])||o.parents(r[n]).length)return;i.prototype.closeOthers(e.target)}}),t(document).data("editable-handlers-attached",!0))},splitOptions:function(){if(this.containerOptions={},this.formOptions={},!t.fn[this.containerName])throw new Error(this.containerName+" not found. Have you included corresponding js file?");for(var e in this.options)e in this.defaults?this.containerOptions[e]=this.options[e]:this.formOptions[e]=this.options[e]},tip:function(){return this.container()?this.container().$tip:null},container:function(){var t;return this.containerDataName&&(t=this.$element.data(this.containerDataName))?t:t=this.$element.data(this.containerName)},call:function(){this.$element[this.containerName].apply(this.$element,arguments)},initContainer:function(){this.call(this.containerOptions)},renderForm:function(){this.$form.editableform(this.formOptions).on({save:t.proxy(this.save,this),nochange:t.proxy(function(){this.hide("nochange")},this),cancel:t.proxy(function(){this.hide("cancel")},this),show:t.proxy(function(){this.delayedHide?(this.hide(this.delayedHide.reason),this.delayedHide=!1):this.setPosition()},this),rendering:t.proxy(this.setPosition,this),resize:t.proxy(this.setPosition,this),rendered:t.proxy(function(){this.$element.triggerHandler("shown",t(this.options.scope).data("editable"))},this)}).editableform("render")},show:function(e){this.$element.addClass("editable-open"),!1!==e&&this.closeOthers(this.$element[0]),this.innerShow(),this.tip().addClass(this.containerClass),this.$form,this.$form=t("<div>"),this.tip().is(this.innerCss)?this.tip().append(this.$form):this.tip().find(this.innerCss).append(this.$form),this.renderForm()},hide:function(t){this.tip()&&this.tip().is(":visible")&&this.$element.hasClass("editable-open")&&(this.$form.data("editableform").isSaving?this.delayedHide={reason:t}:(this.delayedHide=!1,this.$element.removeClass("editable-open"),this.innerHide(),this.$element.triggerHandler("hidden",t||"manual")))},innerShow:function(){},innerHide:function(){},toggle:function(t){this.container()&&this.tip()&&this.tip().is(":visible")?this.hide():this.show(t)},setPosition:function(){},save:function(t,e){this.$element.triggerHandler("save",e),this.hide("save")},option:function(t,e){this.options[t]=e,t in this.containerOptions?(this.containerOptions[t]=e,this.setContainerOption(t,e)):(this.formOptions[t]=e,this.$form&&this.$form.editableform("option",t,e))},setContainerOption:function(t,e){this.call("option",t,e)},destroy:function(){this.hide(),this.innerDestroy(),this.$element.off("destroyed"),this.$element.removeData("editableContainer")},innerDestroy:function(){},closeOthers:function(e){t(".editable-open").each(function(i,n){if(n!==e&&!t(n).find(e).length){var o=t(n),r=o.data("editableContainer");r&&("cancel"===r.options.onblur?o.data("editableContainer").hide("onblur"):"submit"===r.options.onblur&&o.data("editableContainer").tip().find("form").submit())}})},activate:function(){this.tip&&this.tip().is(":visible")&&this.$form&&this.$form.data("editableform").input.activate()}},t.fn.editableContainer=function(e){var o=arguments;return this.each(function(){var r=t(this),s=r.data("editableContainer"),a="object"==typeof e&&e,l="inline"===a.mode?n:i;s||r.data("editableContainer",s=new l(this,a)),"string"==typeof e&&s[e].apply(s,Array.prototype.slice.call(o,1))})},t.fn.editableContainer.Popup=i,t.fn.editableContainer.Inline=n,t.fn.editableContainer.defaults={value:null,placement:"top",autohide:!0,onblur:"cancel",anim:!1,mode:"popup"},e.event.special.destroyed={remove:function(t){t.handler&&t.handler()}}}(t),function(t){"use strict";t.extend(t.fn.editableContainer.Inline.prototype,t.fn.editableContainer.Popup.prototype,{containerName:"editableform",innerCss:".editable-inline",containerClass:"editable-container editable-inline",initContainer:function(){this.$tip=t("<span></span>"),this.options.anim||(this.options.anim=0)},splitOptions:function(){this.containerOptions={},this.formOptions=this.options},tip:function(){return this.$tip},innerShow:function(){this.$element.hide(),this.tip().insertAfter(this.$element).show()},innerHide:function(){this.$tip.hide(this.options.anim,t.proxy(function(){this.$element.show(),this.innerDestroy()},this))},innerDestroy:function(){this.tip()&&this.tip().empty().remove()}})}(t),function(t){"use strict";var e=function(e,i){this.$element=t(e),this.options=t.extend({},t.fn.editable.defaults,i,t.fn.editableutils.getConfigData(this.$element)),this.options.selector?this.initLive():this.init(),this.options.highlight&&!t.fn.editableutils.supportsTransitions()&&(this.options.highlight=!1)};e.prototype={constructor:e,init:function(){var e,i=!1;if(this.options.name=this.options.name||this.$element.attr("id"),this.options.scope=this.$element[0],this.input=t.fn.editableutils.createInput(this.options),this.input){switch(void 0===this.options.value||null===this.options.value?(this.value=this.input.html2value(t.trim(this.$element.html())),i=!0):(this.options.value=t.fn.editableutils.tryParseJson(this.options.value,!0),"string"==typeof this.options.value?this.value=this.input.str2value(this.options.value):this.value=this.options.value),this.$element.addClass("editable"),"textarea"===this.input.type&&this.$element.addClass("editable-pre-wrapped"),"manual"!==this.options.toggle?(this.$element.addClass("editable-click"),this.$element.on(this.options.toggle+".editable",t.proxy(function(t){if(this.options.disabled||t.preventDefault(),"mouseenter"===this.options.toggle)this.show();else{var e="click"!==this.options.toggle;this.toggle(e)}},this))):this.$element.attr("tabindex",-1),"function"==typeof this.options.display&&(this.options.autotext="always"),this.options.autotext){case"always":e=!0;break;case"auto":e=!t.trim(this.$element.text()).length&&null!==this.value&&void 0!==this.value&&!i;break;default:e=!1}t.when(!e||this.render()).then(t.proxy(function(){this.options.disabled?this.disable():this.enable(),this.$element.triggerHandler("init",this)},this))}},initLive:function(){var e=this.options.selector;this.options.selector=!1,this.options.autotext="never",this.$element.on(this.options.toggle+".editable",e,t.proxy(function(i){var n=t(i.target).closest(e);n.data("editable")||(n.hasClass(this.options.emptyclass)&&n.empty(),n.editable(this.options).trigger(i))},this))},render:function(t){if(!1!==this.options.display)return this.input.value2htmlFinal?this.input.value2html(this.value,this.$element[0],this.options.display,t):"function"==typeof this.options.display?this.options.display.call(this.$element[0],this.value,t):this.input.value2html(this.value,this.$element[0])},enable:function(){this.options.disabled=!1,this.$element.removeClass("editable-disabled"),this.handleEmpty(this.isEmpty),"manual"!==this.options.toggle&&"-1"===this.$element.attr("tabindex")&&this.$element.removeAttr("tabindex")},disable:function(){this.options.disabled=!0,this.hide(),this.$element.addClass("editable-disabled"),this.handleEmpty(this.isEmpty),this.$element.attr("tabindex",-1)},toggleDisabled:function(){this.options.disabled?this.enable():this.disable()},option:function(e,i){if(e&&"object"==typeof e)t.each(e,t.proxy(function(e,i){this.option(t.trim(e),i)},this));else{if(this.options[e]=i,"disabled"===e)return i?this.disable():this.enable();"value"===e&&this.setValue(i),this.container&&this.container.option(e,i),this.input.option&&this.input.option(e,i)}},handleEmpty:function(e){!1!==this.options.display&&(void 0!==e?this.isEmpty=e:"function"==typeof this.input.isEmpty?this.isEmpty=this.input.isEmpty(this.$element):this.isEmpty=""===t.trim(this.$element.html()),this.options.disabled?this.isEmpty&&(this.$element.empty(),this.options.emptyclass&&this.$element.removeClass(this.options.emptyclass)):this.isEmpty?(this.$element.html(this.options.emptytext),this.options.emptyclass&&this.$element.addClass(this.options.emptyclass)):this.options.emptyclass&&this.$element.removeClass(this.options.emptyclass))},show:function(e){if(!this.options.disabled){if(this.container){if(this.container.tip().is(":visible"))return}else{var i=t.extend({},this.options,{value:this.value,input:this.input});this.$element.editableContainer(i),this.$element.on("save.internal",t.proxy(this.save,this)),this.container=this.$element.data("editableContainer")}this.container.show(e)}},hide:function(){this.container&&this.container.hide()},toggle:function(t){this.container&&this.container.tip().is(":visible")?this.hide():this.show(t)},save:function(t,e){if(this.options.unsavedclass){var i=!1;(i=(i=(i=(i=i||"function"==typeof this.options.url)||!1===this.options.display)||void 0!==e.response)||this.options.savenochange&&this.input.value2str(this.value)!==this.input.value2str(e.newValue))?this.$element.removeClass(this.options.unsavedclass):this.$element.addClass(this.options.unsavedclass)}if(this.options.highlight){var n=this.$element,o=n.css("background-color");n.css("background-color",this.options.highlight),setTimeout(function(){"transparent"===o&&(o=""),n.css("background-color",o),n.addClass("editable-bg-transition"),setTimeout(function(){n.removeClass("editable-bg-transition")},1700)},10)}this.setValue(e.newValue,!1,e.response)},validate:function(){if("function"==typeof this.options.validate)return this.options.validate.call(this,this.value)},setValue:function(e,i,n){this.value=i?this.input.str2value(e):e,this.container&&this.container.option("value",this.value),t.when(this.render(n)).then(t.proxy(function(){this.handleEmpty()},this))},activate:function(){this.container&&this.container.activate()},destroy:function(){this.disable(),this.container&&this.container.destroy(),this.input.destroy(),"manual"!==this.options.toggle&&(this.$element.removeClass("editable-click"),this.$element.off(this.options.toggle+".editable")),this.$element.off("save.internal"),this.$element.removeClass("editable editable-open editable-disabled"),this.$element.removeData("editable")}},t.fn.editable=function(i){var n={},o=arguments,r="editable";switch(i){case"validate":return this.each(function(){var e,i=t(this).data(r);i&&(e=i.validate())&&(n[i.options.name]=e)}),n;case"getValue":return 2===arguments.length&&!0===arguments[1]?n=this.eq(0).data(r).value:this.each(function(){var e=t(this).data(r);e&&void 0!==e.value&&null!==e.value&&(n[e.options.name]=e.input.value2submit(e.value))}),n;case"submit":var s=arguments[1]||{},a=this,l=this.editable("validate");if(t.isEmptyObject(l)){var c={};if(1===a.length){var u=a.data("editable"),d={name:u.options.name||"",value:u.input.value2submit(u.value),pk:"function"==typeof u.options.pk?u.options.pk.call(u.options.scope):u.options.pk};"function"==typeof u.options.params?d=u.options.params.call(u.options.scope,d):(u.options.params=t.fn.editableutils.tryParseJson(u.options.params,!0),t.extend(d,u.options.params)),c={url:u.options.url,data:d,type:"POST"},s.success=s.success||u.options.success,s.error=s.error||u.options.error}else{var h=this.editable("getValue");c={url:s.url,data:h,type:"POST"}}c.success="function"==typeof s.success?function(t){s.success.call(a,t,s)}:t.noop,c.error="function"==typeof s.error?function(){s.error.apply(a,arguments)}:t.noop,s.ajaxOptions&&t.extend(c,s.ajaxOptions),s.data&&t.extend(c.data,s.data),t.ajax(c)}else"function"==typeof s.error&&s.error.call(a,l);return this}return this.each(function(){var n=t(this),s=n.data(r),a="object"==typeof i&&i;a&&a.selector?s=new e(this,a):(s||n.data(r,s=new e(this,a)),"string"==typeof i&&s[i].apply(s,Array.prototype.slice.call(o,1)))})},t.fn.editable.defaults={type:"text",disabled:!1,toggle:"click",emptytext:"Empty",autotext:"auto",value:null,display:null,emptyclass:"editable-empty",unsavedclass:"editable-unsaved",selector:null,highlight:"#FFFF80"}}(t),function(t){"use strict";t.fn.editabletypes={};var e=function(){};e.prototype={init:function(e,i,n){this.type=e,this.options=t.extend({},n,i)},prerender:function(){this.$tpl=t(this.options.tpl),this.$input=this.$tpl,this.$clear=null,this.error=null},render:function(){},value2html:function(e,i){t(i)[this.options.escape?"text":"html"](t.trim(e))},html2value:function(e){return t("<div>").html(e).text()},value2str:function(t){return String(t)},str2value:function(t){return t},value2submit:function(t){return t},value2input:function(t){this.$input.val(t)},input2value:function(){return this.$input.val()},activate:function(){this.$input.is(":visible")&&this.$input.focus()},clear:function(){this.$input.val(null)},escape:function(e){return t("<div>").text(e).html()},autosubmit:function(){},destroy:function(){},setClass:function(){this.options.inputclass&&this.$input.addClass(this.options.inputclass)},setAttr:function(t){void 0!==this.options[t]&&null!==this.options[t]&&this.$input.attr(t,this.options[t])},option:function(t,e){this.options[t]=e}},e.defaults={tpl:"",inputclass:null,escape:!0,scope:null,showbuttons:!0},t.extend(t.fn.editabletypes,{abstractinput:e})}(t),function(t){"use strict";var e=function(t){};t.fn.editableutils.inherit(e,t.fn.editabletypes.abstractinput),t.extend(e.prototype,{render:function(){var e=t.Deferred();return this.error=null,this.onSourceReady(function(){this.renderList(),e.resolve()},function(){this.error=this.options.sourceError,e.resolve()}),e.promise()},html2value:function(t){return null},value2html:function(e,i,n,o){var r=t.Deferred(),s=function(){"function"==typeof n?n.call(i,e,this.sourceData,o):this.value2htmlFinal(e,i),r.resolve()};return null===e?s.call(this):this.onSourceReady(s,function(){r.resolve()}),r.promise()},onSourceReady:function(e,i){var n;if(t.isFunction(this.options.source)?(n=this.options.source.call(this.options.scope),this.sourceData=null):n=this.options.source,this.options.sourceCache&&t.isArray(this.sourceData))e.call(this);else{try{n=t.fn.editableutils.tryParseJson(n,!1)}catch(t){return void i.call(this)}if("string"==typeof n){if(this.options.sourceCache){var o,r=n;if(t(document).data(r)||t(document).data(r,{}),!1===(o=t(document).data(r)).loading&&o.sourceData)return this.sourceData=o.sourceData,this.doPrepend(),void e.call(this);if(!0===o.loading)return o.callbacks.push(t.proxy(function(){this.sourceData=o.sourceData,this.doPrepend(),e.call(this)},this)),void o.err_callbacks.push(t.proxy(i,this));o.loading=!0,o.callbacks=[],o.err_callbacks=[]}var s=t.extend({url:n,type:"get",cache:!1,dataType:"json",success:t.proxy(function(n){o&&(o.loading=!1),this.sourceData=this.makeArray(n),t.isArray(this.sourceData)?(o&&(o.sourceData=this.sourceData,t.each(o.callbacks,function(){this.call()})),this.doPrepend(),e.call(this)):(i.call(this),o&&t.each(o.err_callbacks,function(){this.call()}))},this),error:t.proxy(function(){i.call(this),o&&(o.loading=!1,t.each(o.err_callbacks,function(){this.call()}))},this)},this.options.sourceOptions);t.ajax(s)}else this.sourceData=this.makeArray(n),t.isArray(this.sourceData)?(this.doPrepend(),e.call(this)):i.call(this)}},doPrepend:function(){null!==this.options.prepend&&void 0!==this.options.prepend&&(t.isArray(this.prependData)||(t.isFunction(this.options.prepend)&&(this.options.prepend=this.options.prepend.call(this.options.scope)),this.options.prepend=t.fn.editableutils.tryParseJson(this.options.prepend,!0),"string"==typeof this.options.prepend&&(this.options.prepend={"":this.options.prepend}),this.prependData=this.makeArray(this.options.prepend)),t.isArray(this.prependData)&&t.isArray(this.sourceData)&&(this.sourceData=this.prependData.concat(this.sourceData)))},renderList:function(){},value2htmlFinal:function(t,e){},makeArray:function(e){var i,n,o,r,s=[];if(!e||"string"==typeof e)return null;if(t.isArray(e)){r=function(t,e){if(n={value:t,text:e},i++>=2)return!1};for(var a=0;a<e.length;a++)"object"==typeof(o=e[a])?(i=0,t.each(o,r),1===i?s.push(n):i>1&&(o.children&&(o.children=this.makeArray(o.children)),s.push(o))):s.push({value:o,text:o})}else t.each(e,function(t,e){s.push({value:t,text:e})});return s},option:function(t,e){this.options[t]=e,"source"===t&&(this.sourceData=null),"prepend"===t&&(this.prependData=null)}}),e.defaults=t.extend({},t.fn.editabletypes.abstractinput.defaults,{source:null,prepend:!1,sourceError:"Error when loading list",sourceCache:!0,sourceOptions:null}),t.fn.editabletypes.list=e}(t),function(t){"use strict";var e=function(t){this.init("text",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.abstractinput),t.extend(e.prototype,{render:function(){this.renderClear(),this.setClass(),this.setAttr("placeholder")},activate:function(){this.$input.is(":visible")&&(this.$input.focus(),this.$input.is("input,textarea")&&!this.$input.is('[type="checkbox"],[type="range"]')&&t.fn.editableutils.setCursorPosition(this.$input.get(0),this.$input.val().length),this.toggleClear&&this.toggleClear())},renderClear:function(){this.options.clear&&(this.$clear=t('<span class="editable-clear-x"></span>'),this.$input.after(this.$clear).css("padding-right",24).keyup(t.proxy(function(e){if(!~t.inArray(e.keyCode,[40,38,9,13,27])){clearTimeout(this.t);var i=this;this.t=setTimeout(function(){i.toggleClear(e)},100)}},this)).parent().css("position","relative"),this.$clear.click(t.proxy(this.clear,this)))},postrender:function(){},toggleClear:function(t){if(this.$clear){var e=this.$input.val().length,i=this.$clear.is(":visible");e&&!i&&this.$clear.show(),!e&&i&&this.$clear.hide()}},clear:function(){this.$clear.hide(),this.$input.val("").focus()}}),e.defaults=t.extend({},t.fn.editabletypes.abstractinput.defaults,{tpl:'<input type="text">',placeholder:null,clear:!0}),t.fn.editabletypes.text=e}(t),function(t){"use strict";var e=function(t){this.init("textarea",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.abstractinput),t.extend(e.prototype,{render:function(){this.setClass(),this.setAttr("placeholder"),this.setAttr("rows"),this.$input.keydown(function(e){e.ctrlKey&&13===e.which&&t(this).closest("form").submit()})},activate:function(){t.fn.editabletypes.text.prototype.activate.call(this)}}),e.defaults=t.extend({},t.fn.editabletypes.abstractinput.defaults,{tpl:"<textarea></textarea>",inputclass:"input-large",placeholder:null,rows:7}),t.fn.editabletypes.textarea=e}(t),function(t){"use strict";var e=function(t){this.init("select",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.list),t.extend(e.prototype,{renderList:function(){this.$input.empty();var e=this.options.escape,i=function(n,o){var r;if(t.isArray(o))for(var s=0;s<o.length;s++)if(r={},o[s].children)r.label=o[s].text,n.append(i(t("<optgroup>",r),o[s].children));else{r.value=o[s].value,o[s].disabled&&(r.disabled=!0);var a=t("<option>",r);a[e?"text":"html"](o[s].text),n.append(a)}return n};i(this.$input,this.sourceData),this.setClass(),this.$input.on("keydown.editable",function(e){13===e.which&&t(this).closest("form").submit()})},value2htmlFinal:function(e,i){var n="",o=t.fn.editableutils.itemsByValue(e,this.sourceData);o.length&&(n=o[0].text),t.fn.editabletypes.abstractinput.prototype.value2html.call(this,n,i)},autosubmit:function(){this.$input.off("keydown.editable").on("change.editable",function(){t(this).closest("form").submit()})}}),e.defaults=t.extend({},t.fn.editabletypes.list.defaults,{tpl:"<select></select>"}),t.fn.editabletypes.select=e}(t),function(t){"use strict";var e=function(t){this.init("checklist",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.list),t.extend(e.prototype,{renderList:function(){var e;if(this.$tpl.empty(),t.isArray(this.sourceData)){for(var i=0;i<this.sourceData.length;i++){e=t("<label>").append(t("<input>",{type:"checkbox",value:this.sourceData[i].value}));var n=t("<span>");n[this.options.escape?"text":"html"](" "+this.sourceData[i].text),e.append(n),t("<div>").append(e).appendTo(this.$tpl)}this.$input=this.$tpl.find('input[type="checkbox"]'),this.setClass()}},value2str:function(e){return t.isArray(e)?e.sort().join(t.trim(this.options.separator)):""},str2value:function(e){var i,n=null;return"string"==typeof e&&e.length?(i=new RegExp("\\s*"+t.trim(this.options.separator)+"\\s*"),n=e.split(i)):n=t.isArray(e)?e:[e],n},value2input:function(e){this.$input.prop("checked",!1),t.isArray(e)&&e.length&&this.$input.each(function(i,n){var o=t(n);t.each(e,function(t,e){o.val()==e&&o.prop("checked",!0)})})},input2value:function(){var e=[];return this.$input.filter(":checked").each(function(i,n){e.push(t(n).val())}),e},value2htmlFinal:function(e,i){var n=[],o=t.fn.editableutils.itemsByValue(e,this.sourceData),r=this.options.escape;o.length?(t.each(o,function(e,i){var o=r?t.fn.editableutils.escape(i.text):i.text;n.push(o)}),t(i).html(n.join("<br>"))):t(i).empty()},activate:function(){this.$input.first().focus()},autosubmit:function(){this.$input.on("keydown",function(e){13===e.which&&t(this).closest("form").submit()})}}),e.defaults=t.extend({},t.fn.editabletypes.list.defaults,{tpl:'<div class="editable-checklist"></div>',inputclass:null,separator:","}),t.fn.editabletypes.checklist=e}(t),function(t){"use strict";var e=function(t){this.init("password",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.text),t.extend(e.prototype,{value2html:function(e,i){e?t(i).text("[hidden]"):t(i).empty()},html2value:function(t){return null}}),e.defaults=t.extend({},t.fn.editabletypes.text.defaults,{tpl:'<input type="password">'}),t.fn.editabletypes.password=e}(t),function(t){"use strict";var e=function(t){this.init("email",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.text),e.defaults=t.extend({},t.fn.editabletypes.text.defaults,{tpl:'<input type="email">'}),t.fn.editabletypes.email=e}(t),function(t){"use strict";var e=function(t){this.init("url",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.text),e.defaults=t.extend({},t.fn.editabletypes.text.defaults,{tpl:'<input type="url">'}),t.fn.editabletypes.url=e}(t),function(t){"use strict";var e=function(t){this.init("tel",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.text),e.defaults=t.extend({},t.fn.editabletypes.text.defaults,{tpl:'<input type="tel">'}),t.fn.editabletypes.tel=e}(t),function(t){"use strict";var e=function(t){this.init("number",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.text),t.extend(e.prototype,{render:function(){e.superclass.render.call(this),this.setAttr("min"),this.setAttr("max"),this.setAttr("step")},postrender:function(){this.$clear&&this.$clear.css({right:24})}}),e.defaults=t.extend({},t.fn.editabletypes.text.defaults,{tpl:'<input type="number">',inputclass:"input-mini",min:null,max:null,step:null}),t.fn.editabletypes.number=e}(t),function(t){"use strict";var e=function(t){this.init("range",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.number),t.extend(e.prototype,{render:function(){this.$input=this.$tpl.filter("input"),this.setClass(),this.setAttr("min"),this.setAttr("max"),this.setAttr("step"),this.$input.on("input",function(){t(this).siblings("output").text(t(this).val())})},activate:function(){this.$input.focus()}}),e.defaults=t.extend({},t.fn.editabletypes.number.defaults,{tpl:'<input type="range"><output style="width: 30px; display: inline-block"></output>',inputclass:"input-medium"}),t.fn.editabletypes.range=e}(t),function(t){"use strict";var e=function(t){this.init("time",t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.abstractinput),t.extend(e.prototype,{render:function(){this.setClass()}}),e.defaults=t.extend({},t.fn.editabletypes.abstractinput.defaults,{tpl:'<input type="time">'}),t.fn.editabletypes.time=e}(t),function(t){"use strict";var e=function(i){if(this.init("select2",i,e.defaults),i.select2=i.select2||{},this.sourceData=null,i.placeholder&&(i.select2.placeholder=i.placeholder),!i.select2.tags&&i.source){var n=i.source;t.isFunction(i.source)&&(n=i.source.call(i.scope)),"string"==typeof n?(i.select2.ajax=i.select2.ajax||{},i.select2.ajax.data||(i.select2.ajax.data=function(t){return{query:t}}),i.select2.ajax.results||(i.select2.ajax.results=function(t){return{results:t}}),i.select2.ajax.url=n):(this.sourceData=this.convertSource(n),i.select2.data=this.sourceData)}if(this.options.select2=t.extend({},e.defaults.select2,i.select2),this.isMultiple=this.options.select2.tags||this.options.select2.multiple,this.isRemote="ajax"in this.options.select2,this.idFunc=this.options.select2.id,"function"!=typeof this.idFunc){var o=this.idFunc||"id";this.idFunc=function(t){return t[o]}}this.formatSelection=this.options.select2.formatSelection,"function"!=typeof this.formatSelection&&(this.formatSelection=function(t){return t.text})};t.fn.editableutils.inherit(e,t.fn.editabletypes.abstractinput),t.extend(e.prototype,{render:function(){this.setClass(),this.isRemote&&this.$input.on("select2-loaded",t.proxy(function(t){this.sourceData=t.items.results},this)),this.isMultiple&&this.$input.on("change",function(){t(this).closest("form").parent().triggerHandler("resize")})},value2html:function(i,n){var o,r="",s=this;this.options.select2.tags?o=i:this.sourceData&&(o=t.fn.editableutils.itemsByValue(i,this.sourceData,this.idFunc)),t.isArray(o)?(r=[],t.each(o,function(t,e){r.push(e&&"object"==typeof e?s.formatSelection(e):e)})):o&&(r=s.formatSelection(o)),r=t.isArray(r)?r.join(this.options.viewseparator):r,e.superclass.value2html.call(this,r,n)},html2value:function(t){return this.options.select2.tags?this.str2value(t,this.options.viewseparator):null},value2input:function(e){if(t.isArray(e)&&(e=e.join(this.getSeparator())),this.$input.data("select2")?this.$input.val(e).trigger("change",!0):(this.$input.val(e),this.$input.select2(this.options.select2)),this.isRemote&&!this.isMultiple&&!this.options.select2.initSelection){var i=this.options.select2.id,n=this.options.select2.formatSelection;if(!i&&!n){var o=t(this.options.scope);if(!o.data("editable").isEmpty){var r={id:e,text:o.text()};this.$input.select2("data",r)}}}},input2value:function(){return this.$input.select2("val")},str2value:function(e,i){if("string"!=typeof e||!this.isMultiple)return e;var n,o,r;if(i=i||this.getSeparator(),null===e||e.length<1)return null;for(o=0,r=(n=e.split(i)).length;o<r;o+=1)n[o]=t.trim(n[o]);return n},autosubmit:function(){this.$input.on("change",function(e,i){i||t(this).closest("form").submit()})},getSeparator:function(){return this.options.select2.separator||t.fn.select2.defaults.separator},convertSource:function(e){if(t.isArray(e)&&e.length&&void 0!==e[0].value)for(var i=0;i<e.length;i++)void 0!==e[i].value&&(e[i].id=e[i].value,delete e[i].value);return e},activate:function(){this.$input.select2("open")},destroy:function(){this.$input&&this.$input.data("select2")&&this.$input.select2("destroy")}}),e.defaults=t.extend({},t.fn.editabletypes.abstractinput.defaults,{tpl:'<input type="hidden">',select2:null,placeholder:null,source:null,viewseparator:", "}),t.fn.editabletypes.select2=e}(t),i=t,(n=function(t,e){this.$element=i(t),this.$element.is("input")?(this.options=i.extend({},i.fn.combodate.defaults,e,this.$element.data()),this.init()):i.error("Combodate should be applied to INPUT element")}).prototype={constructor:n,init:function(){this.map={day:["D","date"],month:["M","month"],year:["Y","year"],hour:["[Hh]","hours"],minute:["m","minutes"],second:["s","seconds"],ampm:["[Aa]",""]},this.$widget=i('<span class="combodate"></span>').html(this.getTemplate()),this.initCombos(),this.datetime=null,this.$widget.on("change","select",i.proxy(function(t){this.$element.val(this.getValue()).change(),this.options.smartDays&&(i(t.target).is(".month")||i(t.target).is(".year"))&&this.fillCombo("day")},this)),this.$widget.find("select").css("width","auto"),this.$element.hide().after(this.$widget),this.setValue(this.$element.val()||this.options.value)},getTemplate:function(){var t=this.options.template,e=this.$element.prop("disabled"),n=this.options.customClass;return i.each(this.map,function(e,i){i=i[0];var n=new RegExp(i+"+"),o=i.length>1?i.substring(1,2):i;t=t.replace(n,"{"+o+"}")}),t=t.replace(/ /g,"&nbsp;"),i.each(this.map,function(i,o){var r=(o=o[0]).length>1?o.substring(1,2):o;t=t.replace("{"+r+"}",'<select class="'+i+" "+n+'"'+(e?' disabled="disabled"':"")+"></select>")}),t},initCombos:function(){for(var t in this.map){var e=this.$widget.find("."+t);this["$"+t]=e.length?e:null,this.fillCombo(t)}},fillCombo:function(t){var e=this["$"+t];if(e){var i=this["fill"+t.charAt(0).toUpperCase()+t.slice(1)](),n=e.val();e.empty();for(var o=0;o<i.length;o++)e.append('<option value="'+i[o][0]+'">'+i[o][1]+"</option>");e.val(n)}},fillCommon:function(t){var e,i=[];if("name"===this.options.firstItem){var n="function"==typeof(e=moment.localeData?moment.localeData()._relativeTime:moment.relativeTime||moment.langData()._relativeTime)[t]?e[t](1,!0,t,!1):e[t];n=n.split(" ").reverse()[0],i.push(["",n])}else"empty"===this.options.firstItem&&i.push(["",""]);return i},fillDay:function(){var t,e,i=this.fillCommon("d"),n=-1!==this.options.template.indexOf("DD"),o=31;if(this.options.smartDays&&this.$month&&this.$year){var r=parseInt(this.$month.val(),10),s=parseInt(this.$year.val(),10);isNaN(r)||isNaN(s)||(o=moment([s,r]).daysInMonth())}for(e=1;e<=o;e++)t=n?this.leadZero(e):e,i.push([e,t]);return i},fillMonth:function(){var t,e,i=this.fillCommon("M"),n=-1!==this.options.template.indexOf("MMMMMM"),o=-1!==this.options.template.indexOf("MMMMM"),r=-1!==this.options.template.indexOf("MMMM"),s=-1!==this.options.template.indexOf("MMM"),a=-1!==this.options.template.indexOf("MM");for(e=0;e<=11;e++)t=n?moment().date(1).month(e).format("MM - MMMM"):o?moment().date(1).month(e).format("MM - MMM"):r?moment().date(1).month(e).format("MMMM"):s?moment().date(1).month(e).format("MMM"):a?this.leadZero(e+1):e+1,i.push([e,t]);return i},fillYear:function(){var t,e,i=[],n=-1!==this.options.template.indexOf("YYYY");for(e=this.options.maxYear;e>=this.options.minYear;e--)t=n?e:(e+"").substring(2),i[this.options.yearDescending?"push":"unshift"]([e,t]);return i=this.fillCommon("y").concat(i)},fillHour:function(){var t,e,i=this.fillCommon("h"),n=-1!==this.options.template.indexOf("h"),o=(this.options.template.indexOf("H"),-1!==this.options.template.toLowerCase().indexOf("hh")),r=n?12:23;for(e=n?1:0;e<=r;e++)t=o?this.leadZero(e):e,i.push([e,t]);return i},fillMinute:function(){var t,e,i=this.fillCommon("m"),n=-1!==this.options.template.indexOf("mm");for(e=0;e<=59;e+=this.options.minuteStep)t=n?this.leadZero(e):e,i.push([e,t]);return i},fillSecond:function(){var t,e,i=this.fillCommon("s"),n=-1!==this.options.template.indexOf("ss");for(e=0;e<=59;e+=this.options.secondStep)t=n?this.leadZero(e):e,i.push([e,t]);return i},fillAmpm:function(){var t=-1!==this.options.template.indexOf("a");return this.options.template.indexOf("A"),[["am",t?"am":"AM"],["pm",t?"pm":"PM"]]},getValue:function(t){var e,n={},o=this,r=!1;return i.each(this.map,function(t,e){var i;if("ampm"!==t)return o["$"+t]?n[t]=parseInt(o["$"+t].val(),10):(i=o.datetime?o.datetime[e[1]]():"day"===t?1:0,n[t]=i),isNaN(n[t])?(r=!0,!1):void 0}),r?"":(this.$ampm&&(12===n.hour?n.hour="am"===this.$ampm.val()?0:12:n.hour="am"===this.$ampm.val()?n.hour:n.hour+12),e=moment([n.year,n.month,n.day,n.hour,n.minute,n.second]),this.highlight(e),null===(t=void 0===t?this.options.format:t)?e.isValid()?e:null:e.isValid()?e.format(t):"")},setValue:function(t){if(t){var e="string"==typeof t?moment(t,this.options.format,!0):moment(t),n=this,o={};e.isValid()?(i.each(this.map,function(t,i){"ampm"!==t&&(o[t]=e[i[1]]())}),this.$ampm&&(o.hour>=12?(o.ampm="pm",o.hour>12&&(o.hour-=12)):(o.ampm="am",0===o.hour&&(o.hour=12))),i.each(o,function(t,e){n["$"+t]&&("minute"===t&&n.options.minuteStep>1&&n.options.roundTime&&(e=r(n["$"+t],e)),"second"===t&&n.options.secondStep>1&&n.options.roundTime&&(e=r(n["$"+t],e)),n["$"+t].val(e))}),this.options.smartDays&&this.fillCombo("day"),this.$element.val(e.format(this.options.format)).change(),this.datetime=e):this.datetime=null}function r(t,e){var n={};return t.children("option").each(function(t,o){var r,s=i(o).attr("value");""!==s&&(r=Math.abs(s-e),(void 0===n.distance||r<n.distance)&&(n={value:s,distance:r}))}),n.value}},highlight:function(t){t.isValid()?this.options.errorClass?this.$widget.removeClass(this.options.errorClass):this.$widget.find("select").css("border-color",this.borderColor):this.options.errorClass?this.$widget.addClass(this.options.errorClass):(this.borderColor||(this.borderColor=this.$widget.find("select").css("border-color")),this.$widget.find("select").css("border-color","red"))},leadZero:function(t){return t<=9?"0"+t:t},destroy:function(){this.$widget.remove(),this.$element.removeData("combodate").show()}},i.fn.combodate=function(t){var e,o=Array.apply(null,arguments);return o.shift(),"getValue"===t&&this.length&&(e=this.eq(0).data("combodate"))?e.getValue.apply(e,o):this.each(function(){var e=i(this),r=e.data("combodate"),s="object"==typeof t&&t;r||e.data("combodate",r=new n(this,s)),"string"==typeof t&&"function"==typeof r[t]&&r[t].apply(r,o)})},i.fn.combodate.defaults={format:"DD-MM-YYYY HH:mm",template:"D / MMM / YYYY   H : mm",value:null,minYear:1970,maxYear:(new Date).getFullYear(),yearDescending:!0,minuteStep:5,secondStep:1,firstItem:"empty",errorClass:null,customClass:"",roundTime:!0,smartDays:!1},function(t){"use strict";var e=function(i){this.init("combodate",i,e.defaults),this.options.viewformat||(this.options.viewformat=this.options.format),i.combodate=t.fn.editableutils.tryParseJson(i.combodate,!0),this.options.combodate=t.extend({},e.defaults.combodate,i.combodate,{format:this.options.format,template:this.options.template})};t.fn.editableutils.inherit(e,t.fn.editabletypes.abstractinput),t.extend(e.prototype,{render:function(){this.$input.combodate(this.options.combodate),"bs3"===t.fn.editableform.engine&&this.$input.siblings().find("select").addClass("form-control"),this.options.inputclass&&this.$input.siblings().find("select").addClass(this.options.inputclass)},value2html:function(t,i){var n=t?t.format(this.options.viewformat):"";e.superclass.value2html.call(this,n,i)},html2value:function(t){return t?moment(t,this.options.viewformat):null},value2str:function(t){return t?t.format(this.options.format):""},str2value:function(t){return t?moment(t,this.options.format):null},value2submit:function(t){return this.value2str(t)},value2input:function(t){this.$input.combodate("setValue",t)},input2value:function(){return this.$input.combodate("getValue",null)},activate:function(){this.$input.siblings(".combodate").find("select").eq(0).focus()},autosubmit:function(){}}),e.defaults=t.extend({},t.fn.editabletypes.abstractinput.defaults,{tpl:'<input type="text">',inputclass:null,format:"YYYY-MM-DD",viewformat:null,template:"D / MMM / YYYY",combodate:null}),t.fn.editabletypes.combodate=e}(t),function(t){"use strict";var e=t.fn.editableform.Constructor.prototype.initInput;t.extend(t.fn.editableform.Constructor.prototype,{initTemplate:function(){this.$form=t(t.fn.editableform.template),this.$form.find(".control-group").addClass("form-group"),this.$form.find(".editable-error-block").addClass("help-block")},initInput:function(){e.apply(this);var i=null===this.input.options.inputclass||!1===this.input.options.inputclass,n="text,select,textarea,password,email,url,tel,number,range,time,typeaheadjs".split(",");~t.inArray(this.input.type,n)&&(this.input.$input.addClass("form-control"),i&&(this.input.options.inputclass="form-control-sm",this.input.$input.addClass("form-control-sm")));for(var o=this.$form.find(".editable-buttons"),r=i?["form-control-sm"]:this.input.options.inputclass.split(" "),s=0;s<r.length;s++)"input-lg"===r[s].toLowerCase()&&o.find("button").removeClass("btn-sm").addClass("btn-lg")}}),t.fn.editableform.buttons='<button type="submit" class="btn btn-primary btn-sm editable-submit"><i class="fa fa-check" aria-hidden="true"></i></button><button type="button" class="btn btn-default btn-sm editable-cancel"><i class="fa fa-times" aria-hidden="true"></i></button>',t.fn.editableform.errorGroupClass="has-error",t.fn.editableform.errorBlockClass=null,t.fn.editableform.engine="bs4"}(t),function(t){"use strict";t.extend(t.fn.editableContainer.Popup.prototype,{containerName:"popover",containerDataName:"bs.popover",innerCss:".popover-body",defaults:t.fn.popover.Constructor.DEFAULTS,initContainer:function(){var e;t.extend(this.containerOptions,{trigger:"manual",selector:!1,content:" ",template:this.defaults.template}),this.$element.data("template")&&(e=this.$element.data("template"),this.$element.removeData("template")),this.call(this.containerOptions),e&&this.$element.data("template",e)},innerShow:function(){this.call("show")},innerHide:function(){this.call("hide")},innerDestroy:function(){this.call("dispose")},setContainerOption:function(t,e){this.container().options[t]=e},setPosition:function(){(function(){}).call(this.container())},tip:function(){return this.container()?t(this.container().tip):null}})}(t),function(t){function e(){return new Date(Date.UTC.apply(Date,arguments))}var i=function(e,i){this._process_options(i),this.element=t(e),this.isInline=!1,this.isInput=this.element.is("input"),this.component=!!this.element.is(".date")&&this.element.find(".add-on, .btn"),this.hasInput=this.component&&this.element.find("input").length,this.component&&0===this.component.length&&(this.component=!1),this.picker=t(d.template),this._buildEvents(),this._attachEvents(),this.isInline?this.picker.addClass("datepicker-inline").appendTo(this.element):this.picker.addClass("datepicker-dropdown dropdown-menu"),this.o.rtl&&(this.picker.addClass("datepicker-rtl"),this.picker.find(".prev i, .next i").toggleClass("icon-arrow-left icon-arrow-right")),this.viewMode=this.o.startView,this.o.calendarWeeks&&this.picker.find("tfoot th.today").attr("colspan",function(t,e){return parseInt(e)+1}),this._allow_update=!1,this.setStartDate(this.o.startDate),this.setEndDate(this.o.endDate),this.setDaysOfWeekDisabled(this.o.daysOfWeekDisabled),this.fillDow(),this.fillMonths(),this._allow_update=!0,this.update(),this.showMode(),this.isInline&&this.show()};i.prototype={constructor:i,_process_options:function(e){this._o=t.extend({},this._o,e);var i=this.o=t.extend({},this._o),n=i.language;switch(u[n]||(n=n.split("-")[0],u[n]||(n=l.language)),i.language=n,i.startView){case 2:case"decade":i.startView=2;break;case 1:case"year":i.startView=1;break;default:i.startView=0}switch(i.minViewMode){case 1:case"months":i.minViewMode=1;break;case 2:case"years":i.minViewMode=2;break;default:i.minViewMode=0}i.startView=Math.max(i.startView,i.minViewMode),i.weekStart%=7,i.weekEnd=(i.weekStart+6)%7;var o=d.parseFormat(i.format);i.startDate!==-1/0&&(i.startDate=d.parseDate(i.startDate,o,i.language)),i.endDate!==1/0&&(i.endDate=d.parseDate(i.endDate,o,i.language)),i.daysOfWeekDisabled=i.daysOfWeekDisabled||[],t.isArray(i.daysOfWeekDisabled)||(i.daysOfWeekDisabled=i.daysOfWeekDisabled.split(/[,\s]*/)),i.daysOfWeekDisabled=t.map(i.daysOfWeekDisabled,function(t){return parseInt(t,10)})},_events:[],_secondaryEvents:[],_applyEvents:function(t){for(var e,i,n=0;n<t.length;n++)e=t[n][0],i=t[n][1],e.on(i)},_unapplyEvents:function(t){for(var e,i,n=0;n<t.length;n++)e=t[n][0],i=t[n][1],e.off(i)},_buildEvents:function(){this.isInput?this._events=[[this.element,{focus:t.proxy(this.show,this),keyup:t.proxy(this.update,this),keydown:t.proxy(this.keydown,this)}]]:this.component&&this.hasInput?this._events=[[this.element.find("input"),{focus:t.proxy(this.show,this),keyup:t.proxy(this.update,this),keydown:t.proxy(this.keydown,this)}],[this.component,{click:t.proxy(this.show,this)}]]:this.element.is("div")?this.isInline=!0:this._events=[[this.element,{click:t.proxy(this.show,this)}]],this._secondaryEvents=[[this.picker,{click:t.proxy(this.click,this)}],[t(window),{resize:t.proxy(this.place,this)}],[t(document),{mousedown:t.proxy(function(t){this.element.is(t.target)||this.element.find(t.target).size()||this.picker.is(t.target)||this.picker.find(t.target).size()||this.hide()},this)}]]},_attachEvents:function(){this._detachEvents(),this._applyEvents(this._events)},_detachEvents:function(){this._unapplyEvents(this._events)},_attachSecondaryEvents:function(){this._detachSecondaryEvents(),this._applyEvents(this._secondaryEvents)},_detachSecondaryEvents:function(){this._unapplyEvents(this._secondaryEvents)},_trigger:function(e,i){var n=i||this.date,o=new Date(n.getTime()+6e4*n.getTimezoneOffset());this.element.trigger({type:e,date:o,format:t.proxy(function(t){var e=t||this.o.format;return d.formatDate(n,e,this.o.language)},this)})},show:function(t){this.isInline||this.picker.appendTo("body"),this.picker.show(),this.height=this.component?this.component.outerHeight():this.element.outerHeight(),this.place(),this._attachSecondaryEvents(),t&&t.preventDefault(),this._trigger("show")},hide:function(t){this.isInline||this.picker.is(":visible")&&(this.picker.hide().detach(),this._detachSecondaryEvents(),this.viewMode=this.o.startView,this.showMode(),this.o.forceParse&&(this.isInput&&this.element.val()||this.hasInput&&this.element.find("input").val())&&this.setValue(),this._trigger("hide"))},remove:function(){this.hide(),this._detachEvents(),this._detachSecondaryEvents(),this.picker.remove(),delete this.element.data().datepicker,this.isInput||delete this.element.data().date},getDate:function(){var t=this.getUTCDate();return new Date(t.getTime()+6e4*t.getTimezoneOffset())},getUTCDate:function(){return this.date},setDate:function(t){this.setUTCDate(new Date(t.getTime()-6e4*t.getTimezoneOffset()))},setUTCDate:function(t){this.date=t,this.setValue()},setValue:function(){var t=this.getFormattedDate();this.isInput?this.element.val(t):this.component&&this.element.find("input").val(t)},getFormattedDate:function(t){return void 0===t&&(t=this.o.format),d.formatDate(this.date,t,this.o.language)},setStartDate:function(t){this._process_options({startDate:t}),this.update(),this.updateNavArrows()},setEndDate:function(t){this._process_options({endDate:t}),this.update(),this.updateNavArrows()},setDaysOfWeekDisabled:function(t){this._process_options({daysOfWeekDisabled:t}),this.update(),this.updateNavArrows()},place:function(){if(!this.isInline){var e=parseInt(this.element.parents().filter(function(){return"auto"!=t(this).css("z-index")}).first().css("z-index"))+10,i=this.component?this.component.parent().offset():this.element.offset(),n=this.component?this.component.outerHeight(!0):this.element.outerHeight(!0);this.picker.css({top:i.top+n,left:i.left,zIndex:e})}},_allow_update:!0,update:function(){if(this._allow_update){var t,e=!1;arguments&&arguments.length&&("string"==typeof arguments[0]||arguments[0]instanceof Date)?(t=arguments[0],e=!0):(t=this.isInput?this.element.val():this.element.data("date")||this.element.find("input").val(),delete this.element.data().date),this.date=d.parseDate(t,this.o.format,this.o.language),e&&this.setValue(),this.date<this.o.startDate?this.viewDate=new Date(this.o.startDate):this.date>this.o.endDate?this.viewDate=new Date(this.o.endDate):this.viewDate=new Date(this.date),this.fill()}},fillDow:function(){var t=this.o.weekStart,e="<tr>";if(this.o.calendarWeeks){var i='<th class="cw">&nbsp;</th>';e+=i,this.picker.find(".datepicker-days thead tr:first-child").prepend(i)}for(;t<this.o.weekStart+7;)e+='<th class="dow">'+u[this.o.language].daysMin[t++%7]+"</th>";e+="</tr>",this.picker.find(".datepicker-days thead").append(e)},fillMonths:function(){for(var t="",e=0;e<12;)t+='<span class="month">'+u[this.o.language].monthsShort[e++]+"</span>";this.picker.find(".datepicker-months td").html(t)},setRange:function(e){e&&e.length?this.range=t.map(e,function(t){return t.valueOf()}):delete this.range,this.fill()},getClassNames:function(e){var i=[],n=this.viewDate.getUTCFullYear(),o=this.viewDate.getUTCMonth(),r=this.date.valueOf(),s=new Date;return e.getUTCFullYear()<n||e.getUTCFullYear()==n&&e.getUTCMonth()<o?i.push("old"):(e.getUTCFullYear()>n||e.getUTCFullYear()==n&&e.getUTCMonth()>o)&&i.push("new"),this.o.todayHighlight&&e.getUTCFullYear()==s.getFullYear()&&e.getUTCMonth()==s.getMonth()&&e.getUTCDate()==s.getDate()&&i.push("today"),r&&e.valueOf()==r&&i.push("active"),(e.valueOf()<this.o.startDate||e.valueOf()>this.o.endDate||-1!==t.inArray(e.getUTCDay(),this.o.daysOfWeekDisabled))&&i.push("disabled"),this.range&&(e>this.range[0]&&e<this.range[this.range.length-1]&&i.push("range"),-1!=t.inArray(e.valueOf(),this.range)&&i.push("selected")),i},fill:function(){var i,n=new Date(this.viewDate),o=n.getUTCFullYear(),r=n.getUTCMonth(),s=this.o.startDate!==-1/0?this.o.startDate.getUTCFullYear():-1/0,a=this.o.startDate!==-1/0?this.o.startDate.getUTCMonth():-1/0,l=this.o.endDate!==1/0?this.o.endDate.getUTCFullYear():1/0,c=this.o.endDate!==1/0?this.o.endDate.getUTCMonth():1/0;this.date&&this.date.valueOf();this.picker.find(".datepicker-days thead th.datepicker-switch").text(u[this.o.language].months[r]+" "+o),this.picker.find("tfoot th.today").text(u[this.o.language].today).toggle(!1!==this.o.todayBtn),this.picker.find("tfoot th.clear").text(u[this.o.language].clear).toggle(!1!==this.o.clearBtn),this.updateNavArrows(),this.fillMonths();var h=e(o,r-1,28,0,0,0,0),p=d.getDaysInMonth(h.getUTCFullYear(),h.getUTCMonth());h.setUTCDate(p),h.setUTCDate(p-(h.getUTCDay()-this.o.weekStart+7)%7);var f=new Date(h);f.setUTCDate(f.getUTCDate()+42),f=f.valueOf();for(var m,g=[];h.valueOf()<f;){if(h.getUTCDay()==this.o.weekStart&&(g.push("<tr>"),this.o.calendarWeeks)){var v=new Date(+h+(this.o.weekStart-h.getUTCDay()-7)%7*864e5),y=new Date(+v+(11-v.getUTCDay())%7*864e5),b=new Date(+(b=e(y.getUTCFullYear(),0,1))+(11-b.getUTCDay())%7*864e5),w=(y-b)/864e5/7+1;g.push('<td class="cw">'+w+"</td>")}(m=this.getClassNames(h)).push("day");var T=this.o.beforeShowDay(h);void 0===T?T={}:"boolean"==typeof T?T={enabled:T}:"string"==typeof T&&(T={classes:T}),!1===T.enabled&&m.push("disabled"),T.classes&&(m=m.concat(T.classes.split(/\s+/))),T.tooltip&&(i=T.tooltip),m=t.unique(m),g.push('<td class="'+m.join(" ")+'"'+(i?' title="'+i+'"':"")+">"+h.getUTCDate()+"</td>"),h.getUTCDay()==this.o.weekEnd&&g.push("</tr>"),h.setUTCDate(h.getUTCDate()+1)}this.picker.find(".datepicker-days tbody").empty().append(g.join(""));var x=this.date&&this.date.getUTCFullYear(),_=this.picker.find(".datepicker-months").find("th:eq(1)").text(o).end().find("span").removeClass("active");x&&x==o&&_.eq(this.date.getUTCMonth()).addClass("active"),(o<s||o>l)&&_.addClass("disabled"),o==s&&_.slice(0,a).addClass("disabled"),o==l&&_.slice(c+1).addClass("disabled"),g="",o=10*parseInt(o/10,10);var C=this.picker.find(".datepicker-years").find("th:eq(1)").text(o+"-"+(o+9)).end().find("td");o-=1;for(var E=-1;E<11;E++)g+='<span class="year'+(-1==E?" old":10==E?" new":"")+(x==o?" active":"")+(o<s||o>l?" disabled":"")+'">'+o+"</span>",o+=1;C.html(g)},updateNavArrows:function(){if(this._allow_update){var t=new Date(this.viewDate),e=t.getUTCFullYear(),i=t.getUTCMonth();switch(this.viewMode){case 0:this.o.startDate!==-1/0&&e<=this.o.startDate.getUTCFullYear()&&i<=this.o.startDate.getUTCMonth()?this.picker.find(".prev").css({visibility:"hidden"}):this.picker.find(".prev").css({visibility:"visible"}),this.o.endDate!==1/0&&e>=this.o.endDate.getUTCFullYear()&&i>=this.o.endDate.getUTCMonth()?this.picker.find(".next").css({visibility:"hidden"}):this.picker.find(".next").css({visibility:"visible"});break;case 1:case 2:this.o.startDate!==-1/0&&e<=this.o.startDate.getUTCFullYear()?this.picker.find(".prev").css({visibility:"hidden"}):this.picker.find(".prev").css({visibility:"visible"}),this.o.endDate!==1/0&&e>=this.o.endDate.getUTCFullYear()?this.picker.find(".next").css({visibility:"hidden"}):this.picker.find(".next").css({visibility:"visible"})}}},click:function(i){i.preventDefault();var n=t(i.target).closest("span, td, th");if(1==n.length)switch(n[0].nodeName.toLowerCase()){case"th":switch(n[0].className){case"datepicker-switch":this.showMode(1);break;case"prev":case"next":var o=d.modes[this.viewMode].navStep*("prev"==n[0].className?-1:1);switch(this.viewMode){case 0:this.viewDate=this.moveMonth(this.viewDate,o);break;case 1:case 2:this.viewDate=this.moveYear(this.viewDate,o)}this.fill();break;case"today":var r=new Date;r=e(r.getFullYear(),r.getMonth(),r.getDate(),0,0,0),this.showMode(-2);var s="linked"==this.o.todayBtn?null:"view";this._setDate(r,s);break;case"clear":var a;this.isInput?a=this.element:this.component&&(a=this.element.find("input")),a&&a.val("").change(),this._trigger("changeDate"),this.update(),this.o.autoclose&&this.hide()}break;case"span":if(!n.is(".disabled")){if(this.viewDate.setUTCDate(1),n.is(".month")){var l=1,c=n.parent().find("span").index(n),u=this.viewDate.getUTCFullYear();this.viewDate.setUTCMonth(c),this._trigger("changeMonth",this.viewDate),1===this.o.minViewMode&&this._setDate(e(u,c,l,0,0,0,0))}else{u=parseInt(n.text(),10)||0,l=1,c=0;this.viewDate.setUTCFullYear(u),this._trigger("changeYear",this.viewDate),2===this.o.minViewMode&&this._setDate(e(u,c,l,0,0,0,0))}this.showMode(-1),this.fill()}break;case"td":if(n.is(".day")&&!n.is(".disabled")){l=parseInt(n.text(),10)||1,u=this.viewDate.getUTCFullYear(),c=this.viewDate.getUTCMonth();n.is(".old")?0===c?(c=11,u-=1):c-=1:n.is(".new")&&(11==c?(c=0,u+=1):c+=1),this._setDate(e(u,c,l,0,0,0,0))}}},_setDate:function(t,e){var i;e&&"date"!=e||(this.date=new Date(t)),e&&"view"!=e||(this.viewDate=new Date(t)),this.fill(),this.setValue(),this._trigger("changeDate"),this.isInput?i=this.element:this.component&&(i=this.element.find("input")),i&&(i.change(),!this.o.autoclose||e&&"date"!=e||this.hide())},moveMonth:function(t,e){if(!e)return t;var i,n,o=new Date(t.valueOf()),r=o.getUTCDate(),s=o.getUTCMonth(),a=Math.abs(e);if(e=e>0?1:-1,1==a)n=-1==e?function(){return o.getUTCMonth()==s}:function(){return o.getUTCMonth()!=i},i=s+e,o.setUTCMonth(i),(i<0||i>11)&&(i=(i+12)%12);else{for(var l=0;l<a;l++)o=this.moveMonth(o,e);i=o.getUTCMonth(),o.setUTCDate(r),n=function(){return i!=o.getUTCMonth()}}for(;n();)o.setUTCDate(--r),o.setUTCMonth(i);return o},moveYear:function(t,e){return this.moveMonth(t,12*e)},dateWithinRange:function(t){return t>=this.o.startDate&&t<=this.o.endDate},keydown:function(t){if(this.picker.is(":not(:visible)"))27==t.keyCode&&this.show();else{var e,i,n,o,r=!1;switch(t.keyCode){case 27:this.hide(),t.preventDefault();break;case 37:case 39:if(!this.o.keyboardNavigation)break;e=37==t.keyCode?-1:1,t.ctrlKey?(i=this.moveYear(this.date,e),n=this.moveYear(this.viewDate,e)):t.shiftKey?(i=this.moveMonth(this.date,e),n=this.moveMonth(this.viewDate,e)):((i=new Date(this.date)).setUTCDate(this.date.getUTCDate()+e),(n=new Date(this.viewDate)).setUTCDate(this.viewDate.getUTCDate()+e)),this.dateWithinRange(i)&&(this.date=i,this.viewDate=n,this.setValue(),this.update(),t.preventDefault(),r=!0);break;case 38:case 40:if(!this.o.keyboardNavigation)break;e=38==t.keyCode?-1:1,t.ctrlKey?(i=this.moveYear(this.date,e),n=this.moveYear(this.viewDate,e)):t.shiftKey?(i=this.moveMonth(this.date,e),n=this.moveMonth(this.viewDate,e)):((i=new Date(this.date)).setUTCDate(this.date.getUTCDate()+7*e),(n=new Date(this.viewDate)).setUTCDate(this.viewDate.getUTCDate()+7*e)),this.dateWithinRange(i)&&(this.date=i,this.viewDate=n,this.setValue(),this.update(),t.preventDefault(),r=!0);break;case 13:this.hide(),t.preventDefault();break;case 9:this.hide()}if(r)this._trigger("changeDate"),this.isInput?o=this.element:this.component&&(o=this.element.find("input")),o&&o.change()}},showMode:function(t){t&&(this.viewMode=Math.max(this.o.minViewMode,Math.min(2,this.viewMode+t))),this.picker.find(">div").hide().filter(".datepicker-"+d.modes[this.viewMode].clsName).css("display","block"),this.updateNavArrows()}};var n=function(e,i){this.element=t(e),this.inputs=t.map(i.inputs,function(t){return t.jquery?t[0]:t}),delete i.inputs,t(this.inputs).datepicker(i).bind("changeDate",t.proxy(this.dateUpdated,this)),this.pickers=t.map(this.inputs,function(e){return t(e).data("datepicker")}),this.updateDates()};function o(e,i){var n=t(e).data(),o={},r=new RegExp("^"+i.toLowerCase()+"([A-Z])");i=new RegExp("^"+i.toLowerCase());for(var s in n)i.test(s)&&(o[s.replace(r,function(t,e){return e.toLowerCase()})]=n[s]);return o}function r(e){var i={};if(u[e]||(e=e.split("-")[0],u[e])){var n=u[e];return t.each(c,function(t,e){e in n&&(i[e]=n[e])}),i}}n.prototype={updateDates:function(){this.dates=t.map(this.pickers,function(t){return t.date}),this.updateRanges()},updateRanges:function(){var e=t.map(this.dates,function(t){return t.valueOf()});t.each(this.pickers,function(t,i){i.setRange(e)})},dateUpdated:function(e){var i=t(e.target).data("datepicker").getUTCDate(),n=t.inArray(e.target,this.inputs),o=this.inputs.length;if(-1!=n){if(i<this.dates[n])for(;n>=0&&i<this.dates[n];)this.pickers[n--].setUTCDate(i);else if(i>this.dates[n])for(;n<o&&i>this.dates[n];)this.pickers[n++].setUTCDate(i);this.updateDates()}},remove:function(){t.map(this.pickers,function(t){t.remove()}),delete this.element.data().datepicker}};var s=t.fn.datepicker,a=t.fn.datepicker=function(e){var s,a=Array.apply(null,arguments);return a.shift(),this.each(function(){var c=t(this),u=c.data("datepicker"),d="object"==typeof e&&e;if(!u){var h=o(this,"date"),p=r(t.extend({},l,h,d).language),f=t.extend({},l,p,h,d);if(c.is(".input-daterange")||f.inputs){var m={inputs:f.inputs||c.find("input").toArray()};c.data("datepicker",u=new n(this,t.extend(f,m)))}else c.data("datepicker",u=new i(this,f))}if("string"==typeof e&&"function"==typeof u[e]&&void 0!==(s=u[e].apply(u,a)))return!1}),void 0!==s?s:this},l=t.fn.datepicker.defaults={autoclose:!1,beforeShowDay:t.noop,calendarWeeks:!1,clearBtn:!1,daysOfWeekDisabled:[],endDate:1/0,forceParse:!0,format:"mm/dd/yyyy",keyboardNavigation:!0,language:"en",minViewMode:0,rtl:!1,startDate:-1/0,startView:0,todayBtn:!1,todayHighlight:!1,weekStart:0},c=t.fn.datepicker.locale_opts=["format","rtl","weekStart"];t.fn.datepicker.Constructor=i;var u=t.fn.datepicker.dates={en:{days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sunday"],daysShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat","Sun"],daysMin:["Su","Mo","Tu","We","Th","Fr","Sa","Su"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],monthsShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],today:"Today",clear:"Clear"}},d={modes:[{clsName:"days",navFnc:"Month",navStep:1},{clsName:"months",navFnc:"FullYear",navStep:1},{clsName:"years",navFnc:"FullYear",navStep:10}],isLeapYear:function(t){return t%4==0&&t%100!=0||t%400==0},getDaysInMonth:function(t,e){return[31,d.isLeapYear(t)?29:28,31,30,31,30,31,31,30,31,30,31][e]},validParts:/dd?|DD?|mm?|MM?|yy(?:yy)?/g,nonpunctuation:/[^ -\/:-@\[\u3400-\u9fff-`{-~\t\n\r]+/g,parseFormat:function(t){var e=t.replace(this.validParts,"\0").split("\0"),i=t.match(this.validParts);if(!e||!e.length||!i||0===i.length)throw new Error("Invalid date format.");return{separators:e,parts:i}},parseDate:function(n,o,r){if(n instanceof Date)return n;if("string"==typeof o&&(o=d.parseFormat(o)),/^[\-+]\d+[dmwy]([\s,]+[\-+]\d+[dmwy])*$/.test(n)){var s,a=/([\-+]\d+)([dmwy])/,l=n.match(/([\-+]\d+)([dmwy])/g);n=new Date;for(var c=0;c<l.length;c++)switch(f=a.exec(l[c]),s=parseInt(f[1]),f[2]){case"d":n.setUTCDate(n.getUTCDate()+s);break;case"m":n=i.prototype.moveMonth.call(i.prototype,n,s);break;case"w":n.setUTCDate(n.getUTCDate()+7*s);break;case"y":n=i.prototype.moveYear.call(i.prototype,n,s)}return e(n.getUTCFullYear(),n.getUTCMonth(),n.getUTCDate(),0,0,0)}l=n&&n.match(this.nonpunctuation)||[],n=new Date;var h,p,f,m={},g=["yyyy","yy","M","MM","m","mm","d","dd"],v={yyyy:function(t,e){return t.setUTCFullYear(e)},yy:function(t,e){return t.setUTCFullYear(2e3+e)},m:function(t,e){for(e-=1;e<0;)e+=12;for(e%=12,t.setUTCMonth(e);t.getUTCMonth()!=e;)t.setUTCDate(t.getUTCDate()-1);return t},d:function(t,e){return t.setUTCDate(e)}};v.M=v.MM=v.mm=v.m,v.dd=v.d,n=e(n.getFullYear(),n.getMonth(),n.getDate(),0,0,0);var y=o.parts.slice();if(l.length!=y.length&&(y=t(y).filter(function(e,i){return-1!==t.inArray(i,g)}).toArray()),l.length==y.length){c=0;for(var b=y.length;c<b;c++){if(h=parseInt(l[c],10),f=y[c],isNaN(h))switch(f){case"MM":p=t(u[r].months).filter(function(){var t=this.slice(0,l[c].length);return t==l[c].slice(0,t.length)}),h=t.inArray(p[0],u[r].months)+1;break;case"M":p=t(u[r].monthsShort).filter(function(){var t=this.slice(0,l[c].length);return t==l[c].slice(0,t.length)}),h=t.inArray(p[0],u[r].monthsShort)+1}m[f]=h}var w;for(c=0;c<g.length;c++)(w=g[c])in m&&!isNaN(m[w])&&v[w](n,m[w])}return n},formatDate:function(e,i,n){"string"==typeof i&&(i=d.parseFormat(i));var o={d:e.getUTCDate(),D:u[n].daysShort[e.getUTCDay()],DD:u[n].days[e.getUTCDay()],m:e.getUTCMonth()+1,M:u[n].monthsShort[e.getUTCMonth()],MM:u[n].months[e.getUTCMonth()],yy:e.getUTCFullYear().toString().substring(2),yyyy:e.getUTCFullYear()};o.dd=(o.d<10?"0":"")+o.d,o.mm=(o.m<10?"0":"")+o.m;e=[];for(var r=t.extend([],i.separators),s=0,a=i.parts.length;s<=a;s++)r.length&&e.push(r.shift()),e.push(o[i.parts[s]]);return e.join("")},headTemplate:'<thead><tr><th class="prev"><i class="icon-arrow-left"/></th><th colspan="5" class="datepicker-switch"></th><th class="next"><i class="icon-arrow-right"/></th></tr></thead>',contTemplate:'<tbody><tr><td colspan="7"></td></tr></tbody>',footTemplate:'<tfoot><tr><th colspan="7" class="today"></th></tr><tr><th colspan="7" class="clear"></th></tr></tfoot>'};d.template='<div class="datepicker"><div class="datepicker-days"><table class=" table-condensed">'+d.headTemplate+"<tbody></tbody>"+d.footTemplate+'</table></div><div class="datepicker-months"><table class="table-condensed">'+d.headTemplate+d.contTemplate+d.footTemplate+'</table></div><div class="datepicker-years"><table class="table-condensed">'+d.headTemplate+d.contTemplate+d.footTemplate+"</table></div></div>",t.fn.datepicker.DPGlobal=d,t.fn.datepicker.noConflict=function(){return t.fn.datepicker=s,this},t(document).on("focus.datepicker.data-api click.datepicker.data-api",'[data-provide="datepicker"]',function(e){var i=t(this);i.data("datepicker")||(e.preventDefault(),a.call(i,"show"))}),t(function(){a.call(t('[data-provide="datepicker-inline"]'))})}(t),function(t){"use strict";t.fn.bdatepicker=t.fn.datepicker.noConflict(),t.fn.datepicker||(t.fn.datepicker=t.fn.bdatepicker);var e=function(t){this.init("date",t,e.defaults),this.initPicker(t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.abstractinput),t.extend(e.prototype,{initPicker:function(e,i){this.options.viewformat||(this.options.viewformat=this.options.format),e.datepicker=t.fn.editableutils.tryParseJson(e.datepicker,!0),this.options.datepicker=t.extend({},i.datepicker,e.datepicker,{format:this.options.viewformat}),this.options.datepicker.language=this.options.datepicker.language||"en",this.dpg=t.fn.bdatepicker.DPGlobal,this.parsedFormat=this.dpg.parseFormat(this.options.format),this.parsedViewFormat=this.dpg.parseFormat(this.options.viewformat)},render:function(){this.$input.bdatepicker(this.options.datepicker),this.options.clear&&(this.$clear=t('<a href="#"></a>').html(this.options.clear).click(t.proxy(function(t){t.preventDefault(),t.stopPropagation(),this.clear()},this)),this.$tpl.parent().append(t('<div class="editable-clear">').append(this.$clear)))},value2html:function(t,i){var n=t?this.dpg.formatDate(t,this.parsedViewFormat,this.options.datepicker.language):"";e.superclass.value2html.call(this,n,i)},html2value:function(t){return this.parseDate(t,this.parsedViewFormat)},value2str:function(t){return t?this.dpg.formatDate(t,this.parsedFormat,this.options.datepicker.language):""},str2value:function(t){return this.parseDate(t,this.parsedFormat)},value2submit:function(t){return this.value2str(t)},value2input:function(t){this.$input.bdatepicker("update",t)},input2value:function(){return this.$input.data("datepicker").date},activate:function(){},clear:function(){this.$input.data("datepicker").date=null,this.$input.find(".active").removeClass("active"),this.options.showbuttons||this.$input.closest("form").submit()},autosubmit:function(){this.$input.on("mouseup",".day",function(e){if(!t(e.currentTarget).is(".old")&&!t(e.currentTarget).is(".new")){var i=t(this).closest("form");setTimeout(function(){i.submit()},200)}})},parseDate:function(t,e){var i=null;return t&&(i=this.dpg.parseDate(t,e,this.options.datepicker.language),"string"==typeof t&&t!==this.dpg.formatDate(i,e,this.options.datepicker.language)&&(i=null)),i}}),e.defaults=t.extend({},t.fn.editabletypes.abstractinput.defaults,{tpl:'<div class="editable-date well"></div>',inputclass:null,format:"yyyy-mm-dd",viewformat:null,datepicker:{weekStart:0,startView:0,minViewMode:0,autoclose:!1},clear:"&times; clear"}),t.fn.editabletypes.date=e}(t),function(t){"use strict";var e=function(t){this.init("datefield",t,e.defaults),this.initPicker(t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.date),t.extend(e.prototype,{render:function(){this.$input=this.$tpl.find("input"),this.setClass(),this.setAttr("placeholder"),this.$input.bdatepicker(this.options.datepicker),this.$input.off("focus keydown"),this.$input.keyup(t.proxy(function(){this.$tpl.removeData("date"),this.$tpl.bdatepicker("update")},this))},value2input:function(t){this.$input.val(t?this.dpg.formatDate(t,this.parsedViewFormat,this.options.datepicker.language):""),this.$tpl.bdatepicker("update")},input2value:function(){return this.html2value(this.$input.val())},activate:function(){t.fn.editabletypes.text.prototype.activate.call(this)},autosubmit:function(){}}),e.defaults=t.extend({},t.fn.editabletypes.date.defaults,{tpl:'<div class="input-append date"><input type="text"/><span class="add-on"><i class="icon-th"></i></span></div>',inputclass:"input-small",datepicker:{weekStart:0,startView:0,minViewMode:0,autoclose:!0}}),t.fn.editabletypes.datefield=e}(t),function(t){"use strict";var e=function(t){this.init("datetime",t,e.defaults),this.initPicker(t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.abstractinput),t.extend(e.prototype,{initPicker:function(e,i){this.options.viewformat||(this.options.viewformat=this.options.format),e.datetimepicker=t.fn.editableutils.tryParseJson(e.datetimepicker,!0),this.options.datetimepicker=t.extend({},i.datetimepicker,e.datetimepicker,{format:this.options.viewformat}),this.options.datetimepicker.language=this.options.datetimepicker.language||"en",this.dpg=t.fn.datetimepicker.DPGlobal,this.parsedFormat=this.dpg.parseFormat(this.options.format,this.options.formatType),this.parsedViewFormat=this.dpg.parseFormat(this.options.viewformat,this.options.formatType)},render:function(){this.$input.datetimepicker(this.options.datetimepicker),this.$input.on("changeMode",function(e){var i=t(this).closest("form").parent();setTimeout(function(){i.triggerHandler("resize")},0)}),this.options.clear&&(this.$clear=t('<a href="#"></a>').html(this.options.clear).click(t.proxy(function(t){t.preventDefault(),t.stopPropagation(),this.clear()},this)),this.$tpl.parent().append(t('<div class="editable-clear">').append(this.$clear)))},value2html:function(t,i){var n=t?this.dpg.formatDate(this.toUTC(t),this.parsedViewFormat,this.options.datetimepicker.language,this.options.formatType):"";if(!i)return n;e.superclass.value2html.call(this,n,i)},html2value:function(t){var e=this.parseDate(t,this.parsedViewFormat);return e?this.fromUTC(e):null},value2str:function(t){return t?this.dpg.formatDate(this.toUTC(t),this.parsedFormat,this.options.datetimepicker.language,this.options.formatType):""},str2value:function(t){var e=this.parseDate(t,this.parsedFormat);return e?this.fromUTC(e):null},value2submit:function(t){return this.value2str(t)},value2input:function(t){t&&this.$input.data("datetimepicker").setDate(t)},input2value:function(){var t=this.$input.data("datetimepicker");return t.date?t.getDate():null},activate:function(){},clear:function(){this.$input.data("datetimepicker").date=null,this.$input.find(".active").removeClass("active"),this.options.showbuttons||this.$input.closest("form").submit()},autosubmit:function(){this.$input.on("mouseup",".minute",function(e){var i=t(this).closest("form");setTimeout(function(){i.submit()},200)})},toUTC:function(t){return t?new Date(t.valueOf()-6e4*t.getTimezoneOffset()):t},fromUTC:function(t){return t?new Date(t.valueOf()+6e4*t.getTimezoneOffset()):t},parseDate:function(t,e){var i=null;return t&&(i=this.dpg.parseDate(t,e,this.options.datetimepicker.language,this.options.formatType),"string"==typeof t&&t!==this.dpg.formatDate(i,e,this.options.datetimepicker.language,this.options.formatType)&&(i=null)),i}}),e.defaults=t.extend({},t.fn.editabletypes.abstractinput.defaults,{tpl:'<div class="editable-date well"></div>',inputclass:null,format:"yyyy-mm-dd hh:ii",formatType:"standard",viewformat:null,datetimepicker:{todayHighlight:!1,autoclose:!1},clear:"&times; clear"}),t.fn.editabletypes.datetime=e}(t),function(t){"use strict";var e=function(t){this.init("datetimefield",t,e.defaults),this.initPicker(t,e.defaults)};t.fn.editableutils.inherit(e,t.fn.editabletypes.datetime),t.extend(e.prototype,{render:function(){this.$input=this.$tpl.find("input"),this.setClass(),this.setAttr("placeholder"),this.$tpl.datetimepicker(this.options.datetimepicker),this.$input.off("focus keydown"),this.$input.keyup(t.proxy(function(){this.$tpl.removeData("date"),this.$tpl.datetimepicker("update")},this))},value2input:function(t){this.$input.val(this.value2html(t)),this.$tpl.datetimepicker("update")},input2value:function(){return this.html2value(this.$input.val())},activate:function(){t.fn.editabletypes.text.prototype.activate.call(this)},autosubmit:function(){}}),e.defaults=t.extend({},t.fn.editabletypes.datetime.defaults,{tpl:'<div class="input-append date"><input type="text"/><span class="add-on"><i class="icon-th"></i></span></div>',inputclass:"input-medium",datetimepicker:{todayHighlight:!1,autoclose:!0}}),t.fn.editabletypes.datetimefield=e}(t)}).call(this,i(1),i(1))}});